/**
 * @license
 * Copyright 2019 The Emscripten Authors
 * SPDX-License-Identifier: MIT
 */

// wasm2js.js - enough of a polyfill for the WebAssembly object so that we can load
// wasm2js code that way.

// Emit "var WebAssembly" if definitely using wasm2js. Otherwise, in MAYBE_WASM2JS
// mode, we can't use a "var" since it would prevent normal wasm from working.
/** @suppress{duplicate, const} */
var
WebAssembly = {
  // Note that we do not use closure quoting (this['buffer'], etc.) on these
  // functions, as they are just meant for internal use. In other words, this is
  // not a fully general polyfill.
  /** @constructor */
  Memory: function(opts) {
    this.buffer = new ArrayBuffer(opts['initial'] * 65536);
  },

  Module: function(binary) {
    // TODO: use the binary and info somehow - right now the wasm2js output is embedded in
    // the main JS
  },

  /** @constructor */
  Instance: function(module, info) {
    // TODO: use the module and info somehow - right now the wasm2js output is embedded in
    // the main JS
    // This will be replaced by the actual wasm2js code.
    this.exports = (
// EMSCRIPTEN_START_ASM
function instantiate(xb){function c(d){d.set=function(a,b){this[a]=b};d.get=function(a){return this[a]};return d}var e;var f=new ArrayBuffer(16);var g=new Int32Array(f);var h=new Float32Array(f);var i=new Float64Array(f);function j(k){return g[k]}function l(k,m){g[k]=m}function n(){return i[0]}function o(m){i[0]=m}function p(m){h[2]=m}function q(){return h[2]}function vb(wb){var r=wb.a;var s=r.buffer;r.grow=tb;var t=new Int8Array(s);var u=new Int16Array(s);var v=new Int32Array(s);var w=new Uint8Array(s);var x=new Uint16Array(s);var y=new Uint32Array(s);var z=new Float32Array(s);var A=new Float64Array(s);var B=Math.imul;var C=Math.fround;var D=Math.abs;var E=Math.clz32;var F=Math.min;var G=Math.max;var H=Math.floor;var I=Math.ceil;var J=Math.trunc;var K=Math.sqrt;var L=wb.abort;var M=NaN;var N=Infinity;var O=wb.b;var P=wb.c;var Q=wb.d;var R=wb.e;var S=wb.f;var T=wb.g;var U=wb.h;var V=wb.i;var W=wb.j;var X=wb.k;var Y=wb.l;var Z=wb.m;var _=wb.n;var $=wb.o;var aa=wb.p;var ba=wb.q;var ca=wb.r;var da=wb.s;var ea=wb.t;var fa=wb.u;var ga=wb.v;var ha=wb.w;var ia=wb.x;var ja=wb.y;var ka=wb.z;var la=wb.A;var ma=wb.B;var na=wb.C;var oa=wb.D;var pa=wb.E;var qa=wb.F;var ra=wb.G;var sa=wb.H;var ta=wb.I;var ua=wb.J;var va=wb.K;var wa=wb.L;var xa=wb.M;var ya=wb.N;var za=wb.O;var Aa=wb.P;var Ba=wb.Q;var Ca=wb.R;var Da=wb.S;var Ea=wb.T;var Fa=wb.U;var Ga=wb.V;var Ha=wb.W;var Ia=wb.X;var Ja=wb.Y;var Ka=wb.Z;var La=wb._;var Ma=wb.$;var Na=wb.aa;var Oa=wb.ba;var Pa=wb.ca;var Qa=wb.da;var Ra=wb.ea;var Sa=wb.fa;var Ta=wb.ga;var Ua=wb.ha;var Va=wb.ia;var Wa=wb.ja;var Xa=wb.ka;var Ya=wb.la;var Za=wb.ma;var _a=wb.na;var $a=wb.oa;var ab=wb.pa;var bb=wb.qa;var cb=wb.ra;var db=wb.sa;var eb=wb.ta;var fb=wb.ua;var gb=wb.va;var hb=wb.wa;var ib=wb.xa;var jb=5711840;var kb=0;var lb=0;var mb=0;
// EMSCRIPTEN_START_FUNCS
function hJ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,V=C(0),W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ba=C(0),Ca=0,Da=0,Ea=0,Fa=0,Ga=0,Ha=0,Ia=0,Ja=0,Ka=0,La=0,Ma=0,Na=0,Oa=0,Pa=0,Qa=0,Ra=0,Sa=0,Ta=0,Ua=0,Va=0,Wa=0,Xa=0,Ya=C(0),Za=0;ca=jb-32|0;jb=ca;ea=ca+24|0;v[ea>>2]=49484;v[ea>>2]=49384;d=gJ(ca+16|0);g=gJ(ca+8|0);fa=b;ma=c;na=v[d>>2];Da=w[d+4|0];oa=v[g>>2];Ea=w[g+4|0];c=0;T=jb-112|0;jb=T;e=a;pa=a+24604|0;a=pa;a:{if(!v[a+16>>2]){break a}b=v[a+20>>2];if(b>>>0>4|!(1<<b&22)){break a}a=v[a+28>>2];if(a>>>0>4){break a}c=23>>>a&1}if(!c){a=T+96|0;tM(a,9035,12860,220,45);b=jb-48|0;jb=b;c=Vb(b+16|0,17572);v[23296]=0;U(5,b|0,1,17235);d=v[23296];v[23296]=0;b:{c:{d:{e:{if((d|0)!=1){v[23296]=0;U(2,b+32|0,c|0,b|0);d=v[23296];v[23296]=0;if((d|0)==1){break e}v[23296]=0;U(796,a|0,1,b+32|0);a=v[23296];v[23296]=0;if((a|0)!=1){break b}a=P()|0;O()|0;zb(b+32|0);break d}a=P()|0;O()|0;break c}a=P()|0;O()|0}zb(b)}zb(c);S(a|0);L()}zb(b+32|0);zb(b);zb(c);jb=b+48|0}qa=e+8204|0;ra=e+397452|0;sa=e+397448|0;aa=e+393352|0;G=e+397456|0;$=e+12|0;Fa=e+1074376|0;Ga=e+1298420|0;Ha=e+1074365|0;while(1){f:{g:{a=v[e+480208>>2];if(!(!fa|a&512)){h:{if(v[e+1074380>>2]){break h}b=a|512;i:{if(a&256){break i}r=0;k=jb-48|0;jb=k;F=jb-32|0;jb=F;l=e+1074312|0;c=e+1074992|0;j=e+1298264|0;m=e+1074424|0;s=e+484360|0;n=e+1074448|0;i=e+1074376|0;b=v[e+1074392>>2];A=e+480188|0;H=e+480180|0;p=e+484376|0;q=e+484348|0;E=e+480210|0;I=e+484364|0;j:{k:{l:while(1){m:{a=b+1|0;v[e+1074392>>2]=a;if(Rk(i)>>>0>a>>>0){break m}IN(F+24|0,v[H>>2],x[A>>1],i,(v[e+480208>>2]&524288)>>>19|0);n:{o:{p:{q:{r:{if(w[e+480208|0]&32){h=v[q>>2];g=v[e+484344>>2];b=x[e+1074446>>1];break r}b=65535;o=v[e+484360>>2];J=w[p|0];a=Zb(o,J);d=v[a>>2];a=Nc(d,v[a+4>>2]);f=x[e+1074448>>1];if(a>>>0>f>>>0){b=x[dc(d,f)>>1]}u[e+1074446>>1]=b;s:{t:{g=v[e+484344>>2];h=v[q>>2];a=b&65535;if(pf(g,h)>>>0<=a>>>0){break t}a=$b(g,a);if(Rb(v[a>>2],v[a+4>>2])){break t}a=0;break s}a=1}while(1){u:{v:{if(!a){b=65534;u[e+1074446>>1]=65534;break v}w:{x:{y:{a=b&65535;if(pf(g,h)>>>0<=a>>>0){z:{A:{if((a|0)==65535){d=Zb(o,J);break A}d=Zb(o,J);if(Nc(v[d>>2],v[d+4>>2])>>>0>(f&65535)>>>0){break z}}b=x[d+28>>1];if(b){g=v[d>>2];h=Nc(g,v[d+4>>2]);break x}a=f&65535;g=v[d>>2];h=Nc(g,v[d+4>>2]);if(!a|h>>>0<a>>>0){break y}while(1){b=a;a=a-1|0;if(!a){break y}if(x[dc(g,a)>>1]!=65535){continue}break}break x}f=f+1|0;u[n>>1]=f;break w}u[e+1074450>>1]=f;break r}b=0}u[e+1074448>>1]=b;v[e+480208>>2]=v[e+480208>>2]&-524289;while(1){a=b&65535;if(a>>>0>=h>>>0){break q}if(x[dc(g,a)>>1]==65534){b=b+1|0;u[n>>1]=b;continue}break}if(!rq(d,a)){break q}f=x[e+1074448>>1];o=v[e+484360>>2];J=w[p|0];d=Zb(o,J)}b=65535;a=f&65535;if(Nc(v[d>>2],v[d+4>>2])>>>0>a>>>0){b=x[dc(v[Zb(o,J)>>2],a)>>1]}u[e+1074446>>1]=b;g=v[e+484344>>2];h=v[q>>2];a=b&65535;if(pf(g,h)>>>0<=a>>>0){break v}a=$b(g,a);if(!Rb(v[a>>2],v[a+4>>2])){break u}}a=1;continue}a=0;continue}}a=b&65535;if(!oe(g,h,a)){break k}b=v[m>>2];if(b>>>0>=y[$b(g,a)+12>>2]){v[m>>2]=0;b=0}if(v[e+480208>>2]&32?v[e+480272>>2]!=-1:0){break n}if(!gt(j,x[n>>1],b,Ep(F+16|0,c),w[F+24|0])){break n}a=v[e+480272>>2];if(a){if((a|0)>0){v[e+480272>>2]=a-1}Xn(j,1);gt(j,x[n>>1],v[m>>2],Ep(F+16|0,c),w[F+24|0]);break n}if(!(w[E|0]&64)){break q}b=0;if(WN(j,n,m)){break o}v[e+1074424>>2]=0;v[e+1074428>>2]=0;v[e+1074448>>2]=0;d=kj(v[e+484360>>2],v[I>>2])-1|0;a=w[p|0];if((d|0)>(a|0)){break p}Ai(s,0)}Xn(j,1);break k}Ai(s,a+1&255);Xn(j,1)}while(1){if((b|0)==256){iM(e);v[e+1074416>>2]=v[e+480196>>2];v[e+1074420>>2]=v[e+480204>>2];v[e+1074456>>2]=v[e+480200>>2];a=x[e+1074448>>1];u[e+1074450>>1]=a;b=v[e+1074424>>2];v[e+1074428>>2]=b;d=Zb(v[e+484360>>2],w[p|0]);g=v[d>>2];if(Nc(g,v[d+4>>2])>>>0>a>>>0){Wa=e,Xa=x[dc(g,a)>>1],u[Wa+1074446>>1]=Xa}gt(j,a,b,Ep(F+16|0,c),w[F+24|0]);if(!oe(v[e+484344>>2],v[q>>2],x[e+1074446>>1])){break k}}else{$n((B(b,872)+e|0)+1074992|0,e,b&65535,134217728);b=b+1|0;continue}break}}HN(e,i,(v[e+480208>>2]&32)>>>5|0);a=$b(v[e+484344>>2],x[e+1074446>>1]);a=fd(v[a>>2],v[v[a+48>>2]+12>>2],v[e+1074424>>2],0);g=c+B(x[A>>1],872)|0;b=c;while(1){if((b|0)==(g|0)){B:{C:{a=v[e+484344>>2];b=x[e+1074446>>1];if(xm(a,v[e+484348>>2],b)){a=$b(a,b);b=v[a+16>>2];a=v[a+20>>2];if(EN(b,a)){break C}}v[e+1074408>>2]=v[e+480216>>2];a=v[e+480220>>2];break B}v[e+1074408>>2]=b}v[e+1074412>>2]=a;if(!w[F+24|0]){break m}b=v[e+1074416>>2];v[e+1074392>>2]=b;continue l}Bb(F+16|0,l,82);D:{if(!Cb(v[v[F+16>>2]>>2],v[F+20>>2])|w[b+805|0]!=1){break D}d=w[a+3|0];if((d|0)!=2&(d|0)!=3){break D}Wa=b,Xa=Rg(e,w[b+800|0],u[b+772>>1],v[b+704>>2]),v[Wa+700>>2]=Xa}Bb(F+16|0,l,91);E:{if(!Cb(v[v[F+16>>2]>>2],v[F+20>>2])){break E}if(Uc(w[a|0])){break E}d=w[b+788|0];if(!Uc(d)|w[b+791|0]!=19){break E}h=w[b+793|0];if((h&240)!=208|y[e+1074416>>2]>(h&15)>>>0){break E}Wa=b,Xa=Rg(e,d,u[b+772>>1],0),v[Wa+700>>2]=Xa}Bb(F+16|0,l,92);F:{if(!Cb(v[v[F+16>>2]>>2],v[F+20>>2])){break F}Bb(F+8|0,l,5);if(Cb(v[v[F+8>>2]>>2],v[F+12>>2])|v[e+1074416>>2]!=1|w[b+791|0]!=17){break F}v[e+1074420>>2]=B(w[b+793|0],1e4)}d=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[b+788|0]=d;t[b+789|0]=d>>>8;t[b+790|0]=d>>>16;t[b+791|0]=d>>>24;d=w[a+4|0]|w[a+5|0]<<8;t[b+792|0]=d;t[b+793|0]=d>>>8;d=v[b+676>>2];v[b+20>>2]=v[b+672>>2];v[b+24>>2]=d;v[b+88>>2]=v[b+88>>2]&-393217;Bb(F+16|0,l,21);if(!Cb(v[v[F+16>>2]>>2],v[F+20>>2])){t[b+831|0]=0}v[b+860>>2]=0;t[b+805|0]=0;a=a+6|0;b=b+872|0;continue}}break}a=v[e+1074416>>2];if(!a){v[e+1074416>>2]=1;a=1}b=v[e+480208>>2];c=v[e+1074392>>2];G:{H:{if(c){g=b&-4097;v[e+480208>>2]=g;d=v[e+480180>>2];if(d&1048580|(b&2097152?0:(d|0)==1)){break G}if(Rk(i)>>>0<=c>>>0){break G}if(!((c>>>0)%(v[e+1074400>>2]+a>>>0)|0)){break H}break G}g=b&-528385}v[e+480208>>2]=g|4096}i=jb-16|0;jb=i;u[e+1074444>>1]=65535;a=e+1074436|0;v[a>>2]=-1;v[a+4>>2]=-1;A=e+480180|0;X=e+1075809|0;q=e+1074312|0;H=e+480208|0;I=e+1074376|0;Y=e+480188|0;Z=e+480210|0;_=e+480190|0;N=e+480192|0;while(1){I:{if(x[Y>>1]<=r>>>0){J:{if(!(w[H+1|0]&16)){break J}if(!xN(e,I,Zb(v[e+484360>>2],w[e+484376|0]),1)){break J}v[H>>2]=v[H>>2]|524288}jb=i+16|0;break I}p=B(r,872)+e|0;j=p+1075785|0;d=w[j|0];l=p+1075784|0;s=w[l|0];Q=p+1075781|0;c=w[Q|0];a=v[e+1074392>>2];b=v[e+1074400>>2];g=v[e+1074416>>2];R=p+1075782|0;f=w[R|0];n=p+1075783|0;J=w[n|0];h=ct(f,J);m=p+1075843|0;t[m|0]=v[H>>2]>>>12&1|w[m|0]&254;g=(a>>>0)%(b+g>>>0)|0;K=p+1075780|0;a=w[K|0];K:{L:{M:{if((a|0)==252){o=Tj(f,s);E=Tj(J,d);a=252;if((c-1&255)>>>0>249){break M}b=v[(B(c,160)+e|0)+906140>>2];if(!b){break M}nb[v[v[b>>2]+44>>2]](b,o,C(C(E>>>0)/C(999)));a=w[K|0]}if((a&255)==251){break L}}if(z[p+1075852>>2]==C(0)|J){break K}}o=v[H>>2]&4096;N:{if(!o){b=w[p+1075862|0];break N}b=w[Q|0];t[p+1075862|0]=b}if((b-1&255)>>>0>249){break K}E=(B(b&255,160)+e|0)+906140|0;b=v[E>>2];if(!b){break K}O:{if(!o){a=x[p+1075860>>1];break O}a=Jy(w[R|0],w[l|0]);u[p+1075860>>1]=a;V=C(C(Jy(w[n|0],w[j|0])>>>0)/C(999));z[p+1075856>>2]=V;Wa=p+1075852|0,Ya=C(C(V-C(nb[v[v[b>>2]+48>>2]](b,a)))/C(Rk(I)>>>0)),z[Wa>>2]=Ya;b=v[E>>2]}n=a;a=(v[e+1074392>>2]+1|0)==(Rk(I)|0);nb[v[v[b>>2]+(a?44:104)>>2]](b,n,z[(a?p+1075856|0:p+1075852|0)>>2]);a=w[K|0]}j=p+1074992|0;if(nN(a&255)){b=jb-16|0;jb=b;u[b+12>>1]=0;v[b+8>>2]=0;a=Th(b+8|0);c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[j+788|0]=c;t[j+789|0]=c>>>8;t[j+790|0]=c>>>16;t[j+791|0]=c>>>24;a=w[a+4|0]|w[a+5|0]<<8;t[j+792|0]=a;t[j+793|0]=a>>>8;jb=b+16|0;h=0;J=0;s=0;f=0;d=0;c=0}P:{if(!(w[H+1|0]&16)){VM(e,j);break P}if(!c){break P}v[p+1075752>>2]=0}Q:{R:{if((J|0)==33){Bb(i+8|0,q,30);a=d>>>4|0;By(e,r&65535,a+(d&15)|0,Cb(v[v[i+8>>2]>>2],v[i+12>>2]));break R}a=0;if((J-19&255)>>>0>1){break R}S:{if(!(!(v[A>>2]&16777250)|d)){d=w[p+1075825|0];break S}t[p+1075825|0]=d}b=d&240;if((b|0)==208){b=d&15;if(!b){b=v[A>>2];if(b&16777248){a=1;break R}if((b|0)==2){break Q}break R}if(b>>>0>=v[e+1074400>>2]+v[e+1074416>>2]>>>0){Bb(i+8|0,q,14);a=b;if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break R}if(!c){break Q}t[p+1075795|0]=c;break Q}a=b;break R}if(!(w[H+1|0]&16)|(b|0)!=224){break R}b=v[A>>2];if(v[e+1074396>>2]?b&16777250:0){break R}n=b&2;b=d&15;if(b?0:n){break R}v[e+1074396>>2]=b+1}b=v[A>>2]==16&(J|0)==19&(d&240)==208;E=b?0:a;T:{if(!E|w[K|0]!=255|w[R|0]!=2){break T}Bb(i+8|0,q,74);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break T}t[R|0]=0}W=d&15;a=v[e+1074392>>2];Bb(i+8|0,q,72);U:{if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){o=0;if(E>>>0>=y[e+1074416>>2]){break U}}Bb(i+8|0,q,88);o=(g|0)==(E|0)|(a|0)==(E|0);if(!(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|!E)){break U}o=(a|0)==(E|0)}Bb(i+8|0,q,44);b=b?W|144:d;V:{if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){a=w[m|0];break V}a=w[m|0]&-2|(g|0)==(E|0)}t[m|0]=a&253|(o?2:0);Bb(i+8|0,q,66);h=(!E|Cb(v[v[i+8>>2]>>2],v[i+12>>2])^1)&h;W:{X:{if(!(v[e+1074392>>2]|(!(w[Z|0]&32)|!c))){v[p+1075652>>2]=0;if(o){break X}if(!qi(v[j+8>>2],v[j+12>>2])){break W}t[p+1075795|0]=c;if(x[_>>1]<c>>>0){break W}a=B(c,104)+e|0;v[p+1075680>>2]=x[a+484410>>1];u[p+1075764>>1]=t[a+484417|0];break W}if(!o){break W}}d=w[K|0];if(c){t[p+1075795|0]=c}Y:{Z:{if(!Uc(d)){break Z}Bb(i+8|0,q,67);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Z}a=u[p+1075762>>1];_:{if(!c|h){break _}g=Oy(e,d,c);if(!g){break _}a=t[$j(e,g)+36|0]}d=(a+d|0)-132>>>0<4294967176?0:d;break Y}if(!(v[A>>2]&25165856)){break Y}l=x[N>>1];if(!l){break Y}if(d){a=Uc(d)}else{a=1}if(!a){break Y}g=c;$:{if(!c){g=w[p+1075796|0];if(!g){break $}}if(v[((g<<2)+e|0)+900380>>2]?g>>>0<=l>>>0:0){break Y}d=0}c=0}if(!((J|0)!=25|b)){Bb(i+8|0,q,55);a=Cb(v[v[i+8>>2]>>2],v[i+12>>2]);c=a?0:c;d=a?0:d}Bb(i+8|0,q,65);a=(c|0)!=0;l=Cb(v[v[i+8>>2]>>2],v[i+12>>2]);ba=!d;M=1;aa:{if(v[A>>2]&16777248){break aa}Bb(i+8|0,q,107);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break aa}Bb(i,q,85);M=0;if(!Cb(v[v[i>>2]>>2],v[i+4>>2])){break aa}if(qi(v[j+8>>2],v[j+12>>2])){break aa}M=1;g=v[p+1075096>>2];if(!g){break aa}M=Ud(v[g>>2],v[g+20>>2])^1}n=a&l;a=a&ba;ba:{ca:{da:{ea:{fa:{ga:{ha:{if(!(v[A>>2]&1048580)){break ha}ia:{if((d|0)!=255){break ia}if(!(!((f|0)==1|c)&(J|0)!=13)){Bb(i+8|0,q,55);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break ia}}g=v[p+1075648>>2];if(t[g+60|0]&1?g:0){break ia}v[p+1075680>>2]=0;a=p+1075080|0;v[a>>2]=v[a>>2]|2097152;ja:{if(!(v[H>>2]&4096)){break ja}Bb(i+8|0,q,86);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break ja}v[a>>2]=v[a>>2]|4096}c=0;d=0;a=0;g=0;l=1;if(n){break ca}break ba}Bb(i+8|0,q,59);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|v[H>>2]&4096){break ha}if(!d){d=w[p+1075789|0]-w[p+1075762|0]|0;break ga}if(d>>>0>250){M=0;n=1;d=0;break ga}if(!c){Bb(i+8|0,q,98);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break ga}}M=1;n=1;break ga}g=0;if(!a){break ea}break fa}g=d;h=0}Bb(i+8|0,q,65);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break da}d=g;g=1}a=d;l=1;if(n){break ca}break ba}d=g;g=1;l=n}ka:{la:{if(!x[N>>1]){if(x[_>>1]<c>>>0){break ka}a=(B(c,104)+e|0)+484380|0;break la}a=v[p+1075096>>2];if(!a){break ka}}ma:{if(u[a+34>>1]<0){break ma}if(v[A>>2]==2){if(!Ud(v[a>>2],v[a+20>>2])){break ma}}v[p+1075680>>2]=x[a+30>>1]}if(!l){break ka}Mp(j,x[a+28>>1],e)}a=d}Bb(i+8|0,q,71);if(!(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|!c)){t[p+1075831|0]=32}na:{if(!x[N>>1]){break na}Bb(i+8|0,q,100);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|!c){break na}if(Uc(a&255)){break na}d=v[H>>2];oa:{if(h){if(d&8){break oa}break na}if(!(d&4)){break na}}Vl(j);v[p+1075688>>2]=65536;d=p+1075080|0;v[d>>2]=v[d>>2]|2097152}if(g){Bb(i+8|0,q,11);pa:{qa:{ra:{if(!(Cb(v[v[i+8>>2]>>2],v[i+12>>2])|v[A>>2]==268435456)){d=x[N>>1];break ra}Bb(i+8|0,q,87);g=0;if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){g=qi(v[j+8>>2],v[j+12>>2])^1}d=x[N>>1];sa:{if(d){if(c>>>0>d>>>0){break qa}if(v[p+1075648>>2]!=v[((c<<2)+e|0)+900380>>2]|g){break sa}break qa}if((g^-1)&v[p+1075096>>2]==((B(c,104)+e|0)+484380|0)){break pa}}a=w[p+1075789|0]}if(!(d&65535)){break pa}}if(!(v[A>>2]&1048588)){break pa}Vl(j);t[p+1075810|0]=0;v[p+1075748>>2]=0;v[p+1075688>>2]=65536;d=p+1075080|0;v[d>>2]=v[d>>2]&-2101249|2097152;Bb(i+8|0,q,86);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break pa}v[d>>2]=v[d>>2]&-2049}c=M?c:0}l=a&255;ta:{if(l>>>0<251){break ta}Bb(i+8|0,q,50);ua:{if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|!c){break ua}d=Oy(e,w[p+1075791|0],c);if(!d){break ua}d=B(d,104)+e|0;if(u[d+484414>>1]<0){break ua}v[p+1075680>>2]=x[d+484410>>1]}Bb(i+8|0,q,100);if(Wa=Cb(v[v[i+8>>2]>>2],v[i+12>>2]),Xa=0,Za=v[H>>2]&4,Za?Wa:Xa){break ta}c=0}d=Uc(l);if(d){t[p+1075794|0]=a;t[p+1075791|0]=a;if(!h){WM(e,r&65535,c,l,0)}iP(j)}va:{wa:{xa:{ya:{za:{if(c){g=p+1075096|0;n=v[g>>2];Dp(e,j,c,h,1,1);a=v[g>>2];Aa:{if(!a|!(w[a+35|0]&2)){break Aa}M=v[e+1298300>>2];if(!xd(M)){break Aa}iz(M,r&65535,a+68|0)}Ba:{Ca:{if(v[A>>2]==1){if(!h){break Ca}Bb(i+8|0,q,85);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ca}break Ba}Bb(i+8|0,q,50);if((d|Cb(v[v[i+8>>2]>>2],v[i+12>>2])^1)!=1){break Ba}}t[p+1075795|0]=0}Bb(i+8|0,q,42);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!d|(n|0)==v[g>>2]){break ya}break za}if(v[A>>2]&16777248){a=0;if(d&(n|0)!=v[g>>2]){break xa}}Bb(i+8|0,q,107);Da:{if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|(n|0)==v[g>>2]){break Da}if((d^1|h)==1){a=p+1075068|0;if(y[a>>2]>=y[j+4>>2]){break Da}v[a>>2]=0;break ya}h=0}Bb(i+8|0,q,85);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break ya}if(!qi(v[j+8>>2],v[j+12>>2])){break za}break ya}if(!l){a=h;break va}g=0;n=p+1075795|0;a=w[n|0];if(!(!a|d^1)){Dp(e,j,a,h,!(v[p+1075096>>2]?1:v[p+1075648>>2]),!(v[A>>2]&1048580));t[n|0]=0;g=1}a=h;break wa}v[j>>2]=0;v[j+4>>2]=0}a=h}g=0;if(!l){break va}}d=v[p+1075096>>2];Ea:{if(!d|!(w[d+35|0]&2)){break Ea}h=v[e+1298300>>2];if(!xd(h)){break Ea}if(!g){if(XM(h,r&65535)){break Ea}}iz(h,r&65535,d+68|0)}d=r&65535;bt(e,j,l,a,!(v[A>>2]&1048580),0,d);CN(v[A>>2],x[Y>>1],I,d);if(!(!a|(!(v[A>>2]&1048580)|!c))){c=p+1075080|0;v[c>>2]=v[c>>2]|2097152;Vl(j);t[p+1075810|0]=0;v[p+1075748>>2]=0}if(!(v[p+1075080>>2]&512)){break va}if(!xd(v[e+1298300>>2])){break va}if(l>>>0<=253){if((l|0)!=253){break va}Bb(i+8|0,q,99);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break va}}Bb(i+8|0,q,110);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){jz(v[e+1298300>>2],d,0,1,0)}Uj(v[e+1298300>>2],d)}Fa:{Ga:{switch(f-1|0){case 0:s=s>>>0<64?s:64;v[p+1075680>>2]=s<<2;c=p+1075080|0;v[c>>2]=v[c>>2]|2097152;break Fa;case 1:break Ga;default:break Fa}}Wl(e,j,s,6)}if(x[N>>1]){UM(e,r&65535)}h=a}Bb(i+8|0,q,77);if(Wa=Cb(v[v[i+8>>2]>>2],v[i+12>>2]),Xa=0,Za=v[((r<<5)+e|0)+480280>>2]&1024,Za?Wa:Xa){break Q}a=v[e+1074392>>2];Bb(i+8|0,q,75);d=a>>>0>=E>>>0;Ha:{Ia:{Ja:{Ka:{if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|!E){break Ka}c=v[e+1074392>>2];if(!c){break Ja}d=1;if((c|0)!=(E|0)){break Ka}d=!w[Q|0]&(f|0)!=11}a=f;if(!d|a>>>0<3){break Ja}if((a|0)==11){a=i+8|0;Ny(a,e,w[K+3|0],w[K+4|0],E);a=w[Ue(a)|0];On(e,j,x[i+8>>1]);if(a){break Ia}f=11;break Ja}Bb(i+8|0,q,62);La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{if(!(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|s)){s=0;f=0;Sa:{switch(a-8|0){case 0:break Ra;case 1:break Sa;default:break Ja}}if(w[H+1|0]&16){break Ja}v[p+1075684>>2]=0;break Ja}Bb(i+8|0,q,41);Ta:{if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ta}if(s){t[p+1075826|0]=s;break Ta}s=w[p+1075826|0]}Ua:{switch(a-3|0){case 0:case 1:Va:{Wa:{if(s){break Wa}Bb(i+8|0,q,41);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Wa}s=w[p+1075826|0];if(s){break Va}s=0;break Ja}t[p+1075826|0]=s}Un(e,j,((a|0)==3?s<<4:s)&255);break Ja;case 2:if((E|0)!=v[e+1074392>>2]){Bb(i+8|0,q,41);f=5;if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ja}}Bb(i+8|0,q,41);Tn(e,j,s,Cb(v[v[i+8>>2]>>2],v[i+12>>2]));f=5;break Ja;case 3:if((E|0)!=v[e+1074392>>2]){Bb(i+8|0,q,41);f=6;if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ja}}Bb(i+8|0,q,41);Sn(e,j,s,Cb(v[v[i+8>>2]>>2],v[i+12>>2]));f=6;break Ja;case 11:break La;case 12:break Ma;case 10:break Na;case 9:break Oa;case 7:break Pa;case 6:break Qa;case 5:break Ra;case 4:break Ua;default:break Ja}}Bb(i+8|0,q,53);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){t[p+1075815|0]=s&15;f=7;break Ja}Qk(j,s<<4);f=7;break Ja}Qk(j,s);f=8;break Ja}Bb(i+8|0,q,62);Ay(e,j,s,Cb(v[v[i+8>>2]>>2],v[i+12>>2])^1);f=9;break Ja}Bb(i+8|0,q,62);Ay(e,j,s<<4&240,Cb(v[v[i+8>>2]>>2],v[i+12>>2])^1);f=10;break Ja}f=12;Bb(i+8|0,q,12);TM(e,r&65535,s<<2&252,Cb(v[v[i+8>>2]>>2],v[i+12>>2]));break Ja}Bb(i+8|0,q,12);SM(e,r&65535,s<<2&252,Cb(v[v[i+8>>2]>>2],v[i+12>>2]));f=13;break Ja}f=15;if(!o){break Ja}a=v[p+1075096>>2];if(!a|s>>>0>9){break Ja}Xa:{if(!s){c=v[p+1075656>>2];break Xa}c=v[Db(a+68|0,s-1|0)>>2];v[p+1075656>>2]=c}Vn(e,j,c);break Ja}f=14;if(s>>>0>1){break Ja}t[m|0]=w[m|0]&247|!s<<3}c=b;Ya:{Za:{_a:{$a:{switch(J-1|0){case 12:if(!(w[H+1|0]&16)){break Ia}a=B(r,872)+e|0;v[a+1075680>>2]=b>>>0<64?b<<2:256;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Ia;case 1:if(!b){c=0;if(t[A|0]&1){break Ha}}TM(e,r&65535,b,0);break Ia;case 2:if(!b){c=0;if(t[A|0]&1){break Ha}}SM(e,r&65535,b,0);break Ia;case 10:if(!b){c=0;if(v[A>>2]==1){break Ha}}Un(e,j,b);break Ia;case 3:On(e,j,b);break Ia;case 5:if(!(!b&v[A>>2]==1)){Un(e,j,b)}On(e,j,0);break Ia;case 4:Qk(j,b);break Ia;case 6:if(!(!b&v[A>>2]==1)){Un(e,j,b)}Qk(j,0);break Ia;case 15:if(!(w[H+1|0]&16)){break Ia}break Ya;case 16:Bb(i+8|0,q,5);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!(w[H+1|0]&16)|!b){break Ia}break Ya}c=Rn(e,x[e+1074446>>1],v[e+1074424>>2],r&65535,0);ab:{if(!(v[e+480180>>2]&16777250)){break ab}if(c){t[(B(r,872)+e|0)+1075827|0]=c;break ab}c=w[(B(r,872)+e|0)+1075827|0]}v[i+8>>2]=B(c,1e4);yc(i+8|0,B(v[v[e+8>>2]+24>>2],1e4));a=jb-16|0;jb=a;d=v[i+8>>2];v[a+8>>2]=d;b=v[e+8>>2];bb:{if(d>>>0>=(v[e+480180>>2]&16393?1e4:32e4)>>>0){d=v[e+480208>>2];Bb(a,e+1074312|0,92);if((Cb(v[v[a>>2]>>2],v[a+4>>2])|0)==((d&4096)>>>12|0)){break bb}v[a>>2]=B(v[b+24>>2],1e4);Wa=e+1074420|0,Xa=v[Ib(a+8|0,a)>>2],v[Wa>>2]=Xa;break bb}if(w[e+480209|0]&16){break bb}g=e+1074420|0;d=(d>>>0)/1e4|0;h=B(d&15,1e4);v[g>>2]=v[g>>2]+((d&240)==16?h:0-h|0);d=v[b+20>>2];b=v[b+24>>2];Bb(a,e+1074312|0,8);Fo(g,B(d,1e4),Cb(v[v[a>>2]>>2],v[a+4>>2])?255e4:B(b,1e4))}jb=a+16|0;break Ha;case 9:if(!o|v[A>>2]==4&h){break Ia}BN(e,j,r&65535,v[e+1074424>>2],x[e+1074446>>1]);break Ia;case 43:if(!o){break Ia}c=Sia(v[(B(r,872)+e|0)+1075068>>2],0,b,0);a=mb;f=a>>>8|0;Vn(e,j,Vc((a&255)<<24|c>>>8,f));break Ia;case 0:if(v[e+1074392>>2]){break Ia}a=B(r,872)+e|0;cb:{if(w[a+1075789|0]?v[a+1075692>>2]:0){break cb}a=v[a+1075648>>2];if(a){if(nj(w[a+31|0])){break cb}}Bb(i+8|0,q,13);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break cb}if(v[A>>2]&16777248){break Ia}}if(!b){c=0;if(w[A|0]&5){break Ha}t[(B(r,872)+e|0)+1075797|0]=1;break Ha}a=B(r,872)+e|0;t[a+1075798|0]=b;t[a+1075797|0]=1;break Ia;case 14:if(v[A>>2]&1048580){b=b&240?b:w[(B(r,872)+e|0)+1075799|0]&240|b;if(!(b&15)){b=w[(B(r,872)+e|0)+1075799|0]&15|b}b=b|256}c=b;Bb(i+8|0,q,23);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){b=e;d=r&65535;if(c){t[(B(r,872)+e|0)+1075799|0]=c;a=c}else{a=w[(B(r,872)+e|0)+1075799|0]}zy(b,d,a&255,(f|0)==15?s+1|0:0);break Ha}db:{if(c){t[(B(r,872)+e|0)+1075799|0]=c;break db}c=w[(B(r,872)+e|0)+1075799|0]}zy(e,r&65535,c,(f|0)==15?s+1|0:0);break Ha;case 17:if(!(w[H+1|0]&16)){break Ia}Bb(i+8|0,q,22);eb:{fb:{if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){if(!b){b=0;break fb}if(w[H|0]&4){break fb}a=b&240?b-16|0:b;b=a-((a&15)!=0)|0;t[(B(r,872)+e|0)+1075832|0]=b;break fb}Bb(i+8|0,q,71);if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break eb}}a=(B(r,872)+e|0)+1075831|0;t[a|0]=w[a|0]|128}a=B(r,872)+e|0;t[a+1075797|0]=18;if(!b){c=0;break Ha}t[a+1075832|0]=b;break Ia;case 22:if(!(w[H+1|0]&16)){break Ia}a=v[A>>2];c=b<<!(a&59593760);if(c>>>0<=128){v[e+1074456>>2]=c<<1;break Ha}if(a&16777250){break Ha}v[e+1074456>>2]=256;break Ha;case 23:Bb(i+8|0,q,9);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){RM(e,b,(B(r,872)+e|0)+1075809|0);break Ia}RM(e,b,X);break Ia;case 8:if(!(w[H+1|0]&16)){break Ia}Wl(e,j,b,8);break Ia;case 28:Ay(e,j,b,1);break Ia;case 7:tN(j,b);break Ia;case 25:uN(e,j,b);break Ia;case 18:h=e+1074376|0;d=r&65535;g=B(d,872);c=(h+g|0)+616|0;a=b&15;gb:{hb:{switch(b>>>4|0){case 0:c=(b&1)<<14;d=x[e+480188>>1];a=0;while(1){if((a|0)==(d|0)){break gb}g=(B(a,872)+e|0)+1075080|0;v[g>>2]=(c|v[g>>2]&-16385)^16384;a=a+1|0;continue};case 1:if(a){yy(e,c,a);break gb}if(!(v[e+480180>>2]&1048580)){break gb}yy(e,c,0);break gb;case 2:if(a){xy(e,c,a);break gb}if(!(v[e+480180>>2]&1048580)){break gb}xy(e,c,0);break gb;case 3:c=(e+g|0)+1075080|0;v[c>>2]=v[c>>2]&-1048577|((a|0)!=0)<<20;break gb;case 4:t[(e+g|0)+1075814|0]=b&7;break gb;case 5:if(!(w[e+480209|0]&16)){break gb}g=v[e+480180>>2];if(g&69206025){c=B(d,872)+e|0;u[c+1075764>>1]=a<<28>>24;g=c+1075692|0;if(!v[g>>2]){break gb}if(!Uc(w[c+1075780|0])){break gb}c=B(d,872)+e|0;Wa=g,Xa=Rg(e,w[c+1075789|0],a<<28>>24,v[c+1075696>>2]),v[Wa>>2]=Xa;break gb}c=Uc(w[(B(d,872)+e|0)+1075780|0]);if((g|0)==16){if(!c){break gb}c=B(d,872)+e|0;g=v[c+1075096>>2];if(!g){break gb}t[g+37|0]=a;u[c+1075764>>1]=a;c=c+1075692|0;if(!v[c>>2]){break gb}g=c;c=B(d,872)+e|0;Wa=g,Xa=Rg(e,w[c+1075789|0],a,v[c+1075696>>2]),v[Wa>>2]=Xa;break gb}if(!c){break gb}a=B(d,872)+e|0;c=(b<<4^-128)<<24>>24;u[a+1075764>>1]=c;d=a+1075692|0;if(!v[d>>2]){break gb}Wa=d,Xa=Rg(e,w[a+1075789|0],c,v[a+1075696>>2]),v[Wa>>2]=Xa;break gb;case 6:if(!(w[e+480209|0]&16)){break gb}My(e,h,c,a);break gb;case 7:t[(e+g|0)+1075817|0]=b&7;break gb;case 8:if(!(w[e+480209|0]&16)){break gb}Wl(e,c,a,4);break gb;case 9:zy(e,d,a,0);break gb;case 10:if(a){Tn(e,c,a,0);break gb}if(!(v[e+480180>>2]&1048580)){break gb}Tn(e,c,0,0);break gb;case 11:if(a){Sn(e,c,a,0);break gb}if(!(v[e+480180>>2]&1048580)){break gb}Sn(e,c,0,0);break gb;case 12:By(e,d,a,0);break gb;case 15:break hb;default:break gb}}if(v[e+480180>>2]==1){t[(B(d,872)+e|0)+1075838|0]=a;if(!(w[e+480209|0]&16)){break gb}VM(e,c);break gb}t[(B(d,872)+e|0)+1075836|0]=a}break Ia;case 19:QM(e,r&65535,b);break Ia;case 24:Bb(i+8|0,q,55);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){if(v[e+1074392>>2]!=(b|0)){break Ia}a=v[(B(r,872)+e|0)+1075648>>2];if(t[a+60|0]&1?a:0){break Za}if(!(!(w[R|0]?1:w[Q|0])|b)){a=(B(r,872)+e|0)+1075080|0;v[a>>2]=v[a>>2]|4096;break Za}a=B(r,872)+e|0;v[a+1075680>>2]=0;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Za}if(!(w[H+1|0]&16)){break Ia}break Za;case 27:a=(b&240)-16>>>4|0;if(a>>>0>9){break Ia}if(!(1<<a&880)){if(!a){break _a}if((a|0)!=1){break Ia}PM(e,j,b&15);break Ia}Bb(i+8|0,q,58);if(Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break Ia}QM(e,r&65535,b);break Ia;case 34:case 35:if(!(w[H+1|0]&16)&(J|0)!=36){break Ia}c=r&65535;yN(e,c,I,(J|0)==36);a=Us(e,v[j+88>>2],v[j+656>>2]);if(!a){break Ia}nb[v[v[a>>2]+80>>2]](a,(x[j+774>>1]&65532)>>>2^8192,c);break Ia;case 20:if(!(w[H+1|0]&16)|b>>>0>64){break Ia}a=B(r,872)+e|0;v[a+1075740>>2]=b;a=a+1075080|0;v[a>>2]=v[a>>2]|2097152;break Ia;case 21:f=v[A>>2];d=v[H>>2];a=b;ib:{if(a){t[j+816|0]=a;break ib}a=w[j+816|0]}g=a&255;h=a&240;c=a&15;jb:{kb:{if(!(!h|(c|0)!=15)){if(!(d&4096)){break jb}a=g>>>4|0;break kb}d=d&4096;if(!(!c|(h|0)!=240)){if(!d){break jb}a=0-c|0;break kb}if(d){break jb}if(c){a=0-c|0;if(!(f&25690144)|!h){break kb}break jb}if((a&255)>>>0<16){break jb}a=g>>>4|0}Wa=j,Xa=Yb(a+v[j+748>>2]|0,0,64),v[Wa+748>>2]=Xa}break Ia;case 26:sN(j,b);break Ia;case 29:if(!(w[H+1|0]&16)){break Ia}a=B(r,872)+e|0;v[a+1075716>>2]=b;Bb(i+8|0,q,60);if(Wa=0,Xa=Cb(v[v[i+8>>2]>>2],v[i+12>>2]),Za=w[a+1075722|0]&4,Za?Wa:Xa){break Ia}a=B(r,872)+e|0;v[a+1075732>>2]=b;v[a+1075724>>2]=b;break Ia;case 11:wN(e,I,r&65535);break Ia;case 13:a=vN(e,I,r&65535,b);if((a|0)==-1){break Ia}v[e+1074436>>2]=a;if(!(w[e+480208|0]&32)){break Ia}u[e+1074444>>1]=x[e+1074448>>1];break Ia;case 37:case 38:case 39:case 40:c=(J|0)==38|(J|0)==40;d=(J&254)==40;lb:{mb:{nb:{if(w[e+480209|0]&16){a=w[j+848|0];g=b&240;if(g){a=g|a&15;t[j+848|0]=a}g=b&15;if(g){a=g|a&-16;t[j+848|0]=a}t[j+849|0]=(a&240)>>>4;if(v[e+480180>>2]!=32768){break lb}break nb}if(v[e+480180>>2]==32768){break nb}a=w[j+849|0]-1|0;t[j+849|0]=a;if(a&255){break lb}a=w[j+848|0];break mb}a=w[j+848|0];if((a&240)==16){break mb}if(!(w[e+480209|0]&16)){break lb}}t[j+849|0]=(a&240)>>>4;a=a&15;a=c?a:0-a|0;c=v[j+656>>2];ob:{if(oj(c)){v[j+852>>2]=v[j+852>>2]+B(a,v[v[c+44>>2]+36>>2]);break ob}Wa=j,Xa=Rg(e,Ts(e,v[j+700>>2],u[j+772>>1],v[j+704>>2])+a|0,u[j+772>>1],v[j+704>>2]),v[Wa+700>>2]=Xa}if(!d){break lb}v[j>>2]=0;v[j+4>>2]=0}break Ia;case 41:AN(j,b);break Ia;case 42:if(v[e+1074392>>2]|W>>>0>1|b>>>0>47){break Ia}a=(b&240)==16;g=a?x[e+480188>>1]-1|0:r;c=a?0:r;a=((W|0)==1)<<26;while(1){d=c&65535;if(d>>>0>(g&65535)>>>0){break Ia}h=((d<<5)+e|0)+480280|0;v[h>>2]=a|v[h>>2]&-67108865;d=(B(d,872)+e|0)+1075080|0;v[d>>2]=a|v[d>>2]&-67108865;c=c+1|0;continue};case 44:break $a;default:break Ha}}zN(j,b);break Ia}OM(e,j,b&15);break Ia}Qn(e,j);break Ia}FN(e,I,b)}c=b}Bb(i+8|0,q,78);if(!(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])|!c)){pN(j,c&255)}a=w[Q|0];if(!a){break Q}t[p+1075796|0]=a}r=r+1|0;continue}break}a=1;break j}a=0}jb=F+32|0;Q=!v[e+1074420>>2]|a^1;pb:{if(Q){break pb}a=DN(e,e+1074376|0);v[e+1074380>>2]=a;v[e+1074404>>2]=a;b=Xd(x[e+480188>>1],1,31);qb:{if(Rd(w[e+1074366|0])){a=v[e+24628>>2];if((a|0)>=129){a=((B(a-128|0,b+4|0)|0)/16|0)+128|0}l=((B(v[e+480228>>2],a)<<1&-128)>>>0)/w[(b>>>1|0)+31984|0]|0;break qb}l=v[e+480228>>2]}u[e+480212>>1]=0;p=e+1074312|0;R=e+1074365|0;F=e+480180|0;I=e+480210|0;M=e+480209|0;W=e+1074366|0;Y=e+1074364|0;_=e+1074360|0;s=0;while(1){if((s|0)==256){a=v[e+24608>>2];g=x[e+480212>>1];if(a>>>0>g>>>0){break pb}d=jb-16|0;jb=d;v[d+8>>2]=e;b=e+1074478|0;c=b;g=b+(g<<1)|0;rb:{a=b+(a<<1)|0;if((b|0)==(a|0)){break rb}sb:{b=a-c|0;if((b|0)<3){break sb}h=b>>1;b=(h-2|0)/2|0;while(1){if((b|0)<0){break sb}ey(c,v[d+8>>2],h,c+(b<<1)|0);b=b-1|0;continue}}h=a-c>>1;b=a;while(1){if((b|0)==(g|0)){b=a-c>>1;while(1){if((b|0)>1){a=a-2|0;fy(c,a);b=b-1|0;ey(c,v[d+8>>2],b,c);continue}break}break rb}if(vp(v[d+8>>2],x[b>>1],x[c>>1])){fy(b,c);ey(c,v[d+8>>2],h,c)}b=b+2|0;continue}}jb=d+16|0}else{m=B(s,872)+e|0;i=m+1075080|0;tb:{if(!(v[i>>2]&4096)|(v[m+1075016>>2]|(v[m+1075012>>2]|v[m+1075688>>2]))){break tb}Bb(k+16|0,p,64);if(Cb(v[v[k+16>>2]>>2],v[k+20>>2])){break tb}v[m+1075068>>2]=0;a=m+1075084|0;v[a>>2]=0;v[a+4>>2]=0}a=x[e+480188>>1];c=v[i>>2];ub:{if(v[m+1075068>>2]|a>>>0>s>>>0?c&1024:1){if(a>>>0>s>>>0){_L(e,s&65535)}u[m+1075834>>1]=0;break ub}d=0;N=m+1075712|0;v[N>>2]=0;H=m+1075672|0;v[H>>2]=0;A=m+1075e3|0;b=A;v[b>>2]=0;v[b+4>>2]=0;v[m+1075092>>2]=0;v[k+44>>2]=1065353216;u[k+42>>1]=0;J=m+1075648|0;E=v[J>>2];v[k+36>>2]=0;g=0;r=m+1075692|0;g=v[r>>2]?v[m+1075068>>2]!=0:g;j=m+1074992|0;vb:{wb:{xb:{if(a>>>0<=s>>>0){break xb}if(w[((s<<5)+e|0)+480288|0]){break wb}if(!E){break xb}d=w[E+34|0]!=0}if((d|g)!=1){break vb}}v[k+8>>2]=v[m+1075680>>2];v[k+32>>2]=v[m+1075744>>2];Bb(k+16|0,p,28);b=k+8|0;a=Cb(v[v[k+16>>2]>>2],v[k+20>>2])?k+32|0:b;c=jb-16|0;jb=c;d=e+1074312|0;Bb(c+8|0,d,28);yb:{if(Cb(v[v[c+8>>2]>>2],v[c+12>>2])){v[a>>2]=v[a>>2]+u[j+776>>1];he(a,0,64);break yb}Bb(c+8|0,d,1);d=u[j+776>>1];if(Cb(v[v[c+8>>2]>>2],v[c+12>>2])){v[a>>2]=d+v[a>>2];he(a,0,256);break yb}v[j+688>>2]=d+v[j+688>>2];he(j+688|0,0,256);v[a>>2]=v[j+688>>2];u[j+776>>1]=0}jb=c+16|0;a=jb-16|0;jb=a;c=e+1074312|0;Bb(a+8|0,c,28);zb:{Ab:{if(!Cb(v[v[a+8>>2]>>2],v[a+12>>2])){Bb(a,c,1);if(!Cb(v[v[a>>2]>>2],v[a+4>>2])){break Ab}}v[j+684>>2]=v[j+692>>2]+u[j+778>>1];he(j+684|0,0,256);break zb}v[j+692>>2]=v[j+692>>2]+u[j+778>>1];he(j+692|0,0,256);u[j+778>>1]=0;v[j+684>>2]=v[j+692>>2]}jb=a+16|0;c=jb-16|0;jb=c;Bb:{if(!(w[j+90|0]&4)|(v[e+480208>>2]&2101248)==2101248){break Bb}Cb:{if(v[b>>2]<=0){Bb(c+8|0,e+1074312|0,21);if(!Cb(v[v[c+8>>2]>>2],v[c+12>>2])){break Cb}}f=5;if(!(v[e+480180>>2]&5)){Bb(c+8|0,e+1074312|0,21);f=Cb(v[v[c+8>>2]>>2],v[c+12>>2])?5:6}a=iy(e,w[j+825|0],w[j+820|0]);Db:{if((w[j+825|0]&3)!=1){break Db}Bb(c+8|0,e+1074312|0,89);if(!Cb(v[v[c+8>>2]>>2],v[c+12>>2])){break Db}a=w[j+819|0];h=w[j+820|0];d=h<<2&124;a=(!(w[j+90|0]&2)|w[e+480209|0]&16?a:w[j+823|0]+a|0)&32?d^127:d;a=h&32?0-a|0:a}if(v[e+480180>>2]!=131072){a=v[b>>2]+((B(w[j+827|0],a)|0)/(1<<f)|0)|0}else{d=64-a|0;a=v[b>>2];a=((B(w[j+827|0],B(d,a))|0)/-8192|0)+a|0}v[b>>2]=a}a=v[e+480208>>2];if(!(v[e+480180>>2]&16777248)|a&4?a&4096:0){break Bb}Bb(c+8|0,e+1074312|0,21);a=w[j+826|0];d=w[j+820|0];h=Cb(v[v[c+8>>2]>>2],v[c+12>>2]);t[j+820|0]=(h?a<<2:d)+(h?d:a)}jb=c+16|0;h=s&65535;c=jb-16|0;jb=c;a=e+1074312|0;Bb(c+8|0,a,71);Eb:{if(Cb(v[v[c+8>>2]>>2],v[c+12>>2])){a=(B(h,872)+e|0)+1075831|0;d=t[a|0];if((d|0)>=0){break Eb}if(!(w[e+480209|0]&16|w[(B(h,872)+e|0)+1075797|0]!=18)){f=d&-33;t[a|0]=f;Fb:{Gb:{if((f|0)!=-64){d=d&223;if((d|0)!=128){break Gb}d=w[(B(h,872)+e|0)+1075832|0]>>>4|-64;break Fb}d=w[(B(h,872)+e|0)+1075832|0]&15|-128;break Fb}d=d-1|0}t[a|0]=d;a=(B(h,872)+e|0)+1075080|0;v[a>>2]=v[a>>2]|2097152}if((d&224)!=128){break Eb}v[b>>2]=0;break Eb}if(w[(B(h,872)+e|0)+1075797|0]!=18){break Eb}Bb(c+8|0,a,22);Hb:{if(Cb(v[v[c+8>>2]>>2],v[c+12>>2])){n=B(h,872)+e|0;a=n+1075831|0;f=w[a|0];d=f<<24>>24;if(!((d|0)>=0|!v[n+1075068>>2])){Ib:{Jb:{if((f|0)!=192){if((f|0)!=128){break Jb}d=w[(B(h,872)+e|0)+1075832|0]>>>4|-64;break Ib}d=w[(B(h,872)+e|0)+1075832|0]&15|-128;break Ib}d=d-1|0}t[a|0]=d}if((d&192)!=128){break Hb}v[b>>2]=0;break Hb}a=w[(B(h,872)+e|0)+1075832|0];f=a>>>4|0;o=f+(a&15)|0;n=v[e+480180>>2];if(!(w[e+480208|0]&4?0:n&16777248)){o=o+2|0;f=f+1|0}a=(B(h,872)+e|0)+1075831|0;d=w[a|0];if(!(n&4)){d=(d&255)>>>0<o>>>0?d:0;if((d&255)>>>0>=f>>>0){v[b>>2]=0}t[a|0]=d+1;break Hb}Kb:{if(w[e+480209|0]&16){d=d&255?d-1|0:0;break Kb}t[a|0]=d+1}if(((d&255)>>>0)%(o>>>0)>>>0<f>>>0){break Hb}v[b>>2]=0}a=(B(h,872)+e|0)+1075080|0;v[a>>2]=v[a>>2]|2097152}a=B(h,872)+e|0;Lb:{if(w[a+1075797|0]!=18){break Lb}d=v[a+1075648>>2];if(!d){break Lb}a=w[d+34|0];if(!a|w[d+15|0]&2){break Lb}f=B(h,872)+e|0;if(v[f+1075080>>2]&134218752){break Lb}f=f+1075791|0;n=w[f|0];if(!Uc(n)){break Lb}a=v[(B(a,160)+e|0)+906140>>2];if(!a){break Lb}n=nb[v[v[a>>2]+100>>2]](a,n,h)|0;o=v[b>>2];if(!(!n|o)){nb[v[v[a>>2]+92>>2]](a,d,w[f|0]+255|0,0,h);break Lb}if(n|!o){break Lb}nb[v[v[a>>2]+92>>2]](a,d,w[f|0],x[(B(h,872)+e|0)+1075680>>1],h)}jb=c+16|0;he(b,0,256);v[k+8>>2]=v[k+8>>2]<<6;Mb:{if(E){Bb(k+16|0,p,31);if(Cb(v[v[k+16>>2]>>2],v[k+20>>2])){Zs(e,j)}b=k+8|0;a=jb-16|0;jb=a;Nb:{if(!gy(e,j,0)){break Nb}c=v[j+656>>2];f=e+1074312|0;Bb(a+8|0,f,31);Ob:{if(Cb(v[v[a+8>>2]>>2],v[a+12>>2])){d=v[j+724>>2];if(d){break Ob}break Nb}d=v[j+724>>2]}Bb(a+8|0,f,31);o=d-Cb(v[v[a+8>>2]>>2],v[a+12>>2])|0;d=Lp(c+48|0,o,256,64);q=w[c+65|0];Pb:{if((q|0)==255){break Pb}n=u[j+728>>1];if((n|0)==-1){break Pb}q=Db(v[c+48>>2],q);c=w[q+2|0];q=x[q>>1];Bb(a+8|0,f,94);f=c<<2;d=(o|0)==(q|0)?f:d;if(Cb(v[v[a+8>>2]>>2],v[a+12>>2])){d=n+(d-f<<1)|0;break Pb}if(!c){d=0;break Pb}d=(B(d,n)|0)/(f|0)|0}Wa=b,Xa=(B(Yb(d,0,512),v[b>>2])|0)/256|0,v[Wa>>2]=Xa}jb=a+16|0;jN(j,b);a=jb-16|0;jb=a;Qb:{if(!gy(e,j,1)){break Qb}b=v[j+656>>2];c=e+1074312|0;Bb(a+8|0,c,31);Rb:{if(Cb(v[v[a+8>>2]>>2],v[a+12>>2])){d=v[j+732>>2];if(d){break Rb}break Qb}d=v[j+732>>2]}Bb(a+8|0,c,31);c=Lp(b+68|0,d-Cb(v[v[a+8>>2]>>2],v[a+12>>2])|0,64,64)-32|0;b=v[j+684>>2];Wa=j,Xa=Yb(((B(c,(b|0)>127?256-b|0:b)|0)/32|0)+b|0,0,256),v[Wa+684>>2]=Xa}jb=a+16|0;Bb(k+16|0,p,115);if(Cb(v[v[k+16>>2]>>2],v[k+20>>2])){break Mb}b=w[m+1075789|0];if(!b){break Mb}a=v[J>>2];if(!a|!w[a+26|0]){break Mb}lN(m+1075676|0,b,w[a+26|0],w[a+27|0]);break Mb}if(!(w[i+1|0]&16)){break Mb}v[m+1075688>>2]=0;v[k+8>>2]=0}Sb:{if(w[m+1075843|0]&8){f=0;v[k+8>>2]=0;break Sb}f=v[k+8>>2];if(!f){f=0;break Sb}if(w[i+3|0]&8){v[H>>2]=0;break Sb}if(Rd(w[R|0])){a=B(v[k+32>>2],v[m+1075740>>2]);b=a;c=a>>31;a=f<<8;Wa=H,Xa=Ic(Tia(Sia(b,c,a,a>>31),mb,1048576,0),mb),v[Wa>>2]=Xa;break Sb}a=B(v[k+32>>2],v[m+1075740>>2]);b=a;c=a>>31;a=B(v[e+1074456>>2],f);Wa=H,Xa=Ic(Tia(Sia(b,c,a,a>>31),mb,1048576,0),mb),v[Wa>>2]=Xa}v[N>>2]=f;Tb:{Ub:{f=v[r>>2];if(!(v[F>>2]==2|(f|0)>=v[e+480260>>2])){if(!gj(e)){break Ub}f=v[r>>2]}if((f|0)<v[e+480264>>2]){break Tb}Bb(k+16|0,p,113);if(!Cb(v[v[k+16>>2]>>2],v[k+20>>2])){break Tb}if(gj(e)){break Tb}v[r>>2]=v[e+480264>>2];break Tb}v[r>>2]=v[e+480260>>2]}Bb(k+16|0,p,73);a=v[r>>2];v[k+36>>2]=a;Vb:{if((v[i>>2]&1572864)!=1572864){break Vb}b=v[e+480208>>2];if(b&2097152){if(!ct(w[m+1075782|0],w[m+1075783|0])|b&4096){break Vb}}b=m+1075704|0;Wb:{if((a|0)==v[b>>2]){f=v[m+1075708>>2];break Wb}v[b>>2]=a;c=a;a=m+1075764|0;b=m+1075696|0;f=Rg(e,Ts(e,c,u[a>>1],v[b>>2]),u[a>>1],v[b>>2]);v[m+1075708>>2]=f}v[k+36>>2]=f}o=jb-16|0;jb=o;q=B(h,872)+e|0;K=q+1075648|0;a=v[K>>2];Xb:{if(!a){break Xb}b=w[a+34|0];if(!b|w[a+15|0]&2|(!v[(B(b,160)+e|0)+906140>>2]|v[(B(h,872)+e|0)+1075080>>2]&134218752)){break Xb}b=B(h,872)+e|0;X=b+1075783|0;n=w[X|0];c=0;d=w[b+1075791|0];if(Uc(d)){c=w[Lb(a+108|0,d-1|0)|0]}b=b+1075780|0;Yb:{Zb:{if((n|0)==1){f=0;_b:{$b:{switch((y[e+1074392>>2]%3|0)-1|0){case 0:f=w[(B(h,872)+e|0)+1075798|0]>>>4|0;break _b;case 1:break $b;default:break _b}}f=w[(B(h,872)+e|0)+1075798|0]&15}a=B(h,872)+e|0;t[a+1075793|0]=c;if(w[a+1075792|0]==(c+f|0)){break Yb}a=c;if(!(w[e+480209|0]&16)){break Zb}a=c;if(!Uc(w[b|0])){break Zb}break Yb}f=0;if(w[b|0]){break Yb}a=B(h,872)+e|0;if(!w[a+1075792|0]){break Yb}a=w[a+1075793|0]}Ul(e,h,(a&255)+f|0,x[(B(h,872)+e|0)+1075680>>1])}a=(B(h,872)+e|0)+1075792|0;d=w[a|0];ac:{if(!d){if(!(w[e+480209|0]&16)|(n|0)!=1){break ac}if(Uc(w[b|0])){break ac}d=c;if(!Uc(d)){break ac}}Ul(e,h,(d&255)+255|0,0)}t[a|0]=w[X|0]==1?w[(B(h,872)+e|0)+1075793|0]+f|0:0}bc:{if(w[q+1075797|0]!=1){break bc}if(oj(v[K>>2])){f=0;cc:{dc:{ec:{switch(y[e+1074392>>2]%3|0){case 1:f=w[(B(h,872)+e|0)+1075798|0]>>>4|0;break dc;case 0:break dc;case 2:break ec;default:break cc}}f=w[(B(h,872)+e|0)+1075798|0]&15}u[k+42>>1]=f}a=(B(h,872)+e|0)+1075843|0;t[a|0]=w[a|0]|96;break bc}if(!(!(w[e+480209|0]&16)|v[e+480180>>2]!=1048576)){a=B(h,872)+e|0;b=Rg(e,w[a+1075789|0],u[a+1075764>>1],v[a+1075696>>2]);v[k+36>>2]=b;v[a+1075692>>2]=b}a=e+1074312|0;Bb(o+8|0,a,13);if(Cb(v[v[o+8>>2]>>2],v[o+12>>2])){f=w[(B(h,872)+e|0)+1075798|0];if(!f){break bc}a=65536;fc:{switch(((y[e+1074392>>2]%(v[e+1074400>>2]+v[e+1074416>>2]>>>0)>>>0)%3|0)-1|0){case 1:f=f<<4;case 0:a=v[((f&240)<<2)+37136>>2];break;default:break fc}}d=gj(e);b=v[k+36>>2];c=b;b=b>>31;if(d){a=Sia(c,b,a,a>>31)+32768|0;h=mb;a=Tia(a,a>>>0<32768?h+1|0:h,65536,0)}else{d=(a|0)/2|0;h=d>>31;n=b<<16|c>>>16;c=c<<16;b=c+d|0;n=h+n|0;a=Tia(b,b>>>0<c>>>0?n+1|0:n,a,a>>31)}b=mb;Wa=k,Xa=Ic(a,b),v[Wa+36>>2]=Xa;break bc}Bb(o+8|0,a,51);if(Cb(v[v[o+8>>2]>>2],v[o+12>>2])){if(w[e+480209|0]&16){break bc}gc:{hc:{a=v[e+1074416>>2];a=a-(y[e+1074392>>2]%(a>>>0)|0)|0;if((a|0)>16){break hc}if((a|0)==16){break bc}c=0;ic:{switch((a|0)%3|0){case 0:break bc;case 2:break hc;case 1:break ic;default:break gc}}c=w[(B(h,872)+e|0)+1075798|0]>>>4|0;break gc}c=w[(B(h,872)+e|0)+1075798|0]&15}a=B(h,872)+e|0;b=a+1075764|0;a=a+1075696|0;c=Ts(e,v[k+36>>2],u[b>>1],v[a>>2])+c|0;b=Rg(e,c,u[b>>1],v[a>>2]);v[k+36>>2]=b;if(c>>>0<109){break bc}v[o+8>>2]=b;Wa=o,Xa=Rg(e,109,0,v[a>>2]),v[Wa+4>>2]=Xa;Wa=k,Xa=v[Yc(o+8|0,o+4|0)>>2],v[Wa+36>>2]=Xa;break bc}b=v[e+1074392>>2];d=e+480180|0;f=v[d>>2];jc:{if((f|0)!=1){c=w[(B(h,872)+e|0)+1075789|0];break jc}c=B(h,872)+e|0;c=Ts(e,v[k+36>>2],u[c+1075764>>1],v[c+1075696>>2]);f=v[d>>2]}kc:{lc:{switch((((f&67633152?b+2|0:b)>>>0)%3|0)-1|0){case 0:c=(w[(B(h,872)+e|0)+1075798|0]>>>4|0)+c|0;break kc;case 1:break lc;default:break kc}}c=(w[(B(h,872)+e|0)+1075798|0]&15)+c|0}if(!(f&67633408|w[(B(h,872)+e|0)+1075789|0]!=(c&255))){Bb(o+8|0,a,82);if(!Cb(v[v[o+8>>2]>>2],v[o+12>>2])){break bc}}if(w[e+480210|0]&32){b=c&255;if((b|0)==85){v[k+36>>2]=2147483647;break bc}c=b>>>0>85?c-37|0:c}b=B(h,872)+e|0;d=Rg(e,c&255,u[b+1075764>>1],v[b+1075696>>2]);v[k+36>>2]=d;if(v[e+480180>>2]&71860480){v[b+1075692>>2]=d;break bc}Bb(o+8|0,a,82);if(!Cb(v[v[o+8>>2]>>2],v[o+12>>2])){break bc}t[(B(h,872)+e|0)+1075792|0]=c}jb=o+16|0;if(!(!(w[I|0]&33)|v[k+36>>2]==2147483647)){mc:{if(v[F>>2]==2){f=452;a=3424;break mc}a=B(x[m+1075764>>1]>>>4&15,24);b=x[a+32870>>1]>>>1|0;f=b>>>0>452?b:452;a=x[a+32848>>1]<<1}he(k+36|0,f,a);he(r,f,a)}qN(e,j);c=v[i>>2]}nc:{if(!(c&256)|w[M|0]&64){break nc}Bb(k+16|0,p,37);if(!Cb(v[v[k+16>>2]>>2],v[k+20>>2])){break nc}v[m+1075676>>2]=128}q=s&65535;_L(e,q);oc:{if(!g){break oc}a=kN(e,j,k+36|0);if((a|0)<0|!(w[i+1|0]&2)){break oc}b=v[e+1298300>>2];if(!xd(b)){break oc}Kp(b,q,a>>>2&255,1)}pc:{if(w[m+1075782|0]!=8){break pc}qc:{rc:{a=w[m+1075783|0];switch(a-5|0){case 1:break pc;case 0:case 2:break qc;default:break rc}}if((a|0)!=26){break pc}}a=v[F>>2];if((a|0)==4){if(w[M|0]&16){break pc}a=m+1075811|0;t[a|0]=w[a|0]+w[m+1075815|0];break pc}if(!(a&16777248)){break pc}Qk(j,w[m+1075784|0]);ZL(e,q,k+36|0,k+44|0)}ZL(e,q,k+36|0,k+44|0);sc:{if(!g){break sc}v[k+32>>2]=0;b=k+36|0;f=jb-16|0;jb=f;d=v[j+104>>2];tc:{if(!d|!w[d+40|0]){break tc}K=oj(v[j+656>>2]);n=gj(e);Bb(f+8|0,e+1074312|0,21);a=n?38160:37136;g=n?37136:38160;if(!(K|!Cb(v[v[f+8>>2]>>2],v[f+12>>2])|v[e+480180>>2]==1048576)){o=w[d+41|0];if(!o){break tc}c=w[j+818|0];v[f+4>>2]=v[j+756>>2]+w[d+39|0];Wh(f+4|0,w[d+40|0]<<8);h=v[f+4>>2];t[j+818|0]=c+o;v[j+756>>2]=h;h=(h|0)/256|0;uc:{vc:{switch(w[d+38|0]-1|0){case 3:c=XL(Pn(e))+-64|0;break uc;case 2:c=64-(c+1>>>1|0)|0;break uc;case 1:c=(c+1>>>1|0)+-64|0;break uc;case 0:c=(c>>>1^-1)&64;break uc;default:break vc}}c=t[c+33440|0]}Wh(b,8388607);d=v[b>>2]<<8;v[b>>2]=d;h=B(c,h);o=(h|0)/64|0;c=o>>31;o=(c^o)-c|0;r=o>>>2|0;c=d;wc:{xc:{if((h|0)<=-64){h=d>>31;a=v[(r<<2)+a>>2];a=Ic(Tia(Sia(d,h,a,a>>31),mb,65536,0),mb)-d|0;g=o&3;if(!g){break wc}g=(g<<2)+(n?37072:37008)|0;break xc}h=d>>31;a=v[g+(r<<2)>>2];a=Ic(Tia(Sia(d,h,a,a>>31),mb,65536,0),mb)-d|0;g=o&3;if(!g){break wc}g=(g<<2)+(n?37008:37072)|0}n=a;a=v[g>>2];a=(n+Ic(Tia(Sia(a,a>>31,d,h),mb,65536,0),mb)|0)-d|0}v[b>>2]=(a+c|0)/256;v[k+32>>2]=a&255;break tc}h=v[e+480180>>2]&16777248;c=w[d+39|0];yc:{if(!(h|c)){v[j+756>>2]=w[d+40|0]<<8;break yc}zc:{Ac:{if(h){o=c<<1;r=v[j+756>>2];c=j+756|0;break Ac}if(w[j+89|0]&8){break zc}r=((w[d+40|0]<<8&65280)>>>0)/(c>>>0)|0;o=v[j+756>>2];c=j+756|0}v[c>>2]=o+r}Wh(j+756|0,w[d+40|0]<<8)}c=w[j+818|0]+w[d+41|0]|0;t[j+818|0]=c;c=c<<24>>24;Bc:{Cc:{switch(w[d+38|0]-1|0){case 3:t[j+818|0]=c+1;h=t[(c&63)+33376|0];break Bc;case 2:h=(64-(c>>>1|0)&127)+-64|0;break Bc;case 1:h=((c>>>1|0)- -64&127)+-64|0;break Bc;case 0:h=(c|0)>=0?-64:64;break Bc;default:break Cc}}h=0-t[(c&255)+33440|0]|0;if(v[e+480180>>2]!=1048576){break Bc}h=(64-t[(c+-64&255)+33440|0]|0)/2<<16>>16}c=h;h=B(c,v[j+756>>2]);r=(h|0)/256|0;if(K){z[k+44>>2]=z[k+44>>2]+C(C(C(C(w[d+40|0])*C(.05000000074505806))*C(c|0))*C(.000244140625));t[j+851|0]=w[j+851|0]|64;break tc}if(v[e+480180>>2]!=4){Dc:{if((h|0)<=-256){r=0-r|0;d=0-h>>>16|0;c=(d<<2)+a|0;break Dc}a=g;d=(h|0)/65536|0;c=a+(d<<2)|0}g=v[b>>2];d=v[((d<<2)+a|0)+4>>2];a=v[c>>2];a=((B(d-a|0,(r|0)/4&63)|0)/64|0)+a|0;a=Ic(Tia(Sia(g,g>>31,a,a>>31),mb,256,0),mb);v[b>>2]=a;v[k+32>>2]=a&255;v[b>>2]=v[b>>2]/256;break tc}v[b>>2]=v[b>>2]+((h|0)/16384|0)}jb=f+16|0;g=v[k+36>>2];if((g|0)<=v[e+480260>>2]){Bb(k+16|0,p,81);if(Cb(v[v[k+16>>2]>>2],v[k+20>>2])){v[m+1075068>>2]=0}g=v[e+480260>>2];v[k+36>>2]=g}Ec:{if(!oj(v[j+656>>2])){break Ec}a=m+1075843|0;b=w[a|0];if(!(v[e+1074392>>2]|!(b&32)?b&64:1)){break Ec}hP(j,z[k+44>>2],u[k+42>>1],e);b=a;a=w[a|0];t[b|0]=(a&64?-65:-33)&a}a=k+16|0;Qy(a,e,j,g,v[k+32>>2]);b=Gb(a);a=Sia(v[k+16>>2],v[k+20>>2],v[e+480240>>2],0);f=mb;c=Tia(a,f,65536,0);d=mb;a=a+65535|0;f=a>>>0<65535?f+1|0:f;a=!f&a>>>0<131071;c=a?1:c;v[k+16>>2]=c;a=a?0:d;v[k+20>>2]=a;v[A>>2]=c;v[A+4>>2]=a;if((v[i>>2]&134219264)!=512){break sc}if(!xd(v[e+1298300>>2])){break sc}Bb(k+8|0,p,99);Fc:{Gc:{if(Wa=Cb(v[v[k+8>>2]>>2],v[k+12>>2]),Xa=1,Za=w[i+1|0]&16,Za?Wa:Xa){a=v[F>>2];break Gc}a=v[F>>2];if((a|0)!=2){break Fc}}c=v[i>>2];d=c&2048;Hc:{if(d?(a|0)==2:0){break Hc}a=Sia(v[b>>2],0,261625,0)+66904|0;b=mb;b=Vc(Via(a,a>>>0<66904?b+1|0:b,133808,0),mb);a=1;Ic:{if(d){break Ic}a=0;if(!(c&4096)){break Ic}a=!v[m+1075688>>2]}Bb(k+8|0,p,110);if(Wa=Cb(v[v[k+8>>2]>>2],v[k+12>>2]),Xa=0,Za=a,Za?Wa:Xa){break Hc}c=v[e+1298300>>2];Bb(k+8|0,p,95);jz(c,q,b,a,Cb(v[v[k+8>>2]>>2],v[k+12>>2]))}b=v[e+1298300>>2];a=Sia(B(v[m+1075744>>2],B(v[m+1075740>>2],v[N>>2])),0,63,0)+33554432|0;f=mb;f=a>>>0<33554432?f+1|0:f;Kp(b,q,Vc((f&67108863)<<6|a>>>26,f>>>26|0)&255,0);a=m+1075676|0;d=a;b=v[a>>2];g=0;a=v[e+1298300>>2];c=Xk(a,q);Jc:{if((c|0)==255){break Jc}h=v[a>>2];if(Vj(h)){break Jc}g=Lb(Hd(a+318|0,c),10);f=v[a+4>>2];c=lt(c)|192;a=w[g|0]&-49;a=(b|0)<171?a|16:a;a=(b|0)>84?a|32:a;b=a&255;Tg(h,f,q,c,b);g=(b>>>5&1)+(a<<27>>31)|0}v[d>>2]=(g<<7)+128}Kc:{a=v[J>>2];if(!a|(w[a+60|0]&7)!=1){break Kc}b=v[a+48>>2];a=v[a+52>>2];if(uc(b,a)){break Kc}b=v[YL(j,0)>>2];a=Kn(a);if(b>>>0<x[a>>1]|w[a+2|0]){break Kc}jj(v[e+1298300>>2],q,1);Bb(k+8|0,p,109);a=v[i>>2];Wa=i,Xa=(Cb(v[v[k+8>>2]>>2],v[k+12>>2])?a:a&-4609)|4096,v[Wa>>2]=Xa;v[m+1075688>>2]=0;break sc}Bb(k+8|0,p,99);if(!Cb(v[v[k+8>>2]>>2],v[k+12>>2])|!(w[i+1|0]&16)|v[m+1075688>>2]){break sc}jj(v[e+1298300>>2],q,1);v[i>>2]=v[i>>2]&-513}Lc:{if(!E){break Lc}Bb(k+16|0,p,31);if(Cb(v[v[k+16>>2]>>2],v[k+20>>2])){break Lc}Zs(e,j)}b=v[i>>2];a=b&-65537;o=m+1075012|0;h=v[H>>2];r=m+1075016|0;f=v[o>>2]|(h|v[r>>2])?(a|b<<7&65536)^65536:a;v[i>>2]=f;q=m+1075664|0;a=q;v[a>>2]=0;v[a+4>>2]=0;d=m+1075834|0;a=w[d|0];b=a-4|0;c=a>>>0<b>>>0?0:b;t[d|0]=c;n=m+1075835|0;a=w[n|0];b=a-4|0;a=a>>>0<b>>>0?0:b;t[n|0]=a;Mc:{Nc:{Oc:{Pc:{Qc:{Rc:{Sc:{Tc:{Uc:{b=v[m+1075096>>2];Vc:{if(!b){break Vc}g=v[b+20>>2];if(!Ud(v[b>>2],g)|!v[m+1075068>>2]){break Vc}if(qi(v[j+8>>2],v[j+12>>2])){break Uc}}v[m+1075008>>2]=0;break Tc}v[m+1075008>>2]=g;if(g){break Sc}}if(!Sj(v[j+656>>2])){break Rc}g=0;if(f&6144){break Rc}}H=v[m+1075676>>2];b=(B(h,256-H|0)|0)/16384|0;b=b>>>0<127?b:127;if(c<<24>>24<0){t[d|0]=b;c=b}b=b>>>1|0;if((c&255)>>>0<b>>>0){t[d|0]=b}b=(B(h,H)|0)/16384|0;b=b>>>0<127?b:127;c=b>>>1|0;if(a<<24>>24<0){t[n|0]=b;a=b}if((a&255)>>>0<c>>>0){break Qc}break Pc}if((c&255)>>>0>=129){t[d|0]=0}g=0;c=0;if((a&255)>>>0<129){break Oc}}t[n|0]=c}if(!g){break Oc}g=128;d=v[e+24624>>2];if(d>>>0>=2){g=Yb(v[m+1075676>>2],0,256)}v[k+16>>2]=g;b=B(h,l)>>>(Rd(w[W|0])?7:8)|0;Wc:{Xc:{Yc:{switch(w[Y|0]){case 0:if(!(w[e+24616|0]&16)){break Xc}case 1:if((g|0)<=127){a=b>>>1|0;b=(B(b,g)|0)/256|0;break Wc}a=(B(b,256-g|0)|0)/256|0;b=b>>>1|0;break Wc;case 3:break Yc;default:break Xc}}Wh(k+16|0,255);c=v[k+16>>2];if((c|0)<=0){a=65536}else{a=x[(0-c<<1)+39696>>1]}a=B(a,b)>>>16|0;b=B(b,x[(c<<1)+39184>>1])>>>16|0;break Wc}a=(B(b,256-g|0)|0)/256|0;b=(B(b,g)|0)/256|0}c=v[J>>2];Zc:{if(c){g=w[c+14|0];if(yo(g)){break Zc}}g=w[e+480268|0];if(yo(g)){break Zc}c=w[e+24648|0];g=w[I|0]&128?v[e+24668>>2]?-1:c:c}h=m+1075668|0;n=m+1075786|0;t[n|0]=g;c=v[A>>2];o=v[A+4>>2];if(!(f&131072|((c|0)!=0|(o|0)!=1)|(v[m+1075748>>2]|(g&255)==255))){t[n|0]=0}g=a;a=1<<v[_>>2];v[q>>2]=(g|0)/(a|0);a=(b|0)/(a|0)|0;v[h>>2]=(f&256)>>>8|0?(d|0)==2?0-a|0:a:a;if(f&128){v[A>>2]=0-c;v[A+4>>2]=0-(((c|0)!=0)+o|0)}r=0;g=jb-16|0;jb=g;v[j+28>>2]=0;v[j+32>>2]=0;Wh(j+672|0,524287);Wh(j+676|0,524287);_c:{$c:{c=v[j+88>>2];if(!(c&65536)){b=v[j+676>>2];a=v[j+672>>2];break $c}a=v[j+20>>2];h=v[j+672>>2];ad:{if((a|0)!=(h|0)){b=v[j+24>>2];d=v[j+676>>2];break ad}b=v[j+24>>2];d=v[j+676>>2];if((b|0)==(d|0)){break $c}}c=v[e+24620>>2];d=(a|0)<(h|0)|(b|0)<(d|0);bd:{if(d){a=pt(c,v[e+24636>>2]);break bd}a=pt(c,v[e+24640>>2])}Bb(g,e+1074312|0,4);if(!(!Cb(v[v[g>>2]>>2],v[g+4>>2])|!(v[e+480180>>2]&4))){a=v[e+24620>>2];a=Sia(a,a>>31,5,0)+500|0;h=mb;a=Ic(Tia(a,a>>>0<500?h+1|0:h,1e3,0),mb)}c=v[j+656>>2];cd:{if(!c){b=a;break cd}b=a;if(!d){break cd}c=x[c+12>>1];if(c){b=(B(c,v[e+24620>>2])>>>0)/1e5|0}r=(c|0)!=0}f=b?b:1;d=v[j+672>>2];n=v[j+20>>2];o=d-n<<12;q=j;c=v[j+676>>2];b=v[j+24>>2];h=c-b<<12;if(!(w[j+90|0]&32|(!(c|d)|(!(b|n)|r)))){v[g+12>>2]=v[e+1074380>>2];he(g+12|0,a,2048);f=v[g+12>>2]}h=(h|0)/(f|0)|0;v[q+32>>2]=h;n=(o|0)/(f|0)|0;v[j+28>>2]=n;b=c+((B(f,h)|0)/-4096|0)|0;v[j+24>>2]=b;a=d+((B(f,n)|0)/-4096|0)|0;v[j+20>>2]=a;if(h|n){v[j+100>>2]=f;c=v[j+88>>2];break _c}v[j+24>>2]=c;v[j+20>>2]=d;b=c;a=d;c=v[j+88>>2]&-65537;break _c}v[j+24>>2]=b;v[j+20>>2]=a;c=c&-65537}v[j+88>>2]=c&-2097153;v[j+40>>2]=b<<12;v[j+36>>2]=a<<12;jb=g+16|0;f=v[i>>2];if(!(f&512)){break Nc}break Mc}v[o>>2]=0;v[r>>2]=0;v[m+1075068>>2]=0;if(v[m+1075088>>2]){break Nc}if(!v[m+1075084>>2]){break Mc}}a=x[e+480212>>1];u[e+480212>>1]=a+1;u[((a<<1)+e|0)+1074478>>1]=s}v[m+1075660>>2]=f}s=s+1|0;continue}break}}jb=k+48|0;if(Q^1){a=v[e+480208>>2];break h}if(Rd(w[Ga|0])){b=v[e+480208>>2]|512;break i}k=0;dd:{a=v[e+24620>>2]/10|0;c=Ic(a,a>>31);if(!c){break dd}b=c>>>0<1048576?c:1048576;v[e+1074380>>2]=b;g=x[e+480212>>1];d=e+1074376|0;while(1){if((g|0)==(k|0)){break dd}a=d+B(x[(d+(k<<1)|0)+102>>1],872)|0;h=a+1288|0;v[h>>2]=0;v[h+4>>2]=0;v[a+716>>2]=b;h=v[a+640>>2]<<12;v[a+656>>2]=h;f=v[a+636>>2]<<12;v[a+652>>2]=f;v[a+704>>2]=v[a+704>>2]|65536;v[a+644>>2]=(0-f|0)/(b|0);v[a+648>>2]=(0-h|0)/(b|0);k=k+1|0;continue}}a=v[e+480208>>2];b=a|256;if(c){break i}b=a|512}a=b;v[e+480208>>2]=a}if(!(a&512)){break g}Wa=e+1074392|0,Xa=Rk(Fa),v[Wa>>2]=Xa}jb=T+112|0;break f}v[T+96>>2]=512;a=v[e+1074380>>2];v[T+104>>2]=fa;v[T+100>>2]=a;j=xB(T+96|0);if(v[e+24632>>2]){n=0;a=jb-48|0;jb=a;b=j<<2;while(1){if((n|0)==4){ed:{n=0;while(1){if((n|0)==4){break ed}v[(a+32|0)+(n<<2)>>2]=((n<<11)+e|0)+16396;n=n+1|0;continue}}}else{v[a+32>>2]=0;c=((n<<11)+e|0)+16396|0;Pz(c,b+c|0,a+32|0);n=n+1|0;continue}break}b=Wg(a+16|0,a+32|0,v[e+24632>>2],j);c=v[v[ea>>2]+8>>2];v[a+8>>2]=v[b+8>>2];d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;nb[c|0](ea,a);jb=a+48|0}if(Rd(Ea)){a=0;while(1){if((a|0)==4){a=Wg(T+80|0,T+96|0,v[e+24632>>2],j);b=v[v[oa>>2]+8>>2];v[T+40>>2]=v[a+8>>2];c=v[a+4>>2];v[T+32>>2]=v[a>>2];v[T+36>>2]=c;nb[b|0](oa,T+32|0)}else{v[(T+96|0)+(a<<2)>>2]=((a<<11)+e|0)+16396;a=a+1|0;continue}break}}ba=0;ga=0;E=jb-48|0;jb=E;if(j){q=e+12|0;s=e+24592|0;A=e+24588|0;Im(q,j,s,A);if(y[e+24624>>2]>=3){Im(e+8204|0,j,e+24600|0,e+24596|0)}u[E+42>>1]=0;ta=e+1074312|0;Ia=e+24648|0;Ja=e+24596|0;Ka=e+24600|0;La=e+8204|0;F=e+397452|0;H=e+397448|0;r=e+393352|0;ua=e+397456|0;ja=e+1074376|0;Ma=e+480190|0;while(1){if(x[e+480212>>1]<=ba>>>0){Wa=e,Xa=x[We(e+480214|0,E+42|0)>>1],u[Wa+480214>>1]=Xa}else{l=(ba<<1)+ja|0;h=x[l+102>>1];a=B(h,872);K=a+ja|0;fd:{gd:{if(v[K+632>>2]){break gd}b=a+e|0;if(v[b+1075088>>2]){break gd}if(!v[b+1075084>>2]){break fd}}k=a+e|0;a=w[k+1075786|0]+1|0;if((a&255)>>>0<=5){f=v[(a<<24>>24<<2)+27616>>2]}else{f=0}I=k+1075080|0;g=v[I>>2];hd:{if(!(!(g&16777216)&w[e+24612|0]>>>5)){a=s;b=A;c=g;d=q;if(!(c&8388608)){break hd}}a=H;b=F;if(!w[ua+12|0]){Im(r,j,a,b)}t[ua+12|0]=1;h=x[l+102>>1];c=v[I>>2];d=r}n=b;b=c>>>8&y[e+24624>>2]>2;R=b?Ja:n;J=b?Ka:a;c=b?La:d;ka=sl(e,ja,h,2,1);va=(ka-1&255)>>>0>249;id:{if(va){break id}b=v[(B(ka,160)+e|0)+906140>>2];if(!b){break id}a=v[b+24>>2];if(!a){break id}R=b+36|0;J=b+40|0;if(!(t[b+28|0]&1)){Im(a,j,J,R);v[b+28>>2]=v[b+28>>2]|1}c=a}l=K+616|0;if(w[k+1075843|0]&8){bD(l,c,j);a=k+1075084|0;v[J>>2]=v[J>>2]+v[a>>2];v[R>>2]=v[R>>2]+v[k+1075088>>2];v[a>>2]=0;v[a+4>>2]=0;break fd}M=0;d=jb-16|0;jb=d;a=E+16|0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;b=d+8|0;h=e+1074312|0;Bb(b,h,33);Wa=a,Xa=Cb(v[v[d+8>>2]>>2],v[d+12>>2]),t[Wa+16|0]=Xa;Bb(b,h,116);Wa=a,Xa=Cb(v[v[d+8>>2]>>2],v[d+12>>2])^1,t[Wa+17|0]=Xa;if(v[l+16>>2]){aD(a,l);m=v[l+8>>2];n=v[l+12>>2];b=n>>31;n=(b^n)-((b>>>0>(b^m)>>>0)+b|0)|0;b=n;v[a+12>>2]=b>>>0>8191?2:16384/(b+1>>>0)|0}Na=g>>>12&8|(g>>>5&2|(f|g&1));Oa=ga&65535;Pa=k+1075795|0;Qa=k+1075778|0;Ra=k+1075688|0;Sa=k+1075024|0;Ta=k+1075020|0;Ua=k+1075668|0;Va=k+1075664|0;W=k+1075088|0;Y=k+1075084|0;wa=k+1075016|0;xa=k+1075012|0;ha=k+1075096|0;_=k+1075076|0;Q=k+1075068|0;N=k+1075e3|0;ia=k+1075072|0;X=k+1075092|0;jb=d+16|0;p=a;a=j;while(1){jd:{b=v[X>>2];da=b?a>>>0>b>>>0?b:a:a;v[E+8>>2]=da;kd:{ld:{if(!da){break ld}k=v[N>>2];g=v[N+4>>2];if(!(k|g)){break ld}f=v[Q>>2];if(!f){break ld}d=v[p>>2];if(!d){break ld}b=v[I>>2];n=v[ia>>2];v[K+632>>2]=d;d=v[l>>2];md:{nd:{m=n&b<<30>>31;h=v[l+4>>2];o=h;if((m|0)>(h|0)){if((g|0)<0){d=Gg(0,m<<1,d,h);v[l>>2]=d;h=mb;v[l+4>>2]=h;if(!((h|0)>=(m|0)&h>>>0<f+m>>>1>>>0)){d=0;v[l>>2]=d;h=m;v[l+4>>2]=h}od:{if(b&4){b=b&-129;v[I>>2]=b;g=0-(((k|0)!=0)+g|0)|0;k=0-k|0;v[N>>2]=k;v[N+4>>2]=g;break od}v[l>>2]=d;h=f-1|0;v[l+4>>2]=h}if(!(b&2)){break ld}if(f>>>0>h>>>0){break md}break ld}if((h|0)>0|(h|0)>=0){break md}h=0;break nd}if(f>>>0>o>>>0){break md}if(!(b&2)){break ld}if(b&4){if(!!k&(g|0)>=0|(g|0)>0){g=0-(((k|0)!=0)+g|0)|0;k=0-k|0;v[N>>2]=k;v[N+4>>2]=g}b=b|128;v[I>>2]=b;if(w[E+33|0]){o=w[E+32|0];i=v[_>>2]-(o+n|0)|0;d=Gg(d,h,0,f);h=mb;if(h>>>0<i>>>0){d=Gg(0,f-o|0,d,h);h=mb;break nd}h=n;d=0;break nd}h=1-((d|0)!=0)|0;d=0-d|0;i=(f<<1)-(h+o|0)|0;o=d;v[l>>2]=d;Z=0;h=Z|i;v[l+4>>2]=h;if(i>>>0>n>>>0&f>>>0>i>>>0){break md}v[E+44>>2]=w[E+32|0]+1;d=o;h=Z|f-v[Ib(Q,E+44|0)>>2];break nd}if((g|0)<0){g=0-(((k|0)!=0)+g|0)|0;k=0-k|0;v[N>>2]=k;v[N+4>>2]=g}Sb(l,0,m-f|0);b=v[I>>2]|8192;v[I>>2]=b;d=v[l>>2];h=v[l+4>>2];break md}v[l>>2]=d;v[l+4>>2]=h}Z=h;pd:{if((h|0)<(m|0)){if((g|h)<0){break ld}v[E+44>>2]=da;f=k;n=g;break pd}f=v[Q>>2];if(f>>>0<Z>>>0|(!!k&(g|0)>=0|(g|0)>0)&(f|0)==(Z|0)){break ld}v[E+44>>2]=da;f=g>>31;n=f;i=f^k;f=i-f|0;n=(g^n)-((i>>>0<n>>>0)+n|0)|0}o=f;i=n;yc(E+8|0,v[E+28>>2]);f=v[ia>>2];ya=f+16|0;za=v[E+8>>2];Ff(d,h,ff(k,g,za-1|0),mb);n=mb;Aa=f>>>0>Z>>>0;if(!(!Aa&Z>>>0<ya>>>0)){b=b&-8193;v[I>>2]=b}qd:{rd:{la=v[E+20>>2];sd:{if(la){f=v[E+24>>2];if(f>>>0<=Z>>>0){td:{if((g|0)<0){k=0;g=f;break td}k=d;g=h;d=0;h=v[_>>2]}Wa=E,Xa=Go(Gg(Gg(d,h,k,g),mb,1,0),mb,o,i)+1|0,v[Wa+44>>2]=Xa;v[K+632>>2]=la;break qd}if(!(Aa|!(b&8192)|Z>>>0>=ya>>>0)){Wa=E,Xa=Go(Gg(Gg(0,m+16|0,d,h),mb,1,0),mb,o,i)+1|0,v[Wa+44>>2]=Xa;Wa=K,Xa=la+B(v[_>>2]-m|0,mk(x[v[ha>>2]+34>>1]))|0,v[Wa+632>>2]=Xa;break qd}if(!k&(g|0)<=0|(g|0)<0){break sd}if(da>>>0<2|f>>>0>n>>>0){break rd}Wa=E,Xa=Go(Gg(Gg(0,f,d,h),mb,1,0),mb,o,i)+1|0,v[Wa+44>>2]=Xa;break qd}if((g|0)>0|(g|0)>=0){break rd}}if((m|0)<=(n|0)){break qd}Wa=E,Xa=Go(Gg(Gg(d,h,0,m),mb,1,0),mb,o,i)+1|0,v[Wa+44>>2]=Xa;break qd}b=v[Q>>2];if((b|0)>(n|0)){break qd}Wa=E,Xa=Go(Gg(Gg(0,b,d,h),mb,1,0),mb,o,i)+1|0,v[Wa+44>>2]=Xa}Fo(E+44|0,1,za);g=v[E+44>>2];if((g|0)>0){break kd}}v[K+632>>2]=0;v[Q>>2]=0;v[l>>2]=0;v[l+4>>2]=0;v[X>>2]=0;bD(l,c,a);v[J>>2]=v[J>>2]+v[Y>>2];v[R>>2]=v[R>>2]+v[W>>2];v[W>>2]=0;v[Y>>2]=0;v[I>>2]=v[I>>2]&-129;break jd}ud:{vd:{if(Oa>>>0<y[e+24608>>2]){b=4;if(v[X>>2]){break vd}b=0;if(v[wa>>2]|v[xa>>2]){break vd}}Sb(l,Sia(v[N>>2],v[N+4>>2],g,g>>31),mb);M=0;v[W>>2]=0;v[Y>>2]=0;c=(g<<3)+c|0;break ud}d=(g<<3)+c|0;h=d-8|0;v[Y>>2]=0-v[h>>2];f=d-4|0;v[W>>2]=0-v[f>>2];nb[v[((b|Na)<<2)+27232>>2]](l,Ia,c,g);v[Y>>2]=v[Y>>2]+v[h>>2];v[W>>2]=v[W>>2]+v[f>>2];M=1;c=d}b=v[X>>2];wd:{if(!b){break wd}if(b>>>0<=g>>>0){v[X>>2]=0;v[xa>>2]=v[Va>>2];v[wa>>2]=v[Ua>>2];v[Ta>>2]=0;v[Sa>>2]=0;if(v[Ra>>2]|!(w[I+1|0]&16)){break wd}v[Q>>2]=0;v[K+632>>2]=0;break wd}v[X>>2]=b-g}n=0;h=0;b=v[l+4>>2];h=b>>>0>=y[_>>2]?(w[I|0]&2)>>>1|0:h;d=b;b=v[Q>>2];n=d>>>0<b>>>0|(!b|w[I|0]&2)?n:!x[Qa>>1];a=a-g|0;Bb(E+8|0,ta,85);xd:{yd:{zd:{Ad:{if(!Cb(v[v[E+8>>2]>>2],v[E+12>>2])){break Ad}b=w[Pa|0];if(!b|b>>>0>x[Ma>>1]){break Ad}b=B(b,104)+e|0;d=b+484380|0;g=v[ha>>2];if((d|0)==(g|0)|(h|n)!=1){break zd}v[ha>>2]=d;v[K+632>>2]=v[b+484400>>2];d=x[b+484414>>1];v[I>>2]=d|v[I>>2]&-768;g=d<<30>>31;d=v[b+484388>>2];v[Q>>2]=g&d;b=v[b+484384>>2];v[ia>>2]=b;v[_>>2]=d;v[l+4>>2]=b;aD(p,l);if(!v[K+632>>2]){break jd}if((a|0)>0){continue}break jd}if(h){break yd}break xd}if(!h|(d|0)!=(g|0)){break xd}}Bb(E+8|0,ta,83);if(!Cb(v[v[E+8>>2]>>2],v[E+12>>2])|v[ia>>2]){break xd}v[l>>2]=v[l>>2];v[l+4>>2]=0;b=v[v[ha>>2]+8>>2];v[Q>>2]=b;v[_>>2]=b}if((a|0)>0){continue}}break}v[K+632>>2]=v[p>>2];ga=M+ga|0;u[E+42>>1]=ga;if(va|!M){break fd}a=v[(B(ka,160)+e|0)+906140>>2];if(!a){break fd}nb[v[v[a>>2]+148>>2]](a)}ba=ba+1|0;continue}break}}jb=E+48|0;p=v[e+1298300>>2];if(xd(p)){a=$;b=j;c=(B(v[e+480232>>2],v[e+480236>>2])>>>0)/48|0;k=jb-16|0;jb=k;Bd:{if(!w[p+534|0]){break Bd}d=Sia(c,0,6169,0);c=mb;f=c>>>16|0;r=Vc((c&65535)<<16|d>>>16,f);while(1){if(!b){break Bd}f=v[p>>2];h=v[f>>2];c=v[f+4>>2];while(1){if((c|0)>=(h|0)){v[f+8>>2]=v[f+12>>2];h=0;l=0;n=0;c=jb-16|0;jb=c;while(1){if((n|0)==18){d=(h|0)<32767?h:32767;u[f+12>>1]=(d|0)>-32768?d:-32768;d=(l|0)<32767?l:32767;u[f+14>>1]=(d|0)>-32768?d:-32768;u[f+3832>>1]=x[f+3832>>1]+1;d=(x[f+3834>>1]+1>>>0)%13440|0;u[f+3834>>1]=d;d=d>>>0<6720?d:13440-d|0;u[f+3836>>1]=(d&65280)>>>8;if(!w[f+3843|0]){u[f+3836>>1]=(d&64512)>>>10}d=x[f+3838>>1]+1|0;u[f+3838>>1]=d;if((d&65535)>>>0>=1024){u[f+3838>>1]=0;u[f+3840>>1]=x[f+3840>>1]+1&7}jb=c+16|0}else{g=f+B(n,44)|0;Cd:{if(!w[g+56|0]){u[c+12>>1]=0;u[c+14>>1]=0;break Cd}m=v[g+32>>2];d=x[m+3840>>1];if(d&3){m=(x[g+36>>1]>>>7&7)>>>(w[m+3844|0]^1)>>>(d&1)<<x[g+38>>1];d=d&4?0-m|0:m}else{d=0}m=v[g+52>>2];Dd:{if(m){s=x[m+32>>1];q=x[g+48>>1];m=_f(v[g+16>>2],v[g+40>>2],d<<16>>16,0,u[g+46>>1]);o=v[g+40>>2];i=v[g+20>>2];if(!s){if(!q){d=d<<16>>16;m=_f(i,o,d,m,0);m=_f(v[g+24>>2],v[g+40>>2],d,m,0);d=_f(v[g+28>>2],v[g+40>>2],d,m,0);break Dd}d=d<<16>>16;o=_f(i,o,d,0,0);o=_f(v[g+24>>2],v[g+40>>2],d,o,0);d=_f(v[g+28>>2],v[g+40>>2],d,o,0)+m|0;break Dd}if(!q){d=d<<16>>16;m=_f(i,o,d,m,0);o=_f(v[g+24>>2],v[g+40>>2],d,0,0);d=_f(v[g+28>>2],v[g+40>>2],d,o,0)+m|0;break Dd}d=d<<16>>16;o=_f(i,o,d,0,0);d=(_f(v[g+24>>2],v[g+40>>2],d,o,0)+m|0)+_f(v[g+28>>2],v[g+40>>2],d,0,0)|0;break Dd}q=x[g+48>>1];d=d<<16>>16;m=_f(v[g+16>>2],v[g+40>>2],d,0,u[g+46>>1]);o=v[g+40>>2];i=v[g+20>>2];if(!q){d=_f(i,o,d,m,0);break Dd}d=_f(i,o,d,0,0)+m|0}u[c+14>>1]=w[g+57|0]?d:0;u[c+12>>1]=w[g+58|0]?d:0}n=n+1|0;l=u[c+12>>1]+l|0;h=u[c+14>>1]+h|0;continue}break}h=v[f>>2];c=v[f+4>>2]-h|0;v[f+4>>2]=c;continue}break}d=h-c|0;u[k+14>>1]=(B(u[f+12>>1],c)+B(d,u[f+8>>1])|0)/(h|0);u[k+12>>1]=(B(u[f+14>>1],c)+B(d,u[f+10>>1])|0)/(h|0);v[f+4>>2]=c+49716;v[a>>2]=v[a>>2]+B(r,u[k+14>>1]);v[a+4>>2]=v[a+4>>2]+B(r,u[k+12>>1]);a=a+8|0;b=b-1|0;continue}}jb=k+16|0}a=w[G+12|0];if(v[G+16>>2]?1:a){if(!a){Im(aa,j,sa,ra)}a=v[G>>2];b=v[G+80>>2];c=B(a,b)>>>4|0;c=c>>>0<32767?c:32767;u[G+98>>1]=c;u[G+96>>1]=c;c=v[G+49948>>2];d=B(c,a)>>>4|0;d=d>>>0<65536?d:65536;g=d+127>>>3|0;u[G+49946>>1]=g;d=d+255>>>4|0;u[G+49944>>1]=d;u[G+49942>>1]=d;u[G+49940>>1]=g;b=(b|0)>(c|0)?b:c;a=36-a>>>1|0;a=16-(a>>>0>8?a:8)|0;a=16-(B((b|0)<32768?b:32768,a>>>0>16?0:a)>>15)|0;n=0;while(1){if((j|0)!=(n|0)){b=n<<3;c=b+$|0;v[c>>2]=v[c>>2]+B(a,v[b+aa>>2]>>4);b=b|4;c=b+$|0;v[c>>2]=v[c>>2]+B(a,v[b+aa>>2]>>4);n=n+1|0;continue}break}m=G+68|0;k=0;b=u[G+84>>1];c=v[G+40>>2];h=v[G+36>>2];while(1){if((j|0)==(k|0)){v[G+40>>2]=c;v[G+36>>2]=h;g=j}else{a=(k<<3)+aa|0;d=v[a>>2]>>12;h=(B(b,d-h|0)>>15)+d|0;v[a>>2]=h;d=a;a=v[a+4>>2]>>12;c=(B(b,a-c|0)>>15)+a|0;v[d+4>>2]=c;k=k+1|0;continue}break}if(g){b=aa;a=g;s=v[m>>2]-1|0;o=x[m+22>>1];d=u[m+26>>1];i=u[m+18>>1];c=x[m+20>>1];h=u[m+24>>1];p=u[m+16>>1];n=v[m+4>>2];f=m+32928|0;while(1){if(a){k=gd(v[b>>2]);l=gd(v[b+4>>2]);c=gd((c<<16>>16)-k|0);o=gd((o<<16>>16)-l|0);c=Xc(gd((B(c,p)|0)/65536<<1)+k|0);o=Xc(gd((B(i,o)|0)/65536<<1)+l|0);l=f+(n<<2)|0;r=u[l>>1];k=Xc(((B(r,h)|0)/-65536|0)+c|0);n=n+1&127;q=f+(n<<2)|0;l=u[l+2>>1];A=Xc(((B(l,d)|0)/-65536|0)+o|0);u[q+2>>1]=A;u[q>>1]=k;s=s+1&8191;q=m+(s<<2)|0;Wa=q,Xa=Xc(r+((B(h,k)|0)/65536|0)|0),u[Wa+160>>1]=Xa;Wa=q,Xa=Xc(l+((B(d,A)|0)/65536|0)|0),u[Wa+162>>1]=Xa;b=b+8|0;a=a-1|0;continue}break}u[m+22>>1]=o;u[m+20>>1]=c;v[m+4>>2]=n}l=G+49892|0;H=G+33508|0;b=g;a=aa;while(1){if(b){d=v[G+76>>2];h=d&4095;o=H+(h<<2)|0;c=a;h=4096-h|0;A=d-v[G+49892>>2]&4095;d=4096-A|0;d=d>>>0>h>>>0?h:d;d=b>>>0<d>>>0?b:d;h=d>>>0<64?d:64;n=h;d=0;i=jb-32|0;jb=i;f=v[m>>2];while(1){if((d|0)==7){Ed:{r=u[m+28>>1]/8<<16>>16;Fd:while(1){if(!n){break Ed}n=n-1|0;d=0;k=0;f=0;while(1)if((d|0)==4){d=4;s=0;q=Xc((f|0)/32768|0);F=Xc((k|0)/32768|0);k=0;while(1)if((d|0)==7){d=Xc(q+((k|0)/32768|0)|0);u[o>>1]=d;v[c>>2]=B(d,r);d=Xc(F+((s|0)/32768|0)|0);u[o+2>>1]=d;v[c+4>>2]=B(d,r);c=c+8|0;o=o+4|0;continue Fd}else{f=i+(d<<2)|0;p=v[f>>2]+1&8191;v[f>>2]=p;p=m+(p<<2)|0;E=u[p+160>>1];f=m+(d<<4)|0;p=u[p+162>>1];s=(B(E,u[f+44>>1])+s|0)+B(p,u[f+46>>1])|0;k=(B(E,u[f+40>>1])+k|0)+B(p,u[f+42>>1])|0;d=d+1|0;continue}}else{p=i+(d<<2)|0;q=v[p>>2]+1&8191;v[p>>2]=q;F=k;k=m+(q<<2)|0;q=u[k+160>>1];p=m+(d<<4)|0;s=u[k+162>>1];k=(F+B(q,u[p+44>>1])|0)+B(s,u[p+46>>1])|0;f=(B(q,u[p+40>>1])+f|0)+B(s,u[p+42>>1])|0;d=d+1|0;continue}}}}else{v[i+(d<<2)>>2]=f+(v[(m+(d<<4)|0)+32>>2]^-1);d=d+1|0;continue}break}jb=i+32|0;n=H+(A<<2)|0;d=a;c=h;f=v[l+4>>2];k=l+8256|0;o=l- -64|0;i=l+24640|0;p=l+16448|0;while(1){r=f&2047;if(c){E=u[k+((f+1206&2047)<<2)>>1];J=u[(k+((f+754&2047)<<2)|0)+2>>1];F=u[(o+((f+1602&2047)<<2)|0)+2>>1];I=u[o+((f+1750&2047)<<2)>>1];q=u[n>>1];s=u[n+2>>1];A=i+((f+502&2047)<<2)|0;M=u[A>>1];N=gd(u[l+32>>1]-M|0);A=u[A+2>>1];K=gd(u[l+34>>1]-A|0);Q=u[l+26>>1];R=i+((f+22&2047)<<2)|0;W=u[R>>1];Y=gd(u[l+36>>1]-W|0);_=u[l+28>>1];R=u[R+2>>1];X=gd(u[l+38>>1]-R|0);Z=u[l+30>>1];M=Xc(gd((B(N,u[l+24>>1])|0)/65536<<1)+M|0);u[l+32>>1]=M;Wa=l,Xa=Xc(gd((B(K,Q)|0)/65536<<1)+A|0),u[Wa+34>>1]=Xa;Wa=l,Xa=Xc(gd((B(Y,_)|0)/65536<<1)+W|0),u[Wa+36>>1]=Xa;A=Xc(gd((B(X,Z)|0)/65536<<1)+R|0);u[l+38>>1]=A;M=gd((B(M,u[l+16>>1])|0)/32768|0);A=gd((B(A,u[l+22>>1])|0)/32768|0);M=gd(M+((q|0)/4<<16>>16)|0);N=gd(A+((s|0)/4<<16>>16)|0);q=u[l+8>>1];K=gd(M+((B(q,I)|0)/-65536|0)|0);s=r<<2;Q=s+o|0;A=u[l+10>>1];R=gd(N+((B(A,F)|0)/-65536|0)|0);u[Q+2>>1]=R;u[Q>>1]=K;I=gd(I+((B(q,K)|0)/65536|0)|0);K=p+s|0;F=gd(F+((B(A,R)|0)/65536|0)|0);u[K+2>>1]=F;u[K>>1]=I;I=gd(I+M|0);M=gd(F+N|0);F=p+((f+682&2047)<<2)|0;N=u[F+2>>1];K=u[F>>1];F=gd((B(N,u[l+42>>1])+B(K,u[l+40>>1])|0)/32768|0);f=p+((f+426&2047)<<2)|0;Q=u[f+2>>1];R=u[f>>1];f=gd((B(Q,u[l+46>>1])+B(R,u[l+44>>1])|0)/32768|0);K=gd(gd(I+K|0)-F|0);N=gd(gd(M+N|0)-f|0);I=gd(gd(I+R|0)-F|0);M=gd(gd(M+Q|0)-f|0);F=gd(F+((B(q,E)|0)/-65536|0)|0);Q=k+s|0;R=gd(f+((B(A,J)|0)/-65536|0)|0);u[Q+2>>1]=R;u[Q>>1]=F;q=(B(q,F)|0)/65536|0;f=gd(q+E|0);s=i+s|0;A=(B(A,R)|0)/65536|0;F=gd(A+J|0);u[s+2>>1]=F;u[s>>1]=f;Wa=d,Xa=(v[d>>2]+B(gd(f+K|0),u[l+48>>1])|0)+B(gd(F+N|0),u[l+50>>1])|0,v[Wa>>2]=Xa;Wa=d,Xa=(v[d+4>>2]+B(gd(gd(q)+I|0),u[l+52>>1])|0)+B(gd(gd(A)+M|0),u[l+54>>1])|0,v[Wa+4>>2]=Xa;d=d+8|0;f=r+1|0;n=n+4|0;c=c-1|0;continue}break}v[l+4>>2]=r;v[G+76>>2]=h+v[G+76>>2]&4095;v[G+68>>2]=h+v[G+68>>2]&8191;b=b-h|0;a=(h<<3)+a|0;continue}break}v[G+68>>2]=v[G+68>>2]&8191;k=aa;d=$;c=g;h=0;f=0;l=v[G+56>>2];b=v[G- -64>>2];n=v[G+52>>2];a=v[G+60>>2];while(1){if(c){h=v[k>>2];f=v[k+4>>2];b=b-f|0;b=(((b|0)/1024|0)-b|0)+l|0;v[d+4>>2]=b+v[d+4>>2];a=a-h|0;a=(((a|0)/1024|0)-a|0)+n|0;v[d>>2]=a+v[d>>2];l=b+((b|0)/-512|0)|0;n=a+((a|0)/-512|0)|0;d=d+8|0;k=k+8|0;c=c-1|0;a=h;b=f;continue}break}v[G+64>>2]=f;v[G+60>>2]=h;v[G+56>>2]=l;v[G+52>>2]=n;a=v[G+20>>2];Gd:{if(w[G+12|0]){break Gd}a=v[G+16>>2];if(a>>>0>g>>>0){a=a-g|0;break Gd}hK(G,sa,ra);a=0}t[G+12|0]=0;v[G+16>>2]=a}if(v[e+946300>>2]){Hd:{f=0;d=0;g=j<<2;o=x[e+480214>>1]!=0;Ba=z[e+1074336>>2];V=z[e+1074332>>2];while(1)if((f|0)==250){h=e+12|0;n=e+12300|0;m=e+14348|0;fv(h,n,m,j,V);a=e+1074476|0;s=w[a|0];t[a|0]=0;a=m;c=n;while(1){Id:{Jd:{Kd:{if((d|0)!=250){i=(B(d,160)+e|0)+906300|0;k=v[i>>2];if(!k|!v[k+24>>2]){break Id}if(!Vh(k+44|0)){break Id}l=k;Ld:{if(ev(w[i+24|0])){break Ld}b=nb[v[v[k>>2]+144>>2]](k)|0;l=v[i>>2];if(b){break Ld}f=0;if(w[l+28|0]&2){break Ld}while(1){if((d|0)==(f|0)){break Id}b=B(f,160);f=f+1|0;if((Gm(v[(b+e|0)+906328>>2])|0)!=(d|0)){continue}break}}b=v[k+44>>2];p=Fc(b,0);q=Fc(b,1);r=(c|0)==(p|0);c=r?n:c;b=c;a=r?m:a;f=v[i+28>>2];g=a;Md:{if(!f){break Md}b=c;f=Gm(f);g=a;if(f>>>0<=d>>>0){break Md}g=a;if(f>>>0>249){break Md}f=v[(B(f,160)+e|0)+906300>>2];g=a;if(!f){break Md}if(!(w[l+28|0]&4)){nb[v[v[f>>2]+148>>2]](f)}g=a;if(!Vh(f+44|0)){break Md}g=v[f+44>>2];b=Fc(g,0);g=Fc(g,1)}if(!ev(w[i+24|0])){break Jd}f=0;Nd:{if(r){break Nd}while(1){if((f|0)==(j|0)){break Nd}r=f<<2;A=r+p|0;F=c+r|0;z[A>>2]=z[F>>2]+z[A>>2];A=q+r|0;r=a+r|0;z[A>>2]=z[r>>2]+z[A>>2];v[F>>2]=0;v[r>>2]=0;f=f+1|0;continue}}a=g;c=b;if(!(o&1)){break Jd}a=v[i>>2];if(a){nb[v[v[a>>2]+148>>2]](a)}f=Gm(v[i+28>>2]);a=d;while(1){c=f;f=c&255;if(f>>>0>249|f>>>0<=(a&255)>>>0){break Kd}r=B(f,160)+e|0;f=Gm(v[r+906328>>2]);a=c;c=v[r+906300>>2];if(!c){continue}nb[v[v[c>>2]+148>>2]](c);continue}}b=0;while(1){if((b|0)!=(j|0)){V=C(z[c>>2]*Ba);Od:{if(C(D(V))<C(2147483648)){d=~~V;break Od}d=-2147483648}v[h>>2]=d;V=C(z[a>>2]*Ba);Pd:{if(C(D(V))<C(2147483648)){d=~~V;break Pd}d=-2147483648}v[h+4>>2]=d;b=b+1|0;h=h+8|0;a=a+4|0;c=c+4|0;continue}break}break Hd}a=g;c=b}f=0;Qd:{Rd:{r=w[i+24|0];if(!((r&2)>>>1|0)){if(!ZC(r)|!(w[l+28|0]&4)){break Rd}}while(1){if((f|0)==(j|0)){break Qd}k=f<<2;i=k+b|0;z[i>>2]=z[k+p>>2]+z[i>>2];i=g+k|0;z[i>>2]=z[k+q>>2]+z[i>>2];f=f+1|0;continue}}if(s){nb[v[v[k>>2]+128>>2]](k)}nb[v[v[k>>2]+60>>2]](k,b,g,j);v[l+32>>2]=j+v[l+32>>2];if(!ZC(w[i+24|0])){break Qd}if((nb[v[v[k>>2]+156>>2]](k)|0)<=0|y[l+32>>2]<v[e+24620>>2]<<2>>>0){break Qd}Sd:{while(1){if((f|0)==(j|0)){break Sd}k=f<<2;V=z[k+b>>2];Td:{if(V>=C(1.1920928955078125e-7)|V<=C(-1.1920928955078125e-7)){break Td}V=z[g+k>>2];if(V>=C(1.1920928955078125e-7)){break Td}f=f+1|0;if(!(V<=C(-1.1920928955078125e-7))){continue}}break}v[l+32>>2]=0;break Qd}v[l+28>>2]=v[l+28>>2]|4}v[l+28>>2]=v[l+28>>2]&-3}d=d+1|0;continue}}else{h=(B(f,160)+e|0)+906300|0;a=v[h>>2];Ud:{if(!a|!v[a+24>>2]){break Ud}if(!Vh(a+44|0)){break Ud}if(!(nb[v[v[a>>2]+112>>2]](a)|0)){nb[v[v[a>>2]+108>>2]](a,1);nb[v[v[a>>2]+120>>2]](a)}c=v[a+44>>2];b=Fc(c,0);c=Fc(c,1);Vd:{if(t[a+28|0]&1){fv(v[a+24>>2],b,c,j,V);break Vd}k=a+40|0;if(v[a+36>>2]?1:v[k>>2]){Im(v[a+24>>2],j,k,a+36|0);fv(v[a+24>>2],b,c,j,V);break Vd}Xb(b,0,g);Xb(c,0,g)}b=a;a=v[a+28>>2];v[b+28>>2]=a&-2;if(ev(w[h+24|0])){break Ud}o=!(a&4)|o}f=f+1|0;continue}}}if(v[e+24624>>2]==1){b=0;while(1){if((b|0)!=(j|0)){a=(b<<3)+$|0;v[(b<<2)+$>>2]=(v[a+4>>2]+v[a>>2]|0)/2;b=b+1|0;continue}break}}if(Rd(w[Ha|0])){c=0;g=jb-16|0;jb=g;Wd:{if(!v[e+1074376>>2]){k=e+1074460|0;a=k;v[a>>2]=0;v[a+4>>2]=0;a=v[e+1074456>>2];v[e+1074468>>2]=a;break Wd}a=v[e+1074456>>2];b=v[e+1074468>>2];Xd:{if((a|0)==(b|0)){d=v[e+1074460>>2];break Xd}v[e+1074468>>2]=a;d=v[e+24620>>2];h=e+1074460|0;Yd:{if((a|0)>(b|0)){d=pt(d,v[e+24636>>2]);break Yd}d=pt(d,v[e+24640>>2])}v[h>>2]=d;v[e+1074464>>2]=d;b=a}k=e+1074460|0;if((d|0)<=0){break Wd}b=(b<<12)-v[e+1074472>>2]|0;c=(b|0)/(d|0)|0;if(w[e+1074368|0]!=2){break Wd}v[g+12>>2]=50;h=v[e+1074464>>2];v[g+8>>2]=1e4/(h+1|0);f=v[Ne(g+12|0,g+8|0)>>2];while(1){l=c>>31;if((f|0)>=((l^c)-l|0)){break Wd}d=d+h|0;v[k>>2]=d;c=(b|0)/(d|0)|0;continue}}Zd:{_d:{switch(v[e+24624>>2]-1|0){case 0:b=0;f=(j|0)>0?j:0;l=a<<12;d=e+12|0;n=a>>31;while(1){if((b|0)==(f|0)){break Zd}$d:{if(v[k>>2]>0){h=v[e+1074472>>2]+c|0;v[e+1074472>>2]=h;m=v[d>>2];Wa=d,Xa=Ic(Tia(Sia(m,m>>31,h,h>>31),mb,1048576,0),mb),v[Wa>>2]=Xa;v[e+1074460>>2]=v[e+1074460>>2]-1;break $d}h=v[d>>2];Wa=d,Xa=Ic(Tia(Sia(h,h>>31,a,n),mb,256,0),mb),v[Wa>>2]=Xa;v[e+1074472>>2]=l}b=b+1|0;d=d+4|0;continue};case 1:b=0;l=(j|0)>0?j:0;n=a<<12;d=e+12|0;h=a>>31;while(1){if((b|0)==(l|0)){break Zd}ae:{if(v[k>>2]>0){f=v[e+1074472>>2]+c|0;v[e+1074472>>2]=f;m=v[d>>2];Wa=d,Xa=Ic(Tia(Sia(m,m>>31,f,f>>31),mb,1048576,0),mb),v[Wa>>2]=Xa;f=v[e+1074472>>2];o=f;m=f>>31;f=v[d+4>>2];Wa=d,Xa=Ic(Tia(Sia(o,m,f,f>>31),mb,1048576,0),mb),v[Wa+4>>2]=Xa;v[e+1074460>>2]=v[e+1074460>>2]-1;break ae}f=v[d>>2];Wa=d,Xa=Ic(Tia(Sia(f,f>>31,a,h),mb,256,0),mb),v[Wa>>2]=Xa;f=v[d+4>>2];Wa=d,Xa=Ic(Tia(Sia(f,f>>31,a,h),mb,256,0),mb),v[Wa+4>>2]=Xa;v[e+1074472>>2]=n}b=b+1|0;d=d+8|0;continue};case 3:break _d;default:break Zd}}f=0;n=(j|0)>0?j:0;m=a<<12;d=e+8204|0;b=e+12|0;h=a>>31;while(1){if((f|0)==(n|0)){break Zd}be:{if(v[k>>2]>0){l=v[e+1074472>>2]+c|0;v[e+1074472>>2]=l;o=v[b>>2];Wa=b,Xa=Ic(Tia(Sia(o,o>>31,l,l>>31),mb,1048576,0),mb),v[Wa>>2]=Xa;l=v[e+1074472>>2];o=l;i=l>>31;l=v[b+4>>2];Wa=b,Xa=Ic(Tia(Sia(o,i,l,l>>31),mb,1048576,0),mb),v[Wa+4>>2]=Xa;l=v[e+1074472>>2];o=l;i=l>>31;l=v[d>>2];Wa=d,Xa=Ic(Tia(Sia(o,i,l,l>>31),mb,1048576,0),mb),v[Wa>>2]=Xa;l=v[e+1074472>>2];o=l;i=l>>31;l=v[d+4>>2];Wa=d,Xa=Ic(Tia(Sia(o,i,l,l>>31),mb,1048576,0),mb),v[Wa+4>>2]=Xa;v[e+1074460>>2]=v[e+1074460>>2]-1;break be}l=v[b>>2];Wa=b,Xa=Ic(Tia(Sia(l,l>>31,a,h),mb,256,0),mb),v[Wa>>2]=Xa;l=v[b+4>>2];Wa=b,Xa=Ic(Tia(Sia(l,l>>31,a,h),mb,256,0),mb),v[Wa+4>>2]=Xa;l=v[d>>2];Wa=d,Xa=Ic(Tia(Sia(l,l>>31,a,h),mb,256,0),mb),v[Wa>>2]=Xa;l=v[d+4>>2];Wa=d,Xa=Ic(Tia(Sia(l,l>>31,a,h),mb,256,0),mb),v[Wa+4>>2]=Xa;v[e+1074472>>2]=m}f=f+1|0;d=d+8|0;b=b+8|0;continue}}jb=g+16|0}if(v[pa>>2]!=128){b=e+12|0;c=e+8204|0;a=v[e+24604>>2];d=v[e+24624>>2];ce:{if((a|0)==128|d>>>0<2){break ce}UL(b,j,a);if(d>>>0<4){break ce}UL(c,j,a)}}if(v[e+24624>>2]==4){a=j;while(1){a=a-1|0;if((a|0)>=0){b=(a<<4)+$|0;c=a<<3;d=c|4;v[b+12>>2]=v[d+qa>>2];v[b+8>>2]=v[c+qa>>2];v[b+4>>2]=v[d+$>>2];v[b>>2]=v[c+$>>2];continue}break}}if(Rd(Da)){a=Wg(T- -64|0,$,v[e+24624>>2],j);b=v[v[na>>2]+8>>2];v[T+24>>2]=v[a+8>>2];c=v[a+4>>2];v[T+16>>2]=v[a>>2];v[T+20>>2]=c;nb[b|0](na,T+16|0)}a=Wg(T+48|0,$,v[e+24624>>2],j);b=v[v[ma>>2]+8>>2];v[T+8>>2]=v[a+8>>2];c=v[a+4>>2];v[T>>2]=v[a>>2];v[T+4>>2]=c;nb[b|0](ma,T);v[e+1074380>>2]=v[e+1074380>>2]-j;v[e+1074376>>2]=j+v[e+1074376>>2];fa=fa-j|0;Ca=j+Ca|0;continue}break}jb=ca+32|0;return Ca}function lg(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,m=0,o=0,p=0,r=0,s=0,E=C(0),F=0,G=0,H=C(0),I=0,J=0,K=0,M=0,N=0;k=jb-2288|0;jb=k;a:{b:{c:{d:{e:{f:{if(hv(v[c>>2])){yc(b,268435456);J=v[c+8>>2];G=k+2264|0;e=G;v[e>>2]=0;v[e+4>>2]=0;Qb(e+8|0);v[k+2260>>2]=0;g:{h:{i:{j:{k:{l:{e=w[a+3|0];m:{n:{if((e-4&255)>>>0<=4){v[23296]=0;d=T(190,c|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break l}v[k+2260>>2]=d;break n}if(e>>>0>17){break m}o:{g=1<<e;if(!(g&63503)){if(!(g&198144)){break m}break o}if(w[a|0]){break o}break n}e=0;f=QA(a,v[b>>2]);v[23296]=0;U(191,k+96|0,c|0,f|0);f=v[23296];v[23296]=0;if((f|0)==1){break k}d=k+96|0;f=v[d+4>>2];v[G>>2]=v[d>>2];v[G+4>>2]=f;pm(G+8|0,d+8|0);Pc(d);f=ye(G);d=v[G>>2];v[k+2260>>2]=d;if(!f){break g}}e=w[a+3|0]}h=1;p:{q:{switch(e&255){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:h=!w[a|0];break p;case 9:case 10:case 16:case 17:break q;default:break p}}h=0}g=v[b>>2];if(!(g>>>0<262145|h)){e=e&255;v[k+96>>2]=((e|0)==10)<<4;h=d-v[Ib(k+96|0,k+2260|0)>>2]|0;if(e>>>0>15){break j}r:{if(!(1<<e&63503)){if((e|0)==10){break r}break j}if(!(w[a|0]&7)){break j}}e=(h|0)>=0?h<<1:-1;break i}e=e&255;if(e>>>0>8){break h}if(!(1<<e&432)){if((e|0)!=6){break h}e=0;if(d>>>0<10){break g}v[23296]=0;Q(176,c|0,4)|0;d=v[23296];v[23296]=0;if((d|0)==1){break l}v[23296]=0;e=T(145,c|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){v[k+96>>2]=e;v[k+72>>2]=v[k+2260>>2];d=v[Ib(k+96|0,k+72|0)>>2];ng(c,8);e=((d>>>0>50529027?-1:B(d,85))>>>0)/(w[a|0]>>>3>>>0)|0;break i}a=P()|0;O()|0;break a}e=8/(cq(w[a+1|0])>>>0)|0;Sia(e,0,d,0);e=mb?-1:B(e,d);break i}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}g=0;d=cq(w[a+1|0]);s:{t:{switch(e|0){case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:g=w[a|0];break s;case 9:g=16;break s;case 10:g=4;break s;case 16:case 17:break t;default:break s}}g=8}e=B(d,g&255)>>>3|0;d=(e+h|0)-1|0;e=((d>>>0<h>>>0?-1:d)>>>0)/(e>>>0)|0}yc(b,e);g=v[b>>2]}if(!g){e=0;break g}u[b+34>>1]=x[b+34>>1]&65470|w[a|0]>15|(w[a+1|0]!=1)<<6;if(!Bg(b)){e=0;v[b>>2]=0;break g}u:{if(fe(a,_c(k+96|0,8,1,0,10))){v[23296]=0;d=Q(192,c|0,k+96|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){e=0;if(!d){break u}a=v[b>>2];d=0;v[23296]=0;v[k+72>>2]=a+1>>>1;e=T(190,c|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break b}yc(k+72|0,e);a=f+16|0;b=v[b+20>>2];h=v[k+72>>2];e=h;while(1)if(e){g=k+96|0;f=d+w[g|w[a|0]&15]|0;t[b|0]=f;d=w[g|w[a|0]>>>4]+(f&255)|0;t[b+1|0]=d;e=e-1|0;a=a+1|0;b=b+2|0;continue}else{e=h+16|0;break u}}a=P()|0;O()|0;break a}v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{g=w[a+3|0];switch(g-4|0){case 3:break D;case 4:break E;case 5:break F;case 2:break G;case 0:case 1:break H;default:break B}}v[23296]=0;b=fa(193,k+1168|0,c|0,b|0,(g|0)==5|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break f}Ab(b);e=v[c+8>>2]-J|0;break u}if(w[a+1|0]!=1){break C}v[23296]=0;Q(176,c|0,4)|0;a=v[23296];v[23296]=0;if((a|0)==1){break f}v[23296]=0;f=T(145,c|0)|0;a=v[23296];v[23296]=0;I:{J:{K:{if((a|0)!=1){v[23296]=0;v[k+72>>2]=f;h=T(194,c|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break K}v[23296]=0;U(195,k+96|0,c|0,f|0);a=v[23296];v[23296]=0;if((a|0)==1){break I}yc(k+72|0,v[k+96>>2]);g=v[k+72>>2];e=ye(k+96|0);d=x[b+34>>1];f=v[b+20>>2];b=v[b>>2];a=v[k+96>>2];v[23296]=0;da(196,e|0,a|0,f|0,uj(b,d)|0,h<<24>>24);a=v[23296];v[23296]=0;if((a|0)!=1){break J}a=P()|0;O()|0;Pc(k+96|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}e=g+9|0;Pc(k+96|0);break u}a=P()|0;O()|0;break a}if(w[a+1|0]!=1|w[a|0]!=16){break C}e=v[k+2260>>2];d=Yl(k+1160|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];h=jb-16|0;jb=h;v[h+12>>2]=e>>>1;v[h+8>>2]=a;d=v[Ib(h+12|0,h+8|0)>>2];e=d;while(1){if(e){a=w[f|0]+g|0;g=a+w[f+1|0]|0;u[b>>1]=g<<8|a&255;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}jb=h+16|0;e=d<<1;break u}if(w[a+1|0]!=1|w[a|0]>16){break C}d=v[c+8>>2];f=v[c>>2];e=0;v[23296]=0;d=W(144,f|0,d|0,8)|0;f=v[23296];v[23296]=0;if((f|0)==1){break f}if(!d){break u}v[23296]=0;d=T(145,c|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break f}v[k+2260>>2]=d;if(d>>>0<4){break u}v[23296]=0;U(178,k+72|0,c|0,d|0);f=v[23296];v[23296]=0;if((f|0)==1){break c}f=k+72|0;s=fr(k+96|0,f);Ab(f);f=v[s>>2];v[23296]=0;d=T(197,f|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break e}e=d+4|0;p=w[a|0];m=(p|0)!=16;g=0;h=0;while(1){if(y[b>>2]<=h>>>0){break w}L:{if(m){break L}v[23296]=0;r=Q(152,s|0,8)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break L}a=V(30320)|0;break x}v[23296]=0;i=Q(152,s|0,1)|0;a=v[23296];v[23296]=0;if((a|0)==1){break y}v[23296]=0;f=Q(152,s|0,1)|0;a=v[23296];v[23296]=0;if((a|0)==1){break y}M:{N:{O:{if(!f){f=8;while(1){v[23296]=0;d=Q(152,s|0,1)|0;a=v[23296];v[23296]=0;if((a|0)==1){break M}if(d){break O}f=f+16|0;continue}}v[23296]=0;a=Q(152,s|0,3)|0;f=v[23296];v[23296]=0;if((f|0)!=1){break N}break y}v[23296]=0;d=Q(152,s|0,4)|0;a=v[23296];v[23296]=0;if((a|0)==1){break y}a=f+d|0}g=(g&255)+(((i?-1:0)^a)&255)|0;P:{if((p|0)!=16){t[v[b+20>>2]+h|0]=g;break P}u[v[b+20>>2]+(h<<1)>>1]=r&255|g<<8}h=h+1|0;continue}break}a=V(30320)|0;break x}if(w[a+1|0]!=1){break B}break A}if((g|0)!=7){break B}if(w[a+1|0]==1){break A}}e=w[a|0];break z}e=w[a|0];if(e>>>0>16){break z}e=0;if(y[k+2260>>2]<5){break u}d=x[b+34>>1];f=v[b+20>>2];a=v[b>>2];v[23296]=0;e=W(198,c|0,f|0,uj(a,d)|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break u}break f}Q:{if((g&254)!=16|(e&255)!=16){break Q}d=w[a+1|0];if((d-1&255)>>>0>1){break Q}K=k,M=B(v[b>>2],cq(d)),v[K+96>>2]=M;yc(k+96|0,v[k+2260>>2]);a=v[b+20>>2];e=v[k+96>>2];if((g|0)==16){b=e;while(1){if(!b){break u}K=a,M=x[dc(30352,w[f|0])>>1],u[K>>1]=M;a=a+2|0;f=f+1|0;b=b-1|0;continue}}b=e;while(1){if(!b){break u}K=a,M=x[dc(30864,w[f|0])>>1],u[K>>1]=M;a=a+2|0;f=f+1|0;b=b-1|0;continue}}d=(e&255)!=8;if(!(d|w[a+1|0]!=1)){R:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2];v[d+8>>2]=a;a=v[Ib(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0];b=b+1|0;f=f+1|0;e=e-1|0;continue}break};jb=d+16|0;e=a;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2];v[d+8>>2]=a;a=v[Ib(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0]^128;b=b+1|0;f=f+1|0;e=e-1|0;continue}break};jb=d+16|0;e=a;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break R}}e=v[k+2260>>2];d=Uy(k- -64|0);a=v[b>>2];b=v[b+20>>2];g=w[d|0];d=jb-16|0;jb=d;v[d+12>>2]=e;v[d+8>>2]=a;a=v[Ib(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=w[f|0]+g|0;t[b|0]=g;b=b+1|0;f=f+1|0;e=e-1|0;continue}break}jb=d+16|0;e=a;break u}if(!(w[a+1|0]!=3|d)){S:{switch(g|0){case 0:i=jb-16|0;jb=i;e=v[k+2260>>2];v[i+12>>2]=e;d=v[b>>2];v[i+8>>2]=d;a=i+8|0;g=v[Ib(a,i+12|0)>>2];v[i+8>>2]=d;v[i+4>>2]=e-g;e=v[Ib(a,i+4|0)>>2];h=v[b+20>>2];a=g;d=f;while(1){if(a){t[h|0]=w[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=v[b+20>>2]+1|0;d=v[b>>2]+f|0;a=e;while(1){if(a){t[h|0]=w[d|0];h=h+2|0;d=d+1|0;a=a-1|0;continue}break};jb=i+16|0;e=e+g|0;break u;case 1:i=jb-16|0;jb=i;e=v[k+2260>>2];v[i+12>>2]=e;d=v[b>>2];v[i+8>>2]=d;a=i+8|0;g=v[Ib(a,i+12|0)>>2];v[i+8>>2]=d;v[i+4>>2]=e-g;e=v[Ib(a,i+4|0)>>2];h=v[b+20>>2];a=g;d=f;while(1){if(a){t[h|0]=w[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};h=v[b+20>>2]+1|0;d=v[b>>2]+f|0;a=e;while(1){if(a){t[h|0]=w[d|0]^128;h=h+2|0;d=d+1|0;a=a-1|0;continue}break};jb=i+16|0;e=e+g|0;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break S}}h=v[k+2260>>2];e=w[Uy(k+56|0)|0];p=jb-16|0;jb=p;v[p+12>>2]=h;g=v[b>>2];v[p+8>>2]=g;d=p+8|0;i=v[Ib(d,p+12|0)>>2];v[p+8>>2]=g;v[p+4>>2]=h-i;h=v[Ib(d,p+4|0)>>2];m=b;r=v[b+20>>2];d=e;b=i;g=f;while(1){if(b){d=w[g|0]+d|0;t[r|0]=d;r=r+2|0;g=g+1|0;b=b-1|0;continue}break}r=v[m+20>>2]+1|0;g=v[m>>2]+f|0;b=h;while(1){if(b){e=w[g|0]+e|0;t[r|0]=e;r=r+2|0;g=g+1|0;b=b-1|0;continue}break}jb=p+16|0;e=h+i|0;if(w[a+3|0]!=11){break u}a=v[m+20>>2];b=a+(v[m>>2]<<1)|0;while(1){if(a>>>0>=b>>>0){break u}t[a+1|0]=w[a+1|0]+w[a|0];a=a+2|0;continue}}d=e&255;if(!((d|0)!=8|w[a+1|0]!=2)){e=0;T:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2]>>>1;v[d+8>>2]=a;a=v[Ib(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0];t[b+1|0]=w[f+1|0];b=b+2|0;f=f+2|0;e=e-1|0;continue}break};jb=d+16|0;e=a<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2]>>>1;v[d+8>>2]=a;a=v[Ib(d+12|0,d+8|0)>>2];e=a;while(1){if(e){t[b|0]=w[f|0]^128;t[b+1|0]=w[f+1|0]^128;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};jb=d+16|0;e=a<<1;break u;case 2:break T;default:break u}}e=v[k+2260>>2];a=Uy(k+48|0);d=v[b>>2];g=v[b+20>>2];a=w[a|0];h=jb-16|0;jb=h;v[h+12>>2]=e>>>1;v[h+8>>2]=d;b=a;e=v[Ib(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=w[f|0]+a|0;t[g|0]=a;b=w[f+1|0]+b|0;t[g+1|0]=b;g=g+2|0;f=f+2|0;d=d-1|0;continue}break}jb=h+16|0;e=e<<1;break u}if(!(w[a+2|0]|((d|0)!=16|w[a+1|0]!=1))){U:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2]>>>1;v[d+8>>2]=a;a=v[Ib(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=w[f|0]|w[f+1|0]<<8;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};jb=d+16|0;e=a<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2]>>>1;v[d+8>>2]=a;a=v[Ib(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=(w[f|0]|w[f+1|0]<<8)^32768;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};jb=d+16|0;e=a<<1;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break U}}e=v[k+2260>>2];d=Yl(k+40|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];d=jb-16|0;jb=d;v[d+12>>2]=e>>>1;v[d+8>>2]=a;a=v[Ib(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=(w[f|0]+g|0)+(w[f+1|0]<<8)|0;u[b>>1]=g;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}jb=d+16|0;e=a<<1;break u}d=e&255;if(!((d|0)!=16|w[a+1|0]!=1|w[a+2|0]!=1)){e=0;V:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];g=jb-16|0;jb=g;v[g+12>>2]=v[k+2260>>2]>>>1;v[g+8>>2]=a;d=v[Ib(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=a<<8|a>>>8;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};jb=g+16|0;e=d<<1;break u;case 1:a=v[b>>2];b=v[b+20>>2];g=jb-16|0;jb=g;v[g+12>>2]=v[k+2260>>2]>>>1;v[g+8>>2]=a;d=v[Ib(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=(a<<8|a>>>8)^32768;b=b+2|0;f=f+2|0;e=e-1|0;continue}break};jb=g+16|0;e=d<<1;break u;case 2:break V;default:break u}}e=v[k+2260>>2];d=Yl(k+32|0);a=v[b>>2];b=v[b+20>>2];g=x[d>>1];d=jb-16|0;jb=d;v[d+12>>2]=e>>>1;v[d+8>>2]=a;a=v[Ib(d+12|0,d+8|0)>>2];e=a;while(1){if(e){g=(w[f+1|0]+g|0)+(w[f|0]<<8)|0;u[b>>1]=g;b=b+2|0;f=f+2|0;e=e-1|0;continue}break}jb=d+16|0;e=a<<1;break u}h=a;if(!(w[a+2|0]|((d|0)!=16|w[a+1|0]!=3))){W:{switch(g|0){case 0:m=jb-16|0;jb=m;d=v[k+2260>>2];v[m+12>>2]=d;i=v[b>>2]<<1;v[m+8>>2]=i;a=m+8|0;g=v[Ib(a,m+12|0)>>2];v[m+8>>2]=i;v[m+4>>2]=d-g;a=v[Ib(a,m+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){u[e>>1]=w[d|0]|w[d+1|0]<<8;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+i|0;d=v[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){u[d>>1]=w[e|0]|w[e+1|0]<<8;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};jb=m+16|0;e=a+h<<1;break u;case 1:m=jb-16|0;jb=m;d=v[k+2260>>2];v[m+12>>2]=d;i=v[b>>2]<<1;v[m+8>>2]=i;a=m+8|0;g=v[Ib(a,m+12|0)>>2];v[m+8>>2]=i;v[m+4>>2]=d-g;a=v[Ib(a,m+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){u[e>>1]=(w[d|0]|w[d+1|0]<<8)^32768;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+i|0;d=v[b+20>>2]+2|0;a=a>>>1|0;g=a;while(1){if(g){u[d>>1]=(w[e|0]|w[e+1|0]<<8)^32768;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};jb=m+16|0;e=a+h<<1;break u;default:e=0;if((g|0)!=11){break u}break;case 2:break W}}g=v[k+2260>>2];a=x[Yl(k+24|0)>>1];s=jb-16|0;jb=s;v[s+12>>2]=g;p=v[b>>2]<<1;v[s+8>>2]=p;d=s+8|0;e=v[Ib(d,s+12|0)>>2];v[s+8>>2]=p;v[s+4>>2]=g-e;m=v[Ib(d,s+4|0)>>2];g=b;d=v[g+20>>2];b=a;i=e>>>1|0;r=i;e=f;while(1){if(r){b=(w[e|0]+b|0)+(w[e+1|0]<<8)|0;u[d>>1]=b;d=d+4|0;e=e+2|0;r=r-1|0;continue}break}e=f+p|0;d=v[g+20>>2]+2|0;b=m>>>1|0;r=b;while(1){if(r){a=(w[e|0]+a|0)+(w[e+1|0]<<8)|0;u[d>>1]=a;d=d+4|0;e=e+2|0;r=r-1|0;continue}break}jb=s+16|0;e=b+i<<1;if(w[h+3|0]!=11){break u}a=v[g+20>>2];b=a+(v[g>>2]<<2)|0;while(1){if(a>>>0>=b>>>0){break u}u[a+2>>1]=x[a+2>>1]+x[a>>1];a=a+4|0;continue}}a=e&255;if(!((a|0)!=16|w[h+1|0]!=3|w[h+2|0]!=1)){e=0;X:{switch(g|0){case 0:p=jb-16|0;jb=p;d=v[k+2260>>2];v[p+12>>2]=d;m=v[b>>2]<<1;v[p+8>>2]=m;a=p+8|0;g=v[Ib(a,p+12|0)>>2];v[p+8>>2]=m;v[p+4>>2]=d-g;i=v[Ib(a,p+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){a=w[d|0]|w[d+1|0]<<8;u[e>>1]=a<<8|a>>>8;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+m|0;d=v[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=w[e|0]|w[e+1|0]<<8;u[d>>1]=a<<8|a>>>8;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};jb=p+16|0;e=b+h<<1;break u;case 1:p=jb-16|0;jb=p;d=v[k+2260>>2];v[p+12>>2]=d;m=v[b>>2]<<1;v[p+8>>2]=m;a=p+8|0;g=v[Ib(a,p+12|0)>>2];v[p+8>>2]=m;v[p+4>>2]=d-g;i=v[Ib(a,p+4|0)>>2];e=v[b+20>>2];h=g>>>1|0;g=h;d=f;while(1){if(g){a=w[d|0]|w[d+1|0]<<8;u[e>>1]=(a<<8|a>>>8)^32768;e=e+4|0;d=d+2|0;g=g-1|0;continue}break};e=f+m|0;d=v[b+20>>2]+2|0;b=i>>>1|0;g=b;while(1){if(g){a=w[e|0]|w[e+1|0]<<8;u[d>>1]=(a<<8|a>>>8)^32768;d=d+4|0;e=e+2|0;g=g-1|0;continue}break};jb=p+16|0;e=b+h<<1;break u;case 2:break X;default:break u}}e=v[k+2260>>2];a=x[Yl(k+16|0)>>1];r=jb-16|0;jb=r;v[r+12>>2]=e;p=v[b>>2]<<1;v[r+8>>2]=p;d=r+8|0;g=v[Ib(d,r+12|0)>>2];v[r+8>>2]=p;v[r+4>>2]=e-g;m=v[Ib(d,r+4|0)>>2];e=b;h=v[b+20>>2];b=a;i=g>>>1|0;d=i;g=f;while(1){if(d){b=(w[g+1|0]+b|0)+(w[g|0]<<8)|0;u[h>>1]=b;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}g=f+p|0;h=v[e+20>>2]+2|0;b=m>>>1|0;d=b;while(1){if(d){a=(w[g+1|0]+a|0)+(w[g|0]<<8)|0;u[h>>1]=a;h=h+4|0;g=g+2|0;d=d-1|0;continue}break}jb=r+16|0;e=b+i<<1;break u}if(!(w[h+2|0]|((a|0)!=16|w[h+1|0]!=2))){e=0;Y:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2]>>>2;v[d+8>>2]=a;a=v[Ib(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=w[f|0]|w[f+1|0]<<8;u[b+2>>1]=w[f+2|0]|w[f+3|0]<<8;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};jb=d+16|0;e=a<<2;break u;case 1:a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=v[k+2260>>2]>>>2;v[d+8>>2]=a;a=v[Ib(d+12|0,d+8|0)>>2];e=a;while(1){if(e){u[b>>1]=(w[f|0]|w[f+1|0]<<8)^32768;u[b+2>>1]=(w[f+2|0]|w[f+3|0]<<8)^32768;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};jb=d+16|0;e=a<<2;break u;case 2:break Y;default:break u}}e=v[k+2260>>2];a=Yl(k+8|0);d=v[b>>2];g=v[b+20>>2];a=x[a>>1];h=jb-16|0;jb=h;v[h+12>>2]=e>>>2;v[h+8>>2]=d;b=a;e=v[Ib(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=(w[f|0]+a|0)+(w[f+1|0]<<8)|0;u[g>>1]=a;b=(w[f+2|0]+b|0)+(w[f+3|0]<<8)|0;u[g+2>>1]=b;g=g+4|0;f=f+4|0;d=d-1|0;continue}break}jb=h+16|0;e=e<<2;break u}a=e&255;if(!((a|0)!=16|w[h+1|0]!=2|w[h+2|0]!=1)){e=0;Z:{switch(g|0){case 0:a=v[b>>2];b=v[b+20>>2];g=jb-16|0;jb=g;v[g+12>>2]=v[k+2260>>2]>>>2;v[g+8>>2]=a;d=v[Ib(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=a<<8|a>>>8;a=w[f+2|0]|w[f+3|0]<<8;u[b+2>>1]=a<<8|a>>>8;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};jb=g+16|0;e=d<<2;break u;case 1:a=v[b>>2];b=v[b+20>>2];g=jb-16|0;jb=g;v[g+12>>2]=v[k+2260>>2]>>>2;v[g+8>>2]=a;d=v[Ib(g+12|0,g+8|0)>>2];e=d;while(1){if(e){a=w[f|0]|w[f+1|0]<<8;u[b>>1]=(a<<8|a>>>8)^32768;a=w[f+2|0]|w[f+3|0]<<8;u[b+2>>1]=(a<<8|a>>>8)^32768;b=b+4|0;f=f+4|0;e=e-1|0;continue}break};jb=g+16|0;e=d<<2;break u;case 2:break Z;default:break u}}e=v[k+2260>>2];a=Yl(k);d=v[b>>2];g=v[b+20>>2];a=x[a>>1];h=jb-16|0;jb=h;v[h+12>>2]=e>>>2;v[h+8>>2]=d;b=a;e=v[Ib(h+12|0,h+8|0)>>2];d=e;while(1){if(d){a=(w[f+1|0]+a|0)+(w[f|0]<<8)|0;u[g>>1]=a;b=(w[f+3|0]+b|0)+(w[f+2|0]<<8)|0;u[g+2>>1]=b;g=g+4|0;f=f+4|0;d=d-1|0;continue}break}jb=h+16|0;e=e<<2;break u}if(!(g|w[h+1|0]!=1|(a|0)!=24)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=(b>>>0)/3;v[g+8>>2]=d;b=v[Ib(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=id(w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24,16),u[K>>1]=M;a=a+2|0;f=f+3|0;e=e-1|0;continue}break}jb=g+16|0;e=B(b,3);break u}g=jb-16|0;jb=g;v[g+12>>2]=(b>>>0)/3;v[g+8>>2]=d;b=v[Ib(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=id(w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24,16),u[K>>1]=M;a=a+2|0;f=f+3|0;e=e-1|0;continue}break}jb=g+16|0;e=B(b,3);break u}a=e&255;if(!(g|w[h+1|0]!=2|(a|0)!=24)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=(b>>>0)/6;v[g+8>>2]=d;b=v[Ib(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=id(w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24,16),u[K>>1]=M;K=a,M=id(w[f+4|0]<<16|w[f+3|0]<<8|w[f+5|0]<<24,16),u[K+2>>1]=M;a=a+4|0;f=f+6|0;e=e-1|0;continue}break}jb=g+16|0;e=B(b,6);break u}g=jb-16|0;jb=g;v[g+12>>2]=(b>>>0)/6;v[g+8>>2]=d;b=v[Ib(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=id(w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24,16),u[K>>1]=M;K=a,M=id(w[f+4|0]<<16|w[f+5|0]<<8|w[f+3|0]<<24,16),u[K+2>>1]=M;a=a+4|0;f=f+6|0;e=e-1|0;continue}break}jb=g+16|0;e=B(b,6);break u}if(!(g|w[h+1|0]!=1|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Ib(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=id(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),16),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<2;break u}g=jb-16|0;jb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Ib(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);K=a,M=id(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<2;break u}a=e&255;if(!(g|w[h+1|0]!=2|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Ib(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=id(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),16),u[K>>1]=M;K=a,M=id(w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),16),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<3;break u}g=jb-16|0;jb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Ib(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);K=a,M=id(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);K=a,M=id(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24),16),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<3;break u}if(!(g|w[h+1|0]!=1|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Ib(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=Rc(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),48),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<3;break u}i=jb-16|0;jb=i;v[i+12>>2]=b>>>3;v[i+8>>2]=d;d=v[Ib(i+12|0,i+8|0)>>2];e=d;while(1){if(e){h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);b=h<<24|h<<8&16711680;m=h>>>8|0;g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);h=h>>>24|0;b=b|((m|g<<24)&65280|(h|g<<8)&255);K=a,M=Rc((m|(g&255)<<24)&-16777216|(h|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24),b,48),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}jb=i+16|0;e=d<<3;break u}a=e&255;if(!(g|w[h+1|0]!=2|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=b>>>4;v[g+8>>2]=d;b=v[Ib(g+12|0,g+8|0)>>2];e=b;while(1){if(e){K=a,M=Rc(w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24),w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24),48),u[K>>1]=M;K=a,M=Rc(w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24),w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24),48),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<4;break u}i=jb-16|0;jb=i;v[i+12>>2]=b>>>4;v[i+8>>2]=d;d=v[Ib(i+12|0,i+8|0)>>2];e=d;while(1){if(e){h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);b=h<<24|h<<8&16711680;m=h>>>8|0;g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);h=h>>>24|0;b=b|((m|g<<24)&65280|(h|g<<8)&255);K=a,M=Rc((m|(g&255)<<24)&-16777216|(h|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24),b,48),u[K>>1]=M;h=w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24);g=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);b=h<<24|h<<8&16711680|((g<<24|h>>>8)&65280|(g<<8|h>>>24)&255);K=a,M=Rc(((g&255)<<24|h>>>8)&-16777216|((g&16777215)<<8|h>>>24)&16711680|(g>>>8&65280|g>>>24),b,48),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}jb=i+16|0;e=d<<4;break u}if(!(w[h+1|0]!=1|(g|0)!=3|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Ib(g+12|0,g+8|0)>>2];e=b;while(1){if(e){j=wf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Qh(C(Sd(dg(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));_:{if(C(D(j))<C(2147483648)){d=~~j;break _}d=-2147483648}K=a,M=Xc(d),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<2;break u}g=jb-16|0;jb=g;v[g+12>>2]=b>>>2;v[g+8>>2]=d;b=v[Ib(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=wf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Qh(C(Sd(dg(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));$:{if(C(D(j))<C(2147483648)){d=~~j;break $}d=-2147483648}K=a,M=Xc(d),u[K>>1]=M;a=a+2|0;f=f+4|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<2;break u}a=e&255;if(!(w[h+1|0]!=2|(g|0)!=3|(a|0)!=32)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-16|0;jb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Ib(g+12|0,g+8|0)>>2];e=b;while(1){if(e){j=wf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Qh(C(Sd(dg(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));aa:{if(C(D(j))<C(2147483648)){d=~~j;break aa}d=-2147483648}K=a,M=Xc(d),u[K>>1]=M;j=wf((l(2,w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24)),q()));j=Qh(C(Sd(dg(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));ba:{if(C(D(j))<C(2147483648)){d=~~j;break ba}d=-2147483648}K=a,M=Xc(d),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<3;break u}g=jb-16|0;jb=g;v[g+12>>2]=b>>>3;v[g+8>>2]=d;b=v[Ib(g+12|0,g+8|0)>>2];e=b;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=wf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Qh(C(Sd(dg(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));ca:{if(C(D(j))<C(2147483648)){d=~~j;break ca}d=-2147483648}K=a,M=Xc(d),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);j=wf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Qh(C(Sd(dg(j)?j>=C(0)?C(1):C(-1):j,C(-1))*C(32768)));da:{if(C(D(j))<C(2147483648)){d=~~j;break da}d=-2147483648}K=a,M=Xc(d),u[K+2>>1]=M;a=a+4|0;f=f+8|0;e=e-1|0;continue}break}jb=g+16|0;e=b<<3;break u}if(!(w[h+1|0]!=1|(g|0)!=3|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-32|0;jb=g;v[g+24>>2]=b>>>3;v[g+16>>2]=d;d=v[Ib(g+24|0,g+16|0)>>2];e=d;while(1){if(e){b=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,b|0);o=cg(+n());K=g,N=af(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=ge(A[zg(g+24|0,g+16|0,g+8|0)>>3]*32768);ea:{if(D(o)<2147483648){b=~~o;break ea}b=-2147483648}K=a,M=Xc(b),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}jb=g+32|0;e=d<<3;break u}m=jb-32|0;jb=m;v[m+24>>2]=b>>>3;v[m+16>>2]=d;h=v[Ib(m+24|0,m+16|0)>>2];e=h;while(1){if(e){b=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=b<<24|b<<8&16711680;r=b>>>8|0;i=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);d=r|i<<24;b=b>>>24|0;l(0,(r|(i&255)<<24)&-16777216|(b|(i&16777215)<<8)&16711680|(i>>>8&65280|i>>>24));l(1,g|(d&65280|(b|i<<8)&255));o=cg(+n());K=m,N=af(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=ge(A[zg(m+24|0,m+16|0,m+8|0)>>3]*32768);fa:{if(D(o)<2147483648){b=~~o;break fa}b=-2147483648}K=a,M=Xc(b),u[K>>1]=M;a=a+2|0;f=f+8|0;e=e-1|0;continue}break}jb=m+32|0;e=h<<3;break u}a=e&255;if(!(w[h+1|0]!=2|(g|0)!=3|(a|0)!=64)){a=v[b+20>>2];d=v[b>>2];b=v[k+2260>>2];if(!w[h+2|0]){g=jb-32|0;jb=g;v[g+24>>2]=b>>>4;v[g+16>>2]=d;d=v[Ib(g+24|0,g+16|0)>>2];e=d;while(1){if(e){b=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,b|0);o=cg(+n());K=g,N=af(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=ge(A[zg(g+24|0,g+16|0,g+8|0)>>3]*32768);ga:{if(D(o)<2147483648){b=~~o;break ga}b=-2147483648}K=a,M=Xc(b),u[K>>1]=M;b=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);l(0,w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24));l(1,b|0);o=cg(+n());K=g,N=af(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[g+16>>2]=0;v[g+20>>2]=-1074790400;v[g+8>>2]=0;v[g+12>>2]=1072693248;o=ge(A[zg(g+24|0,g+16|0,g+8|0)>>3]*32768);ha:{if(D(o)<2147483648){b=~~o;break ha}b=-2147483648}K=a,M=Xc(b),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}jb=g+32|0;e=d<<4;break u}m=jb-32|0;jb=m;v[m+24>>2]=b>>>4;v[m+16>>2]=d;h=v[Ib(m+24|0,m+16|0)>>2];e=h;while(1){if(e){b=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);d=b<<24|b<<8&16711680;i=b>>>8|0;g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);b=b>>>24|0;d=d|((i|g<<24)&65280|(b|g<<8)&255);l(0,(i|(g&255)<<24)&-16777216|(b|(g&16777215)<<8)&16711680|(g>>>8&65280|g>>>24));l(1,d|0);o=cg(+n());K=m,N=af(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=ge(A[zg(m+24|0,m+16|0,m+8|0)>>3]*32768);ia:{if(D(o)<2147483648){b=~~o;break ia}b=-2147483648}K=a,M=Xc(b),u[K>>1]=M;b=w[f+8|0]|w[f+9|0]<<8|(w[f+10|0]<<16|w[f+11|0]<<24);g=b<<24|b<<8&16711680;r=b>>>8|0;i=w[f+12|0]|w[f+13|0]<<8|(w[f+14|0]<<16|w[f+15|0]<<24);d=r|i<<24;b=b>>>24|0;l(0,(r|(i&255)<<24)&-16777216|(b|(i&16777215)<<8)&16711680|(i>>>8&65280|i>>>24));l(1,g|(d&65280|(b|i<<8)&255));o=cg(+n());K=m,N=af(o)?o>=0?1:-1:o,A[K+24>>3]=N;v[m+16>>2]=0;v[m+20>>2]=-1074790400;v[m+8>>2]=0;v[m+12>>2]=1072693248;o=ge(A[zg(m+24|0,m+16|0,m+8|0)>>3]*32768);ja:{if(D(o)<2147483648){b=~~o;break ja}b=-2147483648}K=a,M=Xc(b),u[K+2>>1]=M;a=a+4|0;f=f+16|0;e=e-1|0;continue}break}jb=m+32|0;e=h<<4;break u}if(!((g|0)!=15|(w[h+1|0]-1&255)>>>0>1|(a|0)!=24)){v[k+96>>2]=-2147483648;a=v[k+2260>>2];ka:{if(!w[h+2|0]){r=k+96|0;e=0;s=jb-16|0;jb=s;K=s,M=B(v[b>>2],Gd(x[b+34>>1])),v[K+12>>2]=M;yc(s+12|0,(a>>>0)/3|0);a=f;g=v[s+12>>2];h=g;while(1){if(h){i=w[a+1|0]<<16|w[a|0]<<8|w[a+2|0]<<24;la:{ma:{na:{if((i|0)>=0){d=i;break na}d=-2147483648;if((i|0)==-2147483648){break ma}d=0-i|0}if(d>>>0<=e>>>0){break la}}e=d}h=h-1|0;a=a+3|0;continue}else{oa:{if(!e){break oa}p=e-1|0;m=e>>>1|0;h=v[b+20>>2];a=g;while(1){if(!a){break oa}d=w[f+1|0]<<16|w[f|0]<<8|w[f+2|0]<<24;i=d>>31<<31|d>>>1;d=m|d<<31;pa:{if((i|0)>0|(i|0)>=0){d=Via(d,i,e,0);i=mb;break pa}i=Via(p-d|0,0-((d>>>0>p>>>0)+i|0)|0,e,0);d=0-i|0;i=0-(mb+((i|0)!=0)|0)|0}K=h,M=id(Ic(d,i),16),u[K>>1]=M;a=a-1|0;f=f+3|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=e}jb=s+16|0;e=B(g,3);break ka}r=k+96|0;e=0;s=jb-16|0;jb=s;K=s,M=B(v[b>>2],Gd(x[b+34>>1])),v[K+12>>2]=M;yc(s+12|0,(a>>>0)/3|0);a=f;g=v[s+12>>2];h=g;while(1){if(h){i=w[a+1|0]<<16|w[a+2|0]<<8|w[a|0]<<24;qa:{ra:{sa:{if((i|0)>=0){d=i;break sa}d=-2147483648;if((i|0)==-2147483648){break ra}d=0-i|0}if(d>>>0<=e>>>0){break qa}}e=d}h=h-1|0;a=a+3|0;continue}else{ta:{if(!e){break ta}p=e-1|0;m=e>>>1|0;h=v[b+20>>2];a=g;while(1){if(!a){break ta}d=w[f+1|0]<<16|w[f+2|0]<<8|w[f|0]<<24;i=d>>31<<31|d>>>1;d=m|d<<31;ua:{if((i|0)>0|(i|0)>=0){d=Via(d,i,e,0);i=mb;break ua}i=Via(p-d|0,0-((d>>>0>p>>>0)+i|0)|0,e,0);d=0-i|0;i=0-(mb+((i|0)!=0)|0)|0}K=h,M=id(Ic(d,i),16),u[K>>1]=M;a=a-1|0;f=f+3|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=e}jb=s+16|0;e=B(g,3)}if(!e){break u}a=v[k+96>>2];if((a|0)==-2147483648){break u}f=Sia(x[b+32>>1],0,a,0)+1073741824|0;a=mb;a=f>>>0<1073741824?a+1|0:a;K=b,M=Xd(Vc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[K+32>>1]=M;u[b+34>>1]=x[b+34>>1]|8192;break u}va:{a=e&255;if((a|0)!=32){break va}if(!((g|0)!=15|(w[h+1|0]-1&255)>>>0>1)){v[k+96>>2]=-2147483648;d=v[k+2260>>2];wa:{if(!w[h+2|0]){r=k+96|0;a=0;s=jb-16|0;jb=s;K=s,M=B(v[b>>2],Gd(x[b+34>>1])),v[K+12>>2]=M;yc(s+12|0,d>>>2|0);e=f;h=f;g=v[s+12>>2];f=g;while(1){if(f){i=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);xa:{ya:{za:{if((i|0)>=0){d=i;break za}d=-2147483648;if((i|0)==-2147483648){break ya}d=0-i|0}if(d>>>0<=a>>>0){break xa}}a=d}f=f-1|0;h=h+4|0;continue}else{Aa:{if(!a){break Aa}p=a-1|0;m=a>>>1|0;h=v[b+20>>2];f=g;while(1){if(!f){break Aa}d=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);i=d>>31<<31|d>>>1;d=m|d<<31;Ba:{if((i|0)>0|(i|0)>=0){d=Via(d,i,a,0);i=mb;break Ba}i=Via(p-d|0,0-((d>>>0>p>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(mb+((i|0)!=0)|0)|0}K=h,M=id(Ic(d,i),16),u[K>>1]=M;f=f-1|0;e=e+4|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=a}jb=s+16|0;e=g<<2;break wa}r=k+96|0;a=0;s=jb-16|0;jb=s;K=s,M=B(v[b>>2],Gd(x[b+34>>1])),v[K+12>>2]=M;yc(s+12|0,d>>>2|0);e=f;h=f;g=v[s+12>>2];f=g;while(1){if(f){d=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);i=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);Ca:{Da:{Ea:{if((i|0)>=0){d=i;break Ea}d=-2147483648;if((i|0)==-2147483648){break Da}d=0-i|0}if(a>>>0>=d>>>0){break Ca}}a=d}f=f-1|0;h=h+4|0;continue}else{Fa:{if(!a){break Fa}p=a-1|0;m=a>>>1|0;h=v[b+20>>2];f=g;while(1){if(!f){break Fa}d=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);d=d<<24|d<<8&16711680|(d>>>8&65280|d>>>24);i=d>>31<<31|d>>>1;d=m|d<<31;Ga:{if((i|0)>0|(i|0)>=0){d=Via(d,i,a,0);i=mb;break Ga}i=Via(p-d|0,0-((d>>>0>p>>>0)+i|0)|0,a,0);d=0-i|0;i=0-(mb+((i|0)!=0)|0)|0}K=h,M=id(Ic(d,i),16),u[K>>1]=M;f=f-1|0;e=e+4|0;h=h+2|0;continue}}}break}if(r){v[r>>2]=a}jb=s+16|0;e=g<<2}if(!e){break u}a=v[k+96>>2];if((a|0)==-2147483648){break u}f=Sia(x[b+32>>1],0,a,0)+1073741824|0;a=mb;a=f>>>0<1073741824?a+1|0:a;K=b,M=Xd(Vc((a&2147483647)<<1|f>>>31,a>>>31|0),1,64),u[K+32>>1]=M;u[b+34>>1]=x[b+34>>1]|8192;break u}if((g|0)!=14|(w[h+1|0]-1&255)>>>0>1){break va}v[k+96>>2]=1065353216;a=v[k+2260>>2];Ha:{if(!w[h+2|0]){e=k+96|0;h=jb-16|0;jb=h;K=h,M=B(v[b>>2],Gd(x[b+34>>1])),v[K+12>>2]=M;yc(h+12|0,a>>>2|0);g=f;d=v[h+12>>2];a=d;while(1){if(a){j=wf((l(2,w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24)),q()));j=C(D(dg(j)?j>=C(0)?C(1):C(-1):j));E=j>E?j:E;a=a-1|0;g=g+4|0;continue}else{Ia:{a=E==C(0);if(a){break Ia}H=a?C(1):C(C(1)/E);g=v[b+20>>2];a=d;while(1){if(!a){break Ia}j=wf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Qh(C(Sd(C(H*(dg(j)?j>=C(0)?C(1):C(-1):j)),C(-1))*C(32768)));Ja:{if(C(D(j))<C(2147483648)){i=~~j;break Ja}i=-2147483648}K=g,M=Xc(i),u[K>>1]=M;a=a-1|0;f=f+4|0;g=g+2|0;continue}}if(e){z[e>>2]=E}jb=h+16|0;e=d<<2}break}break Ha}e=k+96|0;i=jb-16|0;jb=i;K=i,M=B(v[b>>2],Gd(x[b+34>>1])),v[K+12>>2]=M;yc(i+12|0,a>>>2|0);g=f;d=v[i+12>>2];a=d;while(1){if(a){h=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);j=wf((l(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),q()));j=C(D(dg(j)?j>=C(0)?C(1):C(-1):j));E=j>E?j:E;a=a-1|0;g=g+4|0;continue}else{Ka:{a=E==C(0);if(a){break Ka}H=a?C(1):C(C(1)/E);g=v[b+20>>2];a=d;while(1){if(!a){break Ka}h=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=wf((l(2,h<<24|h<<8&16711680|(h>>>8&65280|h>>>24)),q()));j=Qh(C(Sd(C(H*(dg(j)?j>=C(0)?C(1):C(-1):j)),C(-1))*C(32768)));La:{if(C(D(j))<C(2147483648)){h=~~j;break La}h=-2147483648}K=g,M=Xc(h),u[K>>1]=M;a=a-1|0;f=f+4|0;g=g+2|0;continue}}if(e){z[e>>2]=E}jb=i+16|0;e=d<<2}break}}if(!e){break u}j=z[k+96>>2];if(j==C(1)){break u}j=Qh(Ty(C(j*C(x[b+32>>1])),C(1),C(64)));a=65535;Ma:{if(j>=C(65535)){break Ma}a=0;if(j<=C(0)){break Ma}a=~~j>>>0;if(j<C(4294967296)&j>=C(0)){break Ma}a=0}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break u}if(!((g|0)!=14|(w[h+1|0]-1&255)>>>0>1|(a|0)!=64)){v[k+96>>2]=0;v[k+100>>2]=1072693248;a=v[k+2260>>2];Na:{if(!w[h+2|0]){h=k+96|0;i=jb-32|0;jb=i;K=i,M=B(v[b>>2],Gd(x[b+34>>1])),v[K+4>>2]=M;yc(i+4|0,a>>>3|0);d=f;e=v[i+4>>2];a=e;while(1){if(a){g=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);l(0,w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));l(1,g|0);o=cg(+n());o=D(af(o)?o>=0?1:-1:o);F=o>F?o:F;a=a-1|0;d=d+8|0;continue}else{Oa:{a=F==0;if(a){break Oa}I=a?1:1/F;d=v[b+20>>2];a=e;while(1){if(!a){break Oa}g=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);l(0,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24));l(1,g|0);o=cg(+n());K=i,N=I*(af(o)?o>=0?1:-1:o),A[K+24>>3]=N;v[i+16>>2]=0;v[i+20>>2]=-1074790400;v[i+8>>2]=0;v[i+12>>2]=1072693248;o=ge(A[zg(i+24|0,i+16|0,i+8|0)>>3]*32768);Pa:{if(D(o)<2147483648){g=~~o;break Pa}g=-2147483648}K=d,M=Xc(g),u[K>>1]=M;a=a-1|0;f=f+8|0;d=d+2|0;continue}}if(h){A[h>>3]=F}jb=i+32|0;e=e<<3}break}break Na}i=k+96|0;p=jb-32|0;jb=p;K=p,M=B(v[b>>2],Gd(x[b+34>>1])),v[K+4>>2]=M;yc(p+4|0,a>>>3|0);d=f;g=v[p+4>>2];a=g;while(1){if(a){e=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);h=e<<24|e<<8&16711680;r=e>>>8|0;m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);e=e>>>24|0;h=h|((r|m<<24)&65280|(e|m<<8)&255);l(0,(r|(m&255)<<24)&-16777216|(e|(m&16777215)<<8)&16711680|(m>>>8&65280|m>>>24));l(1,h|0);o=cg(+n());o=D(af(o)?o>=0?1:-1:o);F=o>F?o:F;a=a-1|0;d=d+8|0;continue}else{Qa:{a=F==0;if(a){break Qa}I=a?1:1/F;d=v[b+20>>2];a=g;while(1){if(!a){break Qa}m=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);e=m<<24|m<<8&16711680;r=m>>>8|0;h=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);m=m>>>24|0;e=e|((r|h<<24)&65280|(m|h<<8)&255);l(0,(r|(h&255)<<24)&-16777216|(m|(h&16777215)<<8)&16711680|(h>>>8&65280|h>>>24));l(1,e|0);o=cg(+n());K=p,N=I*(af(o)?o>=0?1:-1:o),A[K+24>>3]=N;v[p+16>>2]=0;v[p+20>>2]=-1074790400;v[p+8>>2]=0;v[p+12>>2]=1072693248;o=ge(A[zg(p+24|0,p+16|0,p+8|0)>>3]*32768);Ra:{if(D(o)<2147483648){e=~~o;break Ra}e=-2147483648}K=d,M=Xc(e),u[K>>1]=M;a=a-1|0;f=f+8|0;d=d+2|0;continue}}if(i){A[i>>3]=F}jb=p+32|0;e=g<<3}break}}if(!e){break u}o=A[k+96>>3];if(o==1){break u}o=ge(Sy(o*+x[b+32>>1],1,64));a=65535;Sa:{if(o>=65535){break Sa}a=0;if(o<=0){break Sa}a=~~o>>>0;if(o<4294967296&o>=0){break Sa}a=0}u[b+32>>1]=a;u[b+34>>1]=x[b+34>>1]|8192;break u}Ta:{Ua:{Va:{Wa:{a=(e&255)!=32;Xa:{if(!(a|(w[h+1|0]!=1|(g|0)!=12))){E=C(30517578125e-15);e=v[k+2260>>2];if(!w[h+2|0]){break Xa}break Ta}if(!(w[h+1|0]!=2|(g|0)!=12|a)){E=C(30517578125e-15);e=v[k+2260>>2];if(!w[h+2|0]){break Va}break Ua}a=(e&255)!=32;if(a|(w[h+1|0]!=1|(g|0)!=13)){break Wa}E=C(1.1920928955078125e-7);e=v[k+2260>>2];if(w[h+2|0]){break Ta}}a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=e>>>2;v[d+8>>2]=a;a=v[Ib(d+12|0,d+8|0)>>2];e=a;while(1){if(e){j=wf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Qh(C(Sd(C((dg(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));Ya:{if(C(D(j))<C(2147483648)){g=~~j;break Ya}g=-2147483648}K=b,M=Xc(g),u[K>>1]=M;b=b+2|0;f=f+4|0;e=e-1|0;continue}break}jb=d+16|0;e=a<<2;break u}e=0;if(w[h+1|0]!=2|(g|0)!=13|a){break u}E=C(1.1920928955078125e-7);e=v[k+2260>>2];if(w[h+2|0]){break Ua}}a=v[b>>2];b=v[b+20>>2];d=jb-16|0;jb=d;v[d+12>>2]=e>>>3;v[d+8>>2]=a;a=v[Ib(d+12|0,d+8|0)>>2];e=a;while(1){if(e){j=wf((l(2,w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24)),q()));j=Qh(C(Sd(C((dg(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));Za:{if(C(D(j))<C(2147483648)){g=~~j;break Za}g=-2147483648}K=b,M=Xc(g),u[K>>1]=M;j=wf((l(2,w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24)),q()));j=Qh(C(Sd(C((dg(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));_a:{if(C(D(j))<C(2147483648)){g=~~j;break _a}g=-2147483648}K=b,M=Xc(g),u[K+2>>1]=M;b=b+4|0;f=f+8|0;e=e-1|0;continue}break}jb=d+16|0;e=a<<3;break u}a=v[b>>2];b=v[b+20>>2];g=jb-16|0;jb=g;v[g+12>>2]=e>>>3;v[g+8>>2]=a;a=v[Ib(g+12|0,g+8|0)>>2];e=a;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=wf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Qh(C(Sd(C((dg(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));$a:{if(C(D(j))<C(2147483648)){d=~~j;break $a}d=-2147483648}K=b,M=Xc(d),u[K>>1]=M;d=w[f+4|0]|w[f+5|0]<<8|(w[f+6|0]<<16|w[f+7|0]<<24);j=wf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Qh(C(Sd(C((dg(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));ab:{if(C(D(j))<C(2147483648)){d=~~j;break ab}d=-2147483648}K=b,M=Xc(d),u[K+2>>1]=M;b=b+4|0;f=f+8|0;e=e-1|0;continue}break}jb=g+16|0;e=a<<3;break u}a=v[b>>2];b=v[b+20>>2];g=jb-16|0;jb=g;v[g+12>>2]=e>>>2;v[g+8>>2]=a;a=v[Ib(g+12|0,g+8|0)>>2];e=a;while(1){if(e){d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);j=wf((l(2,d<<24|d<<8&16711680|(d>>>8&65280|d>>>24)),q()));j=Qh(C(Sd(C((dg(j)?j>=C(0)?C(1):C(-1):j)*E),C(-1))*C(32768)));bb:{if(C(D(j))<C(2147483648)){d=~~j;break bb}d=-2147483648}K=b,M=Xc(d),u[K>>1]=M;b=b+2|0;f=f+4|0;e=e-1|0;continue}break}jb=g+16|0;e=a<<2;break u}a=V(30320)|0}if((O()|0)!=(ea(30320)|0)){break d}_(a|0)|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)==1){break v}}Ab(s);break u}a=P()|0;O()|0;break d}v[23296]=0;Q(143,c|0,e+J|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break f}}Pc(G)}jb=k+2288|0;return e|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}Ab(s);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Pc(G);S(a|0);L()}function Cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;d=jb-640|0;jb=d;Ac(b);f=jb-16|0;jb=f;h=d+448|0;Aq(f+8|0,h);j=v[f+12>>2];g=b;nc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);b=v[f+4>>2];if((b|0)==(j|0)){ac(g,v[f+12>>2])}jb=f+16|0;b=(b|0)==(j|0);if(!b){eT(h)}a:{b:{c:{if(!b){break c}if(!gT(d+448|0)){break c}if(!Ob(v[g>>2],v[g+8>>2],Vc(fT(d+448|0),mb))){break c}if(!c){e=1;break c}Ed(a,32);t[d+447|0]=0;j=Kb(d+432|0);d:{e:{f:{g:{h:{i:{j:{k:{if(!Pb(d+448|0,16099,4)){v[23296]=0;R(351,a|0,16777216);b=v[23296];v[23296]=0;if((b|0)==1){break b}b=v[g>>2];v[23296]=0;b=T(148,b|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break b}v[23296]=0;Q(143,g|0,b-4|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break b}v[23296]=0;A=T(145,g|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break k}break b}l:{m:{n:{o:{p:{q:{if((x[d+488>>1]-2185&65535)>>>0>1910){break q}b=v[g>>2];v[23296]=0;b=T(148,b|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break b}v[23296]=0;Q(143,g|0,b-4|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break b}v[23296]=0;A=T(145,g|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break b}if(A>>>0<256){break q}b=v[g>>2];v[23296]=0;b=T(148,b|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break b}if(b>>>0<=A>>>0){break q}v[23296]=0;b=Q(143,g|0,A|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break b}if(!b){break q}v[23296]=0;b=T(352,g|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break b}if(!b){break q}v[23296]=0;R(351,a|0,16777216);b=v[23296];v[23296]=0;if((b|0)==1){break b}b=x[d+488>>1];if(b>>>0>=4096){v[23296]=0;c=Q(1,d+168|0,16314)|0;b=v[23296];v[23296]=0;if((b|0)==1){break j}a=v[a+1298464>>2];v[23296]=0;U(353,a|0,1,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(c);e=0;break d}b=P()|0;O()|0;zb(c);break a}if(b>>>0<2194){break q}v[23296]=0;e=Q(1,d+416|0,15838)|0;b=v[23296];v[23296]=0;if((b|0)==1){break p}b=v[a+1298464>>2];v[23296]=0;U(353,b|0,4,e|0);b=v[23296];v[23296]=0;if((b|0)==1){break o}zb(e)}if(v[a+480180>>2]!=32){break k}b=x[d+488>>1];if((b&61440)!=20480){break l}b=b&4095;e=b<<16;if(Pb(d+508|0,13461,4)){break n}t[d+447|0]=1;break m}b=P()|0;O()|0;break a}b=P()|0;O()|0;zb(e);break a}if(b>>>0<297){break m}e=x[d+508>>1]|e}v[a+1074308>>2]=e;break k}e=x[d+490>>1];if(!((e|0)!=2184&(b|0)!=2184)){t[d+447|0]=1;v[a+1074308>>2]=18284544;break k}r:{switch(b-532|0){default:if(v[d+508>>2]|((b|0)!=768|(e|0)!=768)|(x[d+480>>1]!=256|w[d+500|0]!=128)){break k}if(w[d+501|0]){break k}v[a+1074308>>2]=18285088;t[d+447|0]=1;break k;case 3:if(v[d+508>>2]|(e|0)!=512){break k}s:{if(UA(d+512|0,255,64)){v[a+1074308>>2]=18219008;v[23296]=0;b=Q(1,d+400|0,14668)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break s}b=P()|0;O()|0;break a}v[a+1074308>>2]=18284544;v[23296]=0;b=Q(1,d+400|0,16688)|0;e=v[23296];v[23296]=0;if((e|0)==1){break i}}Hb(j,b);zb(b);t[d+447|0]=1;break k;case 1:case 2:break k;case 0:break r}}if(v[d+508>>2]|(e|0)!=514){break k}v[a+1074308>>2]=17367040;v[23296]=0;b=Q(1,d+400|0,14560)|0;e=v[23296];v[23296]=0;if((e|0)==1){break f}Hb(j,b);zb(b);t[d+447|0]=1}b=x[d+492>>1];e=b>>>2|0;v[a+480208>>2]=b<<3&32768|(e&8|(e&4|(v[a+480208>>2]&-32797|b<<1&16)));b=d+280|0;Sq(b,d+448|4);v[23296]=0;R(210,d+168|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break h}b=d+168|0;Bc(a+1298308|0,b);yb(b);if(!(!(w[d+494|0]&4)|v[a+1074308>>2]-18285314>>>0>4276681982)){v[a+480216>>2]=w[d+478|0];v[a+480220>>2]=w[d+479|0]}b=w[d+496|0];v[a+480200>>2]=b>>>0>128?256:b<<1;b=w[d+498|0];if(b){v[a+480196>>2]=b}t[d+168|0]=31;t[d+280|0]=w[d+499|0];b=d+168|0;e=d+280|0;I=a,J=B(w[ef(b,e)|0],1e4),v[I+480204>>2]=J;t[d+168|0]=w[d+497|0];t[d+280|0]=128;I=a,J=w[Wb(b,e)|0],v[I+480228>>2]=J;e=0;while(1){if((e|0)==64){t:{v[23296]=0;Q(143,g|0,192)|0;b=v[23296];v[23296]=0;if((b|0)==1){break b}if(v[a+480180>>2]==16777216&(x[d+488>>1]-2187&65535)>>>0<=2){break t}b=w[a+484376|0];e=v[a+484360>>2];v[23296]=0;da(326,Zb(e,b)|0,g|0,x[d+480>>1],255,254);b=v[23296];v[23296]=0;if((b|0)==1){break b}break e}}else{h=(d+448|0)+e|0;i=h- -64|0;u:{if(w[i|0]==255){break u}f=(e<<5)+a|0;b=f+480280|0;Te(b);I=f+480286|0,J=Xd(w[h+128|0],0,64),u[I>>1]=J;h=t[i|0];if((h|0)<0){v[b>>2]=v[b>>2]|1024}h=h&127;if(h>>>0<=64){u[f+480284>>1]=h<<2;break u}if((h|0)!=100){break u}v[b>>2]=v[b>>2]|256}e=e+1|0;continue}break}e=0;v[23296]=0;b=T(182,g|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break g}if(b){break d}v[23296]=0;b=T(145,g|0)|0;f=v[23296];v[23296]=0;v:{if((f|0)==1){break v}if(b>>>0>4e3){break d}f=w[a+484376|0];h=v[a+484360>>2];v[23296]=0;b=W(354,Zb(h,f)|0,g|0,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break v}if(!b){break d}break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}s=Qb(d+384|0);p=Qb(d+368|0);e=0;n=Qb(d+352|0);v[23296]=0;b=W(355,g|0,s|0,x[d+482>>1])|0;f=v[23296];v[23296]=0;w:{x:{y:{if((f|0)==1){break y}if(!b){break w}v[23296]=0;b=W(355,g|0,p|0,x[d+484>>1])|0;f=v[23296];v[23296]=0;if((f|0)==1){break y}if(!b){break w}v[23296]=0;b=W(355,g|0,n|0,x[d+486>>1])|0;f=v[23296];v[23296]=0;if((f|0)==1){break y}if(!b){break w}v[d+348>>2]=-1;I=d,J=Eb(v[s>>2]),v[I+168>>2]=J;e=Eb(v[s+4>>2]);while(1){b=v[d+168>>2];if(Rb(b,e)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+348>>2])){v[d+348>>2]=b}Ce(d+168|0);continue}else{I=d,J=Eb(v[p>>2]),v[I+168>>2]=J;e=Eb(v[p+4>>2]);while(1){b=v[d+168>>2];if(Rb(b,e)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+348>>2])){v[d+348>>2]=b}Ce(d+168|0);continue}else{I=d,J=Eb(v[n>>2]),v[I+168>>2]=J;e=Eb(v[n+4>>2]);z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{while(1){b=v[d+168>>2];if(Rb(b,e)){b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(!(!b|b>>>0>=y[d+348>>2])){v[d+348>>2]=b}Ce(d+168|0);continue}else{if(t[d+494|0]&1){v[d+168>>2]=v[d+504>>2];I=d,J=v[Ib(d+348|0,d+168|0)>>2],v[I+348>>2]=J}e=0;if(x[d+490>>1]!=532){break H}b=x[d+488>>1];if(w[d+479|0]|(b?(b|0)!=532:0)|(w[d+478|0]|w[d+501|0])){break H}if(v[d+508>>2]|w[d+492|0]&192){break H}if(x[d+482>>1]){break I}f=x[d+484>>1];if(!f){break I}if((v[g+8>>2]+(wc(v[p>>2],v[p+4>>2])<<2)|0)+2>>>0>y[d+348>>2]){break I}}break}while(1){if((e&65535)>>>0<(f&65535)>>>0){v[23296]=0;b=T(145,g|0)|0;f=v[23296];v[23296]=0;J:{if((f|0)!=1){if(!b){break J}ng(g,((e&65535)<<2)+4|0);break I}b=P()|0;O()|0;break x}e=e+1|0;f=x[d+484>>1];continue}break}v[23296]=0;b=Q(1,d+336|0,14812)|0;e=v[23296];v[23296]=0;if((e|0)==1){break G}Hb(j,b);zb(b)}e=1;if(x[d+488>>1]){break H}v[23296]=0;b=Q(1,d+320|0,15186)|0;f=v[23296];v[23296]=0;if((f|0)==1){break F}Hb(j,b);zb(b)}b=x[d+494>>1];K:{if(b&2){v[23296]=0;f=T(182,g|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break A}b=v[g+8>>2];h=v[g>>2];v[23296]=0;i=b;b=f<<3;h=W(144,h|0,i|0,b|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break A}if(!(!h|y[d+348>>2]<b+v[g+8>>2]>>>0)){v[23296]=0;b=a+1298408|0;R(356,b|0,f|0);h=v[23296];v[23296]=0;if((h|0)==1){break A}I=d,J=Eb(v[b>>2]),v[I+280>>2]=J;h=Eb(v[a+1298412>>2]);L:{M:{while(1){b=v[d+280>>2];if(!Rb(b,h)){if(!(!f&e)){break K}if(!(w[d+494|0]&4)){break L}v[23296]=0;b=Q(1,d+304|0,15219)|0;e=v[23296];v[23296]=0;if((e|0)==1){break M}Hb(j,b);zb(b);break K}v[23296]=0;R(357,g|0,d+168|0);i=v[23296];v[23296]=0;if((i|0)!=1){Xb(b,0,44);i=w[d+168|0]|w[d+169|0]<<8;if(i|(w[d+170|0]|w[d+171|0]<<8)){v[b+20>>2]=((i&65024)>>>9|0)+80;I=b,J=Yb((w[d+168|0]|w[d+169|0]<<8)>>>5&15,1,12)-1|0,v[I+16>>2]=J;I=b,J=Yb((w[d+168|0]|w[d+169|0]<<8)&31,1,31),v[I+12>>2]=J;I=b,J=Yb((w[d+170|0]|w[d+171|0]<<8)>>>11|0,0,23),v[I+8>>2]=J;I=b,J=Yb((w[d+170|0]|w[d+171|0]<<8)>>>5&63,0,59),v[I+4>>2]=J;I=b,J=Yb((w[d+170|0]|w[d+171|0]<<8)<<1&62,0,59),v[I>>2]=J}v[b+44>>2]=w[d+172|0]|w[d+173|0]<<8|(w[d+174|0]<<16|w[d+175|0]<<24);v[d+280>>2]=v[d+280>>2]+48;continue}break}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}v[23296]=0;b=Q(1,d+304|0,14839)|0;e=v[23296];v[23296]=0;if((e|0)!=1){Hb(j,b);zb(b);break K}b=P()|0;O()|0;break x}ng(g,2);break K}if(!(b>>>0<2&e)){break K}v[23296]=0;b=T(182,g|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break z}if(!b){v[23296]=0;b=Q(1,d+304|0,14812)|0;e=v[23296];v[23296]=0;if((e|0)!=1){Hb(j,b);zb(b);break K}b=P()|0;O()|0;break x}ng(g,2)}N:{if(!(w[d+494|0]&8?1:w[d+492|0]&128)){break N}v[23296]=0;b=a+901404|0;e=Q(358,g|0,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break E}if(!e){break N}TA(b)}if(x[d+488>>1]<=531){eq(a+901404|0)}v[23296]=0;C=T(162,d+280|0)|0;b=v[23296];v[23296]=0;O:{P:{Q:{if((b|0)!=1){v[23296]=0;b=Q(348,g|0,13698)|0;e=v[23296];v[23296]=0;if((e|0)==1){break Q}if(b){v[23296]=0;b=T(145,g|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break P}v[23296]=0;U(178,d+256|0,g|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break P}b=d+256|0;e=jc(d+168|0,b);cd(C,e);Ab(e);Ab(b)}u[a+480188>>1]=1;v[23296]=0;b=Q(348,g|0,13703)|0;e=v[23296];v[23296]=0;if((e|0)==1){break Q}if(!b){break C}v[23296]=0;b=T(145,g|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){v[23296]=0;U(178,d+256|0,g|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break O}}b=P()|0;O()|0;break B}b=P()|0;O()|0;break x}b=P()|0;O()|0;break B}b=P()|0;O()|0;break B}b=d+256|0;f=jc(d+168|0,b);Ab(b);b=v[f>>2];v[23296]=0;b=T(148,b|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break D}u[d+256>>1]=(b>>>0)/20;b=x[Zc(26484,d+256|0)>>1];u[a+480188>>1]=b;e=0;while(1){if((b|0)==(e|0)){Ab(f);break C}v[23296]=0;U(359,f|0,((e<<5)+a|0)+480289|0,20);h=v[23296];v[23296]=0;if((h|0)!=1){e=e+1|0;continue}break}break D}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;Ab(f);break B}R:{b=v[d+348>>2];e=v[g+8>>2];S:{if(b>>>0>=e>>>0){e=b-e|0;break S}v[23296]=0;e=T(190,g|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break R}}v[23296]=0;U(178,d+168|0,g|0,e|0);b=v[23296];v[23296]=0;if((b|0)==1){break R}b=d+168|0;D=jc(d+256|0,b);Ab(b);v[23296]=0;E=Q(360,a|0,D|0)|0;b=v[23296];v[23296]=0;T:{U:{V:{if((b|0)==1){break V}if(!(t[d+494|0]&1)|!x[d+502>>1]){break U}v[23296]=0;b=Q(143,g|0,v[d+504>>2])|0;e=v[23296];v[23296]=0;if((e|0)==1){break V}if(!b){break U}v[23296]=0;X(317,a+1298332|0,g|0,x[d+502>>1],4);b=v[23296];v[23296]=0;if((b|0)!=1){break U}}b=P()|0;O()|0;break T}h=a+480192|0;u[h>>1]=0;f=0;if(w[d+492|0]&4){u[d+168>>1]=x[d+482>>1];u[d+96>>1]=255;f=x[Zc(d+168|0,d+96|0)>>1];u[h>>1]=f}e=0;W:{while(1){if((f&65535)>>>0<=e>>>0){v[d+252>>2]=0;e=x[d+484>>1];if(e){b=Db(v[p>>2],e-1|0);v[d+252>>2]=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))+80}u[d+168>>1]=e;u[d+96>>1]=3999;q=a+480190|0;f=x[Zc(d+168|0,d+96|0)>>1];u[q>>1]=f;m=c&2;o=d+188|0;z=a+1298464|0;e=0;b=0;while(1){X:{Y:{Z:{_:{$:{aa:{ba:{ca:{if((f&65535)>>>0>e>>>0){f=Db(v[p>>2],e);f=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);if(!f){break Y}v[23296]=0;f=Q(143,g|0,f|0)|0;h=v[23296];v[23296]=0;da:{ea:{fa:{ga:{ha:{if((h|0)==1){break ha}if(!f){break Y}v[23296]=0;f=Q(361,g|0,d+168|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break ha}if(!f){break Y}v[23296]=0;i=e+1|0;f=B(i,104)+a|0;h=f+484380|0;k=Q(362,d+168|0,h|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break ga}l=d+152|0;Sq(l,o);v[23296]=0;R(210,d+96|0,l|0);l=v[23296];v[23296]=0;if((l|0)==1){break fa}l=d+96|0;Ec(((i<<5)+a|0)+946304|0,l);yb(l);v[23296]=0;k=Q(143,g|0,k|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break ga}if(!k){break Y}f=x[f+484414>>1];if(!(f&512)){break ea}v[23296]=0;f=Q(363,g|0,d+96|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break ca}if(!f){break da}v[d+8>>2]=v[d+104>>2];f=v[d+100>>2];v[d>>2]=v[d+96>>2];v[d+4>>2]=f;hl(h,1,d);break da}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if(!(f&16384)){r=x[d+488>>1];k=w[d+186|0];l=k&2;f=w[d+214|0];i=_c(d+96|0,l?16:8,1,0,(f^-1)&1);if(!(!(k&4)|r>>>0<532)){Ao(i,3)}ia:{ja:{if(k&8){k=f&4?5:4;break ja}if(!l){k=10;if((f|0)==255){break ja}}if(f&2){t[i+2|0]=1}if(f&4){Sf(i,2)}if(!(f&8)){break ia}k=9;if(!l){break ia}}Sf(i,k)}if(m){f=0;v[23296]=0;W(207,d+96|0,h|0,g|0)|0;i=v[23296];v[23296]=0;if((i|0)!=1){break _}break X}f=1;i=w[d+99|0];if(i>>>0>17){break Z}i=1<<i;if(!(i&63503)){if(!(i&198144)){break Z}break $}if(w[d+96|0]){break $}break _}v[23296]=0;R(364,g|0,d+80|0);f=v[23296];v[23296]=0;if((f|0)==1){break aa}h=v[d+80>>2];if(!(!m|!h)){f=Kb(d+96|0);v[23296]=0;U(255,g|0,f|0,h|0);h=v[23296];v[23296]=0;ka:{la:{ma:{na:{oa:{pa:{qa:{if((h|0)!=1){v[23296]=0;R(365,d+136|0,16236);h=v[23296];v[23296]=0;if((h|0)==1){break qa}v[d+64>>2]=i;v[23296]=0;U(11,d+120|0,0,f|0);h=v[23296];v[23296]=0;if((h|0)==1){break pa}v[23296]=0;X(366,d+152|0,d+136|0,d- -64|0,d+120|0);h=v[23296];v[23296]=0;if((h|0)==1){break oa}h=v[z>>2];v[23296]=0;U(353,h|0,2,d+152|0);h=v[23296];v[23296]=0;if((h|0)==1){break na}zb(d+152|0);zb(d+120|0);ec(d+136|0);yb(f);break da}b=P()|0;O()|0;break ka}b=P()|0;O()|0;break ka}b=P()|0;O()|0;break la}b=P()|0;O()|0;break ma}b=P()|0;O()|0;zb(d+152|0)}zb(d+120|0)}ec(d+136|0)}yb(f);break T}v[23296]=0;Q(176,g|0,h|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break aa}}f=0;break Z}u[d+168>>1]=1;u[d+96>>1]=f;I=a+480190|0,J=x[We(d+168|0,d+96|0)>>1],u[I>>1]=J;if(!(x[d+488>>1]==516&b)|x[d+490>>1]!=512|(x[d+494>>1]|v[d+508>>2])){break ba}if((x[d+492>>1]&65527)!=21|w[d+496|0]!=128|(w[d+497|0]!=48|w[d+500|0]!=128)){break ba}if(w[d+501|0]|x[d+502>>1]){break ba}f=d+576|0;b=d+512|0;e=1;while(1)if((b|0)==(f|0)){b=d+640|0;while(1)if((b|0)==(f|0)){f=20;while(1){if((f|0)==26){ra:{if(!(e&1)){break ba}v[23296]=0;b=Q(1,d+152|0,9771)|0;e=v[23296];v[23296]=0;if((e|0)==1){break ra}Hb(j,b);zb(b);break ba}}else{e=!w[(d+f|0)+452|0]&e;f=f+1|0;continue}break}b=P()|0;O()|0;break T}else{e=w[f|0]==64&e;f=f+1|0;continue}}else{e=(w[b|0]&127)==32&e;b=b+1|0;continue}}b=P()|0;O()|0;break T}v[a+480260>>2]=0;v[a+480264>>2]=2147483647;b=wc(v[n>>2],v[n+4>>2]);u[d+168>>1]=b;q=x[Zc(d+168|0,v[a+8>>2]+10|0)>>1];u[d+118>>1]=q;sa:{ta:{ua:{va:{if((b|0)!=(q|0)){v[23296]=0;Y(367,d+96|0);b=v[23296];v[23296]=0;if((b|0)==1){break sa}b=v[n+4>>2];e=v[n>>2];v[23296]=0;I=d,J=wc(e,b),v[I+136>>2]=J;X(368,d+168|0,d+96|0,d+136|0,d+118|0);b=v[23296];v[23296]=0;if((b|0)==1){break ua}b=v[a+1298464>>2];v[23296]=0;U(353,b|0,2,d+168|0);b=v[23296];v[23296]=0;if((b|0)==1){break va}zb(d+168|0);ec(d+96|0)}if(!(c&1)){u[d+118>>1]=0;q=0}m=a+480188|0;h=0;wa:{xa:{ya:{za:{Aa:{Ba:{while(1){Ca:{if((h|0)==(q|0)){Da:{Ea:{b=v[d+252>>2];if(!b){break Ea}v[23296]=0;Q(143,g|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break Da}if(!(r&1)){break Ea}while(1){Fa:{b=v[g+8>>2];c=v[g>>2];v[23296]=0;b=W(144,c|0,b|0,4)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Fa}if(!b){break Ea}v[23296]=0;b=Q(348,g|0,13672)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Fa}Ga:{if(!b){v[23296]=0;b=Q(348,g|0,13677)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Fa}if(!b){break Ga}}v[23296]=0;b=T(145,g|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){ng(g,8);if(!(b&1616928864)|b&-2139062144){break Ga}break Ea}b=P()|0;O()|0;break T}v[23296]=0;b=T(182,g|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Fa}v[23296]=0;Q(176,g|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){continue}}break}b=P()|0;O()|0;break T}v[23296]=0;b=Q(369,a|0,g|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Da}b=b|w[d+447|0];t[d+447|0]=b;if(!(!b|E)){du(a+1074312|0);t[a+1074368|0]=0}v[23296]=0;X(370,a|0,g|0,0,d+447|0);b=v[23296];v[23296]=0;if((b|0)==1){break Da}v[23296]=0;o=a+484344|0;R(213,o|0,q|0);b=v[23296];v[23296]=0;if((b|0)==1){break Da}z=a+480188|0;H=a+480183|0;h=0;Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{while(1){Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{if((h|0)!=(q|0)){b=Db(v[n>>2],h);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);if(b){v[23296]=0;b=Q(143,g|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break ab}if(b){break $a}}v[23296]=0;b=W(214,o|0,h&65535,64)|0;c=v[23296];v[23296]=0;if((c|0)==1){break ab}if(b){break bb}u[d+48>>1]=h;v[23296]=0;Y(371,d+96|0);b=v[23296];v[23296]=0;if((b|0)==1){break fb}v[23296]=0;U(372,d+168|0,d+96|0,d+48|0);b=v[23296];v[23296]=0;if((b|0)==1){break eb}b=v[a+1298464>>2];v[23296]=0;U(353,b|0,2,d+168|0);b=v[23296];v[23296]=0;if((b|0)==1){break db}zb(d+168|0);ec(d+96|0)}if(!v[a+1074308>>2]){e=x[d+488>>1];if((e|0)!=2184){break Za}v[a+1074308>>2]=18284544}if(!gh(v[j+4>>2],w[j+11|0])){break _a}v[23296]=0;c=Q(1,d+96|0,17433)|0;b=v[23296];v[23296]=0;if((b|0)==1){break Ra}b=v[a+1074308>>2];v[23296]=0;R(128,d- -64|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break Ta}v[23296]=0;U(2,d+168|0,c|0,d- -64|0);b=v[23296];v[23296]=0;if((b|0)==1){break Ua}e=d+168|0;b=Hb(j,e);zb(e);zb(d- -64|0);zb(c);if(!Pb(d+508|0,13461,4)|(x[d+488>>1]&61440)!=20480){break Ya}v[23296]=0;c=Q(1,d+168|0,16700)|0;e=v[23296];v[23296]=0;if((e|0)==1){break Va}v[23296]=0;Q(87,b|0,c|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break Wa}zb(c);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break cb}b=P()|0;O()|0;zb(d+168|0)}ec(d+96|0);break T}b=v[o>>2];v[23296]=0;R(373,$b(b,h)|0,C|0);b=v[23296];v[23296]=0;if((b|0)!=1){break Pa}}b=P()|0;O()|0;break T}v[23296]=0;b=T(182,g|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Ha}v[23296]=0;F=T(182,g|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Ia}v[23296]=0;c=Q(176,g|0,4)|0;e=v[23296];v[23296]=0;if((e|0)==1){break Ia}if(!c){break Pa}v[23296]=0;c=W(214,o|0,h&65535,F|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break Ia}if(!c){break Pa}v[23296]=0;U(178,d+96|0,g|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break Ja}b=d+96|0;m=jc(d+168|0,b);Ab(b);b=v[o>>2];v[23296]=0;R(373,$b(b,h)|0,C|0);b=v[23296];v[23296]=0;if((b|0)==1){break La}b=x[z>>1];v[23296]=0;l=Q(374,d+120|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break Ma}b=x[z>>1];c=d+96|0;wh(c);v[23296]=0;k=W(375,d+80|0,b|0,c|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break Oa}I=d,J=Eb(v[$b(v[o>>2],h)>>2]),v[I+64>>2]=J;r=0;while(1){gb:{hb:{ib:{jb:{if(r>>>0>=F>>>0){break jb}b=v[m>>2];v[23296]=0;b=W(144,b|0,v[d+176>>2],1)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Qa}if(!b){break jb}v[23296]=0;b=T(194,m|0)|0;c=v[23296];v[23296]=0;kb:{if((c|0)!=1){b=b<<24>>24;if(b){break kb}rT(d- -64|0,x[z>>1]);r=r+1|0;continue}break Qa}lb:{c=b&127;i=c?c-1&65535:0;if(ad(v[l>>2],v[d+124>>2])>>>0>i>>>0){break lb}v[23296]=0;t[d+96|0]=0;c=i+1|0;U(376,l|0,c|0,d+96|0);e=v[23296];v[23296]=0;if((e|0)==1){break Qa}e=d+96|0;wh(e);v[23296]=0;U(377,k|0,c|0,e|0);c=v[23296];v[23296]=0;if((c|0)!=1){break lb}break Qa}if((b|0)<0){v[23296]=0;b=T(194,m|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Qa}I=Lb(v[l>>2],i),J=b,t[I|0]=J}f=d+96|0;wh(f);if(i>>>0<x[z>>1]){f=Dd(v[d+64>>2],i)}b=Lb(v[l>>2],i);e=w[b|0];if(e&16){I=f,J=w[Dd(v[k>>2],i)|0],t[I|0]=J;e=w[b|0]}if(e&32){I=f,J=w[Dd(v[k>>2],i)+1|0],t[I+1|0]=J;e=w[b|0]}if(e&64){c=Dd(v[k>>2],i);t[f+2|0]=w[c+2|0];t[f+4|0]=w[c+4|0];e=w[b|0]}if(e<<24>>24<0){c=Dd(v[k>>2],i);t[f+3|0]=w[c+3|0];t[f+5|0]=w[c+5|0];e=w[b|0]}if(e&1){v[23296]=0;b=T(194,m|0)|0;c=v[23296];v[23296]=0;mb:{nb:{if((c|0)!=1){b=b<<24>>24;b=(((b^-1)&128)>>>7|0)+b|0;if(!(t[H|0]&1)){break nb}c=b;break mb}break Qa}c=253;if((b-121&255)>>>0<132){break mb}c=(b&255)==253?0:b}t[f|0]=c;I=Dd(v[k>>2],i),J=c,t[I|0]=J;b=Lb(v[l>>2],i)}if(w[b|0]&2){v[23296]=0;b=T(194,m|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Qa}t[f+1|0]=b;I=Dd(v[k>>2],i),J=b,t[I+1|0]=J;b=Lb(v[l>>2],i)}if(!(w[b|0]&4)){break gb}v[23296]=0;b=T(194,m|0)|0;c=v[23296];v[23296]=0;ob:{pb:{if((c|0)!=1){if(b>>>0>64){break pb}t[f+4|0]=b;e=1;break ob}break Qa}if(b<<24>>24<=-64){e=2;t[f+2|0]=2;b=b^-128;t[f+4|0]=b;break hb}if(b>>>0<=74){e=5;t[f+2|0]=5;b=b-65|0;t[f+4|0]=b;break hb}if(b>>>0<=84){e=6;t[f+2|0]=6;b=b-75|0;t[f+4|0]=b;break hb}if(b>>>0<=94){e=3;t[f+2|0]=3;b=b-85|0;t[f+4|0]=b;break hb}if(b>>>0<=104){e=4;t[f+2|0]=4;b=b-95|0;t[f+4|0]=b;break hb}if(b>>>0<=114){e=13;t[f+2|0]=13;b=b-105|0;t[f+4|0]=b;break hb}if(b>>>0<=124){e=12;t[f+2|0]=12;b=b-115|0;t[f+4|0]=b;break hb}c=b+63|0;if((c&255)>>>0<=9){t[f+4|0]=c;e=11;t[f+2|0]=11;b=c;break hb}c=b+53|0;G=c&255;if(G>>>0<=9){t[f+4|0]=c;e=8;t[f+2|0]=8;if(!G){b=0;break hb}if(v[a+1074308>>2]-1>>>0>18285139){break ib}e=7;t[f+2|0]=7;break ib}b=b+33|0;if((b&255)>>>0>=10){b=w[f+4|0];e=w[f+2|0];break hb}t[f+4|0]=b;e=15}t[f+2|0]=e;break hb}gk(k);fc(l);Ab(m);break Pa}b=c}c=Dd(v[k>>2],i);t[c+4|0]=b;t[c+2|0]=e;b=Lb(v[l>>2],i)}if(!(w[b|0]&8)){continue}v[23296]=0;R(247,d+32|0,m|0);b=v[23296];v[23296]=0;if((b|0)!=1){t[f+3|0]=w[d+32|0];I=f,J=w[kd(d+32|0)|0],t[I+5|0]=J;RA(f,1);b=Dd(v[k>>2],i);t[b+3|0]=w[f+3|0];t[b+5|0]=w[f+5|0];continue}break}break Qa}e=x[d+488>>1]}qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{b=e&65535;switch(b>>>12|0){case 13:break rb;case 7:break sb;case 6:break tb;case 4:break ub;case 1:break wb;case 0:break xb;default:break Xa}}if(E){v[23296]=0;b=Q(1,d+168|0,8258)|0;c=v[23296];v[23296]=0;if((c|0)!=1){Hb(j,b);zb(b);break Xa}b=P()|0;O()|0;break T}yb:{zb:{Ab:{Bb:{Cb:{Db:{Eb:{Fb:{Gb:{Hb:{Ib:{Jb:{Kb:{Lb:{if((e&65535)==532){f=x[d+490>>1];if((f|0)!=532){if((f|0)!=512){e=532;break Kb}Mb:{if(x[d+494>>1]|x[d+492>>1]!=9|(w[d+479|0]|w[d+478|0])){break Mb}if(x[d+482>>1]|x[d+480>>1]!=(x[d+486>>1]+1|0)|(w[d+496|0]!=128|w[d+497|0]!=100)){break Mb}if(w[d+498|0]!=1|w[d+500|0]!=128|(w[d+501|0]|x[d+502>>1])){break Mb}if(v[d+504>>2]|v[d+508>>2]){break Mb}v[23296]=0;b=Q(1,d+168|0,9752)|0;c=v[23296];v[23296]=0;if((c|0)!=1){Hb(j,b);zb(b);break Xa}b=P()|0;O()|0;break T}e=532;if(v[d+508>>2]|(w[d+479|0]|w[d+478|0])){break Jb}v[a+1074308>>2]=16777381;v[23296]=0;b=Q(1,d+168|0,14749)|0;c=v[23296];v[23296]=0;if((c|0)!=1){Hb(j,b);zb(b);t[d+447|0]=1;break Xa}b=P()|0;O()|0;break T}if(!Pb(d+508|0,13937,4)){v[23296]=0;b=Q(1,d+168|0,8296)|0;c=v[23296];v[23296]=0;if((c|0)!=1){Hb(j,b);zb(b);e=a+1074312|0;f=38;break vb}b=P()|0;O()|0;break T}e=532;if(w[d+501|0]|x[d+494>>1]>1|(v[d+508>>2]|(x[d+492>>1]&4294)!=4)){break Lb}if(!x[a+480190>>1]){break Lb}v[23296]=0;e=Q(54,d+96|0,13326)|0;b=v[23296];v[23296]=0;if((b|0)==1){break Hb}b=jb-16|0;jb=b;c=jb-16|0;jb=c;av(c+8|0,a+484527|0);SS(b+8|0,v[c+8>>2],v[c+12>>2]);jb=c+16|0;ve(b,e);c=Mc(v[b+8>>2],v[b+12>>2],v[b>>2],v[b+4>>2]);jb=b+16|0;yb(e);if(c){break Ib}e=x[d+488>>1]}if(e&65535){break Lb}if(gh(v[j+4>>2],w[j+11|0])){break Fb}}f=x[d+490>>1]}if((f&65535)>>>0>767){break Xa}}if(!gh(v[j+4>>2],w[j+11|0])){break Xa}if((f&65535)>>>0<533){break Db}v[23296]=0;b=Q(1,d- -64|0,14782)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Eb}Hb(j,b);zb(b);break Cb}v[23296]=0;b=Q(1,d+168|0,8322)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Gb}Hb(j,b);zb(b);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}v[23296]=0;b=Q(1,d+168|0,9642)|0;c=v[23296];v[23296]=0;if((c|0)!=1){Hb(j,b);zb(b);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if((e&65535)>>>0>=533){v[23296]=0;R(378,d- -64|0,3976);b=v[23296];v[23296]=0;Nb:{if((b|0)!=1){v[23296]=0;v[d+48>>2]=x[d+488>>1]-532;U(379,d+168|0,d- -64|0,d+48|0);b=v[23296];v[23296]=0;if((b|0)==1){break Nb}b=d+168|0;Hb(j,b);zb(b);ec(d- -64|0);break Cb}b=P()|0;O()|0;break T}b=P()|0;O()|0;ec(d- -64|0);break T}v[23296]=0;R(253,d- -64|0,4275);b=v[23296];v[23296]=0;if((b|0)==1){break Bb}b=x[d+488>>1];v[d+32>>2]=b>>>8&15;v[23296]=0;v[d+16>>2]=b&255;R(380,d+48|0,d+16|0);b=v[23296];v[23296]=0;if((b|0)==1){break Ab}v[23296]=0;X(366,d+168|0,d- -64|0,d+32|0,d+48|0);b=v[23296];v[23296]=0;if((b|0)==1){break zb}b=d+168|0;Hb(j,b);zb(b);zb(d+48|0);ec(d- -64|0)}b=a+1298408|0;if(!uc(v[b>>2],v[a+1298412>>2])){break Xa}c=v[d+508>>2];if(!c){break Xa}c=PC(x[d+488>>1],c);e=sq(d+168|0);v[e+44>>2]=c;v[23296]=0;R(381,b|0,e|0);b=v[23296];v[23296]=0;if((b|0)!=1){break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break yb}b=P()|0;O()|0;zb(d+48|0)}ec(d- -64|0);break T}c=v[d+508>>2];v[23296]=0;U(382,d+168|0,b|0,v[d+508>>2]);e=v[23296];v[23296]=0;Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{if((e|0)!=1){e=d+168|0;Hb(j,e);zb(e);b=(b|0)==8191?c:b-4176|0;if((b|0)>1915){break Tb}f=v[a+480208>>2];if(!(f&16)){break Sb}v[23296]=0;Q(252,a+1074312|0,7)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break Rb}break qb}b=P()|0;O()|0;break T}if(b>>>0>4200){break Pb}f=v[a+480208>>2]}if(!(f&16)){v[23296]=0;Q(252,a+1074312|0,7)|0;c=v[23296];v[23296]=0;if((c|0)==1){break qb}}if((b|0)>2385){break Qb}}v[23296]=0;Q(252,a+1074312|0,38)|0;b=v[23296];v[23296]=0;if((b|0)==1){break qb}}v[23296]=0;b=Q(252,a+1074312|0,102)|0;c=v[23296];v[23296]=0;if((c|0)==1){break qb}v[23296]=0;Q(252,b|0,48)|0;b=v[23296];v[23296]=0;if((b|0)==1){break qb}break Ob}if(b>>>0>4383){break Xa}}v[23296]=0;e=W(251,a+1074312|0,116,1)|0;b=v[23296];v[23296]=0;f=115;if((b|0)==1){break qb}}v[23296]=0;Q(252,e|0,f|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break qb}break Xa}v[23296]=0;Y(383,d+96|0);b=v[23296];v[23296]=0;Ub:{Vb:{Wb:{if((b|0)!=1){b=x[d+488>>1];v[d+48>>2]=b>>>8&15;v[23296]=0;v[d+32>>2]=b&255;R(380,d- -64|0,d+32|0);b=v[23296];v[23296]=0;if((b|0)==1){break Wb}v[23296]=0;X(366,d+168|0,d+96|0,d+48|0,d- -64|0);b=v[23296];v[23296]=0;if((b|0)==1){break Vb}b=d+168|0;Hb(j,b);zb(b);zb(d- -64|0);ec(d+96|0);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break Ub}b=P()|0;O()|0;zb(d- -64|0)}ec(d+96|0);break T}v[23296]=0;b=Q(1,d+168|0,8258)|0;c=v[23296];v[23296]=0;if((c|0)!=1){Hb(j,b);zb(b);break Xa}b=P()|0;O()|0;break T}if(!((b|0)!=32767|x[d+490>>1]!=533)){v[23296]=0;b=Q(1,d+168|0,5003)|0;c=v[23296];v[23296]=0;if((c|0)!=1){Hb(j,b);zb(b);break Xa}b=P()|0;O()|0;break T}v[23296]=0;R(125,d+96|0,4111);b=v[23296];v[23296]=0;Xb:{if((b|0)!=1){b=x[d+488>>1];v[d+64>>2]=b>>>8&15;v[d+48>>2]=b>>>4&15;v[23296]=0;v[d+32>>2]=b&15;da(126,d+168|0,d+96|0,d- -64|0,d+48|0,d+32|0);b=v[23296];v[23296]=0;if((b|0)==1){break Xb}b=d+168|0;Hb(j,b);zb(b);ec(d+96|0);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;ec(d+96|0);break T}v[23296]=0;b=Q(1,d+168|0,6084)|0;c=v[23296];v[23296]=0;if((c|0)!=1){Hb(j,b);zb(b);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}if(!YD(v[a+1074308>>2])){break Xa}v[23296]=0;c=Q(1,d+168|0,16936)|0;e=v[23296];v[23296]=0;Yb:{if((e|0)!=1){v[23296]=0;Q(87,b|0,c|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break Yb}zb(c);break Xa}b=P()|0;O()|0;break T}b=P()|0;O()|0;zb(c);break T}Zb:{_b:{$b:{ac:{bc:{cc:{e=v[a+480180>>2];if(!((e|0)!=16777216|x[d+488>>1]<2186)){v[23296]=0;b=Q(143,g|0,A|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Da}if(b){v[23296]=0;U(384,a|0,g|0,x[d+488>>1]);b=v[23296];v[23296]=0;if((b|0)==1){break Da}}e=v[a+480180>>2]}dc:{if((e|0)==16777216){v[23296]=0;b=Q(1,d+48|0,13645)|0;c=v[23296];v[23296]=0;if((c|0)==1){break cc}Hb(a+1298344|0,b);zb(b);break dc}v[23296]=0;R(253,d+32|0,4275);b=v[23296];v[23296]=0;if((b|0)==1){break bc}b=x[d+490>>1];v[d+28>>2]=b>>>8;v[23296]=0;v[d+12>>2]=b&255;R(380,d+16|0,d+12|0);b=v[23296];v[23296]=0;if((b|0)==1){break ac}v[23296]=0;X(366,d+48|0,d+32|0,d+28|0,d+16|0);b=v[23296];v[23296]=0;if((b|0)==1){break $b}b=d+48|0;Hb(a+1298344|0,b);zb(b);zb(d+16|0);ec(d+32|0)}b=v[a+480180>>2];v[23296]=0;b=Q(1,d+48|0,((b|0)==16777216?10016:6088)|0)|0;c=v[23296];v[23296]=0;e=1;if((c|0)==1){break Zb}Hb(a+1298356|0,b);zb(b);Hb(a+1298368|0,j);v[a+1298404>>2]=v[a+1074308>>2]?8:5;Ab(D);Ab(C);break w}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break _b}b=P()|0;O()|0;zb(d+16|0)}ec(d+32|0);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;zb(c);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;zb(d- -64|0);break Sa}b=P()|0;O()|0}zb(c);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;u[d+48>>1]=h;gk(k);break Na}h=h+1|0;continue}break}b=P()|0;O()|0;u[d+48>>1]=h}fc(l);break Ka}b=P()|0;O()|0;u[d+48>>1]=h;break Ka}b=P()|0;O()|0;u[d+48>>1]=h}Ab(m);break T}b=P()|0;O()|0;u[d+48>>1]=h;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}ec:{b=Db(v[n>>2],h);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);fc:{if(!b){break fc}v[23296]=0;b=Q(143,g|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Ba}if(!b){break fc}v[23296]=0;b=T(182,g|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break wa}v[23296]=0;l=T(182,g|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break xa}if((l-1025&65535)>>>0<64512){break fc}v[23296]=0;c=Q(176,g|0,4)|0;e=v[23296];v[23296]=0;if((e|0)==1){break xa}if(!c){break fc}v[23296]=0;U(178,d+96|0,g|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break ya}b=d+96|0;f=jc(d+168|0,b);Ab(b);c=x[m>>1];b=0;v[23296]=0;i=Q(374,d+136|0,c|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Aa}gc:{while(1){if(b>>>0>=l>>>0){break gc}c=v[f>>2];v[23296]=0;c=W(144,c|0,v[d+176>>2],1)|0;e=v[23296];v[23296]=0;if((e|0)==1){break ec}if(!c){break gc}v[23296]=0;c=T(194,f|0)|0;e=v[23296];v[23296]=0;hc:{if((e|0)!=1){c=c<<24>>24;if(c){break hc}b=b+1|0;continue}break Ca}ic:{e=c&127;o=e?e-1|0:0;k=o&65535;if(ad(v[i>>2],v[d+140>>2])>>>0>k>>>0){break ic}v[23296]=0;t[d+96|0]=0;U(376,i|0,k+1|0,d+96|0);e=v[23296];v[23296]=0;if((e|0)!=1){break ic}break Ca}jc:{if((c|0)<0){v[23296]=0;c=T(194,f|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break jc}I=Lb(v[i>>2],k),J=c,t[I|0]=J}e=Lb(v[i>>2],k);c=w[e|0];if(!(!(c&15)|k>>>0<x[m>>1])){u[m>>1]=o+1;c=w[e|0]}if(c&1){v[23296]=0;Q(176,f|0,1)|0;c=v[23296];v[23296]=0;if((c|0)==1){break jc}e=Lb(v[i>>2],k)}if(w[e|0]&2){v[23296]=0;Q(176,f|0,1)|0;c=v[23296];v[23296]=0;if((c|0)==1){break jc}e=Lb(v[i>>2],k)}if(w[e|0]&4){v[23296]=0;Q(176,f|0,1)|0;c=v[23296];v[23296]=0;if((c|0)==1){break jc}e=Lb(v[i>>2],k)}if(!(w[e|0]&8)){continue}v[23296]=0;Q(176,f|0,2)|0;c=v[23296];v[23296]=0;if((c|0)!=1){continue}}break}break Ca}v[d+96>>2]=v[g+8>>2];I=d,J=v[Yc(d+252|0,d+96|0)>>2],v[I+252>>2]=J;fc(i);Ab(f)}h=h+1|0;continue}}break}b=P()|0;O()|0;fc(i);break za}b=P()|0;O()|0;break T}b=P()|0;O()|0}Ab(f);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;zb(d+168|0);break ta}b=P()|0;O()|0}ec(d+96|0);break T}b=P()|0;O()|0;break T}b=P()|0;O()|0;break T}f=0;i=QA(d+96|0,v[h>>2]);v[23296]=0;Q(176,g|0,i|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break X}}if(w[d+99|0]!=1){break Z}b=v[h>>2]!=0|b}v[d+96>>2]=v[g+8>>2];I=d,J=v[Yc(d+252|0,d+96|0)>>2],v[I+252>>2]=J;r=(f|0)!=0}e=e+1|0;f=x[q>>1];continue}break}b=P()|0;O()|0;break T}kc:{b=Db(v[s>>2],e);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);lc:{if(!b){break lc}v[23296]=0;b=Q(143,g|0,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break kc}if(!b){break lc}b=v[g+8>>2];f=v[g>>2];v[23296]=0;b=W(144,f|0,b|0,554)|0;f=v[23296];v[23296]=0;if((f|0)==1){break kc}if(!b){break lc}v[23296]=0;b=W(239,a|0,e+1&65535,0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break W}if(!b){break lc}v[23296]=0;X(385,a|0,g|0,b|0,x[d+490>>1]);f=v[23296];v[23296]=0;if((f|0)==1){break W}t[b+33|0]=w[d+501|0]}e=e+1|0;f=x[h>>1];continue}break}b=P()|0;O()|0;break T}b=P()|0;O()|0}Ab(D);break B}b=P()|0;O()|0}Ab(C);break x}b=P()|0;O()|0;break x}b=P()|0;O()|0;break x}}}}}b=P()|0;O()|0}vc(n);vc(p);vc(s);break a}vc(n);vc(p);vc(s)}zb(j)}jb=d+640|0;return e|0}b=P()|0;O()|0}zb(j);S(b|0);L()}function Yfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0;d=jb-1744|0;jb=d;Ac(b);a:{if(!Zh(b,d+1736|0)){break a}if(!cS(d+1736|0)){break a}if(!c){e=1;break a}o=w[d+1739|0];t[d+1735|0]=o;v[d+1728>>2]=-1;v[d+1724>>2]=1048576;if(o>>>0>=5){f=qg(b);v[d+1728>>2]=f;if(!Ob(v[b>>2],v[b+8>>2],f)){break a}v[d+304>>2]=134217727;N=d,V=v[Ib(d+304|0,d+1728|0)>>2]<<5,v[N+1724>>2]=V}C=Qb(d+1712|0);v[d+304>>2]=v[d+1740>>2];f=v[Ib(d+1724|0,d+304|0)>>2];v[23296]=0;R(489,C|0,f|0);f=v[23296];v[23296]=0;b:{c:{d:{e:{f:{if((f|0)!=1){v[23296]=0;f=W(490,b|0,C|0,v[d+1740>>2])|0;g=v[23296];v[23296]=0;g:{if((g|0)==1){break g}if(!f){break b}if(o>>>0>=5){v[23296]=0;Q(143,b|0,v[d+1728>>2]+12|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break g}}v[23296]=0;R(234,a|0,0);f=v[23296];v[23296]=0;if((f|0)==1){break g}Dg(a);ke(d+1680|0,v[C>>2],v[C+4>>2]);f=$d(d+1672|0);g=v[f+4>>2];f=v[f>>2];v[23296]=0;m=wg(491,d+1688|0,v[d+1680>>2],v[d+1684>>2],f,g);f=v[23296];v[23296]=0;h:{i:{j:{if((f|0)!=1){v[23296]=0;U(336,m|0,a+1298308|0,-1);f=v[23296];v[23296]=0;if((f|0)==1){break j}v[23296]=0;U(336,m|0,a+1298332|0,-1);f=v[23296];v[23296]=0;if((f|0)==1){break j}v[23296]=0;f=Q(492,m|0,d+1248|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break f}if(!f){break c}f=t[d+1248|0];if((f|0)<=0|(w[d+1257|0]|w[d+1258|0]<<8)>>>0>255|(w[d+1259|0]|w[d+1260|0]<<8)>>>0>3999){break c}D=a+480188|0;u[D>>1]=f&255;_e(Zb(v[a+484360>>2],w[a+484376|0]),w[d+1251|0]|w[d+1252|0]<<8);u[a+480192>>1]=w[d+1257|0]|w[d+1258|0]<<8;u[a+480190>>1]=w[d+1259|0]|w[d+1260|0]<<8;f=w[d+1261|0];v[a+480196>>2]=f?f:6;f=w[d+1262|0];v[a+480204>>2]=B(f?f:125,1e4);g=w[d+1263|0]|w[d+1264|0]<<8|(w[d+1265|0]<<16|w[d+1266|0]<<24);f=32;k:{if(g&256){break k}f=2;if(g&2){break k}f=1;if(g&128){break k}f=g&8?16:4}v[23296]=0;R(351,a|0,f|0);f=v[23296];v[23296]=0;if((f|0)==1){break f}e=v[a+480208>>2];g=e|16777216;v[a+480208>>2]=g;f=w[d+1263|0]|w[d+1264|0]<<8|(w[d+1265|0]<<16|w[d+1266|0]<<24);if(f&1){g=e|16777232;v[a+480208>>2]=g}h=v[a+480180>>2];i=(h|0)==32;e=i&!(f&1024);l=(h|0)==2;q=l&f>>>2;l=l&f>>>4;i=i&!(f&2048);p=f&2097152;if(p?1:q|l|(i|e)){g=l?g|65536:g;g=q?g|2:g;g=i?g|4:g;v[a+480208>>2]=p>>>6|(e?g|8:g)}if(f&524288){v[23296]=0;W(251,a+1074312|0,5,1)|0;f=v[23296];v[23296]=0;if((f|0)==1){break f}h=v[a+480180>>2]}if((h|0)==2){break i}if((h|0)!=32){break h}t[d+304|0]=w[d+1267|0];t[d+224|0]=128;N=a,V=w[Wb(d+304|0,d+224|0)|0]<<1,v[N+480200>>2]=V;break h}c=P()|0;O()|0;break d}c=P()|0;O()|0;break e}t[d+304|0]=w[d+1267|0];t[d+224|0]=64;N=a,V=w[Wb(d+304|0,d+224|0)|0]<<2,v[N+480200>>2]=V}f=t[d+1269|0];l:{if((f|0)<0){f=f+52|0;break l}G=ts(+(f|0)*3.1/20);m:{if(G<4294967296&G>=0){f=~~G>>>0;break m}f=0}f=f+51|0}v[a+480228>>2]=f;u[d+304>>1]=64;i=x[Zc(D,d+304|0)>>1];g=0;l=(h|0)!=32;q=(h|0)==4;e=0;while(1)if((e|0)==(i|0)){e=0;i=0;while(1){if((g|0)!=16){i=w[(d+g|0)+1398|0]!=0|i;g=g+1|0;continue}break}while(1){if((e|0)!=128){i=w[((e<<1)+d|0)+1415|0]!=0|i;e=e+1|0;continue}break}n:{if(!(i&1)){break n}f=a+901692|0;e=0;while(1){if((e|0)==16){f=a+902204|0;e=0;while(1){if((e|0)!=128){g=(d+1248|0)+(e<<1)|0;o:{if(w[g+167|0]){v[23296]=0;Y(493,d+224|0);i=v[23296];v[23296]=0;p:{q:{r:{s:{t:{if((i|0)!=1){i=w[g+167|0];v[23296]=0;v[d+248>>2]=i-1;R(494,d+1192|0,d+248|0);i=v[23296];v[23296]=0;if((i|0)==1){break t}g=w[g+166|0];v[23296]=0;t[d+192|0]=g;R(495,d+1168|0,d+192|0);g=v[23296];v[23296]=0;if((g|0)==1){break s}v[23296]=0;X(496,d+304|0,d+224|0,d+1192|0,d+1168|0);g=v[23296];v[23296]=0;if((g|0)==1){break r}g=d+304|0;ve(d+1224|0,g);Ye(pe(f,e),v[d+1224>>2],v[d+1228>>2]);yb(g);yb(d+1168|0);yb(d+1192|0);Tb(d+224|0);break o}c=P()|0;O()|0;break e}c=P()|0;O()|0;break p}c=P()|0;O()|0;break q}c=P()|0;O()|0;yb(d+1168|0)}yb(d+1192|0)}Tb(d+224|0);break e}g=rc(d+1216|0,21473);Ye(pe(f,e),v[g>>2],v[d+1220>>2])}e=e+1|0;continue}break}h=v[a+480180>>2];break n}g=(d+e|0)+1398|0;u:{if(w[g|0]){v[23296]=0;Y(497,d+224|0);i=v[23296];v[23296]=0;v:{w:{x:{if((i|0)!=1){g=w[g|0];v[23296]=0;v[d+1168>>2]=g-1;R(494,d+1192|0,d+1168|0);g=v[23296];v[23296]=0;if((g|0)==1){break x}v[23296]=0;U(275,d+304|0,d+224|0,d+1192|0);g=v[23296];v[23296]=0;if((g|0)==1){break w}g=d+304|0;ve(d+1240|0,g);Ye(pe(f,e),v[d+1240>>2],v[d+1244>>2]);yb(g);yb(d+1192|0);Tb(d+224|0);break u}c=P()|0;O()|0;break e}c=P()|0;O()|0;break v}c=P()|0;O()|0;yb(d+1192|0)}Tb(d+224|0);break e}g=rc(d+1232|0,21473);Ye(pe(f,e),v[g>>2],v[d+1236>>2])}e=e+1|0;continue}}f=w[a+484376|0];g=v[a+484360>>2];v[23296]=0;g=Zb(g,f);f=h&5;da(326,g|0,m|0,w[d+1249|0]|w[d+1250|0]<<8,(f?65535:255)|0,(f?65535:254)|0);f=v[23296];v[23296]=0;if((f|0)!=1){v[23296]=0;U(178,d+304|0,m|0,B(w[d+1248|0],w[d+1253|0]|w[d+1254|0]<<8)<<1);f=v[23296];v[23296]=0;if((f|0)!=1){f=d+304|0;H=jc(d+1192|0,f);Ab(f);v[23296]=0;U(178,f|0,m|0,(w[d+1253|0]|w[d+1254|0]<<8)<<1);f=v[23296];v[23296]=0;y:{if((f|0)!=1){f=d+304|0;I=jc(d+1168|0,f);Ab(f);v[23296]=0;q=Q(206,d+1152|0,w[d+1255|0]|w[d+1256|0]<<8)|0;f=v[23296];v[23296]=0;z:{if((f|0)!=1){N=d,V=Eb(v[q>>2]),v[N+248>>2]=V;f=Eb(v[q+4>>2]);A:{B:{C:{while(1){g=v[d+248>>2];if(!Rb(g,f)){h=a+480180|0;f=v[h>>2];A=c&1;if(!A){break B}v[23296]=0;R(213,a+484344|0,w[d+1253|0]|w[d+1254|0]<<8);g=v[23296];v[23296]=0;if((g|0)!=1){break B}c=P()|0;O()|0;break A}v[23296]=0;e=T(145,m|0)|0;i=v[23296];v[23296]=0;if((i|0)!=1){v[23296]=0;U(178,d+224|0,m|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break C}h=g;g=d+224|0;e=jc(d+304|0,g);cd(h,e);Ab(e);Ab(g);vh(d+248|0);continue}break}c=P()|0;O()|0;break A}c=P()|0;O()|0;break A}r=(f|0)==16?14:(f|0)==32?1:13;J=a+484344|0;p=0;l=1;while(1){D:{E:{F:{G:{H:{I:{if((w[d+1253|0]|w[d+1254|0]<<8)>>>0<=p>>>0){switch(v[a+480180>>2]-1|0){case 0:break G;case 3:break I;default:break F}}v[23296]=0;f=T(182,I|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break H}v[d+224>>2]=f;if(!A){break D}v[23296]=0;f=W(214,J|0,p&65535,f|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break H}n=0;if(!f){break D}while(1){e=n&65535;if(e>>>0>=w[d+1248|0]){break D}v[23296]=0;f=T(182,H|0)|0;g=v[23296];v[23296]=0;J:{if((g|0)!=1){g=v[q>>2];if(Df(g,v[q+4>>2])>>>0<=f>>>0){break J}k=Cg(g,f);Ac(k);g=0;f=$b(v[J>>2],p);e=fd(v[f>>2],v[v[f+48>>2]+12>>2],0,e);K:while(1){if(y[d+224>>2]<=g>>>0){break J}v[23296]=0;f=T(194,k|0)|0;i=v[23296];v[23296]=0;if((i|0)!=1){if(!f){break J}s=f>>>4|0;z=f&15;wh(d+304|0);i=0;while(1){L:{M:{N:{if(z>>>0>(i&255)>>>0){v[23296]=0;R(498,k|0,d+248|0);f=v[23296];v[23296]=0;if((f|0)==1){break N}O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{f=w[d+248|0];switch(f-1|0){case 2:case 3:case 4:case 7:case 8:case 9:case 11:case 12:case 13:case 16:case 18:case 21:case 22:case 23:case 24:case 25:case 27:case 32:break O;case 33:break S;case 30:case 31:break T;case 29:break U;case 28:break V;case 26:break W;case 19:case 20:break X;case 17:break Y;case 15:break Z;case 14:break _;case 10:break $;case 6:break aa;case 5:break ba;case 1:break ca;case 0:break da;default:break ea}}switch(f-48|0){case 4:break P;case 1:case 2:break Q;case 0:break R;default:break O}}f=w[d+249|0];fa:{if(f>>>0<=119){f=f+r|0;break fa}ga:{switch(f-254|0){case 1:f=255;break fa;case 0:f=254;break fa;default:break ga}}f=253}t[d+304|0]=f;l=YA(f)&l;break L}t[d+305|0]=w[d+249|0]+1;break L}ha:{if(w[d+306|0]){break ha}f=v[h>>2];if((f|0)!=32){if((f|0)!=4){break ha}f=w[d+249|0];if(f&15){break ha}t[d+306|0]=11;t[d+308|0]=f>>>4;break L}f=0;j=w[d+249|0];while(1){if((f|0)==10){break ha}if((j|0)==w[f+43744|0]){t[d+308|0]=f;t[d+306|0]=11;break L}else{f=f+1|0;continue}}}t[d+307|0]=4;t[d+309|0]=w[d+249|0];break L}f=w[d+249|0];if(!(w[d+306|0]|f>>>0>9|v[h>>2]!=32)){t[d+308|0]=f;t[d+306|0]=8;break L}t[d+309|0]=f;t[d+307|0]=5;break L}if(w[d+306|0]){f=w[d+249|0];break M}j=v[h>>2];E=(j|0)!=32;f=w[d+249|0];if(!(E|(f|0)!=255)){t[d+308|0]=64;t[d+306|0]=2;break L}ia:{if(!E){if(f&3){break M}break ia}if(f&15|(j|0)!=4){break M}}t[d+306|0]=2;t[d+308|0]=(f&252)>>>2;break L}f=w[d+249|0];if(!(w[d+306|0]|f>>>0>64|v[h>>2]==1)){t[d+308|0]=f;t[d+306|0]=1;break L}t[d+309|0]=f;t[d+307|0]=13;break L}t[d+307|0]=14;f=w[d+249|0];t[d+309|0]=f;if(v[h>>2]==32){break L}t[d+309|0]=B((f&240)>>>4|0,10)+(f&15);break L}f=w[d+249|0];t[d+309|0]=f;if(f>>>0<=31){t[d+307|0]=16;break L}t[d+307|0]=17;break L}j=w[d+249|0];if(j>>>0>=16){t[d+308|0]=j>>>4;t[d+306|0]=(f|0)==20?3:5;break L}t[d+308|0]=j;t[d+306|0]=(f|0)==20?4:6;break L}f=w[d+249|0];if(f>>>0>=16){t[d+306|0]=10;t[d+308|0]=f>>>4;break L}t[d+308|0]=f;t[d+306|0]=9;break L}t[d+307|0]=28;t[d+309|0]=w[d+249|0]|16;break L}t[d+307|0]=28;t[d+309|0]=w[d+249|0]|32;break L}t[d+308|0]=w[d+249|0];t[d+306|0]=w[f+26656|0];break L}t[d+309|0]=w[d+249|0];f=w[d+307|0];t[d+307|0]=(f|0)==4?6:(f|0)==5?7:11;break L}f=w[d+249|0];t[d+308|0]=(f>>>0)%10;if(f>>>0<=9){t[d+306|0]=5;break L}if(f>>>0<=19){t[d+306|0]=6;break L}if(f>>>0<=29){t[d+306|0]=3;break L}if(f>>>0>39){break L}t[d+306|0]=4;break L}t[d+308|0]=w[d+249|0];t[d+306|0]=w[f+26656|0];break L}f=w[d+249|0]+33|0;if((f&255)>>>0>9){break L}t[d+308|0]=f;t[d+306|0]=15;break L}if(f>>>0>57){break L}t[d+309|0]=w[d+249|0];t[d+307|0]=w[f+26656|0];break L}v[d+248>>2]=g+s;f=v[Ib(d+248|0,d+224|0)>>2];f=g>>>0>f>>>0?g:f;while(1){if((g|0)!=(f|0)){i=v[d+304>>2];t[e|0]=i;t[e+1|0]=i>>>8;t[e+2|0]=i>>>16;t[e+3|0]=i>>>24;i=x[d+308>>1];t[e+4|0]=i;t[e+5|0]=i>>>8;g=g+1|0;e=B(w[d+1248|0],6)+e|0;continue}break}g=f;continue K}c=P()|0;O()|0;break A}t[d+309|0]=f;t[d+307|0]=9}i=i+1|0;continue}}break}c=P()|0;O()|0;break A}c=P()|0;O()|0;break A}n=n+1|0;continue}}e=x[a+480192>>1];f=0;break E}c=P()|0;O()|0;break A}if((l^1)&1|x[D>>1]!=4){break F}v[a+480208>>2]=v[a+480208>>2]|8454144}e=0;f=!((w[d+1263|0]|w[d+1264|0]<<8|(w[d+1265|0]<<16|w[d+1266|0]<<24))&512)}v[23296]=0;A=Q(499,d+1136|0,e|0)|0;g=v[23296];v[23296]=0;ja:{ka:{la:{ma:{na:{if((g|0)!=1){n=a+480192|0;l=o>>>0<5;p=a+480180|0;i=1;oa:{while(1){h=i&65535;if(h>>>0>x[n>>1]){break oa}pa:{qa:{ra:{sa:{if(!f){v[23296]=0;e=W(239,a|0,h|0,0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break sa}if(e){break ra}}while(1){v[23296]=0;g=T(194,m|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break ka}if(g){continue}break}if(!l){while(1){v[23296]=0;g=T(194,m|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){c=P()|0;O()|0;break ja}if(g){continue}break}}v[23296]=0;Q(176,m|0,826)|0;g=v[23296];v[23296]=0;if((g|0)!=1){break qa}}c=P()|0;O()|0;break ja}g=Kb(d+224|0);v[23296]=0;U(336,m|0,g|0,-1);k=v[23296];v[23296]=0;if((k|0)==1){break pa}Ec(e+492|0,g);if(!l){v[23296]=0;U(336,m|0,g|0,-1);k=v[23296];v[23296]=0;if((k|0)==1){break pa}Ec(e+524|0,g)}v[23296]=0;k=Q(500,m|0,d+304|0)|0;j=v[23296];v[23296]=0;if((j|0)==1){break la}if(!k){break na}k=v[p>>2];v[23296]=0;U(501,d+304|0,e|0,k|0);e=v[23296];v[23296]=0;if((e|0)==1){break la}if(v[p>>2]==4){e=Db(v[A>>2],h-1|0);h=x[d+1106>>1]|x[d+1108>>1]<<16;t[e|0]=h;t[e+1|0]=h>>>8;t[e+2|0]=h>>>16;t[e+3|0]=h>>>24}yb(g)}i=i+1|0;continue}break}break la}if(!f){break ma}u[a+480192>>1]=0;break ma}c=P()|0;O()|0;break A}yb(g)}f=x[a+480190>>1];v[23296]=0;p=Q(502,d+288|0,f|0)|0;f=v[23296];v[23296]=0;if((f|0)!=1){E=!(t[d+1263|0]&1)|o>>>0>4;r=c&2;M=a+480180|0;i=1;c=0;while(1){f=c;ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{Da:{Ea:{Fa:{Ga:{n=i&65535;if(n>>>0<=x[a+480190>>1]){h=Kb(d+272|0);v[23296]=0;U(336,m|0,h|0,-1);c=v[23296];v[23296]=0;if((c|0)==1){break Fa}l=B(n,104)+a|0;Ec(((n<<5)+a|0)+946304|0,h);c=o>>>0<5;if(!c){v[23296]=0;U(336,m|0,h|0,-1);g=v[23296];v[23296]=0;if((g|0)==1){break Fa}ze(l+484423|0,h)}v[23296]=0;g=Q(503,m|0,d+304|0)|0;e=v[23296];v[23296]=0;Ha:{Ia:{if((e|0)==1){break Ia}if(!g){break Ha}e=v[M>>2];v[23296]=0;g=l+484380|0;X(504,d+304|0,g|0,e|0,E|0);e=v[23296];v[23296]=0;if((e|0)==1){break Ia}s=0;Ja:{if((x[d+324>>1]&61440)!=28672|c){break Ja}v[23296]=0;s=T(505,m|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break Ja}c=P()|0;O()|0;break wa}if(!r){break ua}e=w[d+339|0]|w[d+340|0]<<8|(w[d+341|0]<<16|w[d+342|0]<<24);c=x[d+324>>1];k=c&61440;if(!(e|k)){c=_c(d+224|0,c&1?16:8,c&1024?3:1,0,0);v[23296]=0;W(207,c|0,g|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break ua}c=P()|0;O()|0;break wa}if((e|0)<0){c=e+n|0;if((c|0)<=0){break ua}bS(g,(B(c,104)+a|0)+484380|0);break ua}if((e|0)<=0){break ua}if(c&1){j=l+484414|0;u[j>>1]=x[j>>1]|1}if(c&1024){j=l+484414|0;u[j>>1]=x[j>>1]|64}v[23296]=0;U(178,d+224|0,b|0,e|0);e=v[23296];v[23296]=0;Ka:{La:{Ma:{Na:{Oa:{Pa:{if((e|0)!=1){j=d+224|0;e=jc(d+248|0,j);Ab(j);j=Gd(x[g+34>>1]);K=(k|0)==16384;if(!K&(k|0)!=8192){break Na}z=v[e>>2];v[23296]=0;z=T(148,z|0)|0;F=v[23296];v[23296]=0;if((F|0)==1){break Ka}F=4/(j>>>0)|0;Sia(F,0,z,0);yc(g,mb?-1:B(F,z));if((k|0)==8192){break Pa}if(!K){break Na}if(!Bg(g)){break Ma}c=v[l+484400>>2];g=v[g>>2];if(!(t[d+324|0]&1)){break Oa}v[23296]=0;X(506,e|0,c|0,g|0,j|0);g=v[23296];v[23296]=0;c=f;if((g|0)==1){break ya}break La}c=P()|0;O()|0;break wa}if(!Bg(g)){break Ma}c=v[l+484400>>2];g=v[g>>2];if(t[d+324|0]&1){v[23296]=0;X(507,e|0,c|0,g|0,j|0);g=v[23296];v[23296]=0;c=f;if((g|0)!=1){break La}break ya}v[23296]=0;X(508,e|0,c|0,g|0,j|0);g=v[23296];v[23296]=0;c=f;if((g|0)==1){break ya}break La}v[23296]=0;X(509,e|0,c|0,g|0,j|0);g=v[23296];v[23296]=0;c=f;if((g|0)==1){break ya}break La}if((c&45056)==12288){c=aS(d+224|0,e,w[d+343|0]|w[d+344|0]<<8,s);N=cd(bl(v[p>>2],n-1|0),c),V=v[c+20>>2],v[N+20>>2]=V;Ab(c);break Ma}if((k|0)!=32768){c=1;if((k|0)!=4096){break La}k=ie(d+224|0,e);v[23296]=0;c=Q(510,d+216|0,e|0)|0;j=v[23296];v[23296]=0;if((j|0)!=1){Qa:{Ra:{if(!w[d+221|0]){break Ra}s=w[d+343|0]|w[d+344|0]<<8;j=x[d+218>>1]<<1;if(s>>>0<(j&65535)>>>0){break Ra}j=s-j|0;t[d+343|0]=j;t[d+344|0]=j>>>8;c=x[c>>1];v[23296]=0;Q(143,e|0,c|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Qa}v[23296]=0;c=T(190,e|0)|0;j=v[23296];v[23296]=0;if((j|0)==1){break Qa}v[23296]=0;U(178,d+168|0,e|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break Qa}c=d+168|0;j=jc(d+192|0,c);cd(k,j);Ab(j);Ab(c)}v[23296]=0;n=W(511,a|0,n|0,k|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Qa}c=1;if(n){c=w[d+343|0]|w[d+344|0]<<8;Sa:{if(!c){break Sa}n=x[g+34>>1];j=uj(v[g>>2],n);if(j>>>0<=c>>>0){break Sa}n=mk(n);l=v[l+484400>>2];aj(l,c+l|0,j-c|0);v[g>>2]=v[g>>2]-((c>>>0)/(n>>>0)|0)}yc(g,v[d+312>>2]);c=f}Ab(k);break La}}c=P()|0;O()|0;Ab(k);break xa}v[23296]=0;c=Q(363,e|0,d+224|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break Ga}if(!c){break Ma}v[d+80>>2]=v[d+232>>2];c=v[d+228>>2];v[d+72>>2]=v[d+224>>2];v[d+76>>2]=c;hl(g,1,d+72|0)}c=f}Ab(e);break ta}c=P()|0;O()|0;break xa}c=P()|0;O()|0;break wa}yb(h)}Ta:{Ua:{Va:{if(!r){break Va}l=1;while(1){e=l&65535;if(e>>>0>x[a+480190>>1]){break Va}b=bl(v[p>>2],e-1|0);c=v[b>>2];v[23296]=0;c=T(166,c|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break Ta}Wa:{Xa:{if(!c){break Xa}g=x[b+22>>1];c=g+l&65535;i=x[b+20>>1];o=(g|0)!=0&(c|0)!=0&c>>>0<=x[a+480190>>1]&(i|0)!=0;Ya:{if(o){g=bl(v[p>>2],c-1|0);break Ya}c=v[b>>2];v[23296]=0;i=T(148,c|0)|0;c=v[23296];v[23296]=0;g=b;if((c|0)==1){break Ua}}Ac(g);Za:{if(o){c=v[g+8>>2];h=v[g>>2];n=x[b+20>>1];v[23296]=0;c=W(144,h|0,c|0,n|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break Ua}if(!c){break Xa}v[d+224>>2]=0;v[d+248>>2]=0;v[23296]=0;U(191,d+304|0,g|0,i|0);c=v[23296];v[23296]=0;_a:{if((c|0)!=1){h=nA(ye(d+304|0),wi(v[d+304>>2]),d+224|0,d+248|0);v[23296]=0;Q(176,g|0,v[d+224>>2])|0;c=v[23296];v[23296]=0;if((c|0)==1){break _a}Pc(d+304|0);break Za}c=P()|0;O()|0;break va}c=P()|0;O()|0;Pc(d+304|0);break va}h=0;v[d+224>>2]=0;v[d+248>>2]=0}v[23296]=0;R(512,d+304|0,b|0);c=v[23296];v[23296]=0;$a:{ab:{if((c|0)!=1){c=ye(d+304|0);i=v[d+304>>2];if(!o){h=nA(c,wi(i),d+224|0,d+248|0);v[23296]=0;g=v[d+224>>2];Q(176,b|0,g|0)|0;o=v[23296];v[23296]=0;if((o|0)==1){break Wa}i=i-g|0;c=c+g|0}if(h){break ab}f=1;break $a}c=P()|0;O()|0;break va}g=B(e,104)+a|0;n=g+484380|0;Bg(n);s=g+484400|0;g=0;e=v[d+248>>2];while(1){bb:{if(!i|(e|0)!=1?e:0){break bb}e=v[n>>2];if(e>>>0<=g>>>0){break bb}if(!Ud(e,v[n+20>>2])){break bb}v[d+192>>2]=0;v[d+168>>2]=0;e=$R(h,c,wi(i),d+192|0,d+272|0,d+168|0);v[23296]=0;v[d+224>>2]=e;Q(176,b|0,e|0)|0;o=v[23296];v[23296]=0;if((o|0)==1){break za}Wh(d+168|0,wi(v[n>>2]-g|0));o=v[d+168>>2];cb:{if((o|0)<=0){break cb}k=v[d+192>>2];z=x[n+34>>1];if((Gd(z)|0)!=(k|0)){break cb}j=B(g,k);r=v[s>>2];if(z&1){k=Wg(d+152|0,r+(j<<1)|0,k,o);j=Wg(d+136|0,v[d+272>>2],v[d+192>>2],o);v[23296]=0;v[d- -64>>2]=v[k+8>>2];r=v[k+4>>2];v[d+56>>2]=v[k>>2];v[d+60>>2]=r;v[d+48>>2]=v[j+8>>2];k=v[j+4>>2];v[d+40>>2]=v[j>>2];v[d+44>>2]=k;R(513,d+56|0,d+40|0);k=v[23296];v[23296]=0;if((k|0)!=1){break cb}break za}k=Wg(d+120|0,j+r|0,k,o);j=Wg(d+104|0,v[d+272>>2],v[d+192>>2],o);v[23296]=0;v[d+32>>2]=v[k+8>>2];r=v[k+4>>2];v[d+24>>2]=v[k>>2];v[d+28>>2]=r;v[d+16>>2]=v[j+8>>2];k=v[j+4>>2];v[d+8>>2]=v[j>>2];v[d+12>>2]=k;R(514,d+24|0,d+8|0);k=v[23296];v[23296]=0;if((k|0)==1){break za}}i=i-e|0;c=c+e|0;e=_R(h);v[d+248>>2]=e;g=g+o|0;continue}break}ZR(h)}Pc(d+304|0)}l=l+1|0;continue}break}break za}db:{if(v[a+480180>>2]!=4){break db}e=0;c=a+480192|0;while(1){if(x[c>>1]<=e>>>0){break db}b=Db(v[A>>2],e);g=w[b+3|0];i=w[b+2|0];h=w[b+1|0];b=w[b|0];v[23296]=0;e=e+1|0;ma(515,a|0,e&65535,b|0,h|0,i|0,g|0);b=v[23296];v[23296]=0;if((b|0)!=1){continue}break}c=P()|0;O()|0;break va}eb:{fb:{gb:{if(!(w[d+1265|0]&16)){break gb}b=v[m+8>>2];c=v[m>>2];v[23296]=0;b=W(144,c|0,b|0,1)|0;c=v[23296];v[23296]=0;hb:{ib:{jb:{if((c|0)!=1){if(!b){break gb}e=0;v[23296]=0;b=T(194,m|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break jb}if(!(b&1)){break hb}while(1){if(x[D>>1]<=e>>>0){break hb}v[23296]=0;b=T(145,m|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break ib}t[((e<<5)+a|0)+480288|0]=b;e=e+1|0;continue}}c=P()|0;O()|0;break va}c=P()|0;O()|0;break va}c=P()|0;O()|0;break va}while(1){b=v[m+8>>2];c=v[m>>2];v[23296]=0;b=W(144,c|0,b|0,1)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Aa}if(!b){break gb}v[23296]=0;b=T(194,m|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break eb}if(!b){break gb}v[23296]=0;c=T(145,m|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break fb}v[23296]=0;U(178,d+224|0,m|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break fb}c=d+224|0;g=jc(d+304|0,c);Ab(c);kb:{if(b>>>0<=250){v[23296]=0;R(386,g|0,(B(b,160)+a|0)+906140|0);b=v[23296];v[23296]=0;if((b|0)==1){break kb}}Ab(g);continue}break}c=P()|0;O()|0;Ab(g);break va}l=a+901404|0;i=Kb(d+192|0);o=a+480180|0;n=a+484348|0;g=0;c=0;while(1){b=v[m+8>>2];e=v[m>>2];v[23296]=0;b=W(144,e|0,b|0,8)|0;e=v[23296];v[23296]=0;lb:{mb:{nb:{ob:{pb:{if((e|0)!=1){if(b){v[23296]=0;e=T(145,m|0)|0;b=v[23296];v[23296]=0;qb:{rb:{sb:{tb:{ub:{vb:{wb:{xb:{if((b|0)!=1){v[23296]=0;b=T(145,m|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break xb}v[23296]=0;U(178,d+304|0,m|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break wb}h=d+304|0;b=jc(d+224|0,h);Ab(h);if((e|0)==1229211981){break tb}if((e|0)==1229476432){break ub}if((e|0)==1397900630){break vb}if((e|0)!=1414548815){break lb}v[23296]=0;e=Q(348,b|0,13698)|0;h=v[23296];v[23296]=0;if((h|0)==1){break Ea}if(!e){break mb}v[23296]=0;e=T(145,b|0)|0;h=v[23296];v[23296]=0;if((h|0)!=1){v[23296]=0;U(178,d+304|0,b|0,e|0);e=v[23296];v[23296]=0;if((e|0)!=1){break sb}}c=P()|0;O()|0;break Da}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;break Ba}yb:{zb:{Ab:{e=v[o>>2];switch(e-2|0){case 1:break lb;case 0:break rb;case 2:break zb;default:break Ab}}if((e|0)==16){break yb}if((e|0)!=32){break lb}v[23296]=0;g=T(182,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Ea}v[23296]=0;c=T(182,b|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break lb}break Ea}v[d+304>>2]=32;e=v[b>>2];v[23296]=0;e=T(148,e|0)|0;h=v[23296];v[23296]=0;if((h|0)!=1){v[d+248>>2]=e;e=v[Ib(d+304|0,d+248|0)>>2];v[23296]=0;U(516,b|0,i|0,e|0);e=v[23296];v[23296]=0;if((e|0)!=1){break lb}}c=P()|0;O()|0;break Da}v[23296]=0;e=T(194,b|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break qb}v[23296]=0;R(517,d+248|0,4172);h=v[23296];v[23296]=0;Bb:{if((h|0)!=1){v[d+272>>2]=e>>>4;v[23296]=0;v[d+88>>2]=e&15;X(288,d+304|0,d+248|0,d+272|0,d+88|0);e=v[23296];v[23296]=0;if((e|0)==1){break Bb}e=d+304|0;Hb(i,e);zb(e);ec(d+248|0);break lb}c=P()|0;O()|0;break Da}c=P()|0;O()|0;ec(d+248|0);break Da}v[23296]=0;e=T(194,b|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break Ea}v[a+480216>>2]=e;v[23296]=0;e=T(194,b|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break Ea}v[a+480220>>2]=e;break lb}v[23296]=0;Q(358,b|0,l|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break Ea}TA(l);break lb}e=d+304|0;h=jc(d+248|0,e);Ab(e);e=v[h>>2];v[23296]=0;e=T(148,e|0)|0;k=v[23296];v[23296]=0;if((k|0)==1){break nb}u[d+304>>1]=e>>>5;N=d,V=pf(v[a+484344>>2],v[n>>2]),u[N+272>>1]=V;k=x[Zc(d+304|0,d+272|0)>>1];e=0;while(1){if((e|0)==(k|0)){Ab(h);break mb}v[23296]=0;R(518,h|0,d+304|0);j=v[23296];v[23296]=0;Cb:{if((j|0)==1){break Cb}j=v[J>>2];v[23296]=0;R(519,$b(j,e)|0,d+304|0);j=v[23296];v[23296]=0;if((j|0)==1){break Cb}e=e+1|0;continue}break}break nb}v[23296]=0;g=T(182,b|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break Ea}break lb}c=P()|0;O()|0;break Da}b=v[a+480180>>2];Db:{Eb:{Fb:{if((b|0)!=32){break Fb}e=g&65535;if(e>>>0<256){break Fb}if(e>>>0<532){break Eb}}b=(b|0)!=2;Gb:{if(b){break Gb}e=g&65535;if(e>>>0<12544){break Gb}if(e>>>0<12820){break Eb}}if(b){break Db}b=g&65535;if(b>>>0<4864|b>>>0>4895){break Db}}eq(l)}e=1;Hb:{if(!(t[d+1265|0]&1)){break Hb}g=v[a+1074308>>2];if(!g){g=a+480192|0;h=a+480180|0;while(1){b=e&65535;if(b>>>0<=x[g>>1]){b=v[((b<<2)+a|0)+900380>>2];if(b){l=v[h>>2];v[23296]=0;R(520,Ei(b,2)|0,l|0);l=v[23296];v[23296]=0;if((l|0)==1){break pb}t[b+19|0]=w[b+19|0]+3>>>2}e=e+1|0;continue}break}g=v[a+1074308>>2]}if(g>>>0<=18350079){v[23296]=0;b=Q(252,a+1074312|0,27)|0;g=v[23296];v[23296]=0;if((g|0)==1){break Ca}v[23296]=0;Q(252,b|0,57)|0;b=v[23296];v[23296]=0;if((b|0)==1){break Ca}g=v[a+1074308>>2]}if(g>>>0<=19070975){v[23296]=0;Q(252,a+1074312|0,73)|0;b=v[23296];v[23296]=0;if((b|0)==1){break Ca}g=v[a+1074308>>2]}if(g>>>0>19267583){break Hb}v[23296]=0;Q(252,a+1074312|0,50)|0;b=v[23296];v[23296]=0;if((b|0)==1){break Ca}}Ib:{Jb:{Kb:{Lb:{Mb:{Nb:{Ob:{Pb:{Qb:{Rb:{Sb:{Tb:{Ub:{Vb:{if(gh(v[i+4>>2],w[i+11|0])){v[23296]=0;Y(521,d+224|0);b=v[23296];v[23296]=0;Wb:{if((b|0)!=1){v[23296]=0;U(486,d+304|0,d+224|0,d+1735|0);b=v[23296];v[23296]=0;if((b|0)==1){break Wb}break Vb}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;ec(d+224|0);break Ba}v[23296]=0;Y(522,d+224|0);b=v[23296];v[23296]=0;if((b|0)==1){break Ub}v[23296]=0;X(523,d+304|0,d+224|0,d+1735|0,i|0);b=v[23296];v[23296]=0;if((b|0)==1){break Tb}}b=d+304|0;Hb(i,b);zb(b);b=d+224|0;ec(b);v[23296]=0;R(485,b|0,3960);b=v[23296];v[23296]=0;if((b|0)==1){break Rb}v[23296]=0;U(486,d+304|0,d+224|0,d+1735|0);b=v[23296];v[23296]=0;if((b|0)==1){break Qb}b=d+304|0;Hb(a+1298344|0,b);zb(b);ec(d+224|0);v[23296]=0;b=Q(1,b|0,14830)|0;g=v[23296];v[23296]=0;if((g|0)==1){break Pb}Hb(a+1298356|0,b);zb(b);b=v[a+480180>>2];switch(b-1|0){case 2:break ob;case 1:break Lb;case 3:break Mb;case 0:break Nb;default:break Sb}}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;ec(d+224|0);break Ba}if((b|0)==16){break Ob}if((b|0)==32){break Kb}if((b|0)!=16777216){break ob}v[23296]=0;b=Q(1,d+224|0,10016)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Jb}Hb(a+1298392|0,b);zb(b);v[23296]=0;b=Q(1,d+248|0,13645)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Ib}Hb(a+1298380|0,b);zb(b);break ob}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;ec(d+224|0);break Ba}c=P()|0;O()|0;break Ba}v[23296]=0;b=Q(1,d+224|0,10021)|0;c=v[23296];v[23296]=0;Xb:{if((c|0)!=1){Hb(a+1298392|0,b);zb(b);v[23296]=0;b=Q(1,d+248|0,8283)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Xb}Hb(a+1298380|0,b);zb(b);break ob}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;break Ba}v[23296]=0;b=Q(1,d+224|0,12176)|0;c=v[23296];v[23296]=0;Yb:{if((c|0)!=1){Hb(a+1298392|0,b);zb(b);v[23296]=0;b=Q(1,d+248|0,14108)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Yb}Hb(a+1298380|0,b);zb(b);break ob}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;break Ba}v[23296]=0;b=Q(1,d+224|0,9994)|0;c=v[23296];v[23296]=0;Zb:{if((c|0)!=1){Hb(a+1298392|0,b);zb(b);v[23296]=0;b=Q(1,d+248|0,15072)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Zb}Hb(a+1298380|0,b);zb(b);break ob}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;break Ba}v[23296]=0;b=Q(1,d+224|0,10366)|0;c=v[23296];v[23296]=0;_b:{if((c|0)!=1){Hb(a+1298392|0,b);zb(b);v[23296]=0;b=Q(1,d+248|0,14870)|0;c=v[23296];v[23296]=0;if((c|0)==1){break _b}Hb(a+1298380|0,b);zb(b);break ob}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;break Ba}v[23296]=0;b=Q(1,d+224|0,6088)|0;g=v[23296];v[23296]=0;$b:{ac:{bc:{cc:{dc:{if((g|0)!=1){Hb(a+1298392|0,b);zb(b);if(!(c&65535)){break $b}v[23296]=0;R(253,d+272|0,4275);b=v[23296];v[23296]=0;if((b|0)==1){break dc}v[d+100>>2]=(c&65280)>>>8;v[23296]=0;v[d+84>>2]=c&255;R(380,d+88|0,d+84|0);b=v[23296];v[23296]=0;if((b|0)==1){break cc}v[23296]=0;X(366,d+248|0,d+272|0,d+100|0,d+88|0);b=v[23296];v[23296]=0;if((b|0)==1){break bc}b=d+248|0;Hb(a+1298380|0,b);zb(b);zb(d+88|0);ec(d+272|0);break ob}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;break ac}c=P()|0;O()|0;zb(d+88|0)}ec(d+272|0);break Ba}v[23296]=0;b=Q(1,d+248|0,8459)|0;c=v[23296];v[23296]=0;if((c|0)!=1){Hb(a+1298380|0,b);zb(b);break ob}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;break Ba}Hb(a+1298368|0,i);ec:{if(v[a+1074308>>2]){v[a+1298404>>2]=8;break ec}if(v[a+480180>>2]==1){v[a+1298404>>2]=13;break ec}v[a+1298404>>2]=5}e=1;fc:{gc:{if(f&1){v[23296]=0;b=Q(1,d+272|0,16448)|0;c=v[23296];v[23296]=0;if((c|0)==1){break gc}a=v[a+1298464>>2];v[23296]=0;U(353,a|0,2,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break fc}zb(b)}zb(i);XR(p);vc(A);ld(q);Ab(I);Ab(H);break c}c=P()|0;O()|0;break Ba}c=P()|0;O()|0;zb(b);break Ba}c=P()|0;O()|0;Ab(h);break Da}v[23296]=0;e=Q(348,b|0,13703)|0;h=v[23296];v[23296]=0;if((h|0)==1){break Ea}hc:{if(!e){break hc}v[23296]=0;e=T(145,b|0)|0;h=v[23296];v[23296]=0;ic:{if((h|0)!=1){v[23296]=0;U(178,d+248|0,b|0,e|0);e=v[23296];v[23296]=0;if((e|0)!=1){break ic}}c=P()|0;O()|0;break Da}e=d+248|0;h=jc(d+304|0,e);Ab(e);e=v[h>>2];v[23296]=0;e=T(148,e|0)|0;k=v[23296];v[23296]=0;if((k|0)!=1){u[d+248>>1]=(e>>>0)/20;u[d+272>>1]=x[D>>1];k=x[Zc(d+248|0,d+272|0)>>1];e=0;while(1){if((e|0)==(k|0)){Ab(h);break hc}v[23296]=0;U(359,h|0,((e<<5)+a|0)+480289|0,20);j=v[23296];v[23296]=0;if((j|0)!=1){e=e+1|0;continue}break}}c=P()|0;O()|0;Ab(h);break Da}v[23296]=0;Q(369,a|0,b|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break Ea}v[23296]=0;X(370,a|0,b|0,1,0);e=v[23296];v[23296]=0;if((e|0)==1){break Ea}if((g-2186&65535)>>>0<=117){v[o>>2]=16777216;v[23296]=0;U(384,a|0,b|0,g&65535);e=v[23296];v[23296]=0;if((e|0)==1){break Ea}}if(!v[a+1074308>>2]){break lb}v[23296]=0;e=Q(1,d+168|0,17433)|0;h=v[23296];v[23296]=0;jc:{kc:{lc:{if((h|0)!=1){h=v[a+1074308>>2];v[23296]=0;R(128,d+248|0,h|0);h=v[23296];v[23296]=0;if((h|0)==1){break lc}v[23296]=0;U(2,d+304|0,e|0,d+248|0);h=v[23296];v[23296]=0;if((h|0)==1){break kc}h=d+304|0;Hb(i,h);zb(h);zb(d+248|0);zb(e);break lb}c=P()|0;O()|0;break Da}c=P()|0;O()|0;break jc}c=P()|0;O()|0;zb(d+248|0)}zb(e);break Da}Ab(b);continue}}c=P()|0;O()|0;break va}c=P()|0;O()|0;break va}c=P()|0;O()|0;break va}c=P()|0;O()|0;break va}c=P()|0;O()|0;break xa}c=P()|0;O()|0;break wa}c=P()|0;O()|0}Ab(b);break Ba}c=P()|0;O()|0}zb(i);break va}c=P()|0;O()|0;break va}c=P()|0;O()|0;Pc(d+304|0);break va}c=P()|0;O()|0}Ab(e)}yb(h)}XR(p);break ja}c=f}yb(h);i=i+1|0;continue}}c=P()|0;O()|0;break ja}c=P()|0;O()|0;yb(g);break ja}c=P()|0;O()|0}vc(A);break A}p=p+1|0;continue}}ld(q);break z}c=P()|0;O()|0}Ab(I);break y}c=P()|0;O()|0}Ab(H);break e}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}else{mc:{nc:{if(!l){t[d+304|0]=w[(d+e|0)+1270|0];t[d+224|0]=64;N=((e<<5)+a|0)+480286|0,V=w[Wb(d+304|0,d+224|0)|0],u[N>>1]=V;break nc}if(q){break mc}}oc:{f=w[(d+e|0)+1334|0];if((f|0)!=255){if((f|0)!=127){break oc}v[((e<<5)+a|0)+480280>>2]=256;break mc}u[((e<<5)+a|0)+480284>>1]=256;break mc}u[((e<<5)+a|0)+480284>>1]=f}e=e+1|0;continue}}c=P()|0;O()|0;break d}c=P()|0;O()|0;break d}c=P()|0;O()|0}Ab(m)}fc(C);S(c|0);L()}Ab(m)}fc(C)}jb=d+1744|0;return e|0}function mga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=0,fa=0,ga=0;e=jb-976|0;jb=e;Ac(b);a:{if(!nS(b,e+920|0)){break a}if(!rS(e+920|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Vc(qS(e+920|0),mb))){break a}if(!c){d=1;break a}Ed(a,8);Dg(a);aa=w[e+923|0];J=aa-48|0;t[e+919|0]=J;$c(b,cc(v[e+928>>2]));f=e+608|0;Yd(f,b,504);_=jc(e+896|0,f);Ab(f);v[23296]=0;R(458,b|0,f|0);f=v[23296];v[23296]=0;b:{c:{d:{e:{f:{g:{if((f|0)!=1){if(w[e+891|0]>63){break b}if(Mb(x[e+608>>1])<<16>>16<0){break b}Xb(e+528|0,0,80);h:{d=cc(v[e+952>>2]);if(!d){break h}v[23296]=0;f=Q(143,b|0,d|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){if(!f){break h}v[23296]=0;R(459,b|0,e+528|0);d=v[23296];v[23296]=0;if((d|0)!=1){break h}}i=P()|0;O()|0;break e}v[23296]=0;U(460,e+520|0,b|0,J&255);d=v[23296];v[23296]=0;if((d|0)!=1){ba=Ue(e+520|0);d=0;f=x[e+520>>1];if((f-128&65535)>>>0<65409){break b}u[a+480188>>1]=f;K=Qb(e+504|0);f=cc(v[e+944>>2]);i:{if(f){v[23296]=0;Q(143,b|0,f|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break g}v[23296]=0;U(461,b|0,K|0,w[e+891|0]);d=v[23296];v[23296]=0;if((d|0)==1){break g}d=w[e+891|0];break i}f=0;if(w[e+891|0]){break c}}j=d&255;u[a+480192>>1]=j;u[a+480190>>1]=j;ca=(J&255)>>>0<2|t[e+872|0]>=0;p=!ca;o=c&2;s=1;C=1;while(1){j:{k:{l:{m:{n:{o:{g=C&65535;if(g>>>0<=(j&65535)>>>0){v[23296]=0;q=s&65535;f=W(239,a|0,g|0,q|0)|0;d=v[23296];v[23296]=0;p:{if((d|0)!=1){if(f){break p}break d}i=P()|0;O()|0;break f}y=v[((g<<2)+a|0)+900380>>2];u[e+84>>1]=0;v[e+80>>2]=0;v[23296]=0;D=T(162,e+480|0)|0;d=v[23296];v[23296]=0;q:{if((d|0)!=1){d=Db(v[K>>2],g-1|0);d=cc(w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));r:{if(!d){break r}v[23296]=0;f=Q(143,b|0,d|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break k}if(!f){break r}v[23296]=0;R(462,b|0,e+80|0);d=v[23296];v[23296]=0;if((d|0)==1){break k}f=v[e+80>>2];d=x[e+84>>1];v[23296]=0;f=cc(f);d=Mb(d);U(178,e+120|0,b|0,f<<(d>>>5&1&d<<16>>16>0));d=v[23296];v[23296]=0;if((d|0)==1){break k}f=e+120|0;d=jc(e+192|0,f);cd(D,d);Ab(d);Ab(f)}d=Mb(x[e+84>>1]);f=d&15;z=d<<16>>16;if((z|0)>=0){break q}St(y,0);ea=1;break o}i=P()|0;O()|0;break f}if(f>>>0>6){break o}A=w[f+26534|0];if(!f){break m}u[a+480190>>1]=(x[a+480190>>1]+A|0)-1;l=y+108|0;r=y+236|0;m=A-2|0;j=4;s:while(1){g=1;if((j|0)==10){break n}k=B(j,12);d=(m<<3)+j|0;h=w[d+26540|0]+s|0;g=w[d+26588|0];d=0;while(1)if((d|0)==12){j=j+1|0;continue s}else{f=d+k|0;fa=dc(r,f),ga=h,u[fa>>1]=ga;f=Lb(l,f);t[f|0]=g+w[f|0];d=d+1|0;continue}}}t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=cc(v[e+532>>2]);if(!d){break D}if(!Mb(x[e+536>>1])){break D}v[23296]=0;f=Q(143,b|0,d|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break C}if(!f){break D}fa=e,ga=Mb(x[e+536>>1]),u[fa+192>>1]=ga;u[e+120>>1]=w[e+891|0];f=e+120|0;o=x[Zc(e+192|0,f)>>1];d=e+128|0;l=f|4;z=Mb(x[e+538>>1]);r=z>>>0<19;m=z>>>0<21;k=z>>>0<15;h=z>>>0<6;j=0;while(1){if((j|0)==(o|0)){break D}v[23296]=0;U(463,b|0,e+192|0,z|0);f=v[23296];v[23296]=0;E:{F:{G:{if((f|0)!=1){j=j+1|0;q=v[((j<<2)+a|0)+900380>>2];p=w[e+192|0];if(p){g=ko(e+120|0,0,64);ko(l,p-1&65535,64);f=w[e+193|0];if(f){f=64/(f>>>0)|0}else{f=0}ko(d,f+p|0,0);v[23296]=0;p=q+48|0;U(464,p|0,g|0,3);f=v[23296];v[23296]=0;if((f|0)==1){break G}if(w[e+192|0]==1){g=v[hc(e+472|0,Eb(v[p>>2]))>>2];f=Eb(v[p>>2]);f=v[p>>2]+(Qt(g,f)<<2)|0;Nd(p,Ji(f+4|0,v[p+4>>2],f));Eb(f)}f=w[e+193|0];v[q>>2]=f?f<<9:32767;t[q+60|0]=w[q+60|0]|1;F=1}H:{if(r){break H}v[q+4>>2]=w[e+210|0]+1>>>1;if(m){break H}u[q+28>>1]=x[e+212>>1]}g=B(x[dc(q+236|0,61)>>1],104)+a|0;t[g+484417|0]=w[e+195|0]<<4;if(k){break F}f=cc(x[e+202>>1]|x[e+204>>1]<<16);v[g+484384>>2]=f;fa=g+484388|0,ga=cc(x[e+206>>1]|x[e+208>>1]<<16)+f|0,v[fa>>2]=ga;break E}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}if(h){continue}}f=g+484414|0;i=f;n=x[f>>1]&65529;f=w[e+197|0];u[i>>1]=n|f<<1&2|f>>>1&4;if(!(f&4)){continue}u[g+484412>>1]=0;continue}}I:{d=cc(v[e+548>>2]);if(!d){break I}if(!Mb(x[e+552>>1])){break I}v[23296]=0;f=Q(143,b|0,d|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break C}if(!f){break I}fa=e,ga=Mb(x[e+552>>1]),u[fa+192>>1]=ga;u[e+120>>1]=w[e+891|0];m=x[Zc(e+192|0,e+120|0)>>1];k=Mb(x[e+554>>1]);d=0;J:while(1){if((d|0)==(m|0)){break I}v[23296]=0;U(465,b|0,e+192|0,k|0);f=v[23296];v[23296]=0;if((f|0)==1){break t}f=e+80|0;zT(f,e+192|0);v[23296]=0;R(210,e+120|0,f|0);f=v[23296];v[23296]=0;if((f|0)==1){break u}d=d+1|0;r=((d<<2)+a|0)+900380|0;g=e+120|0;Ec(v[r>>2]+492|0,g);yb(g);f=v[r>>2];v[23296]=0;R(466,g|0,f|0);f=v[23296];v[23296]=0;if((f|0)==1){break v}fa=e,ga=qj(v[e+120>>2]),v[fa+80>>2]=ga;h=yf(e+120|0);while(1){f=v[e+80>>2];if(Rb(f,h)){l=(x[Wp(f)>>1]<<5)+a|0;g=l+946328|0;o=v[r>>2];f=v[o+520>>2];v[g>>2]=v[o+516>>2];v[g+4>>2]=f;f=v[o+512>>2];g=l+946320|0;v[g>>2]=v[o+508>>2];v[g+4>>2]=f;f=v[o+504>>2];g=l+946312|0;v[g>>2]=v[o+500>>2];v[g+4>>2]=f;f=v[o+496>>2];g=l+946304|0;v[g>>2]=v[o+492>>2];v[g+4>>2]=f;Xg(e+80|0);continue}else{uA(e+120|0);continue J}}}}eq(a+901404|0);d=rc(e+464|0,4901);Ye(pe(a+901692|0,0),v[d>>2],v[d+4>>2]);Ac(b);D=c&1;G=a+484344|0;H=a+1298332|0;da=a+1298308|0;$=a+484360|0;c=0;C=0;while(1){K:{f=c&255;if(f>>>0<w[ba|0]){v[23296]=0;X(467,b|0,e+920|0,e+528|0,e+608|0);d=v[23296];v[23296]=0;L:{M:{N:{O:{P:{if((d|0)==1){break P}Q:{if(!f){d=0;break Q}v[23296]=0;f=T(259,$|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break P}d=c;if((f|0)==255){break d}}n=pj(v[$>>2],d&255);E=hg(e+448|0);Hc(n);I=J&255;if(I>>>0>1){break N}i=0;f=Mb(x[e+610>>1]);if(f>>>0>256|x[a+480188>>1]>16){break L}d=e+192|0;kS(d,e+608|0);v[23296]=0;U(468,n|0,d|0,f|0);d=v[23296];v[23296]=0;if((d|0)==1){break O}fa=e,ga=Eb(v[n>>2]),v[fa+192>>2]=ga;d=Eb(v[n+4>>2]);while(1){f=v[e+192>>2];if(Rb(f,d)){u[f>>1]=x[f>>1]+C;Se(e+192|0);continue}else{xh(a,1);f=x[a+480188>>1];d=0;while(1)if((d|0)==(f|0)){d=32;break M}else{t[e+192|0]=w[(d+e|0)+874|0];t[e+120|0]=64;fa=((d<<5)+a|0)+480286|0,ga=w[Wb(e+192|0,e+120|0)|0],u[fa>>1]=ga;d=d+1|0;continue}}}}i=P()|0;O()|0;break f}i=P()|0;O()|0;break w}kS(e+192|0,e+608|0);R:{S:{T:{U:{d=Mb(x[e+204>>1]);if(!(!d|d>>>0>64|x[a+480188>>1]>64)){l=cc(v[e+212>>2]);d=Mb(x[e+216>>1]);if(d){u[e+120>>1]=d;u[e+80>>1]=800;f=Vc(((x[Zc(e+120|0,e+80|0)>>1]<<5)+50>>>0)/100|0,0)}else{f=32}d=v[e+200>>2];v[23296]=0;g=Q(143,b|0,cc(d)|0)|0;d=v[23296];v[23296]=0;V:{if((d|0)==1){break V}d=0;W:{if(!g){break W}while(1){if(x[a+480188>>1]<=d>>>0){break W}v[23296]=0;h=T(194,b|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){t[e+120|0]=h;t[e+80|0]=64;fa=((d<<5)+a|0)+480286|0,ga=w[Wb(e+120|0,e+80|0)|0],u[fa>>1]=ga;d=d+1|0;continue}break}i=P()|0;O()|0;break w}X:{Y:{d=cc(v[e+208>>2]);if(!d){break Y}v[23296]=0;g=Q(143,b|0,d|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break V}d=0;if(!g){break Y}while(1){if(x[a+480188>>1]<=d>>>0){break X}v[23296]=0;h=T(469,b|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){fa=((d<<5)+a|0)+480284|0,ga=(Yb(h,-16,16)<<3)+128|0,u[fa>>1]=ga;d=d+1|0;continue}break}i=P()|0;O()|0;break w}xh(a,1)}o=Qb(e+176|0);d=v[e+196>>2];v[23296]=0;g=Q(143,b|0,cc(d)|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break U}i=1;d=0;if(!g){break R}k=x[e+610>>1];h=v[b+8>>2];g=v[b>>2];v[23296]=0;h=W(144,g|0,h|0,Mb(k)<<1)|0;g=v[23296];v[23296]=0;if((g|0)==1){break U}if(!h){break R}g=x[e+610>>1];v[23296]=0;h=W(470,b|0,o|0,Mb(g)|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break U}if(!h){break R}fa=e,ga=Eb(v[o>>2]),v[fa+168>>2]=ga;r=Eb(v[e+180>>2]);while(1){d=v[e+168>>2];if(!Rb(d,r)){i=0;d=1;break R}g=Mb(w[d|0]|w[d+1|0]<<8);Z:{if(Mb(x[e+206>>1])>>>0<g>>>0){break Z}d=v[e+192>>2];v[23296]=0;Q(143,b|0,cc(d)+(g<<2)|0)|0;d=v[23296];v[23296]=0;_:{$:{aa:{ba:{ca:{if((d|0)==1){break ca}v[23296]=0;g=T(266,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break ca}v[23296]=0;g=Q(143,b|0,g|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break ca}if(!g){break Z}g=v[b+8>>2];d=v[b>>2];v[23296]=0;g=W(144,d|0,g|0,42)|0;d=v[23296];v[23296]=0;if((d|0)==1){break ca}if(!g){break Z}v[23296]=0;R(471,b|0,e+120|0);d=v[23296];v[23296]=0;da:{if((d|0)!=1){if(uc(v[n>>2],v[n+4>>2])){break da}v[23296]=0;R(472,n|0,65534);d=v[23296];v[23296]=0;if((d|0)!=1){break da}}i=P()|0;O()|0;break S}h=Mb(x[e+160>>1]);v[e+116>>2]=h;g=v[b+8>>2];d=v[b>>2];v[23296]=0;g=W(144,d|0,g|0,h|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break ba}if(!g){v[23296]=0;g=T(190,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break ba}yc(e+116|0,g)}yc(e+116|0,65534);h=v[n+4>>2];g=v[n>>2];d=0;v[23296]=0;m=v[e+116>>2];k=Nc(g,h);R(473,n|0,m+k|0);g=v[23296];v[23296]=0;if((g|0)==1){break $}while(1){ea:{if((d|0)==(m|0)){if(w[e+120|0]){break ea}break aa}v[23296]=0;h=T(258,b|0)|0;g=v[23296];v[23296]=0;fa:{if((g|0)!=1){g=h<<16>>16;if((g|0)<0){break fa}v[23296]=0;R(472,n|0,g+C&65535);g=v[23296];v[23296]=0;if((g|0)!=1){break fa}}i=P()|0;O()|0;break S}d=d+1|0;continue}break}Em(e+104|0,e+120|0);v[23296]=0;U(474,e+56|0,v[e+104>>2],v[e+108>>2]);d=v[23296];v[23296]=0;ga:{ha:{ia:{if((d|0)!=1){v[23296]=0;U(11,e+80|0,13,e+56|0);d=v[23296];v[23296]=0;if((d|0)==1){break ia}v[23296]=0;R(260,n|0,e+80|0);d=v[23296];v[23296]=0;if((d|0)==1){break ha}zb(e+80|0);yb(e+56|0);break aa}i=P()|0;O()|0;break S}i=P()|0;O()|0;break ga}i=P()|0;O()|0;zb(e+80|0)}yb(e+56|0);break S}i=P()|0;O()|0;break S}i=P()|0;O()|0;break S}d=cc(v[e+152>>2]);if(!d){break Z}v[23296]=0;g=Q(143,b|0,d|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break _}}i=P()|0;O()|0;break S}if(!g){break Z}while(1){ja:{v[23296]=0;g=Q(475,b|0,e+104|0)|0;d=v[23296];v[23296]=0;ka:{la:{ma:{if((d|0)!=1){if(!g){break Z}v[23296]=0;U(178,e+56|0,b|0,w[e+107|0]);d=v[23296];v[23296]=0;if((d|0)==1){break ma}d=e+56|0;m=jc(e+80|0,d);Ab(d);d=Mb(x[e+104>>1]);g=ou(d+k|0);u[e+56>>1]=g;if((d|0)==65535){break ja}d=v[n>>2];if(Nc(d,v[n+4>>2])>>>0<=g>>>0){break ja}na:{switch(w[e+106|0]-1|0){case 1:break ka;case 0:break la;default:break na}}Ab(m);continue}i=P()|0;O()|0;break S}i=P()|0;O()|0;break S}fa=dc(d,g),ga=65535,u[fa>>1]=ga;Ab(m);continue}v[23296]=0;h=T(258,m|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break T}v[23296]=0;g=Q(476,E|0,e+56|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break T}u[g>>1]=h;fa=dc(v[n>>2],x[e+56>>1]),ga=65534,u[fa>>1]=ga;Ab(m);continue}break}Ab(m)}Se(e+168|0);continue}}i=P()|0;O()|0;break w}i=0;break L}i=P()|0;O()|0;break S}i=P()|0;O()|0;Ab(m)}ud(o);break w}ud(o);if(d){d=f>>>(l>>>1&1)|0;break M}Pt(E);if(!i){break d}break K}g=Mb(x[e+868>>1]);k=w[e+871|0];q=k&64;f=w[e+872|0];y=f&32;M=(f&31)+1|0;fa=a,ga=hS(g,q>>>6|0,y>>>5|0,M),v[fa+480204>>2]=ga;fa=a,ga=Xd(w[e+873|0],1,32),v[fa+480196>>2]=ga;if(y){v[a+480216>>2]=M;v[a+480220>>2]=M<<2}f=w[e+890|0];if(f){t[e+192|0]=f;t[e+120|0]=64;fa=a,ga=w[Wb(e+192|0,e+120|0)|0]<<2,v[fa+480200>>2]=ga}v[a+480228>>2]=d;v[a+480232>>2]=d;v[a+480208>>2]=v[a+480208>>2]&-3|(k>>>4^-1)&2;oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{d=cc(v[e+572>>2]);if(!d){break ya}v[23296]=0;f=Q(143,b|0,d|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break xa}if(!f){break ya}d=v[e+576>>2];v[23296]=0;U(255,b|0,da|0,cc(d)|0);d=v[23296];v[23296]=0;if((d|0)==1){break xa}if(w[ba|0]<2){break ya}v[23296]=0;U(11,e+192|0,13,da|0);d=v[23296];v[23296]=0;za:{if((d|0)!=1){v[23296]=0;R(260,n|0,e+192|0);d=v[23296];v[23296]=0;if((d|0)==1){break za}zb(e+192|0);break ya}i=P()|0;O()|0;break w}i=P()|0;O()|0;zb(e+192|0);break w}Aa:{if(cc(v[e+544>>2])>>>0<2){break Aa}d=v[e+540>>2];v[23296]=0;f=Q(143,b|0,cc(d)|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break xa}if(!f){break Aa}d=v[e+544>>2];v[23296]=0;X(317,H|0,b|0,cc(d)-1|0,4);d=v[23296];v[23296]=0;if((d|0)==1){break xa}}d=cc(v[e+584>>2]);if(!d){break oa}v[23296]=0;f=Q(143,b|0,d|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break xa}if(!f){break oa}f=v[b+8>>2];d=v[b>>2];v[23296]=0;f=W(144,d|0,f|0,12)|0;d=v[23296];v[23296]=0;if((d|0)==1){break xa}if(!f){break oa}v[23296]=0;Q(176,b|0,6)|0;d=v[23296];v[23296]=0;if((d|0)==1){break xa}v[23296]=0;f=T(258,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break xa}if((f|0)!=1){break oa}v[23296]=0;g=T(266,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break va}if(!g){break oa}f=v[b+8>>2];d=v[b>>2];v[23296]=0;f=W(144,d|0,f|0,g|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break va}if(f){break wa}break oa}i=P()|0;O()|0;break w}h=Sc(e+192|0,H);v[23296]=0;X(317,H|0,b|0,g|0,4);d=v[23296];v[23296]=0;if((d|0)==1){break qa}if(!De(h)){v[23296]=0;f=W(477,e+24|0,2,13)|0;d=v[23296];v[23296]=0;if((d|0)==1){break ua}v[23296]=0;U(478,e+120|0,h|0,f|0);d=v[23296];v[23296]=0;if((d|0)==1){break ta}v[23296]=0;U(479,e+40|0,e+120|0,H|0);d=v[23296];v[23296]=0;if((d|0)==1){break sa}d=e+40|0;Bc(H,d);yb(d);yb(e+120|0);yb(f)}yb(h);break oa}i=P()|0;O()|0;break w}i=P()|0;O()|0;break pa}i=P()|0;O()|0;break ra}i=P()|0;O()|0;yb(e+120|0)}yb(f);break pa}i=P()|0;O()|0}yb(h);break w}Ba:{if(I>>>0<2){break Ba}i=0;if(!cc(v[e+596>>2])){break Ba}while(1){if(x[a+480188>>1]<=i>>>0){break Ba}d=v[e+596>>2];v[23296]=0;f=Q(143,b|0,cc(d)+(i<<2)|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break x}Ca:{if(!f){break Ca}v[23296]=0;f=T(266,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break x}v[23296]=0;f=Q(143,b|0,f|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break x}g=0;d=0;if(!f){break Ca}while(1){Da:{h=v[b+8>>2];f=v[b>>2];v[23296]=0;h=W(144,f|0,h|0,8)|0;f=v[23296];v[23296]=0;Ea:{Fa:{Ga:{if((f|0)!=1){if(!h){break Da}v[23296]=0;R(480,b|0,e+192|0);f=v[23296];v[23296]=0;if((f|0)==1){break Ga}f=cc(v[e+192>>2]);if(!f){break Da}switch((f&536870911)-1|0){case 1:break Ea;case 0:break Fa;default:continue}}i=P()|0;O()|0;break w}i=P()|0;O()|0;break w}g=cc(v[e+196>>2]);continue}d=cc(v[e+196>>2]);continue}break}if(!g|!d){break Ca}v[23296]=0;g=Q(143,b|0,g|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break y}if(!g){break Ca}v[23296]=0;U(359,b|0,((i<<5)+a|0)+480289|0,d|0);d=v[23296];v[23296]=0;if((d|0)==1){break y}}i=i+1|0;continue}}d=x[e+608>>1];v[23296]=0;s=Mb(d);R(213,G|0,C+s&65535);d=v[23296];v[23296]=0;if((d|0)==1){break z}z=k&16;p=C&65535;g=0;Ha:{Ia:{while(1){if((g|0)==(s|0)){fa=e,ga=qj(v[E>>2]),v[fa+120>>2]=ga;g=yf(E);while(1){d=v[e+120>>2];if(!Ag(d,g)){i=1;d=cc(v[e+528>>2]);if(!d){break L}v[23296]=0;f=Q(143,b|0,d|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break z}if(!f){break L}C=s+C|0;Pt(E);break K}k=Wp(d);h=Ue(k);Ja:{Ka:{La:{Ma:{d=x[k>>1];if(!d){j=0;break Ma}v[23296]=0;f=Q(297,n|0,d-1&65535)|0;d=v[23296];v[23296]=0;if((d|0)==1){break Ja}j=x[k>>1];if(!f){break Ma}v[23296]=0;j=Q(346,n|0,j-1&65535)|0;d=v[23296];v[23296]=0;if((d|0)==1){break Ja}break La}if(x[h>>1]==((j&65535)+1|0)){break Ka}v[23296]=0;j=Q(345,G|0,1)|0;d=v[23296];v[23296]=0;if((d|0)==1){break Ja}if((j|0)==65535){break Ka}fa=dc(v[n>>2],x[k>>1]),ga=j,u[fa>>1]=ga}d=$b(v[G>>2],j);qe(d,qm(Ke(Fe(e+192|0,12,ju(x[h>>1])),v[d+12>>2]-1|0)));s=(s&65535)>>>0>j>>>0?s:j+1|0}Xg(e+120|0);continue}break}i=P()|0;O()|0;break w}Na:{Oa:{if(!D){break Oa}d=v[e+936>>2];v[23296]=0;f=Q(143,b|0,cc(d)+(g<<2)|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break Ia}if(!f){break Oa}v[23296]=0;f=T(266,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break Ia}v[23296]=0;f=Q(143,b|0,f|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break Ia}if(!f){break Oa}N=Kb(e+56|0);v[23296]=0;V=T(162,e|0)|0;d=v[23296];v[23296]=0;Pa:{Qa:{if((d|0)!=1){if(I){break Qa}v[23296]=0;R(481,b|0,e+192|0);d=v[23296];v[23296]=0;if((d|0)==1){break Na}u[e+104>>1]=w[e+192|0];Y=w[e+193|0]+1|0;f=48;break Pa}i=P()|0;O()|0;break A}v[23296]=0;m=t[e+870|0];R(482,b|0,e+176|0);d=v[23296];v[23296]=0;Ra:{Sa:{if((d|0)!=1){k=Mb(x[e+176>>1]);u[e+104>>1]=k;Y=Mb(x[e+178>>1])+1|0;d=cc(v[e+180>>2]);if(!d){break Ra}h=v[b+8>>2];v[23296]=0;Q(143,b|0,d|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break B}v[23296]=0;R(483,b|0,e+192|0);d=v[23296];v[23296]=0;if((d|0)==1){break B}d=v[e+196>>2];v[23296]=0;f=Q(143,b|0,cc(d)|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break B}if(!f){break Sa}d=v[e+200>>2];v[23296]=0;U(255,b|0,N|0,cc(d)|0);d=v[23296];v[23296]=0;if((d|0)!=1){break Sa}break B}break B}d=cc(v[e+208>>2]);Ta:{if(!d){break Ta}v[23296]=0;f=Q(143,b|0,d|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break B}if(!f){break Ta}v[23296]=0;f=T(266,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break B}v[23296]=0;f=Q(143,b|0,f|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break B}if(!f){break Ta}v[23296]=0;U(178,e+80|0,b|0,B(k,Y)|0);d=v[23296];v[23296]=0;if((d|0)==1){break B}f=e+80|0;d=jc(e+120|0,f);cd(V,d);Ab(d);Ab(f)}v[23296]=0;Q(143,b|0,h|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break B}}f=m+(I>>>0<3?48:24)|0}v[23296]=0;k=g+p|0;h=W(214,G|0,k&65535,Y|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break B}Ua:{if(!h){break Ua}d=v[G>>2];v[23296]=0;A=$b(d,k);R(268,A|0,N|0);d=v[23296];v[23296]=0;if((d|0)==1){break Ha}ug(e+104|0,x[a+480188>>1]);Z=0;o=x[e+104>>1];Va:while(1){if((Y|0)==(Z|0)){break Ua}i=0;d=fd(v[A>>2],v[v[A+48>>2]+12>>2],Z,0);while(1){if((i&65535)>>>0>=o>>>0){Z=Z+1|0;continue Va}Wa:{if(!I){v[23296]=0;R(484,e+192|0,b|0);h=v[23296];v[23296]=0;if((h|0)!=1){m=w[e+192|0];k=e+192|0;h=kd(k);t[d+1|0]=m>>>3&16|w[h|0]>>>4|m>>>1&32;t[d+3|0]=w[h|0]&15;fa=d,ga=w[Ue(k)|0],t[fa+5|0]=ga;h=m&63;j=h?h+f|0:0;break Wa}break B}v[23296]=0;R(335,e+192|0,b|0);h=v[23296];v[23296]=0;Xa:{Ya:{if((h|0)!=1){h=e+192|0;l=kd(h);r=Ue(h);m=Ci(h);v[23296]=0;k=T(194,V|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break B}t[d+4|0]=k;k=w[e+192|0];h=k&127;if(!h){break Ya}j=f+h|0;break Xa}break B}j=0;if((k|0)!=128){break Xa}t[d|0]=254}t[d+1|0]=w[l|0]&63;t[d+3|0]=w[r|0];t[d+5|0]=w[m|0]}if(j-1>>>0<=119){t[d|0]=j}F=(j|0)>84&ca|F;r=(q|0)!=0;m=(y|0)!=0;k=(z|0)!=0;l=jb-16|0;jb=l;Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{pb:{qb:{rb:{sb:{tb:{ub:{vb:{wb:{h=w[d+3|0];switch(h-4|0){case 42:break $a;case 37:break ab;case 28:break bb;case 27:break cb;case 26:break db;case 25:break eb;case 24:break fb;case 23:break gb;case 22:break hb;case 21:break ib;case 20:break jb;case 18:break kb;case 17:break lb;case 16:break mb;case 14:break nb;case 13:break ob;case 12:break pb;case 11:break qb;case 10:break rb;case 9:break sb;case 8:break tb;case 5:break ub;case 4:break vb;case 0:break wb;default:break _a}}t[d+3|0]=5;k=w[d+5|0];t[l+15|0]=k>>>3;t[l+14|0]=15;h=w[Wb(l+15|0,l+14|0)|0];t[l+13|0]=k<<1&30;t[l+12|0]=15;fa=d,ga=w[Wb(l+13|0,l+12|0)|0]|h<<4,t[fa+5|0]=ga;break Za}t[d+3|0]=0;break Za}if((w[d+5|0]-1&255)>>>0<=19){t[d+3|0]=16;break Za}t[d+3|0]=0;break Za}t[d+3|0]=13;h=w[d+5|0];xb:{if(!k){if(h>>>0>152){break xb}t[d+5|0]=B((h&240)>>>4|0,10)+(h&15);break Za}t[d+5|0]=(h&127)+1>>>1;break Za}t[d+3|0]=0;break Za}t[d+3|0]=11;break Za}t[d+3|0]=0;break Za}h=w[d+5|0];if(!h){t[d+3|0]=14;break Za}if(h>>>0<=240){t[d+3|0]=17;if(h>>>0<=2){t[d+5|0]=112;break Za}fa=d,ga=io(+(hS(h,r,m,M)>>>0)/1e4),t[fa+5|0]=ga;break Za}t[d+3|0]=0;break Za}t[d+3|0]=31;t[d+5|0]=w[d+5|0]|128;break Za}t[d+3|0]=19;t[l+11|0]=15;fa=d,ga=w[Wb(d+5|0,l+11|0)|0]|16,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+10|0]=15;fa=d,ga=w[Wb(d+5|0,l+10|0)|0]|32,t[fa+5|0]=ga;break Za}t[d+3|0]=5;h=w[d+5|0];t[l+9|0]=(h>>>4|0)+1;t[l+8|0]=15;fa=d,ga=h&15|w[Wb(l+9|0,l+8|0)|0]<<4,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[d+5|0]=w[d+5|0]&15|80;break Za}t[d+3|0]=19;t[l+7|0]=15;fa=d,ga=w[Wb(d+5|0,l+7|0)|0]|96,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+6|0]=15;fa=d,ga=w[Wb(d+5|0,l+6|0)|0]|192,t[fa+5|0]=ga;break Za}t[d+3|0]=10;break Za}t[d+3|0]=19;t[l+5|0]=15;fa=d,ga=w[Wb(d+5|0,l+5|0)|0]|160,t[fa+5|0]=ga;break Za}t[d+3|0]=19;t[l+4|0]=15;fa=d,ga=w[Wb(d+5|0,l+4|0)|0]|176,t[fa+5|0]=ga;break Za}h=(w[d+5|0]<<24)-16777216>>24;if((h|0)>=0){t[d+5|0]=h;t[d+3|0]=31;break Za}t[d+3|0]=0;break Za}t[d+3|0]=14;break Za}t[d+3|0]=19;t[l+3|0]=15;fa=d,ga=w[Wb(d+5|0,l+3|0)|0]|224,t[fa+5|0]=ga;break Za}h=w[d+5|0];if(h&240){t[d+3|0]=19;t[d+5|0]=h>>>4|208;break Za}if(h&15){t[d+3|0]=19;t[d+5|0]=h|144;break Za}t[d+3|0]=0;break Za}if(!(w[d+5|0]|w[d+4|0])){if(!Uc(w[d|0])){break Za}t[d+5|0]=159;t[d+3|0]=20;break Za}t[d+3|0]=0;break Za}h=w[d+4|0];if(h){t[d+3|0]=44;fa=d,ga=Bm(Vc(((w[d+5|0]<<8&65280)>>>0)/(h>>>0)|0,0)),t[fa+5|0]=ga;break Za}t[d+3|0]=0;break Za}h=w[d+5|0];if((h+16&255)>>>0<=32){t[d+3|0]=9;fa=d,ga=xi(((h^128)<<3)-896|0),t[fa+5|0]=ga;break Za}t[d+3|0]=0;break Za}if(h>>>0<=15){Of(d);break Za}t[d+3|0]=0}jb=l+16|0;d=d+6|0;i=i+1|0;continue}}}Ab(V);yb(N)}g=g+1|0;continue}break}break B}i=P()|0;O()|0;break w}break B}Pt(E);f=0;if(!i){break c}}Ai($,0);d=1;yb:{if(F&1){break yb}while(1){b=d&65535;if(b>>>0>x[a+480192>>1]){u[a+480192>>1]=0;break yb}c=((b<<2)+a|0)+900380|0;b=v[c>>2];if(b){Jb(Rt(b))}v[c>>2]=0;d=d+1|0;continue}}zb:{if(!ea){break zb}v[23296]=0;c=Q(1,e+192|0,16189)|0;b=v[23296];v[23296]=0;Ab:{if((b|0)!=1){b=v[a+1298464>>2];v[23296]=0;U(353,b|0,2,c|0);b=v[23296];v[23296]=0;if((b|0)==1){break Ab}zb(c);break zb}i=P()|0;O()|0;break f}i=P()|0;O()|0;zb(c);break f}j=21473;Bb:{Cb:{switch(aa-48|0){case 0:j=x[a+480188>>1]>4?17084:17070;break Bb;case 1:j=17052;break Bb;case 2:j=17034;break Bb;case 3:break Cb;default:break Bb}}j=17007}v[23296]=0;R(485,e+80|0,16622);b=v[23296];v[23296]=0;Db:{Eb:{Fb:{if((b|0)!=1){v[23296]=0;U(486,e+120|0,e+80|0,e+919|0);b=v[23296];v[23296]=0;if((b|0)==1){break Fb}b=e+120|0;Hb(a+1298344|0,b);zb(b);ec(e+80|0);v[23296]=0;c=Q(1,b|0,12496)|0;b=v[23296];v[23296]=0;if((b|0)==1){break Eb}Hb(a+1298356|0,c);zb(c);v[23296]=0;R(124,a+1298368|0,j|0);b=v[23296];v[23296]=0;if((b|0)==1){break Db}v[a+1298404>>2]=13;f=1;break c}i=P()|0;O()|0;break f}i=P()|0;O()|0;ec(e+80|0);break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}c=c+1|0;continue}}i=P()|0;O()|0;break f}i=P()|0;O()|0;Ab(V)}yb(N);break w}i=P()|0;O()|0;break w}i=P()|0;O()|0;break w}i=P()|0;O()|0}Pt(E);break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}i=P()|0;O()|0;break f}A=1;if((f|0)!=7){break m}d=y+108|0;f=bA(d);while(1){if((d|0)!=(f|0)){fa=d,ga=qo(w[d|0]-24|0),t[fa|0]=ga;d=d+1|0;continue}break}g=0}F=1;break l}g=0;Gb:{if(p|(z|0)<0){break Gb}m=y+108|0;j=7;Hb:while(1){if((j|0)==10){break Gb}k=B(j,12);h=B(j,-12)+72|0;d=0;while(1)if((d|0)==12){j=j+1|0;continue Hb}else{f=Lb(m,d+k|0);t[f|0]=h+w[f|0];d=d+1|0;continue}}}}v[23296]=0;R(487,_|0,e+192|0);d=v[23296];v[23296]=0;if((d|0)!=1){Ib:{d=w[e+196|0];if((d-1&255)>>>0<=15){t[y+31|0]=d;F=1}d=w[e+197|0];if((d<<24)-16777216>>24>=0){t[y+30|0]=d}d=0;Jb:{while(1){if((d|0)==(A|0)){if(!o){break j}if((z|0)>=0){break Jb}break j}v[23296]=0;h=B(d+q|0,104)+a|0;R(264,h+484380|0,8);f=v[23296];v[23296]=0;if((f|0)!=1){t[e+120|0]=w[e+198|0];t[e+56|0]=64;fa=h+484410|0,ga=w[Wb(e+120|0,e+56|0)|0]<<2,u[fa>>1]=ga;t[h+484416|0]=w[e+199|0];d=d+1|0;continue}break}break k}m=_c(e+120|0,8,1,1,0);h=Mb(x[e+194>>1]);i=Mb(x[e+192>>1]);d=v[D>>2];v[23296]=0;j=T(148,d|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){d=Mb(x[e+84>>1]);if(d&16){Fh(m,16);j=j>>>1|0}if(d&32){Ao(m,3);j=j>>>1|0}if(d&64){Sf(m,2)}j=g?(j>>>0)/((-1<<A^-1)>>>0)|0:j;g=h+i|0;d=0;while(1){if((d|0)==(A|0)){break j}k=B(d+q|0,104)+a|0;f=k+484380|0;v[f>>2]=j;v[23296]=0;W(207,m|0,f|0,D|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break Ib}i=i<<1;g=g<<1;if(h>>>0>=2){v[k+484388>>2]=g;v[k+484384>>2]=i;f=k+484414|0;u[f>>1]=x[f>>1]|2}d=d+1|0;j=j<<1;continue}}}}}i=P()|0;O()|0;Ab(D);break f}Ab(D);C=C+1|0;s=s+A|0;j=x[a+480192>>1];continue}}i=P()|0;O()|0;break e}i=P()|0;O()|0;break e}i=P()|0;O()|0}vc(K)}Ab(_);S(i|0);L()}f=0}d=f;vc(K)}Ab(_)}jb=e+976|0;return d|0}function Rda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,A=0,D=C(0),E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,da=0,ea=C(0),ga=0,ha=0,ia=0,ka=0,la=0,ma=0;e=jb-672|0;jb=e;Ac(b);a:{b:{c:{if(!Zh(b,e+664|0)){break c}if(!aQ(e+664|0)){break c}if((sm(b)|0)>=0){break c}if(!c){d=1;break c}Ed(a,16777216);d=a+480208|0;v[d>>2]=v[d>>2]|1681e4;Mz(e+272|0,32);g=v[e+284>>2];d=a+1074320|0;v[d>>2]=v[e+280>>2];v[d+4>>2]=g;d=v[e+276>>2];v[a+1074312>>2]=v[e+272>>2];v[a+1074316>>2]=d;Bf(a+1074312|0,38);p=Qb(e+648|0);q=Qb(e+632|0);A=Qb(e+616|0);l=Qb(e+600|0);ng(b,4);m=a+480190|0;J=c&1;I=a+1298332|0;r=2500;H=!(c&2);F=a+1298464|0;d:{e:{f:{while(1){c=v[b+8>>2];d=v[b>>2];v[23296]=0;c=W(144,d|0,c|0,4)|0;d=v[23296];v[23296]=0;g:{h:{i:{j:{k:{l:{m:{if((d|0)!=1){n:{if(c){v[23296]=0;c=T(633,b|0)|0;d=v[23296];v[23296]=0;o:{if((d|0)==1){break o}n=4;d=0;p:{q:{r:{switch(c+21|0){case 20:v[23296]=0;c=T(266,b|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){d=c&65535;if(x[a+480188>>1]|d-1>>>0>126){continue}u[a+480188>>1]=c;la=a,ma=Yb(512/(d>>>0)|0,16,128),v[la+480228>>2]=ma;continue}c=P()|0;O()|0;break a;case 19:v[23296]=0;K=T(266,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break o}if(K>>>0<=1024){continue}break m;case 16:v[23296]=0;c=T(266,b|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){if((c&65535)==4){continue}break m}c=P()|0;O()|0;break a;case 15:v[23296]=0;c=T(266,b|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){v[e+272>>2]=c;v[e+168>>2]=800;la=a,ma=Ie(+y[Ib(e+272|0,e+168|0)>>2]*1.24*1e4),v[la+480204>>2]=ma;continue}c=P()|0;O()|0;break a;case 31:v[23296]=0;c=T(266,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break o}Z=1;r=Xd(c,0,1e4);continue;case 32:case 33:v[23296]=0;c=T(266,b|0)|0;d=v[23296];v[23296]=0;s:{t:{if((d|0)!=1){Z=1;if(!c){continue}v[23296]=0;d=Q(1,e+584|0,12405)|0;c=v[23296];v[23296]=0;if((c|0)==1){break t}c=v[F>>2];v[23296]=0;U(353,c|0,2,d|0);c=v[23296];v[23296]=0;if((c|0)==1){break s}zb(d);continue}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;zb(d);break a;case 14:v[23296]=0;Q(176,b|0,4)|0;c=v[23296];v[23296]=0;if((c|0)==1){break o}i=!x[m>>1]|i;continue;case 11:if(!J){break q}if(!uc(v[p>>2],v[p+4>>2])){break q}v[23296]=0;R(634,e+272|0,b|0);c=v[23296];v[23296]=0;if((c|0)!=1){if(v[p>>2]){Hc(p);c=v[p>>2];ho(p);Jb(c);la=Gb(p),ma=0,v[la>>2]=ma;v[p>>2]=0;v[p+4>>2]=0}c=e+272|0;v[p>>2]=v[c>>2];v[p+4>>2]=v[c+4>>2];d=Gb(c);la=Gb(p),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;vi(c);continue}c=P()|0;O()|0;break a;case 3:case 4:case 10:g=rh(v[l>>2],v[l+4>>2]);d=x[m>>1];if(g>>>0<=d>>>0){continue}if((i|H)&1){break q}if(!Sh(d)){break q}d=d+1|0;u[m>>1]=d;s=Qb(e+568|0);v[23296]=0;i=T(162,e+544|0)|0;g=v[23296];v[23296]=0;u:{v:{w:{if((g|0)!=1){if((c|0)==-17){break w}if((c|0)!=-11){break v}v[23296]=0;c=T(266,b|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break u}v[23296]=0;U(178,e+168|0,b|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break u}c=e+168|0;g=jc(e+272|0,c);cd(i,g);Ab(g);break g}c=P()|0;O()|0;break d}v[23296]=0;R(635,e+272|0,b|0);c=v[23296];v[23296]=0;x:{if((c|0)!=1){c=e+272|0;g=pm(s,c);fc(c);ke(e+512|0,v[g>>2],v[e+572>>2]);c=v[$d(e+504|0)>>2];v[23296]=0;c=wg(314,e+520|0,v[e+512>>2],v[e+516>>2],c,v[e+508>>2]);g=v[23296];v[23296]=0;if((g|0)==1){break x}cd(i,c);break g}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}v[23296]=0;R(636,e+272|0,b|0);c=v[23296];v[23296]=0;y:{if((c|0)!=1){c=e+272|0;g=pm(s,c);fc(c);ke(e+472|0,v[g>>2],v[e+572>>2]);c=v[$d(e+464|0)>>2];v[23296]=0;c=wg(314,e+480|0,v[e+472>>2],v[e+476>>2],c,v[e+468>>2]);g=v[23296];v[23296]=0;if((g|0)==1){break y}cd(i,c);break g}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e;case 9:c=x[m>>1];if(!Sh(c)){continue}u[m>>1]=c+1;continue;case 8:if(!J){break q}if(!uc(v[A>>2],v[A+4>>2])){break q}v[23296]=0;R(637,e+272|0,b|0);c=v[23296];v[23296]=0;if((c|0)!=1){c=e+272|0;$P(A,c);vc(c);continue}c=P()|0;O()|0;break a;case 7:if(!uc(v[l>>2],v[l+4>>2])){break q}v[23296]=0;R(638,e+272|0,b|0);c=v[23296];v[23296]=0;if((c|0)!=1){if(v[l>>2]){Hc(l);c=v[l>>2];Lz(l);Jb(c);la=Gb(l),ma=0,v[la>>2]=ma;v[l>>2]=0;v[l+4>>2]=0}c=e+272|0;v[l>>2]=v[c>>2];v[l+4>>2]=v[c+4>>2];d=Gb(c);la=Gb(l),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;zt(c);continue}c=P()|0;O()|0;break a;case 6:if(!J){break q}if(!uc(v[q>>2],v[q+4>>2])){break q}v[23296]=0;R(639,e+272|0,b|0);c=v[23296];v[23296]=0;if((c|0)!=1){if(v[q>>2]){Hc(q);c=v[q>>2];or(q);Jb(c);la=Gb(q),ma=0,v[la>>2]=ma;v[q>>2]=0;v[q+4>>2]=0}c=e+272|0;v[q>>2]=v[c>>2];v[q+4>>2]=v[c+4>>2];d=Gb(c);la=Gb(q),ma=v[d>>2],v[la>>2]=ma;v[d>>2]=0;v[c>>2]=0;v[c+4>>2]=0;dl(c);continue}c=P()|0;O()|0;break a;case 17:case 18:break p;case 0:case 1:case 2:break q;case 5:break r;default:break m}}v[23296]=0;R(640,e+272|0,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break n}z:{c=v[e+272>>2];d=v[e+276>>2];if(uc(c,d)){break z}v[23296]=0;X(323,I|0,c|0,ad(c,d)|0,1);c=v[23296];v[23296]=0;if((c|0)!=1){break z}c=P()|0;O()|0;fc(e+272|0);break a}fc(e+272|0);continue}v[23296]=0;n=T(266,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break o}}v[23296]=0;Q(176,b|0,n|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){continue}}c=P()|0;O()|0;break a}d=0;if(!x[a+480188>>1]|!K){break m}b=v[l>>2];c=v[l+4>>2];if(uc(b,c)){break m}if(J){if(uc(v[p>>2],v[p+4>>2])){break m}if(uc(v[A>>2],v[A+4>>2])){break m}if(uc(v[q>>2],v[q+4>>2])){break m}}b=rh(b,c);if(b>>>0>=256){v[23296]=0;R(641,l|0,255);b=v[23296];v[23296]=0;if((b|0)==1){break b}b=rh(v[l>>2],v[l+4>>2])}u[a+480192>>1]=b;h=a+480190|0;n=a+480192|0;la=h,ma=x[We(m,n)>>1],u[la>>1]=ma;if(i&1){v[23296]=0;b=Q(1,e+568|0,16278)|0;c=v[23296];v[23296]=0;if((c|0)==1){break h}c=v[a+1298464>>2];v[23296]=0;U(353,c|0,2,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break i}zb(b)}i=0;A:while(1){if((i|0)!=2){d=1;while(1){f=d&65535;if(f>>>0>x[n>>1]){i=i+1|0;continue A}B:{c=dm(v[l>>2],f-1|0);if(!w[c|0]|t[c+128|0]<0){break B}if((wt(c)|0)==((i|0)!=1|0)){break B}C:{D:{E:{g=0;F:{if(!wt(c)){break F}if(Mb(w[c+6|0]|w[c+7|0]<<8)){break F}if(Mb(w[c+14|0]|w[c+15|0]<<8)>>>0>20){break F}g=(Mb(w[c+18|0]|w[c+19|0]<<8)|0)==4}G:{H:{if(g){g=w[c+23|0];b=w[c+140|0];v[23296]=0;b=ja(642,c|0,a|0,(b&2)>>>1|0,(B(f,104)+a|0)+484380|0,r&65535)|0;k=v[23296];v[23296]=0;I:{J:{if((k|0)!=1){if(!b){break I}v[23296]=0;b=Q(54,e+400|0,10618)|0;k=v[23296];v[23296]=0;if((k|0)==1){break J}Ec(((f<<5)+a|0)+946304|0,b);yb(b);k=v[l>>2];b=d;if(rh(k,v[l+4>>2])>>>0<=g>>>0){break G}la=c,ma=w[c+143|0]+w[dm(k,g)+143|0]|0,t[la+143|0]=ma;break H}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}b=g+1|0;break G}g=0;K:{if(!wt(c)){break K}if((Mb(w[c+6|0]|w[c+7|0]<<8)|0)!=1){break K}if((Mb(w[c+14|0]|w[c+15|0]<<8)|0)!=2){break K}g=(Mb(w[c+18|0]|w[c+19|0]<<8)|0)==10}b=d;if(!g){break G}qc(e+272|0,c,128);b=Mb(x[e+292>>1]);if(b>>>0>=x[m>>1]){break H}v[23296]=0;g=T(632,e+168|0)|0;k=v[23296];v[23296]=0;if((k|0)==1){break E}k=x[e+308>>1];o=x[h>>1];v[23296]=0;s=B(b,104);b=a+484380|0;k=Mb(k);b=fa(643,e+272|0,(s+b|0)+104|0,(k>>>0<o>>>0?(b+B(k,104)|0)+104|0:g)|0,b+B(f,104)|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break D}if(!b){break H}v[23296]=0;b=Q(54,e+152|0,11111)|0;g=v[23296];v[23296]=0;if((g|0)==1){break C}Ec(((f<<5)+a|0)+946304|0,b);yb(b);t[c+139|0]=w[c+139|0]+12}b=d}v[23296]=0;b=b&65535;g=W(239,a|0,f|0,b|0)|0;f=v[23296];v[23296]=0;if((f|0)!=1){if(!g|b>>>0>x[m>>1]){break B}v[23296]=0;X(644,c|0,g|0,(B(b,104)+a|0)+484380|0,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){break B}}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}d=d+1|0;continue}}break}I=hg(e+136|0);s=hg(e+120|0);b=wc(v[A>>2],v[A+4>>2]);_=B(x[a+480188>>1],K);$=ou((b>>>0)/(_>>>0)|0);v[23296]=0;N=a+484344|0;R(213,N|0,$|0);b=v[23296];v[23296]=0;if((b|0)==1){break k}aa=a+484376|0;Hc(Zb(v[a+484360>>2],w[aa|0]));b=x[a+480188>>1];v[23296]=0;F=Q(645,e+104|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break l}la=e,ma=Eb(v[q>>2]),v[la+48>>2]=ma;ga=a+902204|0;ha=Eb(v[q+4>>2]);ia=a+480208|0;while(1){L:{M:{N:{k=v[e+48>>2];if(!Rb(k,ha)){break N}b=Mb(w[k+6|0]|w[k+7|0]<<8);if((b|0)==1){break L}if((b|0)==65535){break N}g=Mb(w[k|0]|w[k+1|0]<<8);b=v[p>>2];f=v[p+4>>2];c=gg(b,f);if(g>>>0>=c>>>0){break L}d=Mb(w[k+2|0]|w[k+3|0]<<8);if(d>>>0>c>>>0|!d|g>>>0>c-d>>>0){break L}c=b+(gg(b,f)<<5)|0;v[e+272>>2]=b;v[e+276>>2]=c-b>>5;b=v[e+272>>2];gc(e+80|0,b+(Mb(w[k|0]|w[k+1|0]<<8)<<5)|0,Mb(w[k+2|0]|w[k+3|0]<<8));O:{H=Zb(v[a+484360>>2],w[aa|0]);if(uc(v[H>>2],v[H+4>>2])){break O}v[23296]=0;R(472,H|0,65534);b=v[23296];v[23296]=0;if((b|0)!=1){break O}break M}c=v[e+80>>2];ka=pe(c,v[e+84>>2]);while(1){if((c|0)==(ka|0)){break L}b=Mb(Mb(w[k+8|0]|w[k+9|0]<<8)+Mb(w[c+16|0]|w[c+17|0]<<8)&65535);t[c+16|0]=b;t[c+17|0]=b>>>8;g=c;b=Wd(I);while(1){P:{c=0;if(!b){break P}d=b+14|0;if(!tt(g,d)){c=1;if(!tt(d,g)){break P}b=b+4|0}b=v[b>>2];continue}break}Q:{R:{S:{if(c){v[23296]=0;b=Q(646,I|0,g|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break M}E=x[b>>1];break S}E=0;if(!J){break S}b=w[g+12|0]|w[g+13|0]<<8;v[23296]=0;E=Q(345,N|0,Mb(b)|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break M}if((E|0)==65535){break L}v[23296]=0;b=Q(646,I|0,g|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break M}u[b>>1]=E;if(Mb(w[g+8|0]|w[g+9|0]<<8)>>>0>=$>>>0){break R}if(Mb(w[g+10|0]|w[g+11|0]<<8)>>>0>=K>>>0){break R}m=Mb(w[g+14|0]|w[g+15|0]<<8);c=cm(Eb(v[A>>2]),B(Mb(w[g+8|0]|w[g+9|0]<<8),_));b=x[a+480188>>1];la=e,ma=cm(c,B(b,Mb(w[g+10|0]|w[g+11|0]<<8))),v[la+32>>2]=ma;M=0;v[e+16>>2]=0;o=Th(e- -64|0);T:while(1){U:{d=Mb(w[g+12|0]|w[g+13|0]<<8);c=$b(v[N>>2],E);if(d>>>0<=M>>>0){break U}n=0;V=fd(v[c>>2],v[v[c+48>>2]+12>>2],M,0);c=0;while(1){if((b&65535)>>>0<=n>>>0){M=M+1|0;continue T}b=Eb(v[A+4>>2]);d=v[e+32>>2];h=Rb(d,b)?d:e+16|0;b=Eb(v[A+4>>2]);if(Rb(v[e+32>>2],b)){ZP(e+32|0)}d=B(n,6)+V|0;f=w[h+1|0];b=(f>>>0<85?f+25|0:-1)<<24>>24;r=0;i=v[l>>2];ba=rh(i,v[l+4>>2]);G=w[h+3|0];V:{if(ba>>>0<=G>>>0){break V}r=G+1|0;if(t[dm(i,G)+142|0]&1|(b|0)<0){break V}b=Mb(w[g+16|0]|w[g+17|0]<<8)+b<<24>>24;b=(b|0)<120?b:120;b=((b|0)>1?b:1)&255}W:{if(!w[d|0]|!(w[h+2|0]?1:G|(w[h|0]|(f|0)!=255))){break W}f=w[d+1|0];if(!f|f>>>0>ba>>>0){break W}if(w[dm(i,f-1|0)+132|0]!=2){break W}fo(d)}f=yt(v[F>>2],n);X:{Y:{if(c&1){c=w[o|0]|w[o+1|0]<<8|(w[o+2|0]<<16|w[o+3|0]<<24);t[d|0]=c;t[d+1|0]=c>>>8;t[d+2|0]=c>>>16;t[d+3|0]=c>>>24;c=w[o+4|0]|w[o+5|0]<<8;t[d+4|0]=c;t[d+5|0]=c>>>8;Z:{if(w[d+3|0]){break Z}i=w[f+21|0];c=w[yt(v[F>>2],n-1|0)+21|0];if((i|0)==(c|0)){break Z}t[d+3|0]=21;t[f+21|0]=c;t[d+5|0]=c}c=0;i=w[h|0];if(i-24>>>0<2|(i|0)==9|!i&(w[h+2|0]+7&255)>>>0<2){break Y}break X}i=w[h|0]}_:{$:{aa:{ba:{ca:{da:{switch(i|0){case 5:c=w[f+17|0];break ca;case 0:ea:{c=w[h+2|0];if(c>>>0>=201){i=0;fa:{switch(c-242|0){case 11:t[d+4|0]=1;t[d+2|0]=14;t[f+16|0]=0;break $;case 9:if(!w[d|0]){t[d|0]=w[f+17|0]}t[d+4|0]=1;t[d+2|0]=15;break $;case 8:if((m&255)>>>0<2){break $}m=m-1|0;break aa;case 7:if((m&255)==255){m=255;break $}m=m+1|0;break aa;case 6:t[f+17|0]=b;if(w[f+18|0]!=(r&255)){break $}t[d|0]=b;t[d+5|0]=255;t[d+3|0]=4;u[f+32>>1]=0;v[f+8>>2]=0;break $;case 5:t[d+5|0]=242;t[d+3|0]=2;break $;case 4:t[d+5|0]=242;t[d+3|0]=3;break $;case 3:t[d+5|0]=244;t[d+3|0]=2;break $;case 2:t[d+5|0]=244;t[d+3|0]=3;break $;case 1:t[d+5|0]=248;t[d+3|0]=2;break $;case 12:break ea;case 0:break fa;default:break $}}t[d+5|0]=248;t[d+3|0]=3;break $}ga:{if(t[h+1|0]<0){i=0;if(c>>>0<100){break ga}break $}t[f+17|0]=b;t[d|0]=b;t[f+18|0]=r;t[d+1|0]=r;u[f+32>>1]=0;v[f+8>>2]=0;c=w[h+2|0]}b=c&255;if(!b){i=0;break $}la=f,ma=io(+(b>>>0)*.64),t[la+19|0]=ma;j=z[f>>2];v[f>>2]=0;i=j!=C(0);break $}t[d+4|0]=0;t[d+2|0]=14;t[f+16|0]=1;break $;case 1:v[f+4>>2]=0;z[f>>2]=C(w[h+2|0])*C(.0333000011742115);break _;case 2:v[f+4>>2]=0;z[f>>2]=C(w[h+2|0])*C(-.0333000011742115);break _;case 12:t[e+272|0]=15;t[e+100|0]=w[h+3|0]>>>3;b=w[Wb(e+272|0,e+100|0)|0];t[e+272|0]=15;t[e+100|0]=w[h+2|0]>>>3;la=f,ma=w[Wb(e+272|0,e+100|0)|0]|b<<4,t[la+24|0]=ma;break _;case 3:v[f+12>>2]=0;b=w[h+2|0];u[f+32>>1]=0;z[f+8>>2]=C(b>>>0)*C(.0333000011742115);break _;case 4:v[f+12>>2]=0;b=w[h+2|0];u[f+32>>1]=0;z[f+8>>2]=C(b>>>0)*C(-.0333000011742115);break _;case 15:if(!w[h+2|0]|(b|0)<0){break _}i=b-w[f+17|0]<<5;c=i>>31;c=(c^i)-c|0;v[e+272>>2]=c;t[f+17|0]=b;v[f+8>>2]=0;t[d|0]=b;t[d+3|0]=4;b=xi((c>>>0)/(w[h+2|0]<<1>>>0)|0);t[d+5|0]=b;t[f+27|0]=b;v[e+100>>2]=B(b,(m&255)-1|0);la=f,ma=c-v[td(e+272|0,e+100|0)>>2]|0,u[la+32>>1]=ma;break _;case 10:case 11:t[d+3|0]=0;t[d+5|0]=0;break _;case 13:t[e+272|0]=15;t[e+100|0]=w[h+3|0]>>>3;b=w[Wb(e+272|0,e+100|0)|0];t[e+272|0]=15;t[e+100|0]=w[h+2|0];la=f,ma=w[Wb(e+272|0,e+100|0)|0]|b<<4,t[la+23|0]=ma;break _;case 18:b=w[h+2|0]+w[f+17|0]&255;b=b?b>>>0<120?b:120:1;t[f+17|0]=b;t[d|0]=b;t[d+5|0]=255;t[d+3|0]=4;break ba;case 23:case 24:case 25:b=Wd(s);while(1){ha:{c=0;if(!b){break ha}i=b+13|0;if(!ut(h,i)){c=1;if(!ut(i,h)){break ha}b=b+4|0}b=v[b>>2];continue}break};if(c){t[d+3|0]=31;v[23296]=0;b=Q(647,s|0,h|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break M}t[d+5|0]=w[b|0];break _}b=v[Gb(s)>>2];if(b>>>0>127){break _}v[e+96>>2]=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);c=v[ia>>2];v[23296]=0;v[e+12>>2]=v[e+96>>2];c=W(648,e+12|0,pe(ga,b&255)|0,c|0)|0;i=v[23296];v[23296]=0;ia:{if((i|0)==1){break ia}if(!c){break _}t[d+3|0]=31;v[23296]=0;c=Q(647,s|0,h|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break ia}b=b|-128;t[c|0]=b;t[d+5|0]=b;ca=(w[h|0]&254)==24|ca;break _}break M;case 16:if(!w[h+2|0]){break _}t[d+3|0]=15;v[e+272>>2]=15;v[e+100>>2]=w[h+3|0]+1;la=d,ma=v[td(e+272|0,e+100|0)>>2],t[la+5|0]=ma;u[f+30>>1]=B(w[h+2|0],w[h+3|0]+1|0);break _;case 9:t[d+3|0]=16;b=w[h+2|0];m=b?b:4;t[d+5|0]=m;break _;case 19:ja:{ka:{switch(w[h+1|0]){case 0:b=128;break ja;case 4:break ka;default:break _}}b=w[h+3|0]}t[e+95|0]=b;t[e+272|0]=w[h+2|0];t[e+100|0]=100;c=e+272|0;r=e+100|0;i=w[Wb(c,r)|0];v[e+272>>2]=128;v[e+100>>2]=256-(b&255);b=v[td(c,r)>>2];t[e+272|0]=128;c=w[Wb(c,e+95|0)|0];b=(B(b,i)|0)/128|0;r=b&255;if((r|0)!=w[f+20|0]){t[f+20|0]=b;t[d+3|0]=21;b=Vc(((B(r,w[f+19|0])+50&65535)>>>0)/100|0,0);t[f+21|0]=b;t[d+5|0]=b}if(w[h+1|0]!=4|(x[a+480188>>1]-1|0)<=(n|0)){break _}b=n+1|0;h=yt(v[F>>2],b);c=B(c,i)>>>7|0;if(w[h+20|0]==(c&255)){break _}t[h+20|0]=c;b=B(b,6)+V|0;t[b+3|0]=21;c=Vc(((B(w[f+20|0],w[f+19|0])+50&65535)>>>0)/100|0,0);t[f+21|0]=c;t[b+5|0]=c;break _;case 17:case 20:t[d+3|0]=0;break _;case 7:b=w[h+2|0];t[f+25|0]=0;t[f+26|0]=0;t[f+22|0]=b;break _;case 8:t[f+22|0]=w[f+22|0]+w[h+2|0];break _;case 14:t[f+25|0]=w[h+3|0];t[f+26|0]=w[h+2|0];break _;case 6:break da;default:break _}}t[f+18|0]=r;t[f+17|0]=b;t[d+1|0]=r;c=b}t[d|0]=c;if((b|0)>=0){t[f+18|0]=r;t[d+1|0]=r}if(w[h|0]==5){t[d+4|0]=1;t[d+2|0]=11}c=w[f+22|0];b=w[f+26|0];if(!(b?1:c|w[h+2|0])){break ba}if(b){da=(ti(+x[f+28>>1]*.006135923151542565+4.71238898038469)+-1)*+(b>>>0)*.25}else{da=0}t[d+3|0]=44;la=d,ma=io(da+ +(c+w[h+2|0]|0)),t[la+5|0]=ma}u[f+32>>1]=0;break _}t[d+5|0]=m;t[d+3|0]=16}b=Vc(((B(w[f+20|0],w[f+19|0])+50&65535)>>>0)/100|0,0);if(!(!i&w[f+21|0]==(b&255))){t[f+21|0]=b;t[d+5|0]=b;t[d+3|0]=21}if(n&1|t[h+1|0]<=0|(x[a+480188>>1]-1|0)<=(n|0)){break _}b=v[l>>2];if(rh(b,v[l+4>>2])>>>0<=G>>>0){break _}if(w[dm(b,G)+132|0]!=1){break _}h=n+1|0;b=B(h,6)+V|0;c=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[d+4|0]|w[d+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;t[b+1|0]=w[b+1|0]+1;b=yt(v[F>>2],h);t[b+19|0]=w[f+19|0];z[b>>2]=z[f>>2];z[b+4>>2]=z[f+4>>2];z[b+8>>2]=z[f+8>>2];z[b+12>>2]=z[f+12>>2];u[b+30>>1]=x[f+30>>1]}la:{if(w[d|0]){t[f+16|0]=0;break la}c=0;if(w[f+16|0]){break X}}ma:{if(!x[f+30>>1]){break ma}b=m&255;u[e+272>>1]=b;c=f+30|0;la=c,ma=x[We(c,e+272|0)>>1]-b|0,u[la>>1]=ma;if(w[d+3|0]){break ma}t[d+3|0]=15;t[d+5|0]=0}j=z[f>>2];na:{if(j==C(0)){break na}b=m&255;j=C(C(j*C(b>>>0))+z[f+4>>2]);z[f+4>>2]=j;if(w[d+3|0]){break na}oa:{pa:{qa:{ra:{if(b>>>0>=2){h=b-1|0;D=C(h|0);if(!(D<=j)){break ra}t[e+272|0]=15;la=e,ma=Vg(C(j/D)),t[la+100|0]=ma;b=w[Wb(e+272|0,e+100|0)|0];z[f+4>>2]=j-C(B(b,h)|0);t[d+3|0]=22;c=b<<4;break oa}if(!(j>=C(1))){break qa}break pa}if(j>=C(1)){break pa}if(!(j<=C(1-b|0))){break qa}t[e+272|0]=15;la=e,ma=Vg(C(C(-j)/D)),t[la+100|0]=ma;c=w[Wb(e+272|0,e+100|0)|0];z[f+4>>2]=j+C(B(h,c)|0);t[d+3|0]=22;break oa}if(!(j<=C(-1))){break na}t[e+272|0]=14;la=e,ma=Vg(C(-j)),t[la+100|0]=ma;b=w[Wb(e+272|0,e+100|0)|0];z[f+4>>2]=j+C(b>>>0);t[d+3|0]=22;c=b|-16;break oa}t[e+272|0]=15;la=e,ma=Vg(j),t[la+100|0]=ma;b=w[Wb(e+272|0,e+100|0)|0];z[f+4>>2]=j-C(b>>>0);t[d+3|0]=22;c=b<<4|15}t[d+5|0]=c}j=z[f+8>>2];sa:{if(j==C(0)){break sa}b=m&255;j=C(C(j*C(b>>>0))+z[f+12>>2]);z[f+12>>2]=j;ta:{if(!w[d+3|0]){ua:{va:{if(b>>>0>=2){c=b-1|0;D=C(c|0);if(!(D<=j)){break va}t[e+272|0]=223;la=e,ma=Vg(C(j/D)),t[la+100|0]=ma;b=w[Wb(e+272|0,e+100|0)|0];z[f+12>>2]=j-C(B(b,c)|0);t[d+3|0]=2;t[d+5|0]=b;break sa}if(!(j>=C(1))){break ua}break ta}if(j>=C(1)){break ta}if(!(j<=C(1-b|0))){break ua}t[e+272|0]=223;la=e,ma=Vg(C(C(-j)/D)),t[la+100|0]=ma;b=w[Wb(e+272|0,e+100|0)|0];z[f+12>>2]=j+C(B(b,c)|0);t[d+3|0]=3;t[d+5|0]=b;break sa}if(!(j<=C(-1))){break sa}t[e+272|0]=14;la=e,ma=Vg(C(-j)),t[la+100|0]=ma;b=w[Wb(e+272|0,e+100|0)|0];z[f+12>>2]=j+C(b>>>0);t[d+3|0]=3;t[d+5|0]=b|240;break sa}if(w[d+2|0]|b>>>0<2){break sa}ea=C(j*C(.25));c=b-1|0;D=C(c|0);if(ea>=D){t[e+272|0]=9;la=e,ma=Vg(C(j/D))>>>2|0,t[la+100|0]=ma;b=w[Wb(e+272|0,e+100|0)|0];z[f+12>>2]=j-C(B(b,c)<<2);t[d+2|0]=12;t[d+4|0]=b;break sa}if(!(C(1-b|0)>=ea)){break sa}t[e+272|0]=9;la=e,ma=Vg(C(C(-j)/D))>>>2|0,t[la+100|0]=ma;b=w[Wb(e+272|0,e+100|0)|0];z[f+12>>2]=j+C(B(b,c)<<2);t[d+2|0]=13;t[d+4|0]=b;break sa}t[e+272|0]=15;la=e,ma=Vg(j),t[la+100|0]=ma;b=w[Wb(e+272|0,e+100|0)|0];z[f+12>>2]=j-C(b>>>0);t[d+3|0]=2;t[d+5|0]=b|240}wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{b=w[d+3|0];switch(b|0){case 4:break wa;case 0:break Ca;default:break Ba}}Da:{b=w[f+23|0];if(!b){b=w[f+24|0];if(b){break Da}if(!x[f+32>>1]){break wa}c=f+32|0;break Aa}t[d+3|0]=5;t[d+5|0]=b;if(!x[f+32>>1]){break wa}break za}t[d+3|0]=8;t[d+5|0]=b;if(x[f+32>>1]){break za}break wa}if(!x[f+32>>1]){break wa}c=f+32|0;if(b){break ya}}t[d+3|0]=4;break xa}c=f+32|0}t[d+2|0]=11}u[e+272>>1]=B(w[f+27|0],(m&255)-1|0);la=f,ma=x[f+32>>1]-x[Zc(c,e+272|0)>>1]|0,u[la+32>>1]=ma}u[f+28>>1]=x[f+28>>1]+B(w[f+25|0],m&255)&1023;c=0;if(n&1){break X}b=w[f+18|0];if(!b){break X}f=v[l>>2];if(rh(f,v[l+4>>2])>>>0<b>>>0){break X}f=dm(f,b-1|0);if(!(w[f+142|0]&4)){break X}b=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);t[o|0]=b;t[o+1|0]=b>>>8;t[o+2|0]=b>>>16;t[o+3|0]=b>>>24;b=w[d+4|0]|w[d+5|0]<<8;t[o+4|0]=b;t[o+5|0]=b>>>8;c=1;b=w[e+65|0];if(!b|w[f+132|0]!=1){break X}t[e+65|0]=b+1}n=n+1|0;b=x[a+480188>>1];continue}}break}qe(c,yh(Ke(Fe(e+272|0,16,Mb(w[g+14|0]|w[g+15|0]<<8)&255),0)))}b=fl(v[H>>2],v[H+4>>2]);la=e,ma=Mb(w[g+4|0]|w[g+5|0]<<8),u[la+272>>1]=ma;u[e+64>>1]=1;c=x[We(e+272|0,e- -64|0)>>1];v[23296]=0;X(649,H|0,b|0,c|0,E&65535);b=v[23296];v[23296]=0;if((b|0)==1){break Q}b=Mb(w[k+8|0]|w[k+9|0]<<8);b=Mb(Mb(w[g+16|0]|w[g+17|0]<<8)-b&65535);t[g+16|0]=b;t[g+17|0]=b>>>8}c=g+32|0;continue}break}break M}c=ca&1;if(c){v[23296]=0;Y(271,a+906300|0);b=v[23296];v[23296]=0;if((b|0)==1){break M}b=a+906324|0;v[b>>2]=655376;v[b+4>>2]=0;b=a+906316|0;v[b>>2]=1299020115;v[b+4>>2]=1869112133;v[e+272>>2]=0;d=a+906348|0;b=e+272|0;DU(a+906332|0,d,b);v[23296]=0;b=Q(54,b|0,9458)|0;g=v[23296];v[23296]=0;if((g|0)==1){break M}yB(d,b);yb(b);v[23296]=0;b=Q(54,e+80|0,9451)|0;d=v[23296];v[23296]=0;if((d|0)==1){break M}uu(a+906380|0,b);yb(b);v[23296]=0;b=Q(54,e- -64|0,9443)|0;d=v[23296];v[23296]=0;if((d|0)==1){break M}yB(a+906508|0,b);yb(b)}b=0;while(1){if(x[a+480188>>1]>b>>>0){iB(a,b&65535);d=(b<<5)+a|0;t[d+480288|0]=c;u[d+480284>>1]=b<<8&256;b=b+1|0;continue}break}v[23296]=0;b=Q(1,e+48|0,11955)|0;c=v[23296];v[23296]=0;Ea:{Fa:{Ga:{if((c|0)!=1){Hb(a+1298344|0,b);zb(b);v[23296]=0;b=Q(1,e+32|0,12173)|0;c=v[23296];v[23296]=0;if((c|0)==1){break M}Hb(a+1298356|0,b);zb(b);if(Z){break Ga}v[23296]=0;b=Q(1,e+16|0,11955)|0;c=v[23296];v[23296]=0;if((c|0)==1){break M}break Fa}break M}if(rh(v[l>>2],v[l+4>>2])>>>0<=128){v[23296]=0;b=Q(1,e+16|0,9200)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break Fa}break M}v[23296]=0;b=Q(1,e+16|0,14640)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Ea}}Hb(a+1298368|0,b);zb(b);v[a+1298404>>2]=13;YP(F);QP(s);PP(I);d=1;break m}}c=P()|0;O()|0;YP(F);break j}eo(e+48|0);continue}}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}zt(l);vc(A);dl(q);vi(p);break c}c=P()|0;O()|0;break j}c=P()|0;O()|0}QP(s);PP(I);break a}c=P()|0;O()|0;zb(b);break a}c=P()|0;O()|0;break a}Ab(c);v[23296]=0;c=d&65535;d=W(650,a|0,c|0,i|0)|0;g=v[23296];v[23296]=0;Ha:{Ia:{Ja:{Ka:{if((g|0)==1){break Ka}if(d){break Ha}v[23296]=0;d=W(651,a|0,c|0,i|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break Ka}if(d){break Ha}v[23296]=0;d=W(652,a|0,c|0,i|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break Ka}if(d){break Ha}v[23296]=0;d=Q(653,(B(c,104)+a|0)+484380|0,i|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break Ka}if(d){break Ha}v[23296]=0;d=Q(1,e+448|0,15984)|0;g=v[23296];v[23296]=0;if((g|0)==1){break Ja}g=v[F>>2];v[23296]=0;U(353,g|0,2,d|0);g=v[23296];v[23296]=0;if((g|0)==1){break Ia}zb(d);break Ha}c=P()|0;O()|0;break e}c=P()|0;O()|0;break e}c=P()|0;O()|0;zb(d);break e}La:{Ma:{Na:{E=B(c,104)+a|0;if(w[E+484414|0]&64){d=x[m>>1];if(Sh(d)){break Na}}d=v[l>>2];if(rh(d,v[l+4>>2])>>>0<=c>>>0){break Ma}if(w[dm(d,c)+132|0]!=2){break Ma}c=x[m>>1];if(!Sh(c)){break Ma}u[m>>1]=c+1;break Ma}c=d+1|0;u[m>>1]=c;G=B(c&65535,104)+a|0;o=G+484380|0;h=E+484380|0;g=v[h>>2];c=v[h+20>>2];Oa:{if(!Ud(g,c)){break Oa}f=x[h+34>>1];if((h|0)==(o|0)|(Gd(f)|0)!=2){break Oa}d=(h|0)==(o|0);if(!(Ud(v[o>>2],v[o+20>>2])?d:1)){break Oa}Ud(v[h>>2],v[h+20>>2]);if(!d){c=vt(g,Hm(f))}f=v[h+20>>2];if(!(f?c:0)){if(!d){uz(c)}break Oa}Pa:{Qa:{switch(Hm(x[h+34>>1])-1|0){case 1:g=c;d=f;n=v[h+20>>2];k=v[h>>2];while(1){if(k){u[g>>1]=x[n>>1];u[d>>1]=x[n+2>>1];n=n+4|0;d=d+2|0;g=g+2|0;k=k-1|0;continue}break};break Pa;case 0:break Qa;default:break Pa}}g=c;d=f;n=v[h+20>>2];k=v[h>>2];while(1){if(k){t[g|0]=w[n|0];t[d|0]=w[n+1|0];n=n+2|0;d=d+1|0;g=g+1|0;k=k-1|0;continue}break}}d=go(o,h);u[d+34>>1]=x[d+34>>1]&65471;v[o+20>>2]=c;g=go(h,h);u[g+34>>1]=x[g+34>>1]&65471;v[h+20>>2]=f;f=a+1298224|0;c=a+1074992|0;while(1){if((c|0)!=(f|0)){h=v[c+104>>2];if(!((h|0)!=(d|0)&(g|0)!=(h|0))){v[c+88>>2]=v[c+88>>2]&-65}c=c+872|0;continue}break}mj(d,a);mj(g,a)}v[23296]=0;c=Q(54,e+432|0,6281)|0;d=v[23296];v[23296]=0;if((d|0)==1){break La}ze(G+484423|0,c);yb(c);v[23296]=0;c=Q(54,e+416|0,6184)|0;d=v[23296];v[23296]=0;if((d|0)==1){break f}ze(E+484423|0,c);yb(c)}Ab(i);fc(s);i=0;continue}break}c=P()|0;O()|0;break e}c=P()|0;O()|0}Ab(i)}fc(s);break a}jb=e+672|0;return d|0}c=P()|0;O()|0}zt(l);vc(A);dl(q);vi(p);S(c|0);L()}function Kt(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,T=0,V=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0,ea=0,fa=0,ga=0,ha=0,ka=0,la=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0,wa=0,xa=0,ya=0,za=0,Aa=0,Ca=0,Da=0,Ea=0,Fa=C(0),Ga=0,Ha=0,Ia=0,Ja=C(0);h=jb-208|0;jb=h;$=Qb(a);s=h+176|0;t[s+26|0]=0;u[s+24>>1]=0;v[s+16>>2]=0;v[s+20>>2]=-1;v[s+8>>2]=-1;v[s+12>>2]=-1;v[s>>2]=0;v[s+4>>2]=0;K=v[d+16>>2];a=w[d+6|0];na=b+484360|0;i=v[na>>2];oa=(Ga=a,Ha=w[b+484376|0],Ia=kj(i,v[b+484364>>2])>>>0>a>>>0,Ia?Ga:Ha);a=oa&255;G=pj(i,a);v[23296]=0;D=Q(531,h+144|0,b|0)|0;i=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((i|0)!=1){l=v[D+4>>2];v[23296]=0;H=W(532,h+104|0,b|0,a|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break i}ca=c&7;e=v[d>>2];a=x[d+4>>1];while(1){i=a&65535;if(Nc(v[G>>2],v[G+4>>2])>>>0<=i>>>0){break g}v[23296]=0;i=Q(297,G|0,i|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break h}if(i){break g}a=a+1|0;e=0;continue}}m=P()|0;O()|0;break d}m=P()|0;O()|0;break e}m=P()|0;O()|0;v[d>>2]=e;u[d+4>>1]=a;break f}v[d>>2]=e;u[d+4>>1]=a;v[l+52>>2]=e;J=l+48|0;v[J>>2]=e;v[s+16>>2]=e;u[l+74>>1]=a;u[l+72>>1]=a;u[s+24>>1]=a;pa=$d(h+96|0);qa=Cc(h+88|0);j:{if((ca|0)!=7){break j}Sk(Sk(Sk(Sk(Sk(Sk(Sk(Sk(pa,1),2),3),28),38),40),39),41);KN(KN(qa,12),13);if((K|0)!=2){break j}a=v[G>>2];e=Nc(a,v[G+4>>2]);i=x[d+12>>1];if(e>>>0<=i>>>0){break j}e=v[b+484344>>2];f=v[b+484348>>2];a=x[dc(a,i)>>1];if(!oe(e,f,a)){break j}i=$b(e,a);e=v[d+8>>2];if(y[i+12>>2]<=e>>>0){break j}a=0;m=fd(v[i>>2],v[v[i+48>>2]+12>>2],e,0);i=x[b+480188>>1];e=v[D+8>>2];f=x[b+480192>>1];while(1){if((a|0)==(i|0)){break j}k:{l:{m:{n:{k=w[m|0];switch(k-253|0){case 1:case 2:break l;case 0:break n;default:break m}}if(f){break l}}if(!Uc(k)){break k}if(ct(w[m+2|0],w[m+3|0])){break k}}Ga=Re(e,a),Ha=-1,v[Ga>>2]=Ha}m=m+6|0;a=a+1|0;continue}}aa=c&1;if(aa){JN(l+223860|0)}N=l+74|0;xa=l+223872|0;ya=(K|0)!=3;T=l+80|0;za=b+901692|0;Aa=b+902204|0;ga=l+44|0;ha=l+223860|0;ba=l+20|0;F=b+1074312|0;ra=l+616|0;ea=32768;sa=A[d+8>>3];o(+sa);a=j(1)|0;Ca=j(0)|0;ka=a;_=b+480188|0;E=b+480180|0;la=b+484348|0;ta=(K|0)!=2;Da=l+223884|0;ua=b+480192|0;Ea=(ca|0)!=7;d=0;o:{p:{q:{r:{s:{t:while(1){i=ka;while(1){IN(h+24|0,v[E>>2],x[_>>1],l,q&1);if(!(!(A[D+24>>3]>=sa)|ya)){break p}k=w[h+24|0];a=65535;e=v[G>>2];g=Nc(e,v[G+4>>2]);f=x[l+72>>1];if(g>>>0>f>>>0){a=x[dc(e,f)>>1]}u[l+70>>1]=a;g=v[b+484344>>2];e=v[la>>2];p=a&65535;if(!(oe(g,e,p)|(p|0)==65535|ta)&(f|0)==(i&65535)){break p}u:{v:{while(1){a=a&65535;if(pf(g,e)>>>0>a>>>0){break u}p=x[l+72>>1];w:{x:{if((a|0)!=65535){n=v[G>>2];f=Nc(n,v[G+4>>2]);if(p>>>0<f>>>0){break x}}a=x[G+28>>1];if((p|0)==(a|0)){break u}n=v[G>>2];f=Nc(n,v[G+4>>2]);break w}a=p+1|0}u[l+72>>1]=a;m=65535;p=f;f=a&65535;if(p>>>0>f>>>0){m=x[dc(n,f)>>1]}u[l+74>>1]=a;u[l+70>>1]=m;y:{if(!oe(g,e,m&65535)){e=Ep(h+24|0,ra);v[23296]=0;a=ja(533,H|0,a&65535,0,e|0,(k|0)!=0|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break y}if(a){break v}g=v[b+484344>>2];e=v[la>>2]}a=x[l+70>>1];continue}break}m=P()|0;O()|0;break f}if(K>>>0<=1){a=x[l+72>>1];v[s+8>>2]=0;u[s+20>>1]=a;if(!K){break u}}v[23296]=0;a=W(534,H|0,N|0,J|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break q}if(!a){break u}A[s>>3]=A[D+24>>3];v[23296]=0;R(535,$|0,s|0);a=v[23296];v[23296]=0;if((a|0)==1){break q}v[s+16>>2]=v[J>>2];u[s+24>>1]=x[N>>1];v[23296]=0;Y(536,D|0);a=v[23296];v[23296]=0;if((a|0)==1){break q}a=x[l+74>>1];u[l+72>>1]=a;Ga=l,Ha=x[dc(v[G>>2],a)>>1],u[Ga+70>>1]=Ha;v[l+52>>2]=v[l+48>>2]}if(x[N>>1]==65535){break o}a=v[b+484344>>2];e=x[l+70>>1];if(!oe(a,v[la>>2],e)){a=x[l+72>>1];if((a|0)==x[G+28>>1]){if(!K){break o}v[23296]=0;a=W(534,H|0,N|0,J|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break q}if(!a){break o}A[s>>3]=A[D+24>>3];v[23296]=0;R(535,$|0,s|0);a=v[23296];v[23296]=0;if((a|0)==1){break q}v[s+16>>2]=v[J>>2];u[s+24>>1]=x[N>>1];v[23296]=0;Y(536,D|0);a=v[23296];v[23296]=0;if((a|0)==1){break q}v[l+52>>2]=v[l+48>>2];continue}u[N>>1]=a+1;continue}g=v[J>>2];if(g>>>0>=y[$b(a,e)+12>>2]){v[J>>2]=0;g=0}if(!(x[l+72>>1]!=(i&65535)|ta)&(g|0)==(Ca|0)){break p}a=0;if(!((K|0)==3|y[H+28>>2]<ea>>>0)){v[D+24>>2]=0;v[D+28>>2]=2146435072;v[H+28>>2]=0;ea=ea>>>(ea>>>0>256)|0;g=v[J>>2];a=1}e=x[l+72>>1];f=Ep(h+24|0,ra);v[23296]=0;e=ja(533,H|0,e|0,g|0,f|0,(k|0)!=0|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break s}if((a|e)==1){if(K>>>0<=1){u[s+20>>1]=x[l+72>>1];v[s+8>>2]=v[l+48>>2];if(!K){break o}}v[23296]=0;a=W(534,H|0,N|0,J|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break r}if(!a){break o}A[s>>3]=A[D+24>>3];v[23296]=0;R(535,$|0,s|0);a=v[23296];v[23296]=0;if((a|0)==1){break r}v[s+16>>2]=v[J>>2];u[s+24>>1]=x[N>>1];v[23296]=0;Y(536,D|0);a=v[23296];v[23296]=0;if((a|0)==1){break r}v[l+52>>2]=v[l+48>>2];continue}u[s+22>>1]=x[l+72>>1];v[s+12>>2]=v[l+48>>2];HN(b,l,0);m=v[l+48>>2];e=$b(v[b+484344>>2],x[l+70>>1]);if(m>>>0>=y[e+12>>2]){v[J>>2]=0;m=0}if(k){continue}break}a=0;m=fd(v[e>>2],v[v[e+48>>2]+12>>2],m,0);Bb(h+24|0,F,77);k=Cb(v[v[h+24>>2]>>2],v[h+28>>2]);z:{while(1){if(x[_>>1]>a>>>0){A:{if(!(!Ry(m)&(!k|!(w[((a<<5)+b|0)+480281|0]&4)))){fo((l+B(a,872)|0)+1404|0);break A}if(Sg(w[m|0])){B:{if(!Rd(w[Da|0])){break B}i=w[m+1|0];if(i-251>>>0<5|!i){break B}f=w[m+5|0];q=w[m+3|0];p=Tj(w[m+2|0],w[m+4|0]);e=h+24|0;t[e|0]=i-1;v[e+4>>2]=p&65535;v[23296]=0;i=Q(537,xa|0,e|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break z}Ga=i,Ja=C(C(Tj(q,f)>>>0)/C(999)),z[Ga>>2]=Ja}fo((l+B(a,872)|0)+1404|0);break A}i=l+B(a,872)|0;e=i+1408|0;f=w[m+4|0]|w[m+5|0]<<8;t[e|0]=f;t[e+1|0]=f>>>8;e=i+1404|0;f=w[m|0]|w[m+1|0]<<8|(w[m+2|0]<<16|w[m+3|0]<<24);t[e|0]=f;t[e+1|0]=f>>>8;t[e+2|0]=f>>>16;t[e+3|0]=f>>>24;C:{D:{E:{F:{switch(w[m+3|0]-16|0){case 0:e=w[m+5|0];break E;case 3:break C;case 4:break D;case 1:break F;default:break A}}Bb(h+24|0,F,5);if(!Cb(v[v[h+24>>2]>>2],v[h+28>>2])){break A}e=w[m+5|0];if(!e){break A}}FN(b,l,e&255);break A}e=i+1409|0;f=w[e|0];G:{if(!(f|!(v[E>>2]&16777250))){t[e|0]=w[i+1449|0];break G}t[i+1449|0]=f}i=w[m+5|0];e=i&240;if((e|0)!=224){if((e|0)!=96){break A}v[l+24>>2]=v[l+24>>2]+(i&15);break A}if(v[ba>>2]){break A}i=i&15;if(i?0:w[E|0]&2){break A}v[ba>>2]=i+1;break A}i=w[m+5|0];if((i&240)!=224){break A}v[ba>>2]=(i&15)+1}m=m+6|0;a=a+1|0;continue}break}i=Rk(l);v[h+24>>2]=1;a=v[Yc(ba,h+24|0)>>2];u[l+68>>1]=65535;v[l+60>>2]=-1;v[l+64>>2]=-1;V=i-1|0;a=i-a|0;M=B(a,1e4);m=0;while(1){if(x[_>>1]<=m>>>0){if(v[E>>2]==4&v[l+40>>2]==65535){break o}v[l+32>>2]=v[b+480216>>2];a=$b(v[b+484344>>2],x[l+70>>1]);e=v[a+16>>2];if(EN(e,v[a+20>>2])){v[l+32>>2]=e}e=DN(b,l);a=B(e,i);A[D+24>>3]=A[D+24>>3]+ +(a>>>0)/+y[b+24620>>2];v[l>>2]=a+v[l>>2];H:{I:{if(Ea){break I}m=0;fa=(d|0)!=0&(d|0)!=(e|0);while(1){if(x[_>>1]<=m>>>0){break I}r=Re(v[D+8>>2],m);J:{if(v[r>>2]==-1){break J}n=l+B(m,872)|0;V=n+1404|0;I=v[n+1316>>2];if(!I){if(Ry(V)){break J}}p=n+1409|0;f=1;K:{L:{M=n+1407|0;switch(w[M|0]-4|0){case 0:case 2:break K;default:break L}}f=w[n+1406|0]==11}a=w[p|0];if(w[n+1405|0]){v[n+1276>>2]=0}k=n+616|0;g=a&15;q=0;M:{N:{O:{if(!Uc(w[V|0])){break O}if(!(!f|!w[r+4|0])){Qy(h+24|0,b,k,I,0);q=v[h+28>>2];v[n+624>>2]=v[h+24>>2];v[n+628>>2]=q}t[n+1418|0]=w[n+1415|0];I=n+1308|0;Z=v[I>>2];q=w[n+1419|0];if(q){Dp(b,k,q,f,1,1)}q=w[V|0];v[23296]=0;ia(538,b|0,k|0,q|0,f|0,1,0,65535);q=v[23296];v[23296]=0;if((q|0)==1){break N}a=a>>>4|0;CN(v[E>>2],x[_>>1],l,m&65535);va=Re(v[D+8>>2],m);t[va+4|0]=1;r=w[M|0];P:{if(!((w[p|0]&240)!=208|(r-19&255)>>>0>1)){q=g;if(g>>>0<i>>>0){break P}}q=(r|0)==33?a>>>0<i>>>0?a:0:0}wa=v[ba>>2];if(!(!(v[E>>2]&16777250)|(!q|wa>>>0<2))){q=B(wa-1|0,v[l+24>>2]+v[l+40>>2]|0)+q|0}if(!f){v[va>>2]=0}Q:{if((r|0)==9){break Q}R:{if((r|0)!=19){if((r|0)!=20|(a|0)!=8){break R}break Q}if((a|0)==8){break Q}}if(w[n+1406|0]!=2){break O}}v[I>>2]=Z}S:{if(!Uc(w[V|0])){Bb(h+24|0,F,114);if(!Cb(v[v[h+24>>2]>>2],v[h+28>>2])){break S}}T:{U:{V:{W:{a=w[M|0];switch(a-42|0){case 1:break T;case 0:break U;case 2:break V;default:break W}}if((a|0)!=10){break T}a=x[l+70>>1];r=v[l+48>>2];v[23296]=0;da(539,b|0,k|0,m&65535,r|0,a|0);a=v[23296];v[23296]=0;if((a|0)!=1){break S}break H}I=Sia(w[p|0],0,v[n+692>>2],0);r=mb;a=r>>>8|0;Vn(b,k,Vc((r&255)<<24|I>>>8,a));break S}if(!v[n+720>>2]){break T}v[23296]=0;X(540,D|0,m&65535,d|0,-1);a=v[23296];v[23296]=0;if((a|0)==1){break H}AN(k,w[p|0]);q=v[l+40>>2]-1|0;break S}if(w[n+1406|0]!=15){break S}r=v[n+720>>2];if(!r){break S}a=w[n+1408|0];if(a>>>0>9){break S}X:{if(!a){r=v[n+1280>>2];break X}r=v[Db(r+68|0,a-1|0)>>2];v[n+1280>>2]=r}Vn(b,k,r)}Y:{Z:{_:{switch(w[V|0]-253|0){case 0:if(x[ua>>1]){break Z}break;case 1:case 2:break Z;default:break _}}a=w[M|0];if(!((w[p|0]&240)!=192|(a-19&255)>>>0>1)&g>>>0<i>>>0){break Z}r=0;if((a|0)==33&(g|0)!=0&i>>>0>g+q>>>0){break Z}if((a|0)!=25){break Y}}a=w[M|0];r=1}I=n+1304|0;$:{if((a|0)!=13){if(w[n+1406|0]!=1){break $}g=n+1408|0}else{g=p}v[I>>2]=w[g|0]<<2}aa:{if(!(!v[n+720>>2]|r)){r=0;ba:{ca:{da:{if(a>>>0>45){break da}Bb(h+24|0,pa,a);if(Cb(v[v[h+24>>2]>>2],v[h+28>>2])){break ca}if(w[M|0]!=19){break da}r=(w[p|0]-16&255)>>>0<32}a=w[n+1406|0];if(a>>>0<16){break ba}if(r){break aa}break M}r=1;a=w[n+1406|0];if(a>>>0>=16){break aa}}tk(h+24|0,qa,a);a=Cb(v[v[h+24>>2]>>2],v[h+28>>2]);if(r){break aa}if(!a){break M}break aa}if(!r){break M}}lP(k);Ga=Re(v[D+8>>2],m),Ha=0,v[Ga>>2]=Ha;break J}m=P()|0;O()|0;break f}if(fa){v[23296]=0;X(540,D|0,m&65535,d|0,-1);a=v[23296];v[23296]=0;if((a|0)==1){break H}}ea:{fa:{ga:{ha:{ia:{a=w[M|0];if(a-6>>>0>=2){ja:{switch(a-19|0){case 1:break ha;case 0:break ia;default:break ja}}if(a-35>>>0<2){break fa}if((a|0)==45){break ga}if((a|0)!=11){break ea}}if(!w[p|0]&v[E>>2]==1){break ea}a=n+1467|0;g=0;while(1){if((g|0)==(i|0)){break ea}t[a|0]=!g|w[a|0]&254;Un(b,k,w[p|0]);g=g+1|0;continue}}p=w[p|0];a=p&15;if(!(v[E>>2]&1048580?1:a)){break ea}g=n+1467|0;t[g|0]=w[g|0]|1;p=p&240;if((p|0)!=176){if((p|0)!=160){break ea}Tn(b,k,a,0);break ea}Sn(b,k,a,0);break ea}ka:{la:{ma:{a=w[p|0];switch(a-158|0){case 1:break la;case 0:break ma;default:break ka}}v[23296]=0;X(540,D|0,m&65535,d|0,-1);a=v[23296];v[23296]=0;if((a|0)==1){break H}v[n+704>>2]=v[n+704>>2]&-129;break ea}v[23296]=0;X(540,D|0,m&65535,d|0,-1);a=v[23296];v[23296]=0;if((a|0)==1){break H}a=v[n+704>>2];v[n+704>>2]=a|128;if(v[k+4>>2]){break ea}p=v[n+692>>2];if(!p){break ea}if(!(Ga=Uc(w[V|0]),Ha=1,Ia=a&2,Ia?Ga:Ha)){break ea}v[k>>2]=-1;v[k+4>>2]=p-1;break ea}if((a&240)!=112|a>>>0<115){break ea}gP(k,a,v[E>>2]);break ea}zN(k,w[p|0]);break ea}v[23296]=0;a=m&65535;X(540,D|0,a|0,d|0,-1);p=v[23296];v[23296]=0;if((p|0)==1){break H}yN(b,a,l,0)}p=n+1467|0;a=w[p|0]|1;t[p|0]=a;na:{oa:{pa:{qa:{ra:{g=n+1406|0;switch(w[g|0]-3|0){case 11:break oa;case 0:case 1:break pa;case 3:break qa;case 2:break ra;default:break na}}a=w[n+1408|0];Bb(h+24|0,F,41);Tn(b,k,a,Cb(v[v[h+24>>2]>>2],v[h+28>>2]));break na}a=w[n+1408|0];Bb(h+24|0,F,41);Sn(b,k,a,Cb(v[v[h+24>>2]>>2],v[h+28>>2]));break na}a=w[n+1408|0];sa:{if(a){break sa}Bb(h+24|0,F,41);a=0;if(!Cb(v[v[h+24>>2]>>2],v[h+28>>2])){break sa}a=w[n+1450|0];if(!a){break na}}g=w[g|0]==3?a<<4:a;a=0;while(1){if((a|0)==(i|0)){break na}t[p|0]=!a|w[p|0]&254;Un(b,k,g&255);a=a+1|0;continue}}k=w[n+1408|0];if(k>>>0>1){break na}t[p|0]=a&247|!k<<3}if(w[p|0]&8){break J}if(f){f=Re(v[D+8>>2],m);a=v[f>>2];v[f>>2]=a+i;v[23296]=0;X(540,D|0,m&65535,e|0,(a+q|0)+1|0);a=v[23296];v[23296]=0;if((a|0)!=1){break J}m=P()|0;O()|0;break f}a=Re(v[D+8>>2],m);v[a>>2]=v[a>>2]+(i-q|0)}m=m+1|0;continue}}q=xN(b,l,G,0);d=e;continue t}m=P()|0;O()|0;break f}k=l+B(m,872)|0;e=k+1404|0;ta:{if(Ry(e)){break ta}q=k+616|0;fa=k+1409|0;g=w[fa|0];I=k+1407|0;p=w[I|0];ua:{va:{if(!aa){break va}n=w[e|0];f=n;r=k+1405|0;Z=w[r|0];if(Z){t[k+1415|0]=0;t[k+1419|0]=Z;Ga=Re(v[D+8>>2],m),Ha=255,t[Ga+5|0]=Ha;f=w[e|0]}if(Uc(f)){t[k+1415|0]=n;iP(q);f=w[e|0]}wa:{if(!(Ga=1,Ha=Uc(f),Ia=w[r|0],Ia?Ga:Ha)){break wa}Z=k+1419|0;f=w[Z|0];xa:{if(!f){f=0;break xa}if(x[ua>>1]<f>>>0){break xa}r=v[((f<<2)+b|0)+900380>>2];if(!r|!(t[r+15|0]&1)){break xa}Mp(q,v[r+8>>2],b);f=w[Z|0]}f=Oy(b,n,f);if(!f){break wa}f=B(f,104)+b|0;if(!(w[f+484414|0]&32)){break wa}Mp(q,x[f+484408>>1],b)}ya:{za:{Aa:{f=w[k+1406|0];switch(f-1|0){case 1:break va;case 2:case 3:break za;case 0:break Aa;default:break ya}}Ga=Re(v[D+8>>2],m),Ha=w[k+1408|0],t[Ga+5|0]=Ha;break va}e=w[k+1408|0];if(!e){break va}t[k+1450|0]=e;break va}if((f|0)!=11){break va}f=w[k+1408|0];if(!f){break va}n=h+24|0;Ny(n,b,w[e+3|0],f,0);u[k+1384>>1]=x[h+24>>1];if(w[Ue(n)|0]){break ua}}Ba:{Ca:{Da:{Ea:{Fa:{switch(p-12|0){case 0:wN(b,l,m&65535);break Ba;case 2:e=vN(b,l,m&65535,g);if((e|0)==-1){break Ba}v[l+60>>2]=e;break Ba;case 5:Bb(h+24|0,F,5);if(Cb(v[v[h+24>>2]>>2],v[h+28>>2])){break Ba}e=B(Rn(b,x[l+70>>1],v[l+48>>2],m&65535,0),1e4);Ga:{if(!aa|!(v[E>>2]&16777250)){break Ga}if(e>>>0>=1e4){t[k+1451|0]=(e>>>0)/1e4;break Ga}e=B(w[k+1451|0],1e4)}Ha:{if(e>>>0>319999){break Ha}n=(e>>>0)/1e4|0;f=B(M,n&15);e=v[ga>>2];if((n&240)==16){e=e+f|0;break Ha}f=e-f|0;e=e>>>0<f>>>0?0:f}v[ga>>2]=e;e=v[b+8>>2];f=v[e+20>>2];e=v[e+24>>2];Bb(h+24|0,F,8);Fo(ga,B(f,1e4),Cb(v[v[h+24>>2]>>2],v[h+28>>2])?255e4:B(e,1e4));break Ba;case 8:Ia:{switch((g&240)-144>>>4|0){case 0:if(g>>>0>145){break Ba}v[k+704>>2]=v[k+704>>2]&-257|((g|0)==145)<<8;break Ba;case 1:t[k+1452|0]=g&15;break Ba;case 2:break Ea;case 6:break Ia;default:break Ba}}t[k+1460|0]=g&15;break Ba;case 1:case 3:case 4:case 6:break Ba;case 7:break Fa;default:break Ca}}e=g&240;if((e|0)==240){break Da}if((e|0)!=96){break Ba}}My(b,l,q,g&15);break Ba}t[k+1460|0]=g&15;break Ba}if((p|0)!=28|(g&240)!=160){break Ba}Bb(h+24|0,F,58);if(Cb(v[v[h+24>>2]>>2],v[h+28>>2])){break Ba}t[k+1452|0]=g&15}if(!aa){break ta}Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{switch(p-2|0){case 0:if(!g){break Ja}Bb(h+24|0,F,90);if(!Cb(v[v[h+24>>2]>>2],v[h+28>>2])){t[k+1428|0]=g}t[k+1427|0]=g;break ua;case 1:if(!g){break Ja}Bb(h+24|0,F,90);if(!Cb(v[v[h+24>>2]>>2],v[h+28>>2])){t[k+1427|0]=g}t[k+1428|0]=g;break ua;case 2:if(!g){break Ja}u[k+1384>>1]=g;break ua;case 8:if(!g){break Ja}v[k+1280>>2]=g<<8;break ua;case 4:case 9:if(!g){break Ja}t[k+1425|0]=g;break ua;case 11:Ga=Re(v[D+8>>2],m),Ha=g,t[Ga+5|0]=Ha;break ua;case 21:e=v[E>>2];g=g<<(!(e&59593760)&g<<24>>24>=0);f=g&255;if(f>>>0<=128){v[T>>2]=f<<1;break ua}if(e&16777250){break ua}v[T>>2]=256;break ua;case 22:Bb(h+24|0,F,9);Sa:{if(Cb(v[v[h+24>>2]>>2],v[h+28>>2])){e=k+1433|0;if(g){t[e|0]=g;break Sa}g=w[e|0];break Sa}if(g){t[l+1433|0]=g;break Sa}g=w[l+1433|0]}e=g&240;f=g&15;Ta:{if(!(!e|(f|0)!=15)){g=e>>>4<<!(v[E>>2]&59593760);e=v[T>>2]+(g<<1)|0;break Ta}if(!(!f|(e|0)!=240)){g=f<<(v[E>>2]&59593760?1:2);e=v[T>>2]-g|0;break Ta}if(e){g=(g>>>3&30)<<!(v[E>>2]&59593760);e=v[T>>2]+B(a,g)|0;break Ta}g=f<<(v[E>>2]&59593760?1:2);e=v[T>>2]-B(a,g)|0}v[T>>2]=e;he(T,0,256);break ua;case 19:if(g>>>0>64){break ua}v[k+1364>>2]=g;break ua;case 20:e=k+1432|0;Ua:{if(g){t[e|0]=g;break Ua}g=w[e|0]}p=g&255;n=k+1364|0;e=v[n>>2];r=g&240;f=g&15;Va:{if(!(!r|(f|0)!=15)){v[h+24>>2]=e+(p>>>4|0);break Va}if(!(!f|(r|0)!=240)){v[h+24>>2]=e-f;break Va}if(f){v[h+24>>2]=e-B(a,f);break Va}v[h+24>>2]=e+B(a,p>>>4|0)}he(h+24|0,0,64);v[n>>2]=v[h+24>>2];break ua;case 7:Wl(b,q,g,8);break ua;case 29:case 30:break Ka;case 25:break La;case 6:break Ma;case 24:break Na;case 3:break Oa;case 5:break Pa;case 18:break Qa;case 17:break Ra;default:break ua}}if(g>>>0>15){break Qa}f=(g&1)<<14;p=x[_>>1];e=0;while(1){if((e|0)==(p|0)){break Qa}n=l+B(e,872)|0;v[n+704>>2]=(f|v[n+704>>2]&-16385)^16384;e=e+1|0;continue}}if((g&240)!=128){break ua}Wl(b,q,g&15,4);break ua}if(g){t[k+1425|0]=g}g=0}Qk(q,g);break ua}uN(b,q,g);break ua}tN(q,g);break ua}sN(q,g);break ua}Wa:{if(g<<24>>24>=0){e=pe(za,w[k+1460|0]);break Wa}e=pe(Aa,g&127)}f=w[fa|0];v[23296]=0;ma(541,b|0,l|0,m&65535,0,e|0,f|0);e=v[23296];v[23296]=0;if((e|0)!=1){break ua}m=P()|0;O()|0;break f}g=0}Xa:{Ya:{switch(w[k+1406|0]-2|0){case 0:Wl(b,q,w[k+1408|0],6);break Xa;case 5:Bb(h+24|0,F,53);e=w[k+1408|0];if(Cb(v[v[h+24>>2]>>2],v[h+28>>2])){t[k+1439|0]=e&15;break Xa}Qk(q,e<<4);break Xa;case 6:break Ya;default:break Xa}}Qk(q,w[k+1408|0])}Za:{_a:{$a:{ab:{bb:{e=w[I|0];switch(e-5|0){case 1:break Za;case 3:break $a;case 0:case 2:break ab;default:break bb}}switch(e-26|0){case 1:break _a;case 0:break ab;default:break Za}}cb:{if(v[E>>2]&16777248){e=i;if(!(w[b+480208|0]&4)){break cb}}e=a}f=w[k+1439|0];Bb(h+24|0,F,21);k=k+1435|0;p=w[k|0];e=B(e,f);Ga=k,Ha=(Cb(v[v[h+24>>2]>>2],v[h+28>>2])?e<<2:e)+p|0,t[Ga|0]=Ha;break Za}db:{if(v[E>>2]&16777248){e=i;if(!(w[b+480208|0]&4)){break db}}e=a}f=w[k+1442|0];Bb(h+24|0,F,21);k=k+1436|0;p=w[k|0];e=B(e,f);Ga=k,Ha=(Cb(v[v[h+24>>2]>>2],v[h+28>>2])?e<<2:e)+p|0,t[Ga|0]=Ha;break Za}e=k+1437|0;t[e|0]=w[e|0]+B(V,w[k+1445|0]);qN(b,q)}Bb(h+24|0,F,78);if(!Cb(v[v[h+24>>2]>>2],v[h+28>>2])){break ta}e=g&255;if(!e){break ta}pN(q,e)}m=m+1|0;continue}}break}m=P()|0;O()|0;break f}m=P()|0;O()|0;break f}m=P()|0;O()|0;break f}m=P()|0;O()|0;break f}t[s+26|0]=1}eb:{if((ca|0)!=7){break eb}a=0;i=b+480188|0;while(1){if(x[i>>1]<=a>>>0){break eb}fb:{if(v[Re(v[D+8>>2],a)>>2]==-1){break fb}v[23296]=0;X(540,D|0,a&65535,d|0,-1);e=v[23296];v[23296]=0;if((e|0)!=1){break fb}m=P()|0;O()|0;break f}a=a+1|0;continue}}if(w[s+26|0]){u[s+20>>1]=x[l+72>>1];v[s+8>>2]=v[l+48>>2]}A[s>>3]=A[D+24>>3];v[23296]=0;R(535,$|0,s|0);a=v[23296];v[23296]=0;if((a|0)!=1){if(!aa){break a}if(!(K?w[s+26|0]:1)){break c}f=Gy(h+56|0);if(Rd(w[ha+24|0])){eN(f,ha)}Ly(ha);a=qc(b+1074376|0,l,614);e=0;while(1){if((e|0)==256){pm(a+223848|0,l+223848|0);d=a+223860|0;e=w[d+24|0];i=l+223860|0;gb:{if((Rd(w[i+24|0])|0)==(e|0)){if(!e){break gb}e=kc(d);Xs(d,v[e>>2]);v[d>>2]=v[i>>2];v[d+4>>2]=v[i+4>>2];v[d+8>>2]=v[i+8>>2];hb:{if(!v[Gb(d)>>2]){v[d>>2]=e;break hb}v[v[e>>2]+8>>2]=e;e=kc(i);v[i>>2]=e;v[e>>2]=0;Ga=Gb(i),Ha=0,v[Ga>>2]=Ha}d=d+12|0;e=kc(d);Ws(d,v[e>>2]);i=i+12|0;v[d>>2]=v[i>>2];v[d+4>>2]=v[i+4>>2];v[d+8>>2]=v[i+8>>2];ib:{if(!v[Gb(d)>>2]){v[d>>2]=e;break ib}v[v[e>>2]+8>>2]=e;d=kc(i);v[i>>2]=d;v[d>>2]=0;Ga=Gb(i),Ha=0,v[Ga>>2]=Ha}break gb}if(e){Ly(d);break gb}eN(d,i)}}else{d=B(e,872);Bp((d+a|0)+616|0,(d+l|0)+616|0);e=e+1|0;continue}break}Ky(a);a=0;v[b+1074400>>2]=0;t[b+1074476|0]=1;d=b+1074392|0;v[d>>2]=-2;v[d+4>>2]=0;v[b+1074428>>2]=v[b+1074424>>2];jb:{kb:{d=v[b+1298300>>2];if(!xd(d)){break kb}v[23296]=0;Y(542,d|0);d=v[23296];v[23296]=0;if((d|0)!=1){break kb}break jb}while(1){if(x[b+480188>>1]<=a>>>0){a=Yz(h+24|0);Ga=h,Ha=qj(v[f+12>>2]),v[Ga+16>>2]=Ha;k=yf(f+12|0);while(1){d=v[h+16>>2];if(!Ag(d,k)){lb:{e=250;d=a;mb:{while(1){if(e>>>0>=32){if(v[a>>2]){a=1;break mb}else{e=e-32|0;a=a+4|0;continue}}break}a=(v[d+28>>2]&67108863)!=0}if(!a){break lb}a=0;while(1){if((a|0)==250){break lb}Bb(h+8|0,d,a);nb:{if(!Cb(v[v[h+8>>2]>>2],v[h+12>>2])){break nb}i=v[(B(a,160)+b|0)+906300>>2];e=v[v[i>>2]+176>>2];v[23296]=0;Y(e|0,i|0);i=v[23296];v[23296]=0;if((i|0)!=1){break nb}break jb}a=a+1|0;continue}}Ga=h,Ha=qj(v[f>>2]),v[Ga+8>>2]=Ha;a=yf(f);while(1){d=v[h+8>>2];if(Ag(d,a)){d=vd(d);Ga=(B(w[d|0],160)+b|0)+906444|0,Ja=z[kc(d)>>2],z[Ga>>2]=Ja;Xg(h+8|0);continue}else{Cp(f);break b}}}i=vd(d);q=Gb(i);ob:{e=w[i|0];d=v[(B(e,160)+b|0)+906300>>2];if(d){Bb(h+8|0,a,e);if(!Cb(v[v[h+8>>2]>>2],v[h+12>>2])){v[23296]=0;Q(543,a|0,e|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break ob}e=v[v[d>>2]+172>>2];v[23296]=0;R(e|0,d|0,-1);e=v[23296];v[23296]=0;if((e|0)==1){break ob}}Fa=z[q>>2];i=v[i+4>>2];e=v[v[d>>2]+44>>2];v[23296]=0;Ba(e|0,d|0,i|0,C(Fa));d=v[23296];v[23296]=0;if((d|0)==1){break ob}}Xg(h+16|0);continue}break}break jb}d=B(a,872)+b|0;i=w[d+1075791|0];if(i){t[d+1075794|0]=i}d=Re(v[D+8>>2],a);if(!((ca|0)==7|w[d+5|0]==255)){t[h+24|0]=64;Ga=(B(a,872)+b|0)+1075680|0,Ha=w[Wb(d+5|0,h+24|0)|0]<<2,v[Ga>>2]=Ha}pb:{i=B(a,872)+b|0;d=v[i+1075096>>2];qb:{if(!d|!(w[d+35|0]&2)){break qb}e=v[b+1298300>>2];if(!xd(e)){break qb}v[23296]=0;ka=e;e=a&65535;U(544,ka|0,e|0,d+68|0);d=v[23296];v[23296]=0;if((d|0)==1){break pb}d=v[b+1298300>>2];v[23296]=0;U(545,d|0,e|0,1);d=v[23296];v[23296]=0;if((d|0)==1){break pb}}v[i+1075008>>2]=0;a=a+1|0;continue}break}}m=P()|0;O()|0;Cp(f);break f}m=P()|0;O()|0}at(H)}oN(D)}vi($);S(m|0);L()}if((c|0)==3){break b}v[b+1074416>>2]=v[b+480196>>2];v[b+1074420>>2]=v[b+480204>>2];v[b+1074456>>2]=v[b+480200>>2]}a=oa&255;if((a|0)==w[b+484376|0]){break a}Ai(na,a)}if(c&9){a=b+1298264|0;if(v[a>>2]){fO(a);b=v[a>>2];Ej(a);Jb(b);Ga=Gb(a),Ha=0,v[Ga>>2]=Ha;v[a>>2]=0;v[a+4>>2]=0}v[a>>2]=v[H>>2];v[a+4>>2]=v[H+4>>2];b=Gb(H);Ga=Gb(a),Ha=v[b>>2],v[Ga>>2]=Ha;v[b>>2]=0;v[H>>2]=0;v[H+4>>2]=0;a=a+12|0;c=kc(a);Hp(a,v[c>>2]);b=H+12|0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];rb:{if(!v[Gb(a)>>2]){v[a>>2]=c;break rb}v[v[c>>2]+8>>2]=c;a=kc(b);v[b>>2]=a;v[a>>2]=0;Ga=Gb(b),Ha=0,v[Ga>>2]=Ha}}at(H);oN(D);jb=h+208|0}function $R(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,A=C(0),D=C(0),E=0,F=0,G=0,H=0,I=C(0),J=C(0),K=0,M=C(0),N=C(0),O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=C(0),_=C(0),$=0,ba=C(0),ca=C(0),da=0,ea=0,fa=C(0),ga=0,ha=0,ia=0,ja=0,ka=0,la=0,ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=0,ta=0,ua=0,va=0;U=jb-16|0;jb=U;a:{if(v[a+1420>>2]>=0){v[f>>2]=0;Q=v[a+1420>>2];d=(Q|0)>0?Q:0;while(1){if((d|0)!=(E|0)){v[(B(E,20)+a|0)+1436>>2]=0;E=E+1|0;continue}break}b:{c:{d:{if((Q|0)>3){break d}E=0;if((c|0)<4){break c}c=c-3|0;d=0;while(1){if((c|0)==(d|0)){break d}e:{f:{h=b+d|0;if(w[h|0]!=79){break f}if(Pb(h,92704,4)){break f}g=d+26|0;if((g|0)>=(c|0)){break e}j=d+27|0;i=b+g|0;f=w[i|0];if((j+f|0)>=(c|0)){break e}k=f+27|0;E=0;e=0;while(1)if((e|0)==(f|0)){e=0;while(1){f=22;if((E|0)!=22){e=Yw(e,w[(d+E|0)+b|0]);E=E+1|0;continue}break}while(1){if((f|0)!=26){f=f+1|0;e=Yw(e,0);continue}break}v[a+1420>>2]=Q+1;f=B(Q,20)+a|0;v[f+1432>>2]=e;v[f+1428>>2]=k-26;v[f+1424>>2]=w[h+22|0]|w[h+23|0]<<8|(w[h+24|0]<<16|w[h+25|0]<<24);e=w[(g+w[i|0]|0)+b|0]==255?-1:w[h+6|0]|w[h+7|0]<<8|(w[h+8|0]<<16|w[h+9|0]<<24);v[f+1436>>2]=g;v[f+1440>>2]=e;Q=v[a+1420>>2];if((Q|0)!=4){break f}Q=4;break d}else{k=w[(e+j|0)+b|0]+k|0;e=e+1|0;continue}}d=d+1|0;continue}break}c=d}d=0;g:while(1){i=(d|0)>(Q|0)?d:Q;while(1){if((d|0)==(i|0)){break b}E=0;f=B(d,20)+a|0;n=f+1428|0;h=v[n>>2];k=v[f+1436>>2];j=c-k|0;g=(h|0)<(j|0)?h:j;l=(g|0)>0?g:0;da=f+1432|0;e=v[da>>2];while(1){if((l|0)!=(E|0)){e=Yw(e,w[(k+E|0)+b|0]);E=E+1|0;continue}break}v[n>>2]=h-g;v[da>>2]=e;if((h|0)<=(j|0)){h=e;e=f+1424|0;if((h|0)==v[e>>2]){v[a+1380>>2]=-1;v[a+992>>2]=0;v[a+1420>>2]=-1;b=v[(B(d,20)+a|0)+1440>>2];v[a+1060>>2]=b;v[a+1064>>2]=(b|0)!=-1;E=g+k|0;break c}f=Q-1|0;v[a+1420>>2]=f;f=B(f,20)+a|0;v[e+16>>2]=v[f+1440>>2];h=f+1432|0;g=v[h+4>>2];v[e+8>>2]=v[h>>2];v[e+12>>2]=g;f=f+1424|0;h=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=h;Q=v[a+1420>>2];continue g}else{d=d+1|0;continue}}}}c=E}break a}v[a+100>>2]=0;v[a+32>>2]=b;v[a+40>>2]=b+c;if(!XH(a)){v[f>>2]=0;c=0;break a}qa=U+12|0;da=jb-16|0;jb=da;v[a+1504>>2]=0;v[a+1508>>2]=0;h:{if(v[a+96>>2]){break h}i:{j:{k:{if(v[a+1380>>2]!=-1){break k}c=Pe(a);if(v[a+96>>2]){break i}if((c|0)!=79){break j}if((Pe(a)|0)!=103){break j}if((Pe(a)|0)!=103){break j}if((Pe(a)|0)!=83){break j}if(!WH(a)){break i}if(!(t[a+1375|0]&1)){break k}t[a+1376|0]=0;v[a+1384>>2]=0;bc(a,32);break i}k=Vw(a);break i}bc(a,30)}if(!k){break h}if(pc(a,1)){bc(a,35);break h}s=da;l:{m:{if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){c=pc(a,Kl(v[a+408>>2]-1|0));if((c|0)==-1|(c|0)>=v[a+408>>2]){break h}v[da+12>>2]=c;k=B(c,6)+a|0;if(!w[k+412|0]){h=v[a+112>>2];g=h>>1;break m}h=v[a+116>>2];g=h>>1;c=pc(a,1);j=pc(a,1);if(c|!w[k+412|0]){break m}v[U+4>>2]=h-v[a+112>>2]>>2;c=v[a+112>>2]+h>>2;break l}aa(6286,13048,3152,10626);L()}v[U+4>>2]=0;c=g}v[s+8>>2]=c;n:{if(!(!w[k+412|0]|j)){c=B(h,3);v[U+8>>2]=c-v[a+112>>2]>>2;h=c+v[a+112>>2]>>2;break n}v[U+8>>2]=g}v[da+4>>2]=h;h=1}if(h){E=v[U+4>>2];la=v[U+8>>2];ka=v[da+4>>2];O=jb-2368|0;jb=O;F=v[a+404>>2];oa=B(v[da+12>>2],6)+a|0;G=w[oa+413|0];R=F+B(G,40)|0;V=v[((w[oa+412|0]<<2)+a|0)+104>>2];ha=V>>1;sa=0-ha|0;o:{while(1){c=v[a+4>>2];if((c|0)>(n|0)){c=w[(v[R+4>>2]+B(n,3)|0)+2|0];P=(O+1344|0)+(n<<2)|0;v[P>>2]=0;h=w[(c+R|0)+9|0];if(!x[((h<<1)+a|0)+132>>1]){bc(a,21);c=0;break o}g=v[a+260>>2];p:{q:{if(!pc(a,1)){break q}c=2;k=v[((n<<2)+a|0)+996>>2];g=g+B(h,1596)|0;r=v[(w[g+1588|0]<<2)+71532>>2];h=Kl(r)-1|0;ta=k,ua=pc(a,h),u[ta>>1]=ua;ta=k,ua=pc(a,h),u[ta+2>>1]=ua;H=g+82|0;W=g+65|0;T=g+49|0;S=g+33|0;K=g+1|0;o=0;while(1){if(w[g|0]>o>>>0){p=w[o+K|0];q=w[p+T|0];l=-1<<q;X=w[p+S|0];r:{if(!q){i=0;break r}h=v[a+124>>2]+B(w[p+W|0],2096)|0;if(v[a+1396>>2]<=9){Gk(a)}j=v[a+1392>>2];i=u[(h+((j&1023)<<1)|0)+36>>1];s:{if((i|0)>=0){s=j;i=i&65535;j=w[i+v[h+8>>2]|0];v[a+1392>>2]=s>>>j;j=v[a+1396>>2]-j|0;v[a+1396>>2]=(j|0)>0?j:0;i=(j|0)>=0?i:-1;break s}i=Jl(a,h)}if(!w[h+23|0]){break r}i=v[v[h+2088>>2]+(i<<2)>>2]}ea=l^-1;h=c+X|0;while(1){if((c|0)!=(h|0)){l=0;j=u[(H+(p<<4)|0)+((i&ea)<<1)>>1];t:{if((j|0)<0){break t}j=v[a+124>>2]+B(j&65535,2096)|0;if(v[a+1396>>2]<=9){Gk(a)}l=v[a+1392>>2];X=u[(j+((l&1023)<<1)|0)+36>>1];u:{if((X|0)>=0){s=l;X=X&65535;l=w[X+v[j+8>>2]|0];v[a+1392>>2]=s>>>l;l=v[a+1396>>2]-l|0;v[a+1396>>2]=(l|0)>0?l:0;l=(l|0)>=0?X:-1;break u}l=Jl(a,j)}if(!w[j+23|0]){break t}l=v[v[j+2088>>2]+(l<<2)>>2]}i=i>>q;u[k+(c<<1)>>1]=l;c=c+1|0;continue}break}o=o+1|0;c=h;continue}break}if(v[a+1396>>2]==-1){break q}u[O+320>>1]=257;h=g+338|0;o=g+1088|0;c=2;while(1){l=v[g+1592>>2];if((l|0)<=(c|0)){c=0;while(1){if((c|0)>=(l|0)){break p}if(!w[(O+320|0)+c|0]){u[k+(c<<1)>>1]=65535;l=v[g+1592>>2]}c=c+1|0;continue}}else{j=c<<1;l=j+o|0;q=w[l|0];p=q<<1;i=x[p+h>>1];P=w[l+1|0];H=P<<1;W=u[k+p>>1];l=u[H+k>>1]-W|0;p=l>>31;i=(B((l^p)-p|0,x[h+j>>1]-i|0)|0)/(x[h+H>>1]-i|0)|0;l=W+((l|0)<0?0-i|0:i)|0;H=k+j|0;i=x[H>>1];v:{w:{if(i){j=O+320|0;t[j+P|0]=1;t[j+q|0]=1;t[c+j|0]=1;j=i<<16>>16;p=r-l|0;if((j|0)>=((l|0)>(p|0)?p:l)<<1){if((l|0)<(p|0)){break v}l=r+(i^-1)|0;break w}if(j&1){l=l-(j+1>>>1|0)|0;break w}l=(j>>1)+l|0;break w}t[(O+320|0)+c|0]=0}u[H>>1]=l}c=c+1|0;continue}}}v[P>>2]=1}n=n+1|0;continue}break}if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){qc(O+320|0,O+1344|0,c<<2);g=x[R>>1];c=0;while(1){if((c|0)==(g|0)){c=F+B(G,40)|0}else{k=v[R+4>>2]+B(c,3)|0;h=w[k+1|0];l=O+1344|0;k=l+(w[k|0]<<2)|0;if(!(v[(h<<2)+l>>2]?v[k>>2]:0)){v[(O+1344|0)+(h<<2)>>2]=0;v[k>>2]=0}c=c+1|0;continue}break}X=c;i=0;while(1){x:{if(w[X+8|0]>i>>>0){l=0;c=v[a+4>>2];k=(c|0)>0?c:0;c=0;while(1){if((c|0)==(k|0)){break x}if(w[(v[R+4>>2]+B(c,3)|0)+2|0]==(i|0)){h=l+O|0;g=c<<2;y:{if(v[g+(O+1344|0)>>2]){g=0;n=1;break y}g=v[(a+g|0)+800>>2];n=0}t[h|0]=n;v[(O+256|0)+(l<<2)>>2]=g;l=l+1|0}c=c+1|0;continue}}if(!(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0)){k=(ha|0)>0?ha:0;h=x[R>>1];g=a+800|0;z:while(1){if((h|0)<=0){P=ha<<2;l=0;c=0;while(1){i=v[a+4>>2];if((i|0)<=(c|0)){while(1){if((i|0)>(l|0)){P=w[oa+412|0];R=V>>1;h=R<<2;X=v[a+92>>2];p=V>>3;W=V>>2;k=v[((l<<2)+a|0)+800>>2];c=R<<2;G=k+c|0;A:{if(v[a+80>>2]){j=vn(a,h);break A}j=Jd(h)}h=(j+c|0)-8|0;g=v[((P<<2)+a|0)+1068>>2];i=g;c=k;while(1){if((c|0)!=(G|0)){z[h+4>>2]=C(z[c>>2]*z[i>>2])-C(z[i+4>>2]*z[c+8>>2]);z[h>>2]=C(z[c>>2]*z[i+4>>2])+C(z[c+8>>2]*z[i>>2]);c=c+16|0;i=i+8|0;h=h-8|0;continue}break}c=((R<<2)+k|0)-12|0;while(1){if(h>>>0>=j>>>0){z[h+4>>2]=C(z[c>>2]*z[i+4>>2])-C(z[c+8>>2]*z[i>>2]);z[h>>2]=C(C(-z[c+8>>2])*z[i+4>>2])-C(z[i>>2]*z[c>>2]);c=c-16|0;i=i+8|0;h=h-8|0;continue}break}c=W<<2;o=c+k|0;h=c+j|0;i=(g+(R<<2)|0)-32|0;c=j;n=k;while(1){if(g>>>0<=i>>>0){m=z[c>>2];A=z[h>>2];D=z[h+4>>2];I=z[c+4>>2];z[o+4>>2]=D+I;z[o>>2]=z[h>>2]+z[c>>2];D=C(D-I);m=C(A-m);z[n+4>>2]=C(D*z[i+16>>2])-C(z[i+20>>2]*m);z[n>>2]=C(m*z[i+16>>2])+C(D*z[i+20>>2]);m=z[c+8>>2];A=z[h+8>>2];D=z[h+12>>2];I=z[c+12>>2];z[o+12>>2]=D+I;z[o+8>>2]=z[h+8>>2]+z[c+8>>2];D=C(D-I);m=C(A-m);z[n+12>>2]=C(D*z[i>>2])-C(z[i+4>>2]*m);z[n+8>>2]=C(m*z[i>>2])+C(D*z[i+4>>2]);c=c+16|0;h=h+16|0;n=n+16|0;o=o+16|0;i=i-32|0;continue}break}h=Kl(V);c=V>>4;n=R-1|0;i=0-p|0;TH(c,k,n,i,g);TH(c,k,n-W|0,i,g);H=V>>5;c=0-c|0;gp(H,k,n,c,g,16);gp(H,k,n-p|0,c,g,16);gp(H,k,n-(p<<1)|0,c,g,16);gp(H,k,n+B(p,-3)|0,c,g,16);c=h-4>>1;o=(c|0)>2?c:2;c=2;while(1){B:{C:{D:{if((c|0)==(o|0)){c=h-7|0;ea=(c|0)<(o|0)?o:c;break D}i=0;p=2<<c;p=(p|0)>0?p:0;r=8<<c;q=V>>c+4;F=V>>c+2;T=0-(F>>1)|0;while(1){if((i|0)==(p|0)){break C}gp(q,k,n-B(i,F)|0,T,g,r);i=i+1|0;continue}}while(1){E:{if((o|0)!=(ea|0)){ma=32<<o;r=2<<o;T=8<<o;i=V>>o+6;Y=V>>o+2;$=0-(Y>>1)|0;h=n;c=g;while(1){if((i|0)<=0){break E}p=r;F=(h<<2)+k|0;q=F+($<<2)|0;S=B(T,12)+c|0;m=z[S>>2];K=(T<<3)+c|0;A=z[K>>2];s=(T<<2)+c|0;D=z[s>>2];I=z[S+4>>2];M=z[K+4>>2];Z=z[s+4>>2];_=z[c+4>>2];fa=z[c>>2];S=0-Y<<2;while(1){if((p|0)>0){K=q-4|0;N=z[K>>2];ba=z[F>>2];ca=z[q>>2];z[F>>2]=ba+ca;s=F-4|0;J=z[s>>2];z[s>>2]=J+z[K>>2];J=C(J-N);N=C(ba-ca);z[K>>2]=C(J*fa)+C(_*N);z[q>>2]=C(N*fa)-C(_*J);K=q-12|0;ba=z[K>>2];s=F-8|0;J=z[s>>2];ia=s;s=q-8|0;ca=z[s>>2];z[ia>>2]=J+ca;ga=F-12|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-ba);J=C(J-ca);z[K>>2]=C(N*D)+C(Z*J);z[s>>2]=C(J*D)-C(Z*N);K=q-20|0;ba=z[K>>2];s=F-16|0;J=z[s>>2];ia=s;s=q-16|0;ca=z[s>>2];z[ia>>2]=J+ca;ga=F-20|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-ba);J=C(J-ca);z[K>>2]=C(N*A)+C(M*J);z[s>>2]=C(J*A)-C(M*N);K=q-28|0;ba=z[K>>2];s=F-24|0;J=z[s>>2];ia=s;s=q-24|0;ca=z[s>>2];z[ia>>2]=J+ca;ga=F-28|0;N=z[ga>>2];z[ga>>2]=N+z[K>>2];N=C(N-ba);J=C(J-ca);z[K>>2]=C(N*m)+C(I*J);z[s>>2]=C(J*m)-C(I*N);p=p-1|0;q=q+S|0;F=F+S|0;continue}break}i=i-1|0;h=h-8|0;c=(ma<<2)+c|0;continue}}c=(n<<2)+k|0;i=c-(H<<6)|0;m=z[g+(V>>3<<2)>>2];fa=C(-m);while(1){if(c>>>0>i>>>0){M=z[c>>2];h=c-32|0;Z=z[h>>2];z[c>>2]=M+Z;g=c-4|0;A=z[g>>2];n=g;g=c-36|0;_=z[g>>2];z[n>>2]=A+_;n=c-8|0;D=z[n>>2];s=n;n=c-40|0;J=z[n>>2];z[s>>2]=D+J;p=c-12|0;I=z[p>>2];s=p;p=c-44|0;N=z[p>>2];z[s>>2]=I+N;z[h>>2]=M-Z;z[g>>2]=A-_;g=c-16|0;A=z[g>>2];s=g;g=c-48|0;ba=z[g>>2];z[s>>2]=A+ba;D=C(D-J);I=C(I-N);z[n>>2]=m*C(D+I);z[p>>2]=m*C(I-D);n=c-28|0;D=z[n>>2];p=c-60|0;I=z[p>>2];r=c-24|0;M=z[r>>2];o=c-56|0;Z=z[o>>2];q=c-20|0;_=z[q>>2];s=q;q=c-52|0;J=z[q>>2];z[s>>2]=_+J;z[r>>2]=M+Z;z[n>>2]=D+I;z[g>>2]=_-J;z[q>>2]=-C(A-ba);A=C(D-I);D=C(M-Z);z[o>>2]=m*C(A-D);z[p>>2]=C(D+A)*fa;SH(c);SH(h);c=c+-64|0;continue}break}p=R-4|0;h=j+(p<<2)|0;i=(j+(W<<2)|0)-16|0;c=v[((P<<2)+a|0)+1100>>2];while(1){if(i>>>0>=j>>>0){g=(x[c>>1]<<2)+k|0;z[h+12>>2]=z[g>>2];z[h+8>>2]=z[g+4>>2];z[i+12>>2]=z[g+8>>2];z[i+8>>2]=z[g+12>>2];g=(x[c+2>>1]<<2)+k|0;z[h+4>>2]=z[g>>2];z[h>>2]=z[g+4>>2];z[i+4>>2]=z[g+8>>2];z[i>>2]=z[g+12>>2];c=c+4|0;h=h-16|0;i=i-16|0;continue}break}c=v[((P<<2)+a|0)+1084>>2];i=j;h=i+(R<<2)|0;g=h;while(1){n=g-16|0;if(n>>>0>i>>>0){m=z[i+4>>2];r=g-4|0;A=z[r>>2];D=C(m-A);I=z[c+4>>2];m=C(m+A);A=z[i>>2];o=g-8|0;M=z[o>>2];Z=C(A-M);_=z[c>>2];fa=C(C(I*m)-C(Z*_));z[i+4>>2]=D+fa;A=C(A+M);m=C(C(I*Z)+C(m*_));z[i>>2]=A+m;z[r>>2]=fa-D;z[o>>2]=A-m;m=z[i+8>>2];A=z[n>>2];D=C(m+A);I=z[c+12>>2];m=C(m-A);A=z[i+12>>2];g=g-12|0;M=z[g>>2];Z=C(A+M);_=z[c+8>>2];fa=C(C(I*m)+C(Z*_));z[i+8>>2]=D+fa;A=C(A-M);m=C(C(I*Z)-C(m*_));z[i+12>>2]=A+m;z[n>>2]=D-fa;z[g>>2]=m-A;i=i+16|0;c=c+16|0;g=n;continue}break}i=v[((P<<2)+a|0)+1076>>2]+(R<<2)|0;c=(p<<2)+k|0;g=((V<<2)+k|0)-16|0;while(1){n=h-32|0;if(n>>>0>=j>>>0){m=z[h-8>>2];A=z[i-4>>2];D=z[i-8>>2];I=z[h-4>>2];M=C(C(m*A)-C(D*I));z[k>>2]=M;z[c+12>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G>>2]=m;z[g+12>>2]=m;m=z[h-16>>2];A=z[i-12>>2];D=z[i-16>>2];I=z[h-12>>2];M=C(C(m*A)-C(D*I));z[k+4>>2]=M;z[c+8>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+4>>2]=m;z[g+8>>2]=m;m=z[h-24>>2];A=z[i-20>>2];D=z[i-24>>2];I=z[h-20>>2];M=C(C(m*A)-C(D*I));z[k+8>>2]=M;z[c+4>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+8>>2]=m;z[g+4>>2]=m;m=z[n>>2];A=z[i-28>>2];i=i-32|0;D=z[i>>2];I=z[h-28>>2];M=C(C(m*A)-C(D*I));z[k+12>>2]=M;z[c>>2]=-M;m=C(C(D*C(-m))-C(A*I));z[G+12>>2]=m;z[g>>2]=m;g=g-16|0;c=c-16|0;G=G+16|0;k=k+16|0;h=n;continue}break}if(!v[a+80>>2]){Jb(j)}v[a+92>>2]=X;break B}o=o+1|0;continue}}c=c+1|0;continue}break}l=l+1|0;i=v[a+4>>2];continue}break}}else{h=c<<2;g=h+a|0;i=v[g+800>>2];F:{if(v[h+(O+320|0)>>2]){Xb(i,0,P);break F}F=v[g+996>>2];G:{h=w[(R+w[(v[R+4>>2]+B(c,3)|0)+2|0]|0)+9|0];if(!x[((h<<1)+a|0)+132>>1]){bc(a,21);break G}n=V>>1;p=v[a+260>>2]+B(h,1596)|0;H=p+338|0;W=p+838|0;k=B(w[p+1588|0],u[F>>1]);o=1;h=0;while(1){if(v[p+1592>>2]>(o|0)){g=w[o+W|0]<<1;j=u[g+F>>1];if((j|0)>=0){j=B(w[p+1588|0],j&65535);g=x[g+H>>1];if((g|0)!=(h|0)){q=j-k|0;r=g-h|0;G=(q|0)/(r|0)|0;H:{T=(g|0)<(n|0)?g:n;if((T|0)<=(h|0)){break H}s=q;q=q>>31;S=G>>31;S=((s^q)-q|0)-B(r,(S^G)-S|0)|0;K=q|1;q=i+(h<<2)|0;z[q>>2]=z[((k&255)<<2)+71552>>2]*z[q>>2];T=T-1|0;q=0;while(1){if((h|0)==(T|0)){break H}h=h+1|0;X=i+(h<<2)|0;q=q+S|0;ea=(q|0)<(r|0);k=(k+G|0)+(ea?0:K)|0;z[X>>2]=z[((k&255)<<2)+71552>>2]*z[X>>2];q=q-(ea?0:r)|0;continue}}h=g}k=j}o=o+1|0;continue}break}if((h|0)>=(n|0)){break G}g=(k<<2)+71552|0;while(1){if((h|0)==(n|0)){break G}k=i+(h<<2)|0;z[k>>2]=z[g>>2]*z[k>>2];h=h+1|0;continue}}}c=c+1|0;continue}break}VH(a);I:{if(w[a+1377|0]){v[a+1060>>2]=sa;t[a+1377|0]=0;v[a+1064>>2]=1;v[a+1412>>2]=V-ka;break I}c=v[a+1412>>2];if(!c){break I}h=la-E|0;if((h|0)<=(c|0)){v[a+1412>>2]=c-h;v[U+4>>2]=la;E=la;break I}E=c+E|0;v[U+4>>2]=E;v[a+1412>>2]=0}c=v[a+1064>>2];J:{K:{L:{M:{if(v[a+1388>>2]==v[a+1404>>2]){N:{if(!c|!(w[a+1375|0]&4)){break N}c=v[a+1408>>2];h=v[a+1060>>2];if(c>>>0>=h+(ka-E|0)>>>0){break N}h=c-h|0;c=(c>>>0<h>>>0?0:h)+E|0;c=(c|0)<(ka|0)?c:ka;v[qa>>2]=c;v[a+1060>>2]=c+v[a+1060>>2];break K}v[a+1064>>2]=1;c=v[a+1408>>2]+(E-ha|0)|0;break M}if(!c){break L}c=v[a+1060>>2]}v[a+1060>>2]=c+(la-E|0)}if(v[a+84>>2]!=v[a+92>>2]?v[a+80>>2]:0){break J}v[qa>>2]=ka}c=1;break o}aa(6286,13048,3451,5595);L()}h=h-1|0;c=v[R+4>>2]+B(h,3)|0;j=v[g+(w[c+1|0]<<2)>>2];i=v[g+(w[c|0]<<2)>>2];c=0;while(1){if((c|0)==(k|0)){continue z}n=c<<2;l=n+j|0;D=z[l>>2];n=i+n|0;m=z[n>>2];O:{if(m>C(0)){if(D>C(0)){A=C(m-D);break O}A=m;m=C(m+D);break O}if(D>C(0)){A=C(m+D);break O}A=m;m=C(m-D)}z[n>>2]=m;z[l>>2]=A;c=c+1|0;continue}}}aa(6286,13048,3335,5595);L()}W=O+256|0;n=0;q=jb-16|0;jb=q;G=v[a+4>>2];F=v[a+396>>2];o=w[(i+X|0)+24|0];p=F+B(o,24)|0;h=v[p+4>>2];ea=x[((o<<1)+a|0)+268>>1];c=ha<<((ea|0)==2);g=c>>>0>h>>>0?h:c;h=v[p>>2];P=(g-(c>>>0>h>>>0?h:c)>>>0)/y[p+8>>2]|0;k=P<<2;c=B(G,k+4|0);K=v[v[a+124>>2]+B(w[p+13|0],2096)>>2];ga=v[a+92>>2];P:{if(v[a+80>>2]){h=vn(a,c);G=v[a+4>>2];break P}h=Jd(c)}j=(l|0)>0?l:0;H=ha<<2;g=0;c=(G|0)>0?G:0;r=(G<<2)+h|0;while(1){if((c|0)!=(g|0)){v[(g<<2)+h>>2]=r;g=g+1|0;r=k+r|0;continue}break}k=h;c=0;while(1){if((c|0)!=(j|0)){if(!w[c+O|0]){Xb(v[W+(c<<2)>>2],0,H)}c=c+1|0;continue}break}Q:{if(!((l|0)==1|(ea|0)!=2)){c=0;while(1){R:{if((c|0)!=(j|0)){if(w[c+O|0]){break R}}else{c=j}if((c|0)==(l|0)){break Q}r=F+B(o,24)|0;G=(l|0)!=2;F=(l|0)<3;while(1){if((n|0)==8){break Q}S:{if(!G){h=0;o=0;while(1){if((o|0)>=(P|0)){break S}c=v[p>>2]+B(v[p+8>>2],o)|0;v[q+12>>2]=c&1;v[q+8>>2]=c>>1;c=0;if(!n){j=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){Gk(a)}g=v[a+1392>>2];H=u[(j+((g&1023)<<1)|0)+36>>1];T:{if((H|0)>=0){s=g;H=H&65535;g=w[H+v[j+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?H:-1;break T}g=Jl(a,j)}g=w[j+23|0]?v[v[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k>>2]+(h<<2)>>2]=v[v[r+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(o|0)>=(P|0))){g=v[p+8>>2];j=u[(v[r+20>>2]+(w[v[v[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(n<<1)>>1];U:{if((j|0)>=0){if(UH(a,v[a+124>>2]+B(j&65535,2096)|0,W,2,q+12|0,q+8|0,ha,g)){break U}break Q}g=v[p>>2]+(g+B(g,o)|0)|0;v[q+8>>2]=g>>1;v[q+12>>2]=g&1}o=o+1|0;c=c+1|0;continue}break}h=h+1|0;continue}}if(F){break S}h=0;o=0;while(1){if((o|0)>=(P|0)){break S}g=v[p>>2]+B(v[p+8>>2],o)|0;c=(g|0)/(l|0)|0;v[q+12>>2]=g-B(c,l);v[q+8>>2]=c;c=0;if(!n){j=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){Gk(a)}g=v[a+1392>>2];H=u[(j+((g&1023)<<1)|0)+36>>1];V:{if((H|0)>=0){s=g;H=H&65535;g=w[H+v[j+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?H:-1;break V}g=Jl(a,j)}g=w[j+23|0]?v[v[j+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k>>2]+(h<<2)>>2]=v[v[r+16>>2]+(g<<2)>>2]}while(1){if(!((c|0)>=(K|0)|(o|0)>=(P|0))){g=v[p+8>>2];j=u[(v[r+20>>2]+(w[v[v[k>>2]+(h<<2)>>2]+c|0]<<4)|0)+(n<<1)>>1];W:{if((j|0)>=0){if(!UH(a,v[a+124>>2]+B(j&65535,2096)|0,W,l,q+12|0,q+8|0,ha,g)){break Q}break W}g=v[p>>2]+(g+B(g,o)|0)|0;j=(g|0)/(l|0)|0;v[q+8>>2]=j;v[q+12>>2]=g-B(j,l)}o=o+1|0;c=c+1|0;continue}break}h=h+1|0;continue}}n=n+1|0;continue}}c=c+1|0;continue}}ma=F+B(o,24)|0;l=0;while(1){if((l|0)==8){break Q}n=0;T=0;X:while(1){if((n|0)<(P|0)){h=0;c=0;Y:{if(l){break Y}while(1){if((c|0)==(j|0)){break Y}if(!w[c+O|0]){r=v[a+124>>2]+B(w[p+13|0],2096)|0;if(v[a+1396>>2]<=9){Gk(a)}g=v[a+1392>>2];o=u[(r+((g&1023)<<1)|0)+36>>1];Z:{if((o|0)>=0){s=g;o=o&65535;g=w[o+v[r+8>>2]|0];v[a+1392>>2]=s>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;g=(g|0)>=0?o:-1;break Z}g=Jl(a,r)}g=w[r+23|0]?v[v[r+2088>>2]+(g<<2)>>2]:g;if((g|0)==-1){break Q}v[v[k+(c<<2)>>2]+(T<<2)>>2]=v[v[ma+16>>2]+(g<<2)>>2]}c=c+1|0;continue}}while(1){_:{$:{if((h|0)>=(K|0)){break $}c=0;if((n|0)>=(P|0)){break $}while(1){if((c|0)==(j|0)){break _}aa:{if(w[c+O|0]){break aa}g=c<<2;r=u[(v[ma+20>>2]+(w[v[v[g+k>>2]+(T<<2)>>2]+h|0]<<4)|0)+(l<<1)>>1];if((r|0)<0){break aa}G=v[a+124>>2]+B(r&65535,2096)|0;Y=v[g+W>>2];S=v[p+8>>2];H=v[p>>2]+B(S,n)|0;ba:{ca:{if(ea){F=0;while(1){g=1;if((F|0)>=(S|0)){break ba}$=Y+(H<<2)|0;g=S-F|0;o=0;m=C(0);da:{s=RH(a,G);if((s|0)<0){break da}r=v[G>>2];g=(g|0)>(r|0)?r:g;s=B(r,s);if(w[G+22|0]){r=0;g=(g|0)>0?g:0;o=1;while(1){if((g|0)==(r|0)){break da}ja=$+(r<<2)|0;m=C(m+z[v[G+28>>2]+(r+s<<2)>>2]);z[ja>>2]=z[ja>>2]+m;r=r+1|0;m=C(m+z[G+12>>2]);continue}}r=0;g=(g|0)>0?g:0;o=1;while(1){if((g|0)==(r|0)){break da}ja=$+(r<<2)|0;z[ja>>2]=z[ja>>2]+C(z[v[G+28>>2]+(r+s<<2)>>2]+C(0));r=r+1|0;continue}}if(!o){break ca}g=v[G>>2];H=g+H|0;F=g+F|0;continue}}F=0;r=(S|0)/v[G>>2]|0;s=(r|0)>0?r:0;ja=Y+(H<<2)|0;g=1;while(1){if((F|0)==(s|0)){break ba}o=F+H|0;Y=F<<2;F=F+1|0;ia=Y+ja|0;Y=S-o|0;$=0;m=C(0);ea:{na=RH(a,G);if((na|0)<0){break ea}o=0;$=v[G>>2];Y=(Y|0)>($|0)?$:Y;Y=(Y|0)>0?Y:0;na=B($,na);$=1;while(1){if((o|0)==(Y|0)){break ea}ra=(B(o,r)<<2)+ia|0;A=C(m+z[v[G+28>>2]+(o+na<<2)>>2]);z[ra>>2]=z[ra>>2]+A;m=w[G+22|0]?A:m;o=o+1|0;continue}}if($){continue}break}}g=0}if(!g){break Q}}c=c+1|0;continue}}T=T+1|0;continue X}n=n+1|0;h=h+1|0;continue}}break}l=l+1|0;continue}}if(!v[a+80>>2]){Jb(k)}v[a+92>>2]=ga;jb=q+16|0;i=i+1|0;continue}}aa(6286,13048,3302,5595);L()}jb=O+2368|0}else{c=0}jb=da+16|0;if(!c){fa:{ga:{ha:{c=v[a+100>>2];switch(c-32|0){case 0:break ga;case 3:break ha;default:break fa}}v[a+100>>2]=0;while(1){if(ta=0,ua=(mh(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;c=v[a+32>>2]-b|0;break a}if(v[a+992>>2]){break fa}v[a+100>>2]=0;while(1){if(ta=0,ua=(mh(a)|0)!=-1,va=v[a+96>>2],va?ta:ua){continue}break}v[f>>2]=0;c=v[a+32>>2]-b|0;break a}v[a+1420>>2]=0;v[a+992>>2]=0;v[a+1504>>2]=0;v[a+1508>>2]=0;v[a+1412>>2]=0;v[a+1416>>2]=0;t[a+1377|0]=0;v[a+1064>>2]=0;v[a+100>>2]=c;v[f>>2]=0;c=1;break a}g=v[U+12>>2];j=v[U+4>>2];h=v[U+8>>2];ia:{ja:{k=v[a+992>>2];if(k){i=k<<1;ka:{if((i|0)==v[a+112>>2]){c=a+1092|0}else{c=0;if((i|0)!=v[a+116>>2]){break ka}c=a+1096|0}c=v[c>>2]}if(!c){break ja}n=(k|0)>0?k:0;while(1){if(v[a+4>>2]>(Q|0)){i=(Q<<2)+a|0;E=0;while(1){if((n|0)!=(E|0)){l=v[i+800>>2]+(j+E<<2)|0;s=l;A=z[l>>2];l=E<<2;z[s>>2]=C(A*z[l+c>>2])+C(z[l+v[i+928>>2]>>2]*z[c+(k+(E^-1)<<2)>>2]);E=E+1|0;continue}break}Q=Q+1|0;continue}break}Q=v[a+992>>2]}v[a+992>>2]=g-h;k=(g|0)<(h|0);i=(k?h:g)-h|0;while(1){if(v[a+4>>2]>(pa|0)){c=(pa<<2)+a|0;E=0;while(1){if((i|0)!=(E|0)){z[v[c+928>>2]+(E<<2)>>2]=z[v[c+800>>2]+(h+E<<2)>>2];E=E+1|0;continue}break}pa=pa+1|0;continue}break}if(!Q){break ja}c=(k?g:h)-j|0;v[a+1416>>2]=c+v[a+1416>>2];break ia}c=0}h=c;v[U+12>>2]=c;c=0;g=v[a+4>>2];k=(g|0)>0?g:0;while(1){if((c|0)!=(k|0)){i=(c<<2)+a|0;v[i+864>>2]=v[i+800>>2]+(j<<2);c=c+1|0;continue}break}if(d){v[d>>2]=g}v[f>>2]=h;v[e>>2]=a+864;c=v[a+32>>2]-b|0}jb=U+16|0;return c}function ifa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=jb-1760|0;jb=d;Ac(b);f=jb-16|0;jb=f;h=d+1632|0;uR(f+8|0,h);g=v[f+12>>2];l=b;nc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);b=v[f+4>>2];if((b|0)==(g|0)){ac(l,v[f+12>>2])}jb=f+16|0;b=(b|0)==(g|0);if(!b){tR(h)}a:{if(!b){break a}if(!vR(d+1632|0)){break a}if(!Ob(v[l>>2],v[l+8>>2],Vc(256,0))){break a}b:{if(!c){break b}Ed(a,1048576);Dg(a);b=jb-16|0;jb=b;e=Vb(b,4191);Sc(d+1376|0,e);zb(e);jb=b+16|0;b=x[d+1640>>1];v[d+160>>2]=b>>>8;v[23296]=0;v[d+16>>2]=b&255;R(380,d+88|0,d+16|0);b=v[23296];v[23296]=0;c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((b|0)!=1){v[23296]=0;X(366,d+272|0,d+1376|0,d+160|0,d+88|0);b=v[23296];v[23296]=0;if((b|0)==1){break m}b=d+272|0;Hb(a+1298344|0,b);zb(b);e=d+88|0;zb(e);f=d+1376|0;ec(f);g=Vb(b,14959);Hb(a+1298356|0,g);zb(g);Ze(e,2,d+1642|0);Gc(f,e);v[23296]=0;U(11,b|0,8,f|0);b=v[23296];v[23296]=0;if((b|0)==1){break i}b=d+272|0;Hb(a+1298368|0,b);zb(b);e=d+1376|0;yb(e);v[a+1298404>>2]=8;Zz(e,2,d+1674|0);Gc(b,e);Bc(a+1298308|0,b);yb(b);u[a+480188>>1]=x[d+1744>>1];f=w[d+1748|0];v[a+480204>>2]=125e4;v[a+480208>>2]=32792;G=a,H=Xd(f,1,31),v[G+480196>>2]=H;u[a+480192>>1]=x[d+1754>>1];u[a+480190>>1]=x[d+1756>>1];f=Xd(w[d+1749|0],1,32);v[a+480216>>2]=f;v[a+480228>>2]=96;v[a+480232>>2]=48;v[a+480220>>2]=f<<2;Su(l,e);f=a+484360|0;g=a+484376|0;Kq(Zb(v[f>>2],w[g|0]),e,x[d+1738>>1],65535,65535);_e(Zb(v[f>>2],w[g|0]),x[d+1740>>1]);q=Fg(l);Yd(b,l,q?274:0);A=jc(d+1352|0,b);Ab(b);v[23296]=0;b=T(145,l|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break k}v[23296]=0;U(178,d+272|0,l|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break k}b=d+272|0;s=jc(d+1328|0,b);Ab(b);b=a+480188|0;p=x[b>>1];if(q){u[b>>1]=p+8}z=c&1;if(!z){break j}v[23296]=0;R(213,a+484344|0,x[d+1742>>1]);b=v[23296];v[23296]=0;if((b|0)!=1){break j}g=P()|0;O()|0;break e}g=P()|0;O()|0;break l}g=P()|0;O()|0;zb(d+88|0)}ec(d+1376|0);break c}g=P()|0;O()|0;break d}o=a+484344|0;C=a+480188|0;g=0;while(1){n:{o:{p:{q:{r:{s:{if(x[d+1742>>1]<=r>>>0){b=x[d+1746>>1];if((b-2&65535)>>>0>=4998){break q}if(!(g&1)){break s}h=0;b=Ic(((b>>>1|0)+11025e5>>>0)/(b>>>0)|0,0);break r}v[23296]=0;b=T(182,l|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break f}v[d+160>>2]=b;v[23296]=0;b=T(145,l|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break g}v[23296]=0;U(178,d+88|0,l|0,b+1&-2);b=v[23296];v[23296]=0;if((b|0)==1){break g}b=d+88|0;j=jc(d+272|0,b);Ab(b);yc(d+160|0,1024);if(!z){break o}n=v[d+160>>2];if(!n){break o}v[23296]=0;b=W(214,o|0,r&65535,n|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){if(!b){break o}k=0;e=0;if(t[d+1750|0]&1){break p}t:while(1){if((k|0)==(n|0)){break o}e=0;b=$b(v[o>>2],r);b=Qf(v[b>>2],v[v[b+48>>2]+12>>2],k);while(1){if((e|0)==(p|0)){k=k+1|0;continue t}v[23296]=0;R(552,j|0,d+88|0);f=v[23296];v[23296]=0;if((f|0)!=1){g=sR(b+B(e,6)|0,d+88|0)|g;e=e+1|0;continue}break}break}break h}break h}h=2;b=Ie(2646e3/+(B(b,B(v[a+480216>>2],v[a+480196>>2]))>>>0)*1e4)}t[a+480224|0]=h;v[a+480204>>2]=b}h=a+480188|0;b=x[h>>1];v[23296]=0;t[d+272|0]=0;r=W(553,d+1312|0,b|0,d+272|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){j=a+1298320|0;n=a+1298332|0;m=a+484348|0;k=0;u:{v:{w:{x:{y:{z:{while(1){b=v[s+8>>2];e=v[s>>2];v[23296]=0;b=W(144,e|0,b|0,8)|0;e=v[23296];v[23296]=0;A:{if((e|0)!=1){if(b){break A}f=v[r>>2];h=0;g=a+480188|0;while(1){e=x[g>>1];if(e>>>0<=h>>>0){v[d+264>>2]=0;v[d+268>>2]=0;v[d+256>>2]=0;v[d+260>>2]=0;v[d+248>>2]=0;v[d+252>>2]=0;v[d+240>>2]=0;v[d+244>>2]=0;B:{C:{if(!q){break C}e=0;v[23296]=0;R(554,A|0,d+272|0);b=v[23296];v[23296]=0;if((b|0)==1){break B}while(1){if((e|0)==8){e=0;v[23296]=0;j=Q(206,d+224|0,x[d+272>>1])|0;b=v[23296];v[23296]=0;if((b|0)!=1){D:{E:{F:{G:{while(1){if(x[d+272>>1]<=e>>>0){v[23296]=0;n=W(555,d+208|0,x[d+1742>>1],26764)|0;b=v[23296];v[23296]=0;if((b|0)==1){break E}i=a+484376|0;z=a+484348|0;C=a+480188|0;f=0;break F}v[23296]=0;b=T(182,l|0)|0;f=v[23296];v[23296]=0;if((f|0)!=1){v[23296]=0;U(178,d+160|0,l|0,b<<5);b=v[23296];v[23296]=0;if((b|0)==1){break G}f=d+160|0;b=jc(d+88|0,f);cd(Cg(v[j>>2],e),b);Ab(b);e=e+1|0;Ab(f);continue}break}g=P()|0;O()|0;break D}g=P()|0;O()|0;break D}while(1){if(x[d+1738>>1]<=f>>>0){ud(n);ld(j);break C}H:{g=d+f|0;e=w[g+290|0];if(e>>>0>=x[d+272>>1]){break H}b=x[dc(v[Zb(v[a+484360>>2],w[i|0])>>2],f)>>1];if(b>>>0>=x[d+1742>>1]){break H}I:{h=dc(v[n>>2],b);m=x[h>>1];J:{if((m|0)==65535){u[h>>1]=e;break J}if((e|0)==(m|0)){break J}v[23296]=0;e=Q(556,o|0,b|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break I}if((e|0)==65535){break J}G=dc(v[Zb(v[a+484360>>2],w[i|0])>>2],f),H=e,u[G>>1]=H;b=e}if(!oe(v[a+484344>>2],v[z>>2],b)){break H}q=Cg(v[j>>2],w[g+290|0]);Ac(q);e=v[q>>2];v[23296]=0;e=T(148,e|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break I}D=e>>>5|0;h=0;K:while(1){e=$b(v[o>>2],b);if(y[e+12>>2]<=h>>>0){break H}g=0;e=fd(v[e>>2],v[v[e+48>>2]+12>>2],h,x[C>>1]-8&65535);while(1){if((g|0)==8){h=h+1|0;continue K}wh(d+88|0);m=x[d+92>>1];t[e+4|0]=m;t[e+5|0]=m>>>8;m=v[d+88>>2];t[e|0]=m;t[e+1|0]=m>>>8;t[e+2|0]=m>>>16;t[e+3|0]=m>>>24;L:{if(h>>>0>=D>>>0){break L}v[23296]=0;Q(557,q|0,d+88|0)|0;m=v[23296];v[23296]=0;if((m|0)==1){break I}if(t[d+88|0]>=0){break L}t[e|0]=61;t[e+1|0]=w[(d+256|0)+(g<<1)|0];m=w[d+88|0]&31;t[d+160|0]=m;if(m){nf(d+160|0,15);t[e+3|0]=20;t[e+5|0]=w[d+160|0]|208}t[e+2|0]=1;t[e+4|0]=w[d+89|0]+3>>>2}e=e+6|0;g=g+1|0;continue}}}g=P()|0;O()|0;ud(n);break D}f=f+1|0;continue}}g=P()|0;O()|0}ld(j);break u}g=P()|0;O()|0;break u}f=e<<1;g=f+(d+256|0)|0;b=x[a+480192>>1]+1&65535;h=x[v[a+8>>2]+58>>1];while(1){M:{N:{j=b&65535;if(j>>>0<=h>>>0){if(v[((j<<2)+a|0)+900380>>2]){break N}}else{b=65535}b=b&65535;break M}b=b+1|0;continue}break}u[g>>1]=b;h=f+(d+240|0)|0;f=x[(d+f|0)+274>>1];u[h>>1]=f;O:{if((b|0)!=65535){v[23296]=0;b=W(239,a|0,b|0,f+1&65535)|0;f=v[23296];v[23296]=0;P:{Q:{if((f|0)!=1){if(!b){break O}v[23296]=0;R(273,d+160|0,4436);f=v[23296];v[23296]=0;if((f|0)==1){break Q}v[23296]=0;v[d+16>>2]=e+1;U(558,d+88|0,d+160|0,d+16|0);f=v[23296];v[23296]=0;if((f|0)==1){break P}f=b+492|0;b=d+88|0;Ec(f,b);yb(b);Tb(d+160|0);break O}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}g=P()|0;O()|0;Tb(d+160|0);break u}u[g>>1]=0}e=e+1|0;continue}}R:{S:{b=x[d+1750>>1]|x[d+1752>>1]<<16;if(!(b&2)){break S}b=(((b&8?x[a+480188>>1]:p)&65535)+(x[d+1640>>1]>591?k:0)|0)+(b>>>4&1)|0;f=0;T:while(1){e=0;if(x[d+1742>>1]<=f>>>0){break S}while(1){U:{if((b|0)!=(e|0)){g=v[l+8>>2];h=v[l>>2];v[23296]=0;g=W(144,h|0,g|0,4)|0;h=v[23296];v[23296]=0;if((h|0)==1){break R}if(g){break U}}f=f+1|0;continue T}v[23296]=0;R(559,x[d+1640>>1],l|0);g=v[23296];v[23296]=0;if((g|0)==1){break R}e=e+1|0;continue}}}v[23296]=0;j=Q(206,d+192|0,255)|0;b=v[23296];v[23296]=0;if((b|0)!=1){m=a+480208|0;f=0;while(1){V:{b=f;W:{if((b|0)==255){o=Yz(d+88|0);n=Yz(d+160|0);g=0;while(1){X:{Y:{Z:{if((g|0)==256){k=0;break Z}v[23296]=0;R(560,l|0,d+272|0);b=v[23296];v[23296]=0;if((b|0)==1){break Y}v[23296]=0;b=T(145,l|0)|0;e=v[23296];v[23296]=0;_:{$:{aa:{if((e|0)!=1){v[23296]=0;U(178,d+16|0,l|0,b|0);e=v[23296];v[23296]=0;if((e|0)==1){break aa}e=d+16|0;k=jc(d- -64|0,e);Ab(e);if(x[d+1756>>1]>g>>>0){e=d+48|0;Ze(e,2,d+272|0);v[23296]=0;R(210,d+16|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break _}e=d+16|0;Ec(((g<<5)+a|0)+946336|0,e);yb(e)}if(!b){break X}if(x[d+1756>>1]>g>>>0){break $}break X}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}v[23296]=0;b=B(g+1|0,104)+a|0;e=b+484380|0;R(264,e|0,32);f=v[23296];v[23296]=0;ba:{ca:{da:{if((f|0)!=1){Bo(e);v[23296]=0;R(561,k|0,d+16|0);f=v[23296];v[23296]=0;if((f|0)==1){break _}f=v[d+16>>2];v[e>>2]=f;v[b+484404>>2]=v[d+20>>2];if(w[d+24|0]>=2){h=b+484414|0;u[h>>1]=x[h>>1]|1;f=f>>>1|0;v[e>>2]=f}if(w[d+25|0]>=2){h=b+484414|0;u[h>>1]=x[h>>1]|64;v[e>>2]=f>>>1}h=2;switch(w[d+27|0]-1|0){case 0:break ca;case 1:break da;default:break ba}}break _}h=6}e=b+484414|0;u[e>>1]=x[e>>1]|h}v[b+484384>>2]=v[d+28>>2];v[b+484388>>2]=v[d+32>>2];u[b+484410>>1]=x[d+36>>1]>>>7;e=w[d+38|0];ea:{if((e|0)==128){e=b+484414|0;f=x[e>>1]|256;u[e>>1]=f;break ea}u[b+484408>>1]=(e<<24>>24)+128;f=x[b+484414>>1]}h=b+484414|0;u[h>>1]=f|32;t[b+484416|0]=w[d+39|0];e=w[d+26|0];if(e&2){b=d+48|0;Bb(b,n,g);nm(b);e=w[d+26|0]}if(e&5){u[h>>1]=x[h>>1]|16384}if(!(e&8)){break X}b=d+48|0;Bb(b,o,g);nm(b);e=0;while(1){if((e|0)==8){break X}b=e<<1;fa:{if(x[b+(d+240|0)>>1]!=(g|0)){break fa}b=v[((x[b+(d+256|0)>>1]<<2)+a|0)+900380>>2];if(!b){break fa}t[b+14|0]=0}e=e+1|0;continue}}g=P()|0;O()|0;Ab(k);break W}while(1){ga:{ha:{if(x[d+1754>>1]<=k>>>0){if(!(c&2)){break ha}e=a+1298404|0;f=a+1298464|0;g=0;ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{while(1){if(x[a+480190>>1]<=g>>>0){break ha}g=g+1|0;c=B(g,104)+a|0;h=c+484380|0;b=c+484416|0;iq(h,(+(t[b|0]-49|0)+ +t[c+484417|0]*-.0078125)/-12);u[b>>1]=0;b=x[c+484414>>1];if(!(b&16384)){b=_c(d+272|0,b&1?16:8,b&64?3:1,0,11);v[23296]=0;W(207,b|0,h|0,l|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){continue}g=P()|0;O()|0;break W}v[23296]=0;h=T(145,l|0)|0;b=v[23296];v[23296]=0;qa:{if((b|0)==1){break qa}v[23296]=0;Q(176,l|0,12)|0;b=v[23296];v[23296]=0;if((b|0)==1){break qa}b=Kb(d+272|0);v[23296]=0;U(255,l|0,b|0,h|0);h=v[23296];v[23296]=0;if((h|0)==1){break pa}ze(c+484423|0,b);v[23296]=0;R(365,d- -64|0,16236);c=v[23296];v[23296]=0;if((c|0)==1){break oa}v[d+12>>2]=g;c=v[e>>2];v[23296]=0;U(11,d+48|0,c|0,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break na}v[23296]=0;X(366,d+16|0,d- -64|0,d+12|0,d+48|0);c=v[23296];v[23296]=0;if((c|0)==1){break ma}c=v[f>>2];v[23296]=0;U(353,c|0,2,d+16|0);c=v[23296];v[23296]=0;if((c|0)==1){break la}zb(d+16|0);zb(d+48|0);ec(d- -64|0);yb(b);continue}break}g=P()|0;O()|0;break W}g=P()|0;O()|0;break ia}g=P()|0;O()|0;break ia}g=P()|0;O()|0;break ja}g=P()|0;O()|0;break ka}g=P()|0;O()|0;zb(d+16|0)}zb(d+48|0)}ec(d- -64|0)}yb(b);break W}b=v[Cg(v[j>>2],k)>>2];v[23296]=0;b=T(148,b|0)|0;e=v[23296];v[23296]=0;ra:{sa:{if((e|0)!=1){if(!b){k=k+1|0;continue}b=Cg(v[j>>2],k);Ac(b);v[23296]=0;R(562,b|0,d+272|0);b=v[23296];v[23296]=0;if((b|0)==1){break sa}h=Qb(d+16|0);v[23296]=0;U(563,l|0,h|0,x[d+272>>1]);b=v[23296];v[23296]=0;if((b|0)==1){break ra}k=k+1|0;b=v[((k<<2)+a|0)+900380>>2];if(!b|w[b+34|0]){break ga}v[b+4>>2]=32;e=0;St(b,0);m=b+108|0;i=b+236|0;while(1){if((e|0)==96){break ga}f=w[(d+e|0)+274|0];ta:{if(f>>>0>=x[d+272>>1]){break ta}g=Re(v[h>>2],f);q=e+12|0;z=dc(i,q);f=w[g|0];p=f+1|0;u[z>>1]=p;if(f>>>0>=x[a+480190>>1]){break ta}f=B(p,104)+a|0;t[f+484418|0]=w[d+370|0]&3;t[f+484419|0]=w[d+371|0];t[f+484420|0]=w[d+372|0];t[f+484421|0]=w[d+373|0];u[f+484412>>1]=w[g+1|0]<<1;t[f+484417|0]=w[g+2|0];f=p-1|0;Bb(d- -64|0,o,f);if(Cb(v[v[d+64>>2]>>2],v[d+68>>2])){t[b+14|0]=0}Bb(d- -64|0,n,f);if(!Cb(v[v[d+64>>2]>>2],v[d+68>>2])){break ta}G=Lb(m,q),H=61,t[G|0]=H}e=e+1|0;continue}}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}g=P()|0;O()|0;je(h);break W}ld(j);fc(r);Ab(s);Ab(A);break b}je(h);continue}}g=P()|0;O()|0;break W}Ab(k);g=g+1|0;continue}}v[23296]=0;R(560,l|0,d+160|0);e=v[23296];v[23296]=0;ua:{va:{wa:{xa:{if((e|0)!=1){v[23296]=0;e=T(145,l|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break xa}v[23296]=0;e=(e|0)==32?428:e;k=e?x[d+1640>>1]>513?e+4|0:e:e;U(178,d+88|0,l|0,k|0);e=v[23296];v[23296]=0;if((e|0)==1){break wa}g=d+88|0;e=jc(d+272|0,g);h=ie(d+16|0,cd(Cg(v[j>>2],b),e));Ab(e);f=b+1|0;Ab(g);if(b>>>0>=x[d+1754>>1]){break V}v[23296]=0;b=f&65535;g=W(239,a|0,b|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break va}break ua}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}g=P()|0;O()|0;break W}if(!g){break V}b=d+88|0;Ze(b,2,d+160|0);v[23296]=0;R(210,d+272|0,b|0);b=v[23296];v[23296]=0;ya:{if((b|0)!=1){b=d+272|0;Ec(g+492|0,b);yb(b);if(!k){break V}v[23296]=0;R(562,h|0,d+272|0);b=v[23296];v[23296]=0;if((b|0)!=1){k=3;o=0;if(x[d+1640>>1]<513){n=0;break ya}v[23296]=0;n=T(182,h|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break ua}if(x[d+1640>>1]<514){break ya}v[23296]=0;k=T(145,h|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break ya}break ua}break ua}break ua}v[g>>2]=x[d+374>>1];t[g+16|0]=w[(x[d+376>>1]&3)+26766|0];t[g+17|0]=w[(w[d+377|0]&3)+26766|0];t[g+18|0]=w[(x[d+376>>1]>>>12&3)+26770|0];while(1){za:{Aa:{if((o|0)==4){if(!(t[g+60|0]&1|w[g+16|0]==3)){v[g>>2]=32767}Dm(g,127,1);Cm(g,0,1);if(!n){break V}v[23296]=0;R(564,h|0,d+88|0);b=v[23296];v[23296]=0;if((b|0)==1){break ua}if(n&2){Dm(g,pR(v[m>>2],+x[d+90>>1]),1);Cm(g,w[d+92|0],1)}t[g+25|0]=w[d+89|0]==1;if(!(n&4)){break V}t[g+31|0]=w[d+95|0]+1;b=t[d+96|0];t[g+34|0]=b+1;if((b|0)<0){t[g+30|0]=w[d+103|0]+1}if(!w[d+100|0]){break Aa}k=g+108|0;e=0;while(1){if((e|0)==128){break Aa}b=e+1|0;v[d+64>>2]=b+t[d+100|0];oR(d- -64|0);G=Lb(k,e),H=v[d+64>>2],t[G|0]=H;e=b;continue}}if(!(k&1)){break za}v[23296]=0;R(565,h|0,d+88|0);b=v[23296];v[23296]=0;Ba:{if((b|0)!=1){b=Ei(g,w[o+26774|0]);Ca:{if((o|0)!=3){e=w[d+88|0];p=w[b+12|0]&-17;break Ca}e=w[d+88|0];p=e<<4&16|w[b+12|0]&-17}t[b+12|0]=e>>>1&2|(e<<1&4|(p&248|e&1));t[d+64|0]=w[d+89|0];t[d+48|0]=16;e=w[Wb(d- -64|0,d+48|0)|0];v[23296]=0;R(278,b|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break Ba}e=w[d+90|0];t[b+15|0]=e;t[b+16|0]=e;t[b+13|0]=w[d+91|0];t[b+14|0]=w[d+92|0];e=0;p=v[b>>2];i=re(p,v[b+4>>2]);while(1){if((e|0)==(i|0)){break za}q=Db(p,e);b=(d+88|0)+(e<<2)|0;u[q>>1]=w[b+8|0]|w[b+9|0]<<8;G=q,H=Xd(w[b+10|0]|w[b+11|0]<<8,0,64),t[G+2|0]=H;e=e+1|0;continue}}break ua}break ua}St(g,0);break V}o=o+1|0;k=k>>>1|0;continue}}g=P()|0;O()|0;Ab(h)}ld(j);break u}Ab(h);continue}}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}else{b=t[Lb(f,h)|0];Da:{if((b|0)<=(h|0)|(b|0)>=(e|0)){break Da}b=w[((b<<5)+a|0)+480288|0];if(!b){break Da}e=((h<<5)+a|0)+480288|0;j=w[e|0];if(!j){t[e|0]=b;break Da}e=j-1|0;while(1){j=B(e&255,160)+a|0;e=Gm(v[j+906328>>2]);if((e|0)!=255){continue}break}b=b-1&255;v[(j+906300|0)+28>>2]=b>>>0<250?b+128|0:0}h=h+1|0;continue}}}g=P()|0;O()|0;break u}v[23296]=0;f=T(145,s|0)|0;b=v[23296];v[23296]=0;Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{if((b|0)!=1){v[23296]=0;b=T(145,s|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break Ma}v[23296]=0;U(178,d+272|0,s|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break Ma}e=d+272|0;b=jc(d+88|0,e);Ab(e);if((f|0)==4674381){break Ia}if((f|0)==5068115){break Ha}if((f|0)==726487106){break La}if((f|0)==844387158){break Ga}e=0;if((f|0)==1280004692){break Ka}if((f|0)==1314144592){break Ja}if((f|0)!=1397445204){break Fa}v[23296]=0;e=T(182,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break w}e=e>>>0<256?48:e>>>8|0;v[a+480228>>2]=e;v[a+480232>>2]=e>>>1;e=0;while(1){if(x[h>>1]<=e>>>0){break Fa}v[23296]=0;f=Q(566,b|0,d+272|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break z}if(f){u[((e<<5)+a|0)+480286>>1]=x[d+272>>1]>>>10;G=Lb(v[r>>2],e),H=w[d+275|0],t[G|0]=H}e=e+1|0;continue}}g=P()|0;O()|0;break u}g=P()|0;O()|0;break u}if(g&1){break Fa}t[a+480224|0]=2;v[23296]=0;E=+na(567,b|0);e=v[23296];v[23296]=0;if((e|0)==1){break Ea}if(!(E>1e-8)){break Fa}G=a,H=Ie(2646e3/(E*+(B(v[a+480216>>2],v[a+480196>>2])>>>0))*1e4),v[G+480204>>2]=H;break Fa}while(1){Na:{if(x[h>>1]<=e>>>0){break Fa}f=v[b>>2];v[23296]=0;f=W(144,f|0,v[d+96>>2],1)|0;i=v[23296];v[23296]=0;if((i|0)==1){break y}if(!f){break Fa}f=Kb(d+272|0);v[23296]=0;U(336,b|0,f|0,-1);i=v[23296];v[23296]=0;if((i|0)!=1){i=d+16|0;Rf(i,3,Jc(f),Fb(f));v[23296]=0;R(210,d+160|0,i|0);i=v[23296];v[23296]=0;if((i|0)==1){break Na}i=d+160|0;wm(((e<<5)+a|0)+480289|0,i);yb(i);yb(f);e=e+1|0;continue}}break}g=P()|0;O()|0;yb(f);break v}while(1){if(x[d+1742>>1]<=e>>>0){break Fa}f=v[b>>2];v[23296]=0;f=W(144,f|0,v[d+96>>2],1)|0;i=v[23296];v[23296]=0;if((i|0)==1){break x}if(!f){break Fa}if(!xm(v[a+484344>>2],v[m>>2],e&65535)){break Fa}f=Kb(d+272|0);v[23296]=0;U(336,b|0,f|0,-1);i=v[23296];v[23296]=0;Oa:{if((i|0)==1){break Oa}i=v[o>>2];v[23296]=0;R(268,$b(i,e)|0,f|0);i=v[23296];v[23296]=0;if((i|0)==1){break Oa}yb(f);e=e+1|0;continue}break}g=P()|0;O()|0;yb(f);break v}v[23296]=0;Q(176,b|0,1)|0;e=v[23296];v[23296]=0;if((e|0)==1){break w}v[23296]=0;e=T(190,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break w}v[23296]=0;X(317,n|0,b|0,e|0,2);e=v[23296];v[23296]=0;if((e|0)!=1){break Fa}break w}v[23296]=0;Q(568,b|0,d+16|0)|0;e=v[23296];v[23296]=0;Pa:{if((e|0)!=1){e=Kb(d+272|0);v[23296]=0;U(336,b|0,e|0,-1);f=v[23296];v[23296]=0;if((f|0)==1){break Pa}if(gq(e,12472)){v[23296]=0;U(11,d+160|0,8,e|0);f=v[23296];v[23296]=0;if((f|0)==1){break Pa}f=d+160|0;Hb(j,f);zb(f)}yb(e);break Fa}g=P()|0;O()|0;break v}g=P()|0;O()|0;yb(e);break v}v[23296]=0;k=T(145,b|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break w}}Ab(b);continue}break}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0;break v}g=P()|0;O()|0}Ab(b)}fc(r);break e}g=P()|0;O()|0;break e}while(1){b=v[j>>2];v[23296]=0;b=W(144,b|0,v[d+280>>2],1)|0;f=v[23296];v[23296]=0;Qa:{if((f|0)!=1){if(!b){break o}v[23296]=0;h=T(194,j|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break h}m=0;if((h|0)!=255){break Qa}v[23296]=0;m=T(194,j|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){v[23296]=0;h=T(194,j|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break Qa}}break h}break h}if(h&127){b=$b(v[o>>2],r);f=fd(v[b>>2],v[v[b+48>>2]+12>>2],e,k&65535);Du(d+88|0);if(h&1){v[23296]=0;b=T(194,j|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break n}t[d+88|0]=b}if(h&2){v[23296]=0;b=T(194,j|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break n}t[d+89|0]=b}if(h&4){v[23296]=0;b=T(194,j|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break n}t[d+90|0]=b}if(h&8){v[23296]=0;b=T(194,j|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break n}t[d+91|0]=b}if(h&16){v[23296]=0;b=T(194,j|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break n}t[d+92|0]=b}if(h&32){v[23296]=0;b=T(194,j|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break n}t[d+93|0]=b}if(h&64){v[23296]=0;b=T(194,j|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break n}t[d+94|0]=b}D=sR(f,d+88|0);v[d+16>>2]=m;v[d+64>>2]=n+(e^-1);F=v[Ib(d+16|0,d- -64|0)>>2];h=0;b=f;while(1){if((h|0)!=(F|0)){b=B(x[C>>1],6)+b|0;i=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[b|0]=i;t[b+1|0]=i>>>8;t[b+2|0]=i>>>16;t[b+3|0]=i>>>24;i=w[f+4|0]|w[f+5|0]<<8;t[b+4|0]=i;t[b+5|0]=i>>>8;h=h+1|0;continue}break}g=g|D}e=(e+m|0)+1|0;while(1){if(e>>>0>=n>>>0){k=k+1|0;e=e-n|0;continue}break}if(p>>>0>(k&65535)>>>0){continue}break}}Ab(j);r=r+1|0;continue}break}break h}g=P()|0;O()|0;yb(d+1376|0);break c}g=P()|0;O()|0;Ab(j);break e}g=P()|0;O()|0;break e}g=P()|0;O()|0}Ab(s)}Ab(A)}S(g|0);L()}e=1}jb=d+1760|0;return e|0}function a9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,R=0,T=0,U=0,V=0,X=0,Y=0,Z=0,_=0,$=0,ba=0,ca=0;m=jb-1152|0;jb=m;Ac(b);a:{if(!ir(b,m+1128|0)){break a}if(!GL(m+1128|0)){break a}if(v[m+1136>>2]!=(Ig(v[b>>2])|0)){break a}if(v[m+1144>>2]!=(cf(b)|0)){break a}if(!c){e=1;break a}d=m+1072|0;Xb(d,0,56);o=-2;b:{if(!d){break b}v[d+44>>2]=0;v[d+48>>2]=0;v[d+52>>2]=0;v[d+20>>2]=0;v[d+24>>2]=0;v[d+8>>2]=0;o=v[d+32>>2];if(!o){v[d+32>>2]=1036;o=1036}if(!v[d+36>>2]){v[d+36>>2]=1037}h=nb[o|0](v[d+40>>2],1,43784)|0;o=-4;if(!h){break b}v[d+28>>2]=h;v[h+43780>>2]=1;v[h+10992>>2]=0;v[h+10996>>2]=0;v[h>>2]=0;v[h+11008>>2]=15;v[h+11e3>>2]=1;v[h+11004>>2]=0;o=0}if(o){break a}e=v[m+1144>>2];v[m+1068>>2]=e;H=v[m+1148>>2];R=hB(m+1056|0,H);c:{d:{while(1){if(!(!e|!H|(f|0)==1)){v[m+16>>2]=1024;f=m+16|0;T=v[Ib(f,m+1068|0)>>2];d=gc(m+24|0,m+32|0,T);e=v[d+4>>2];d=v[d>>2];v[23296]=0;_m(153,f,b,d,e);f=v[23296];v[23296]=0;if((f|0)==1){break d}d=m+32|0;f=d;e=T;h=_^-1;while(1){if(e>>>0<4){while(1){if(e){h=v[((w[f|0]^h&255)<<2)+61968>>2]^h>>>8;e=e-1|0;f=f+1|0;continue}break}_=h^-1}else{h=v[((w[f|0]^h&255)<<2)+61968>>2]^h>>>8;h=h>>>8^v[((w[f+1|0]^h&255)<<2)+61968>>2];h=h>>>8^v[((w[f+2|0]^h&255)<<2)+61968>>2];h=h>>>8^v[((w[f+3|0]^h&255)<<2)+61968>>2];e=e-4|0;f=f+4|0;continue}break}v[m+1076>>2]=T;v[m+1072>>2]=d;v[m+1088>>2]=H;v[m+1084>>2]=v[R>>2]+$;E=jb-16|0;jb=E;f=-2;p=m+1072|0;e:{if(!p){break e}i=v[p+28>>2];if(!i){break e}ca=v[p+4>>2];v[i+11e3>>2]=0;f:{if(v[i+43780>>2]<0){break f}if(v[i+11004>>2]){break e}e=v[i+11008>>2];f=0;v[i+11004>>2]=0;d=v[i+10996>>2];if(!d){X=(e|0)>0?11:10;I=i+11012|0;e=v[p+4>>2];k=v[i+10992>>2];while(1){v[E+12>>2]=e;v[E+8>>2]=32768-k;D=v[p>>2];d=0;e=0;o=0;G=0;J=0;U=0;Y=0;Z=jb-144|0;jb=Z;g:{h:{C=k+I|0;if(I>>>0<=C>>>0){f=v[E+8>>2];V=f+((I^-1)+C|0)|0;s=V+1|0;if(!(s&V)){break h}}v[E+8>>2]=0;v[E+12>>2]=0;n=-3;break g}K=f+C|0;q=v[E+12>>2];A=q+D|0;M=v[i+60>>2];z=v[i+40>>2];f=v[i+36>>2];r=v[i+32>>2];h=v[i+56>>2];g=v[i+4>>2];n=-1;j=D;l=C;i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{k=v[i>>2];switch(k|0){case 36:break k;case 39:break n;case 10:break o;case 35:break p;case 17:break q;case 21:break r;case 34:break s;case 42:break w;case 41:break x;case 53:break y;case 52:break z;case 51:break A;case 38:break B;case 27:break C;case 26:break D;case 25:break E;case 24:break F;case 23:break G;case 18:break H;case 16:break I;case 14:break J;case 11:break K;case 9:break L;case 7:break M;case 6:break N;case 3:break O;case 37:break P;case 32:break Q;case 5:break R;case 2:break S;case 1:break T;case 0:break U;default:break j}}v[i+28>>2]=1;h=0;v[i+8>>2]=0;v[i+12>>2]=0;v[i+16>>2]=1;z=0;f=0;r=0;g=0;if(X&1){break T}break v}if((q|0)<=0){v[i>>2]=1;break m}v[i+8>>2]=w[D|0];j=D+1|0}if(j>>>0>=A>>>0){v[i>>2]=2;n=1;break i}f=w[j|0];v[i+12>>2]=f;q=1;e=v[i+8>>2];if(!(((f|e<<8)>>>0)%31|f&32)){q=(e&15)!=8}j=j+1|0;k=36;f=256<<(e>>>4);if(f>>>0>32768|f>>>0>s>>>0){break l}f=0;if(q){break l}break v}if((q|0)<=0){v[i>>2]=5;break m}U=g+8|0;j=D+1|0;h=w[D|0]<<g|h;d=2;break v}if((q|0)<=0){v[i>>2]=32;break m}g=g+8|0;j=D+1|0;break u}k=37;break k}d=1;break v}d=4;break v}d=3;break v}d=7;break v}d=9;break v}d=10;break v}d=11;break v}d=12;break v}d=13;break v}d=14;break v}d=15;break v}d=16;break v}d=17;break v}d=8;break v}d=5;break v}d=6;break v}d=18;break v}k=2;break t}k=1;break t}V:while(1){W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{va:{wa:{xa:{ya:{za:{Aa:{Ba:{Ca:{switch(d|0){case 0:if(g>>>0>2){break Ba}d=1;continue;case 3:break za;case 2:break Aa;case 1:break Ca;case 9:break fa;case 10:break ga;case 11:break ha;case 12:break ia;case 13:break ja;case 14:break ka;case 15:break la;case 16:break ma;case 17:break na;case 8:break ta;case 7:break ua;case 6:break va;case 5:break wa;case 4:break ya;default:break oa}}while(1){if(j>>>0>=A>>>0){v[i>>2]=3;n=1;break i}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;if(g>>>0<3){continue}break}}d=h&7;v[i+20>>2]=d;k=d>>>1|0;v[i+24>>2]=k;g=g-3|0;h=h>>>3|0;if(d>>>0>=2){break sa}U=g;break pa}g=U&-8;h=h>>>(U&7)|0;f=0;d=0;break ra}if(j>>>0<A>>>0){break xa}v[i>>2]=7;n=1;break i}while(1){if(j>>>0>=A>>>0){v[i>>2]=6;n=1;break i}h=w[j|0]<<g|h;d=g>>>0>4294967287;j=j+1|0;g=g+8|0;if(d){continue}break}d=1;break ra}t[(f+i|0)+10528|0]=w[j|0];j=j+1|0;d=2;break ra}while(1){if(j>>>0>=A>>>0){v[i>>2]=51;n=1;break i}h=w[j|0]<<g|h;d=g>>>0>4294967287;j=j+1|0;g=g+8|0;if(d){continue}break}break Z}if(l>>>0<K>>>0){t[l|0]=r;f=f-1|0;l=l+1|0;break _}n=2;k=52;break k}if(l>>>0<K>>>0){break qa}n=2;k=9;break k}if(j>>>0<A>>>0){d=K-l|0;e=A-j|0;d=d>>>0<e>>>0?d:e;d=d>>>0<f>>>0?d:f;f=f-d|0;l=qc(l,j,d)+d|0;j=d+j|0;break Y}v[i>>2]=38;n=1;break i}e=0;Da:{switch(k-1|0){case 0:v[i+44>>2]=288;v[i+48>>2]=32;d=i+3552|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3560|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3568|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i+3576|0;v[d>>2]=84215045;v[d+4>>2]=84215045;d=i- -64|0;k=0;while(1){e=144;if((k|0)==144){while(1){k=256;if((e|0)==256){while(1){e=280;if((k|0)==280){while(1){if((e|0)==288){break ca}t[d|0]=8;e=e+1|0;d=d+1|0;continue}}else{t[d|0]=7;k=k+1|0;d=d+1|0;continue}}}else{t[d|0]=9;e=e+1|0;d=d+1|0;continue}}}else{t[d|0]=8;k=k+1|0;d=d+1|0;continue}};case 2:break o;default:break Da}}d=0;break ea}while(1){Ea:{Fa:{Ga:{Ha:{Ia:{switch(d|0){case 0:if(f>>>0>3){break Ha}if(!g){g=0;d=3;continue V}if(g>>>0>7){break Fa}d=4;continue V;case 1:t[(f+i|0)+10528|0]=h;g=g-8|0;h=h>>>8|0;break Ea;default:break Ia}}f=f+1|0;break Ga}f=x[i+10528>>1];if((f|0)==(x[i+10530>>1]^65535)){break _}break n}d=0;continue}d=1;continue}d=2;continue}}d=8;continue}d=2;continue}if(l>>>0>=K>>>0){n=2;k=53;break k}t[l|0]=w[(M-r&V)+I|0];l=l+1|0;M=M+1|0;d=7;break $}while(1){if(j>>>0>=A>>>0){v[i>>2]=27;n=1;break i}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;if(z>>>0>g>>>0){continue}break}d=6;break $}if(j>>>0>=A>>>0){v[i>>2]=26;n=1;break i}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;d=4;if(g>>>0<15){break $}d=5;break $}while(1){if(j>>>0>=A>>>0){v[i>>2]=25;n=1;break i}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;if(z>>>0>g>>>0){continue}break}d=3;break $}if(l>>>0>=K>>>0){n=2;k=24;break k}t[l|0]=f;l=l+1|0;break aa}if(j>>>0>=A>>>0){v[i>>2]=23;n=1;break i}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;d=0;if(g>>>0<15){break $}d=1;break $}while(1){if(j>>>0>=A>>>0){v[i>>2]=18;n=1;break i}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;if(z>>>0>g>>>0){continue}break}Y=r-16|0;d=3;break ba}if(j>>>0>=A>>>0){v[i>>2]=16;n=1;break i}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;d=1;if(g>>>0<15){break ba}d=2;break ba}while(1){if(j>>>0>=A>>>0){v[i>>2]=14;n=1;break i}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;if(g>>>0<3){continue}break}d=1;break da}d=f+21454|0;while(1){if(j>>>0>=A>>>0){v[i>>2]=11;n=1;break i}h=w[j|0]<<g|h;j=j+1|0;g=g+8|0;J=t[d|0];if(g>>>0<J>>>0){continue}break}e=f;d=1}while(1){Ja:{Ka:{La:{if(!d){if(e>>>0>2){break La}f=e;J=t[e+21454|0];if(J>>>0<=g>>>0){break Ja}d=9;continue V}f=e<<2;v[(f+i|0)+44>>2]=v[f+63504>>2]+((-1<<J^-1)&h);e=e+1|0;g=g-J|0;h=h>>>J|0;break Ka}f=0;Xb(i+7040|0,0,288);d=0;break da}d=0;continue}d=1;continue}}while(1){Ma:{Na:{Oa:{if(!d){if(y[i+52>>2]<=f>>>0){break Oa}if(g>>>0>2){break Ma}d=10;continue V}t[(w[f+63520|0]+i|0)+7040|0]=h&7;f=f+1|0;g=g-3|0;h=h>>>3|0;break Na}v[i+52>>2]=19;break ca}d=0;continue}d=1;continue}}G=v[i+24>>2];d=0}while(1){Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{switch(d|0){case 0:d=0;if((G|0)<0){break aa}N=Xb(Z,0,64);e=B(G,3488)+i|0;Xb(e+352|0,0,3200);ba=e- -64|0;F=v[i+24>>2];e=v[((F<<2)+i|0)+44>>2];while(1){if((d|0)!=(e|0)){k=(w[d+ba|0]<<2)+N|0;v[k>>2]=v[k>>2]+1;d=d+1|0;continue}break};v[N+64>>2]=0;v[N+68>>2]=0;s=0;d=1;k=0;while(1){if((d|0)!=16){q=d<<2;d=d+1|0;q=v[q+N>>2];k=q+k<<1;v[(N- -64|0)+(d<<2)>>2]=k;s=q+s|0;continue}break};Q=0;q=-1;if((k|0)!=65536&s>>>0>=2){break p}while(1){if(e>>>0>Q>>>0){s=w[Q+ba|0];Ya:{if(!s){break Ya}d=(N- -64|0)+(s<<2)|0;k=v[d>>2];v[d>>2]=k+1;d=0;e=s;while(1){if(e){d=k&1|d<<1;k=k>>>1|0;e=e-1|0;continue}break}if(s>>>0<=10){e=1<<s;k=s<<9|Q;s=B(G,3488)+i|0;while(1){if(d>>>0>1023){break Ya}u[(s+(d<<1)|0)+352>>1]=k;d=d+e|0;continue}}F=B(G,3488)+i|0;k=F+((d&1023)<<1)|0;e=u[k+352>>1];Za:{if(e){k=q;q=e;break Za}u[k+352>>1]=q;k=q-2|0}d=d>>>9|0;while(1){d=d>>>1|0;e=d&1;if(s>>>0>=12){e=(F+(e+(q^-1)<<1)|0)+2400|0;q=u[e>>1];if(!q){u[e>>1]=k;q=k;k=k-2|0}s=s-1|0;continue}break}u[((B(G,3488)+i|0)+(e+(q^-1)<<1)|0)+2400>>1]=Q;q=k}Q=Q+1|0;F=v[i+24>>2];e=v[((F<<2)+i|0)+44>>2];continue}break};d=0;if((F|0)!=2){break Qa}break Ua;case 1:d=u[(((h&1023)<<1)+i|0)+7328>>1];_a:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>g>>>0){break _a}break Ta}if(g>>>0<11){break _a}e=10;while(1){d=u[(((h>>>e&1)+(d^-1)<<1)+i|0)+9376>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(g>>>0>=k>>>0){continue}}break}if((d|0)>=0){break Ta}}d=11;continue V;case 2:r=u[(((h&1023)<<1)+i|0)+7328>>1];if((r|0)>=0){break Wa}d=10;while(1){e=h>>>d|0;d=d+1|0;r=u[(((e&1)+(r^-1)<<1)+i|0)+9376>>1];if((r|0)<0){continue}break};break Va;default:break Xa}}d=t[Y+17663|0]+((-1<<z^-1)&h)|0;g=g-z|0;h=h>>>z|0;e=f+i|0;Xb(e+10532|0,(r|0)==16?w[e+10531|0]:0,d);d=d+f|0;break Ua}d=r>>9;r=r&511}g=g-d|0;h=h>>>d|0;if(r>>>0>15){break Sa}t[(f+i|0)+10532|0]=r;d=f+1|0}e=v[i+48>>2];f=v[i+44>>2];k=e+f|0;if(k>>>0<=d>>>0){break Ra}if(g>>>0<=14){if((A-j|0)<=1){f=d;d=1;continue}h=w[j|0]<<g|h|w[j+1|0]<<g+8;j=j+2|0;g=g+16|0}f=d}d=2;continue}if(!((r|0)!=16|f)){f=0;r=16;break q}Y=r-16|0;z=t[r+21429|0];if(z>>>0<=g>>>0){break Pa}d=12;continue V}if((d|0)!=(k|0)){f=d;break r}k=i+10532|0;qc(i- -64|0,k,f);qc(i+3552|0,f+k|0,e);F=v[i+24>>2];f=d}G=F-1|0;v[i+24>>2]=G;d=0;continue}d=3;continue}}o=h;d=2}$a:while(1){ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{ib:{jb:{kb:{lb:{mb:{nb:{ob:{switch(d|0){case 0:d=u[(((h&1023)<<1)+i|0)+352>>1];pb:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>g>>>0){break pb}break ab}if(g>>>0<11){break pb}e=10;while(1){d=u[(((h>>>e&1)+(d^-1)<<1)+i|0)+2400>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(g>>>0>=k>>>0){continue}}break}if((d|0)>=0){break ab}}d=13;continue V;case 1:f=u[(((h&1023)<<1)+i|0)+352>>1];if((f|0)>=0){break nb}d=10;while(1){e=h>>>d|0;d=d+1|0;f=u[(((e&1)+(f^-1)<<1)+i|0)+2400>>1];if((f|0)<0){continue}break};break mb;case 3:break db;case 4:break eb;case 5:break ib;case 6:break jb;case 2:break ob;default:break kb}}while(1){d=A-j|0;if(!((K-l|0)>1&(d|0)>=4)){if(g>>>0>14){h=o;break ab}if((d|0)<=1){h=o;d=0;continue $a}h=w[j|0]<<g|o|w[j+1|0]<<g+8;g=g+16|0;j=j+2|0;break ab}if(g>>>0>14){k=j}else{o=(w[j|0]|w[j+1|0]<<8)<<g|o;g=g+16|0;k=j+2|0}f=u[(((o&1023)<<1)+i|0)+352>>1];qb:{if((f|0)<0){d=10;while(1){e=o>>>d|0;d=d+1|0;f=u[(((e&1)+(f^-1)<<1)+i|0)+2400>>1];if((f|0)<0){continue}break}break qb}d=f>>9}g=g-d|0;h=o>>>d|0;if(f&256){j=k;break lb}if(!(g>>>0>14)){h=(w[k|0]|w[k+1|0]<<8)<<g|h;k=k+2|0;g=g+16|0}s=g;j=k;e=u[(((h&1023)<<1)+i|0)+352>>1];rb:{if((e|0)<0){d=10;while(1){o=h>>>d|0;d=d+1|0;e=u[(((o&1)+(e^-1)<<1)+i|0)+2400>>1];if((e|0)<0){continue}break}break rb}d=e>>9}t[l|0]=f;g=s-d|0;o=h>>>d|0;if(!(e&256)){t[l+1|0]=e;l=l+2|0;continue}break}l=l+1|0;h=o;f=e;break lb}d=f>>9;f=f&511}g=g-d|0;h=h>>>d|0;if(f>>>0>255){break lb}d=14;continue V}e=f&511;f=256;if((e|0)==256){break X}d=e-257<<2;f=v[d+62992>>2];z=0;if(e-285>>>0<4294967276){break cb}z=v[d+63120>>2];if(z>>>0>g>>>0){d=15;continue V}d=3;continue}if(!f){o=h;f=-1;break gb}f=f-1|0;d=18;continue V}g=g-z|0;o=h>>>z|0;r=((-1<<z^-1)&h)+r|0;break hb}d=u[(((h&1023)<<1)+i|0)+3840>>1];sb:{if((d|0)<0){e=10;while(1){k=h>>>e|0;e=e+1|0;d=u[(((k&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){continue}break}break sb}e=d>>9;d=d&511}g=g-e|0;h=h>>>e|0;e=d<<2;r=v[e+63248>>2];z=0;if(d-30>>>0<4294967270){o=h;break hb}z=v[e+63376>>2];if(z>>>0<=g>>>0){break fb}d=17;continue V}M=l-I|0;d=(M-r&V)+I|0;if((d>>>0<l>>>0?l:d)+f>>>0>K>>>0){h=o;d=7;continue}while(1){if(f>>>0>=3){t[l|0]=w[d|0];t[l+1|0]=w[d+1|0];t[l+2|0]=w[d+2|0];f=f-3|0;d=d+3|0;l=l+3|0;continue}break}if(!f){f=0;break gb}t[l|0]=w[d|0];if((f|0)!=1){t[l+1|0]=w[d+1|0]}l=f+l|0}d=2;continue}d=6;continue}d=u[(((h&1023)<<1)+i|0)+3840>>1];tb:{if((d|0)>=0){if(d>>>0<512|d>>9>>>0>g>>>0){break tb}break bb}if(g>>>0<11){break tb}e=10;while(1){d=u[(((h>>>e&1)+(d^-1)<<1)+i|0)+5888>>1];if((d|0)<0){k=e+2|0;e=e+1|0;if(g>>>0>=k>>>0){continue}}break}if((d|0)>=0){break bb}}d=16;continue V}g=g-z|0;f=((-1<<z^-1)&h)+f|0;h=h>>>z|0}if(g>>>0>14){break bb}if((A-j|0)<=1){d=4;continue}h=w[j|0]<<g|h|w[j+1|0]<<g+8;g=g+16|0;j=j+2|0}d=5;continue}d=1;continue}}if(!f|!g){break Y}if(g>>>0>7){break Z}d=5;continue}g=g-8|0;r=h&255;h=h>>>8|0;d=6;continue}if(f){break W}f=0}if(t[i+20|0]&1){break u}d=0;continue}d=7;continue}}h=0;d=g>>>3|0;e=j-D|0;e=e>>>0>j>>>0?0:e;d=d>>>0<e>>>0?d:e;if((g&-8)==d<<3){j=j-d|0;e=0;d=0;g=0;if(!(X&1)){break s}k=0;break t}aa(6800,13026,2797,6810);L()}while(1){ub:{vb:{wb:{xb:{yb:{zb:{switch(k|0){case 0:if(e>>>0>3){f=e;g=d;break s}g=0;if(d){break yb}f=e;k=1;continue;case 1:break zb;default:break xb}}if(j>>>0<A>>>0){break vb}v[i>>2]=42;n=1;break i}f=e;g=d;if(d>>>0>7){break wb}k=2;continue}while(1){if(j>>>0>=A>>>0){v[i>>2]=41;n=1;break i}h=w[j|0]<<g|h;e=g>>>0>4294967287;j=j+1|0;d=g+8|0;g=d;if(e){continue}break}e=f}k=h&255;h=h>>>8|0;d=d-8|0;break ub}k=w[j|0];j=j+1|0;e=f;d=g}v[i+16>>2]=v[i+16>>2]<<8|k;e=e+1|0;k=0;continue}}n=0;k=34;break k}k=21;break k}k=17;break k}k=35;break k}k=10;break k}k=39;break k}n=1;break i}f=1}v[i>>2]=k}d=g>>>3|0;e=j-D|0;e=e>>>0>j>>>0?0:e;d=d>>>0<e>>>0?d:e;j=j-d|0;g=g-(d<<3)|0}v[i+4>>2]=g;v[i+60>>2]=M;v[i+40>>2]=z;v[i+36>>2]=f;v[i+32>>2]=r;v[i+56>>2]=(((g&63)>>>0>=32?0:-1<<g)^-1)&h;v[E+12>>2]=j-D;h=l-C|0;v[E+8>>2]=h;if((n|0)<0){break g}g=(h>>>0)%5552|0;f=v[i+28>>2];d=f>>>16|0;e=f&65535;while(1){k=0;if(h){while(1){if((k|7)>>>0<g>>>0){f=w[C|0]+e|0;o=f+w[C+1|0]|0;j=o+w[C+2|0]|0;q=j+w[C+3|0]|0;s=q+w[C+4|0]|0;l=s+w[C+5|0]|0;D=l+w[C+6|0]|0;e=D+w[C+7|0]|0;d=e+(D+(l+(s+(q+(j+(o+(d+f|0)|0)|0)|0)|0)|0)|0)|0;C=C+8|0;k=k+8|0;continue}break}f=g&7;k=g&8184;j=C;while(1){if((g|0)!=(k|0)){k=k+1|0;e=w[j|0]+e|0;d=e+d|0;j=j+1|0;continue}break}h=h-g|0;d=(d>>>0)%65521|0;e=(e>>>0)%65521|0;C=f+C|0;g=5552;continue}else{f=d<<16|e;v[i+28>>2]=f;if(n){break g}n=0;if(!(X&1)){break g}n=(f|0)==v[i+16>>2]?0:-2}break}}jb=Z+144|0;v[i+43780>>2]=n;f=v[E+12>>2];v[p>>2]=f+v[p>>2];v[p+4>>2]=v[p+4>>2]-f;v[p+8>>2]=f+v[p+8>>2];v[p+48>>2]=v[i+28>>2];f=v[E+8>>2];v[i+10996>>2]=f;d=v[p+16>>2];d=d>>>0>f>>>0?f:d;qc(v[p+12>>2],v[i+10992>>2]+I|0,d);v[p+12>>2]=d+v[p+12>>2];v[p+16>>2]=v[p+16>>2]-d;v[p+20>>2]=d+v[p+20>>2];h=v[i+10996>>2];v[i+10996>>2]=h-d;k=d+v[i+10992>>2]&32767;v[i+10992>>2]=k;if((n|0)<0){break f}if(!((n|0)!=1|ca)){f=-5;break e}if(n){f=0;e=v[p+4>>2];if(!e|!v[p+16>>2]){break e}if((d|0)==(h|0)){continue}break e}break}f=(d|0)==(h|0);break e}e=v[p+16>>2];d=d>>>0<e>>>0?d:e;qc(v[p+12>>2],(v[i+10992>>2]+i|0)+11012|0,d);v[p+12>>2]=d+v[p+12>>2];v[p+16>>2]=v[p+16>>2]-d;v[p+20>>2]=d+v[p+20>>2];e=v[i+10996>>2];v[i+10996>>2]=e-d;v[i+10992>>2]=d+v[i+10992>>2]&32767;if(v[i+43780>>2]){break e}f=(d|0)==(e|0);break e}f=-3}jb=E+16|0;e=v[m+1068>>2]-T|0;v[m+1068>>2]=e;d=H+$|0;H=v[m+1088>>2];$=d-H|0;continue}break}b=m+1072|0;Ab:{if(!b){break Ab}d=v[b+28>>2];if(!d){break Ab}nb[v[b+36>>2]](v[b+40>>2],d);v[b+28>>2]=0}e=0;Bb:{Cb:{if(!(v[m+1140>>2]!=(_|0)|H|(f|0)!=1)){ke(m+8|0,v[R>>2],v[R+4>>2]);b=$d(m);f=v[b+4>>2];b=v[b>>2];v[23296]=0;b=wg(491,m+32|0,v[m+8>>2],v[m+12>>2],b,f);f=v[23296];v[23296]=0;if((f|0)==1){break Cb}v[23296]=0;e=W(823,a|0,b|0,c|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break Bb}Ab(b)}fc(R);break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;Ab(b);break c}a=P()|0;O()|0}fc(R);S(a|0);L()}jb=m+1152|0;return e|0}function Ffa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),y=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=C(0),Q=0,R=C(0),T=0,U=0,X=0,Y=0,$=0,aa=0,ba=0,ca=0,da=0,fa=0,ga=0,ha=0,ia=0,ja=0,ka=0,la=C(0),ma=0,na=0,oa=0,pa=0,qa=0,ra=0,sa=C(0);p=jb-11360|0;jb=p;Ac(c);a:{while(1){b:{if(!Ob(v[c>>2],v[c+8>>2],4)){break b}e=p+16|0;d=jb-16|0;jb=d;c:{if(!Ob(v[c>>2],v[c+8>>2],3)){f=0;while(1){if((f|0)!=3){vg(e+f|0);f=f+1|0;continue}break}break c}kv(d+8|0,e);qd(d,c,v[d+8>>2],v[d+12>>2])}jb=d+16|0;d:{e:{if(!Pb(e,14862,3)){e=p+4648|0;d=jb-16|0;jb=d;f:{if(!Ob(v[c>>2],v[c+8>>2],7)){f=0;while(1){if((f|0)!=7){vg(e+f|0);f=f+1|0;continue}break}break f}wo(d+8|0,e);qd(d,c,v[d+8>>2],v[d+12>>2])}jb=d+16|0;H=0;i=3;while(1){if((i|0)==7){break d}e=w[(p+4648|0)+i|0];if(e&128){break e}i=i+1|0;H=e|H<<7;continue}}g:{if(Pb(p+16|0,14041,3)){break g}if(!HR(c,13412)){break g}ac(c,qg(c)+16|0);continue}if(!Pb(p+16|0,30062,3)){continue}if(!Pb(p+16|0,30066,3)){continue}if(!w[p+16|0]){ng(c,2);continue}if(qP(p+16|0)){break b}}i=0;break a}ac(c,H);continue}break}Ac(c);e=p+11336|0;LA(e,c);ca=v[p+11336>>2];Y=ye(e);X=Qb(p+11320|0);c=p+4648|0;Xb(c,0,6668);$y(c);c=p+4640|0;v[c>>2]=0;v[c+4>>2]=0;c=p+4632|0;v[c>>2]=0;v[c+4>>2]=0;v[p+4624>>2]=0;v[p+4628>>2]=0;H=0;c=0;h:{while(1){d=Ic(ca,da);aa=p+16|0;I=p+4624|0;e=0;n=jb-17168|0;jb=n;v[n+17164>>2]=0;i:{j:{E=p+4648|0;k:{if(w[E+6152|0]!=255|(d|0)<5){break k}if(!ip(E+6152|0,Y)){break k}i=bx(w[Y+1|0],w[Y+2|0],v[E+6148>>2])+hp(Y)|0;v[n+17164>>2]=i;if((d|0)==(i|0)){i=d;break j}l:{if((d|0)>=(i+4|0)){if(ip(Y,i+Y|0)){break l}}v[n+17164>>2]=0;break k}if(i){break j}}f=Y;J=Xb(E,0,6668)+6148|0;$=n+17164|0;i=0;j=0;D=d-4|0;q=(D|0)>0?D:0;while(1){m:{n:{o:{p:{if((i|0)==(q|0)){i=d;break p}if(!bI(f)){break n}h=bx(w[f+1|0],w[f+2|0],v[J>>2]);e=h+hp(f)|0;g=4;o=i+4|0;q:{while(1){if(!(g>>>0>2303|h)){if((D|0)<=((g<<1)+i|0)){break q}h=0;m=f+g|0;r:{if(!ip(f,m)){break r}k=g-hp(f)|0;y=hp(m)+k|0;if((d|0)<(y+(g+o|0)|0)){break r}if(!ip(f,m+y|0)){break r}v[J>>2]=k;h=k;e=g}g=g+1|0;continue}break}if(!h|(d|0)<(e+i|0)){break q}y=d-i|0;g=0;A=0;while(1){s:{t:{if((A|0)!=10){k=(A|0)!=0;F=g;g=f+g|0;g=(F+bx(w[g+1|0],w[g+2|0],h)|0)+hp(g)|0;if((y|0)<(g+4|0)){break s}if(ip(f,f+g|0)){break t}k=0}else{k=1}break s}A=A+1|0;continue}break}if(!k){break q}j=e;break p}if((d|0)!=(e|0)|i){break o}i=0;j=d}v[$>>2]=j;e=i;break m}v[J>>2]=0}f=f+1|0;i=i+1|0;continue}break}i=v[n+17164>>2];if((d|0)>=(e+i|0)?i:0){break j}v[I>>2]=e;A=0;break i}d=e+Y|0;v[E+6152>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[I+4>>2]=e;v[I>>2]=e+i;v[I+8>>2]=w[d+3|0]>191?1:2;qa=I,ra=eI(w[d+1|0],w[d+2|0]),v[qa+12>>2]=ra;v[I+16>>2]=4-(w[d+1|0]>>>1&3);qa=I,ra=ax(w[d+1|0],w[d+2|0]),v[qa+20>>2]=ra;if(!aa){A=$w(w[d+1|0]);break i}dI(n+17152|0,d+4|0,i-4|0);if(!(t[d+1|0]&1)){ce(n+17152|0,16)}u:{if(v[I+16>>2]==3){A=0;m=n+17152|0;ja=n+3740|0;e=ja;f=0;g=w[d+1|0];i=B((g>>>3&1)+(g>>>4&1)|0,3)+(w[d+2|0]>>>2&3)|0;j=i-((i|0)!=0)|0;$=d;d=w[d+3|0]>191?1:2;v:{if(g&8){i=ce(m,9);d=d<<1;f=ce(m,d+7|0);break v}i=ce(m,d|8)>>>d|0}g=B(j,40);q=g+63840|0;o=g+64160|0;y=B(j,23)+63648|0;l=-1;h=0;w:{while(1){j=w[$+3|0];k=ce(m,12);u[e+4>>1]=k;g=ce(m,9);u[e+6>>1]=g;if((g&65535)>>>0>288){break w}g=j>>>0>191?f<<4:f;qa=e,ra=ce(m,8),t[qa+10|0]=ra;f=ce(m,w[$+1|0]&8?4:9);t[e+13|0]=22;t[e+14|0]=0;v[e>>2]=y;u[e+8>>1]=f;x:{if(ce(m,1)){f=ce(m,2);t[e+11|0]=f;if(!(f&255)){break w}f=ce(m,1);u[e+18>>1]=65287;t[e+12|0]=f;if(w[e+11|0]==2){y:{if(!(f&255)){v[e>>2]=q;t[e+18|0]=8;j=39;f=0;break y}v[e>>2]=o;j=30;f=w[$+1|0]&8?8:6}t[e+14|0]=j;t[e+13|0]=f;g=g&3855}f=ce(m,10);qa=e,ra=ce(m,3),t[qa+21|0]=ra;qa=e,ra=ce(m,3),t[qa+22|0]=ra;qa=e,ra=ce(m,3),t[qa+23|0]=ra;f=f<<5;break x}t[e+11|0]=0;t[e+12|0]=0;f=ce(m,15);qa=e,ra=ce(m,4),t[qa+18|0]=ra;j=ce(m,3);t[e+20|0]=255;t[e+19|0]=j}t[e+17|0]=f&31;t[e+15|0]=f>>>10;t[e+16|0]=f>>>5&31;h=(k&65535)+h|0;z:{if(w[$+1|0]&8){f=ce(m,1);break z}f=x[e+8>>1]>499}t[e+24|0]=f;qa=e,ra=ce(m,1),t[qa+25|0]=ra;f=ce(m,1);t[e+27|0]=g>>>12&15;t[e+26|0]=f;e=e+28|0;f=g<<4;d=d-1|0;if(d){continue}break}l=(v[m+4>>2]+h|0)>(v[m+8>>2]+(i<<3)|0)?-1:i}if(!((l|0)<0|v[n+17156>>2]>v[n+17160>>2])){h=n+17152|0;i=v[h+4>>2];f=v[h+8>>2];d=n+912|0;g=v[E+6144>>2];e=g-l|0;j=(g|0)<(l|0)?g:l;g=qc(d+12|0,(((e|0)>0?e:0)+E|0)+6156|0,j);e=(f-i|0)/8|0;qc(g+j|0,v[h>>2]+(v[h+4>>2]/8|0)|0,e);dI(d,g,e+j|0);A:{i=v[E+6144>>2]>=(l|0);if(!i){break A}ma=E+2304|0;na=n+8620|0;oa=n+3852|0;while(1){if((w[$+1|0]&8?2:1)>>>0<=A>>>0){break A}pa=Xb(oa,0,4608);d=v[I+8>>2];K=B(B(d,A),28)+ja|0;e=0;ka=(d|0)>0?d:0;G=n+912|0;y=G+7548|0;ba=E+6152|0;while(1){if((e|0)!=(ka|0)){o=B(e,28)+K|0;J=x[o+4>>1];D=v[G+4>>2];d=(G+B(e,39)|0)+16156|0;h=y;q=e;j=jb-48|0;jb=j;ia=w[o+25|0];l=B(!w[o+13|0]+(w[o+14|0]!=0)|0,28)+64480|0;B:{if(w[ba+1|0]&8){e=w[o+27|0];g=w[x[o+8>>1]+64576|0];f=g&3;t[j+47|0]=f;t[j+46|0]=f;f=g>>>2|0;t[j+45|0]=f;t[j+44|0]=f;break B}e=(w[ba+3|0]&16)>>>4&(q|0)!=0;g=e?12:0;r=x[o+8>>1]>>>e|0;while(1){if((r|0)>=0){e=3;f=1;while(1){if((e|0)>=0){k=w[(e+g|0)+64592|0];t[(j+44|0)+e|0]=((r|0)/(f|0)|0)%(k|0);e=e-1|0;f=B(f,k);continue}break}g=g+4|0;r=r-f|0;continue}break}l=g+l|0;e=-16}g=d;f=j;m=f+44|0;r=0;while(1){C:{D:{E:{if((r|0)==4){break E}Q=w[l+r|0];if(!Q){break E}if(e&8){qc(f,g,Q);break D}fa=w[m+r|0];if(!fa){Xb(f,0,Q);Xb(g,0,Q);break D}d=(e|0)>=0?-1:-1<<fa^-1;k=0;while(1){if((k|0)==(Q|0)){break D}M=ce(G,fa);t[g+k|0]=(d|0)==(M|0)?-1:M;t[f+k|0]=M;k=k+1|0;continue}}t[f+2|0]=0;t[f|0]=0;t[f+1|0]=0;break C}e=e<<1;r=r+1|0;f=f+Q|0;g=g+Q|0;continue}break}F:{f=w[o+14|0];if(f){e=2-ia|0;m=w[o+23|0]<<e;k=w[o+22|0]<<e;g=w[o+21|0]<<e;d=w[o+13|0];e=0;while(1){if(e>>>0>=f>>>0){break F}M=j+(d+e|0)|0;t[M|0]=g+w[M|0];t[M+1|0]=k+w[M+1|0];t[M+2|0]=m+w[M+2|0];e=e+3|0;continue}}if(!w[o+24|0]){break F}e=0;while(1){if((e|0)==10){break F}d=e+j|0;t[d+11|0]=w[d+11|0]+w[e+64616|0];e=e+1|0;continue}}d=ia+1|0;e=0;s=_w(C(2048),((((w[ba+3|0]&224)==96)<<1)-w[o+10|0]|0)+258|0);while(1){if(w[o+13|0]+(f&255)>>>0>e>>>0){qa=(e<<2)+h|0,sa=_w(s,w[e+j|0]<<d),z[qa>>2]=sa;e=e+1|0;f=w[o+14|0];continue}break}jb=j+48|0;k=(G+B(q,2304)|0)+2940|0;ia=D+J|0;s=C(0);e=v[G+4>>2];f=v[G>>2]+((e|0)/8|0)|0;d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);g=(d<<24|d<<8&16711680|(d>>>8&65280|d>>>24))<<(e&7);l=e|-8;r=f+4|0;T=v[o>>2];U=x[o+6>>1];e=0;while(1){G:{H:{if((U|0)>0){j=e+1|0;e=e+o|0;d=w[e+15|0];fa=(u[(d<<1)+69040>>1]<<1)+64656|0;ga=w[e+18|0];if(d>>>0>=16){M=w[d+69104|0];m=32-M|0;while(1){J=w[T|0]>>>1|0;D=(J|0)>(U|0)?U:J;s=z[h>>2];while(1){e=g>>>27|0;d=5;while(1){e=u[fa+(e<<1)>>1];if((e|0)<0){g=g<<d;f=e&7;e=(g>>>32-f|0)-(e>>3)|0;l=d+l|0;d=f;continue}break}f=e&65535;e=f>>>8|0;l=e+l|0;g=g<<e;d=0;while(1){if((d|0)!=2){F=f&15;I:{if((F|0)==15){l=l+M|0;e=g<<M;while(1){if((l|0)>=0){e=w[r|0]<<l|e;r=r+1|0;l=l-8|0;continue}break}F=(g>>>m|0)+15|0;g=F;J:{if((g|0)<=128){N=z[(g<<2)+69200>>2];break J}ha=g<<3;Q=g;g=g>>>0<1024;ha=g?ha:Q;Q=ha<<1&64;R=C(C((ha&63)-Q|0)/C(Q+(ha&-64)|0));N=C((g?C(16):C(256))*C(C(C(R*C(C(R*C(.2222222238779068))+C(1.3333333730697632)))+C(1))*z[(Q+ha>>6<<2)+69200>>2]))}N=C(C(s*N)*C(e>>31|1));break I}e=g;N=C(s*z[(((e>>>27&16|F)^16)<<2)+69136>>2])}z[k>>2]=N;f=f>>>4|0;k=k+4|0;d=d+1|0;g=(F|0)!=0;l=g+l|0;g=e<<g;continue}break}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}D=D-1|0;if(D){continue}break}h=h+4|0;T=T+1|0;U=U-J|0;if((U|0)<=0){break H}e=(ga|0)>0;ga=ga-1|0;if(e){continue}break}break H}while(1){m=w[T|0]>>>1|0;F=(m|0)>(U|0)?U:m;s=z[h>>2];while(1){e=g>>>27|0;d=5;while(1){e=u[fa+(e<<1)>>1];if((e|0)<0){g=g<<d;f=e&7;e=(g>>>32-f|0)-(e>>3)|0;l=d+l|0;d=f;continue}break}d=e&65535;e=d>>>8|0;l=e+l|0;g=g<<e;e=0;while(1){if((e|0)!=2){f=d&15;z[k>>2]=s*z[(((f|g>>>27&16)^16)<<2)+69136>>2];d=d>>>4|0;k=k+4|0;e=e+1|0;f=(f|0)!=0;l=f+l|0;g=g<<f;continue}break}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}F=F-1|0;if(F){continue}break}h=h+4|0;T=T+1|0;U=U-m|0;if((U|0)<=0){break H}e=(ga|0)>0;ga=ga-1|0;if(e){continue}break}break H}d=1-U|0;while(1){K:{f=w[o+26|0]?69024:68992;e=w[f+(g>>>28|0)|0];if(!(e&8)){e=w[f+((g<<4>>>32-(e&3))+(e>>>3)|0)|0]}f=e&7;l=f+l|0;if((ia|0)<((l+(r-v[G>>2]<<3)|0)-24|0)){break K}d=d-1|0;if(!d){d=w[T|0];if(d>>>0<2){break K}T=T+1|0;s=z[h>>2];h=h+4|0;d=d>>>1|0}g=g<<f;if(e&128){z[k>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}if(e&64){z[k+4>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}d=d-1|0;if(!d){d=w[T|0];if(d>>>0<2){break K}T=T+1|0;s=z[h>>2];h=h+4|0;d=d>>>1|0}if(e&32){z[k+8>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}if(e&16){z[k+12>>2]=(g|0)<0?C(-s):s;l=l+1|0;g=g<<1}while(1){if((l|0)>=0){g=w[r|0]<<l|g;r=r+1|0;l=l-8|0;continue}break}k=k+16|0;continue}break}v[G+4>>2]=ia;break G}e=j;continue}break}e=q+1|0;continue}break}e=w[E+6155|0];L:{if(e&16){D=jb-16|0;jb=D;e=G+2940|0;g=e+2304|0;q=v[K>>2];o=w[K+14|0];f=o+w[K+13|0]|0;d=0;m=D+4|0;v[m+8>>2]=-1;v[m>>2]=-1;v[m+4>>2]=-1;while(1){if((d|0)!=(f|0)){y=d+q|0;j=w[y|0];h=0;M:{while(1){if(h>>>0>=j>>>0){break M}k=h<<2;if(z[k+g>>2]==C(0)){h=h+2|0;if(z[(k|4)+g>>2]==C(0)){continue}}break}v[m+((d>>>0)%3<<2)>>2]=d;j=w[y|0]}d=d+1|0;g=(j<<2)+g|0;continue}break}if(w[K+13|0]){g=v[D+4>>2];d=v[D+8>>2];g=(d|0)<(g|0)?g:d;d=v[D+12>>2];d=(d|0)<(g|0)?g:d;v[D+12>>2]=d;v[D+8>>2]=d;v[D+4>>2]=d}m=G+16195|0;j=o?3:1;g=f-j|0;h=0;while(1){if((h|0)!=(j|0)){f=g+h|0;d=f-j|0;if((d|0)<=v[(D+4|0)+(h<<2)>>2]){d=w[ba+1|0]<<28>>31&3}else{d=w[d+m|0]}t[f+m|0]=d;h=h+1|0;continue}break}q=v[K>>2];o=D+4|0;y=u[K+36>>1]&1;g=0;k=w[ba+1|0]&8?7:64;while(1){j=g+q|0;d=w[j|0];if(d){f=w[ba+3|0]&32;N:{O:{if(v[o+((g>>>0)%3<<2)>>2]>=(g|0)){break O}h=w[g+m|0];if(h>>>0>=k>>>0){break O}N=f?C(1.4142135381698608):C(1);P:{if(w[ba+1|0]&8){f=h<<3;s=z[f+69732>>2];R=z[f+69728>>2];break P}R=_w(C(1),h+1>>>1<<y);f=h&1;s=f?C(1):R;R=f?R:C(1)}R=C(N*R);s=C(N*s);h=0;while(1){if((d|0)!=(h|0)){f=(h<<2)+e|0;N=z[f>>2];z[f+2304>>2]=N*s;z[f>>2]=N*R;h=h+1|0;continue}break}break N}if(!f){break N}aI(e,d)}g=g+1|0;e=(w[j|0]<<2)+e|0;continue}break}jb=D+16|0;break L}if((e&224)!=96){break L}aI(G+2940|0,576)}k=G+7708|0;e=0;while(1){if((e|0)!=(ka|0)){d=w[E+6153|0];q=(w[K+12|0]!=0)<<1<<((B((d>>>3&1)+(d>>>4&1)|0,3)+(w[E+6154|0]>>>2&3)|0)==2);j=(G+B(e,2304)|0)+2940|0;g=j;if(w[K+14|0]){r=v[K>>2]+w[K+13|0]|0;h=((G+B(e,2304)|0)+B(q,72)|0)+2940|0;d=h;f=k;while(1){o=w[r|0];if(o){y=o<<1;l=0;while(1){if((l|0)!=(o|0)){z[f>>2]=z[d>>2];z[f+4>>2]=z[(o<<2)+d>>2];z[f+8>>2]=z[(y<<2)+d>>2];d=d+4|0;l=l+1|0;f=f+12|0;continue}break}r=r+3|0;d=(y<<2)+d|0;continue}break}qc(h,k,f-k|0);f=q-1|0}else{f=31}while(1){d=0;if((f|0)>0){while(1){if((d|0)!=8){y=d<<2;h=y+g|0;la=z[h+72>>2];F=h;N=z[y+69792>>2];R=z[y+69824>>2];h=(17-d<<2)+g|0;s=z[h>>2];z[F+72>>2]=C(la*N)-C(R*s);z[h>>2]=C(la*R)+C(s*N);d=d+1|0;continue}break}g=g+72|0;f=f-1|0;continue}break}d=j;f=B(e,1152)+E|0;g=w[K+11|0];if(q){$H(d,f,69856,q);f=B(q,36)+f|0;d=B(q,72)+d|0}Q:{if((g|0)==2){h=32-q|0;m=jb-80|0;jb=m;q=m|8;o=m|4;while(1){if((h|0)>0){y=qc(m,d,72);g=v[f+20>>2];v[d+16>>2]=v[f+16>>2];v[d+20>>2]=g;g=v[f+12>>2];v[d+8>>2]=v[f+8>>2];v[d+12>>2]=g;g=v[f+4>>2];v[d>>2]=v[f>>2];v[d+4>>2]=g;g=f+24|0;Zw(y,d+24|0,g);Zw(o,d+48|0,g);Zw(q,f,g);d=d+72|0;f=f+36|0;h=h-1|0;continue}break}jb=m+80|0;break Q}$H(d,f,B((g|0)==3,72)+69856|0,32-q|0)}h=0;f=j+72|0;while(1){d=1;if(h>>>0<=31){while(1){if(d>>>0<=17){g=(d<<2)+f|0;z[g>>2]=-z[g>>2];d=d+2|0;continue}break}f=f+144|0;h=h+2|0;continue}break}K=K+28|0;e=e+1|0;continue}break}cI(ma,pa,18,v[I+8>>2],aa,na);A=A+1|0;aa=B(v[I+8>>2],1152)+aa|0;continue}}g=n+912|0;d=v[g+8>>2]>>>3|0;e=v[g+4>>2]+7>>>3|0;j=d-e|0;f=(j|0)<511?j:511;if((j|0)>0){aj(E+6156|0,(g+(j>>>0>511?d-511|0:e)|0)+12|0,f)}v[E+6144>>2]=f;break u}$y(E);break i}q=n+17152|0;f=0;g=0;h=0;A=0;e=d;R:{S:{T:{d=w[d+3|0];i=d>>>6|0;switch(i-1|0){case 2:break R;case 0:break T;default:break S}}g=(d>>>2&12)+4|0;break R}g=32}k=w[e+1|0];U:{if((k&6)==6){i=71260;d=32;break U}if(!(k&8)){i=71263;d=30;break U}d=w[e+2|0];j=d>>>2&3;d=ax(k,d)>>>((i|0)!=3)|0;d=d?d:192;if(d>>>0<=55){i=71284;d=(j|0)==2?12:8;break U}i=71272;d=d>>>0>95?(j|0)!=1?30:27:27}t[n+768|0]=d;t[n+769|0]=(d|0)>(g|0)?g:d;d=i;j=71168;while(1){g=w[n+768|0];if(g>>>0<=f>>>0){f=0;while(1){j=g<<1&510;if(j>>>0>f>>>0){i=f+n|0;V:{if(!w[i+770|0]){d=6;break V}d=2;if((w[e+1|0]&6)==6){break V}d=ce(q,2);g=w[n+768|0]}t[i+834|0]=d;f=f+1|0;continue}break}g=n+770|0;o=n+834|0;e=n;f=0;while(1){if((f|0)!=(j|0)){d=w[g|0];i=d?19>>>w[f+o|0]&3|4:0;g=g+1|0;y=B(d,3)-6|0;s=C(0);d=4;while(1){if(d){if(d&i){k=ce(q,6);h=(k|0)/3|0;s=C(z[(y+(B(h,-3)+k|0)<<2)+71296>>2]*C(2097152>>>h|0))}z[e>>2]=s;d=d>>>1|0;e=e+4|0;continue}break}f=f+1|0;continue}break}f=w[n+769|0];e=w[n+768|0];e=e>>>0<f>>>0?f:e;while(1){if((e|0)!=(f|0)){t[((f<<1)+n|0)+771|0]=0;f=f+1|0;continue}break}}else{if((f|0)==(A|0)){j=w[d|0]+71168|0;A=w[d+2|0]+f|0;h=w[d+1|0];d=d+3|0}k=f<<1;g=w[ce(q,h)+j|0];t[(k+n|0)+770|0]=g;i=w[n+769|0];if(i>>>0>f>>>0){g=w[ce(q,h)+j|0];i=w[n+769|0]}t[((k|1)+n|0)+770|0]=i?g:0;f=f+1|0;continue}break}i=0;d=Xb(n+3852|0,0,4608);q=E+2304|0;o=n+8620|0;A=0;W:{while(1){if((A|0)==3){break W}y=d+(i<<2)|0;D=n+17152|0;j=0;J=v[I+16>>2]|1;m=(J|0)>0?J:0;l=576;while(1){if((j|0)!=4){f=y+(B(j,J)<<2)|0;g=0;while(1){if(w[n+768|0]<<1>>>0>g>>>0){X:{k=w[(g+n|0)+770|0];if(!k){break X}if(k>>>0<=16){h=(-1<<k-1)+1|0;e=0;while(1){if((e|0)==(m|0)){break X}qa=(e<<2)+f|0,sa=C(ce(D,k)+h|0),z[qa>>2]=sa;e=e+1|0;continue}}h=2<<k-17;k=h>>>1|0;$=h|1;e=0;h=ce(D,(h-(h>>>3|0)|0)+3|0);while(1){if((e|0)==(m|0)){break X}F=h;h=(h>>>0)/($>>>0)|0;z[(e<<2)+f>>2]=F-(k+B($,h)|0)|0;e=e+1|0;continue}}g=g+1|0;f=(l<<2)+f|0;l=18-l|0;continue}break}j=j+1|0;continue}break}i=(J<<2)+i|0;if((i|0)==12){j=(A<<2)+n|0;e=d;i=w[n+769|0];f=d+B(i,72)|0;qc(f+2304|0,f,B(w[n+768|0]-i|0,72));g=0;while(1){if(w[n+768|0]>g>>>0){f=0;while(1){if((f|0)!=12){i=(f<<2)+e|0;z[i>>2]=z[j>>2]*z[i>>2];i=i+2304|0;z[i>>2]=z[j+12>>2]*z[i>>2];f=f+1|0;continue}break}j=j+24|0;e=e+72|0;g=g+1|0;continue}break}cI(q,d,12,v[I+8>>2],aa,o);Xb(d,0,4608);aa=B(v[I+8>>2],768)+aa|0;i=0}A=A+1|0;if(v[n+17156>>2]<=v[n+17160>>2]){continue}break}$y(E);A=0;break i}i=1}A=B($w(w[E+6153|0]),i)}jb=n+17168|0;e=v[p+4624>>2];if((e|0)<0|!e&(A|0)!=0|!(e|A)){break h}Y:{if(e){e=v[p+4636>>2];if((e|0)!=(H|0)?H:0){break h}d=v[p+4632>>2];if((d|0)!=(c|0)?c:0){break h}if(d-3>>>0<4294967294|(e|0)<=0){break Y}v[p+12>>2]=0;qa=p,ra=Ic(ca,da),v[qa+8>>2]=ra;c=v[wj(p+4624|0,p+12|0,p+8|0)>>2];v[p+12>>2]=0;qa=p,ra=Ic(ca,da),v[qa+8>>2]=ra;Y=c+Y|0;c=ca;f=v[wj(p+4624|0,p+12|0,p+8|0)>>2];ca=c-f|0;da=da-((f>>31)+(c>>>0<f>>>0)|0)|0;Z:{if(!A){break Z}v[23296]=0;c=p+16|0;W(525,X|0,c|0,c+(B(d,A)<<1)|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break Z}H=V(91780)|0;if((O()|0)==(ea(91780)|0)){_(H|0)|0;v[23296]=0;Z(17);f=v[23296];v[23296]=0;H=e;c=d;if((f|0)!=1){break h}H=P()|0;O()|0}ud(X);Pc(p+11336|0);S(H|0);L()}H=e;c=d}if((Nc(v[X>>2],v[X+4>>2])>>>0)/(c>>>0)>>>0>268435456){break h}if(!!ca&(da|0)>=0|(da|0)>0){continue}break h}break}H=e;c=d}i=0;_:{if(!H|!c){break _}d=v[X>>2];e=v[X+4>>2];if(uc(d,e)){break _}if((Nc(d,e)>>>0)/(c>>>0)>>>0>268435456){break _}ft(a,b);e=B(b,104)+a|0;d=e+484380|0;qa=d,ra=(Nc(v[X>>2],v[X+4>>2])>>>0)/(c>>>0)|0,v[qa>>2]=ra;a=e+484414|0;b=x[a>>1];u[a>>1]=(c|0)==2?b|65:b&65470|1;Bg(d);a=e+484400|0;i=Ud(v[d>>2],v[a>>2]);if(!i){break _}Wn(Eb(v[X>>2]),Eb(v[X+4>>2]),v[a>>2]);i=Ud(v[d>>2],v[d+20>>2])}ud(X);Pc(p+11336|0)}jb=p+11360|0;return i|0}function nA(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),A=0,E=0,F=0,G=0,I=C(0),J=0,K=0,M=0,N=0,O=C(0);r=jb-1520|0;jb=r;e=r+8|0;M=Xb(e,0,1512),N=-1,v[M+1420>>2]=N;t[r+56|0]=1;v[r+48>>2]=a+b;v[r+40>>2]=a;l=jb-1024|0;jb=l;t[e+1377|0]=1;a:{if(!as(e)){break a}b=w[e+1375|0];if(!(b&2)){bc(e,34);break a}if(b&4){bc(e,34);break a}if(b&1){bc(e,34);break a}if(v[e+1116>>2]!=1){bc(e,34);break a}b=w[e+1120|0];if((b|0)!=30){b:{if((b|0)!=64){break b}if(!Ww(e,l+1018|0,6)|w[l+1018|0]!=102|(w[l+1019|0]!=105|w[l+1020|0]!=115)){break b}if(w[l+1021|0]!=104|w[l+1022|0]!=101|w[l+1023|0]!=97){break b}if((Pe(e)|0)!=100){break b}if(Pe(e)){break b}bc(e,38);break a}bc(e,34);break a}if((Pe(e)|0)!=1){bc(e,34);break a}if(!Ww(e,l+1018|0,6)){bc(e,10);break a}if(!Uw(l+1018|0)){bc(e,34);break a}if($i(e)){bc(e,34);break a}b=Pe(e);v[e+4>>2]=b;if(!b){bc(e,34);break a}if(b>>>0>=17){bc(e,5);break a}b=$i(e);v[e>>2]=b;if(!b){bc(e,34);break a}$i(e);$i(e);$i(e);b=Pe(e);j=b>>>4|0;v[e+116>>2]=1<<j;g=b&15;v[e+112>>2]=1<<g;if(g-14>>>0<=4294967287){bc(e,20);break a}if((b<<24)+536870912>>24>=0){bc(e,20);break a}c:{if(g>>>0>j>>>0){bc(e,20);break c}if(!(Pe(e)&1)){bc(e,34);break c}if(!as(e)){break a}if(!Vw(e)){break a}if(!Xw(e)){break a}if((mh(e)|0)==3){while(1){if((f|0)!=6){M=(l+1018|0)+f|0,N=mh(e),t[M|0]=N;f=f+1|0;continue}break}if(!Uw(l+1018|0)){bc(e,20);break c}b=Tw(e);f=be(e,b+1|0);v[e+20>>2]=f;if(f){f=0;g=(b|0)>0?b:0;while(1){if((f|0)!=(g|0)){j=mh(e);t[v[e+20>>2]+f|0]=j;f=f+1|0;continue}break}t[b+v[e+20>>2]|0]=0;b=Tw(e);v[e+28>>2]=0;v[e+24>>2]=b;d:{if((b|0)<=0){break d}b=be(e,b<<2);v[e+28>>2]=b;if(b){break d}bc(e,3);break c}while(1){e:{f:{if(v[e+24>>2]>(h|0)){b=Tw(e);f=be(e,b+1|0);g=h<<2;v[g+v[e+28>>2]>>2]=f;if(!v[g+v[e+28>>2]>>2]){break f}f=0;j=(b|0)>0?b:0;while(1){if((f|0)==(j|0)){break e}i=mh(e);t[v[g+v[e+28>>2]>>2]+f|0]=i;f=f+1|0;continue}}if(!(mh(e)&1)){bc(e,20);break c}QH(e,w[e+1376|0]);t[e+1376|0]=0;while(1){b=Xw(e);QH(e,b);t[e+1376|0]=0;if(b){continue}break}f=0;if(!Vw(e)){break a}if(!XH(e)){if(v[e+100>>2]!=21){break a}v[e+100>>2]=20;break a}b=0;while(1){if((b|0)!=256){j=b<<24;g=0;while(1){if((g|0)!=8){j=j>>31&79764919^j<<1;g=g+1|0;continue}break}v[(b<<2)+462064>>2]=j;b=b+1|0;continue}break}if((mh(e)|0)==5){while(1){if((f|0)!=6){M=(l+1018|0)+f|0,N=mh(e),t[M|0]=N;f=f+1|0;continue}break}if(!Uw(l+1018|0)){bc(e,20);break c}b=pc(e,8)+1|0;v[e+120>>2]=b;b=be(e,B(b,2096));v[e+124>>2]=b;if(!b){bc(e,3);break c}Xb(b,0,B(v[e+120>>2],2096));g:{h:{while(1){i:{if(v[e+120>>2]>(E|0)){b=v[e+124>>2];if((pc(e,8)&255)!=66){bc(e,20);break c}if((pc(e,8)&255)!=67){bc(e,20);break c}if((pc(e,8)&255)!=86){bc(e,20);break c}g=b+B(E,2096)|0;M=g,N=pc(e,8)&255|pc(e,8)<<8,v[M>>2]=N;M=g,N=pc(e,8)&255|(pc(e,8)<<8&65280|pc(e,8)<<16),v[M+4>>2]=N;k=g+4|0;f=0;m=pc(e,1);if(!m){f=pc(e,1)}t[g+23|0]=f;h=v[k>>2];if(v[g>>2]){b=h;break i}b=0;if(!h){break i}bc(e,20);break c}b=pc(e,6)+1&255;f=0;j:{while(1){if((b|0)==(f|0)){break j}f=f+1|0;if(!pc(e,16)){continue}break}bc(e,20);break c}b=pc(e,6)+1|0;v[e+128>>2]=b;b=be(e,B(b,1596));v[e+260>>2]=b;k:{if(b){E=0;k=0;l:while(1){if(v[e+128>>2]<=(k|0)){break k}b=pc(e,16);u[((k<<1)+e|0)+132>>1]=b;b=b&65535;if(b>>>0>=2){bc(e,20);break c}if(!b){b=v[e+260>>2]+B(k,1596)|0;M=b,N=pc(e,8),t[M|0]=N;M=b,N=pc(e,16),u[M+2>>1]=N;M=b,N=pc(e,16),u[M+4>>1]=N;M=b,N=pc(e,6),t[M+6|0]=N;M=b,N=pc(e,8),t[M+7|0]=N;j=pc(e,4)+1|0;t[b+8|0]=j;h=b+9|0;f=0;while(1){if((j&255)>>>0>f>>>0){M=f+h|0,N=pc(e,8),t[M|0]=N;f=f+1|0;j=w[b+8|0];continue}break}bc(e,4);break c}f=v[e+260>>2]+B(k,1596)|0;b=pc(e,5);t[f|0]=b;m=f+1|0;j=0;g=-1;while(1)if((b&255)>>>0<=j>>>0){h=g+1|0;g=f+82|0;i=f+65|0;o=f+49|0;n=f+33|0;b=0;while(1){if((b|0)!=(h|0)){M=b+n|0,N=pc(e,3)+1|0,t[M|0]=N;q=b+o|0;p=pc(e,2);t[q|0]=p;j=0;m:{if(!(p&255)){break m}p=pc(e,8);t[b+i|0]=p;if(v[e+120>>2]>(p&255)){break m}bc(e,20);break c}n:{while(1){if(1<<w[q|0]<=(j|0)){break n}p=pc(e,8)-1|0;u[(g+(b<<4)|0)+(j<<1)>>1]=p;j=j+1|0;if(v[e+120>>2]>p<<16>>16){continue}break}bc(e,20);break c}b=b+1|0;continue}break}g=2;M=f,N=pc(e,2)+1|0,t[M+1588|0]=N;b=pc(e,4);v[f+1592>>2]=2;h=0;u[f+338>>1]=0;t[f+1589|0]=b;u[f+340>>1]=1<<b;b=f+338|0;i=0;while(1){if(w[f|0]>i>>>0){o=n+w[i+m|0]|0;j=0;while(1){if(w[o|0]>j>>>0){g=pc(e,w[f+1589|0]);u[b+(v[f+1592>>2]<<1)>>1]=g;g=v[f+1592>>2]+1|0;v[f+1592>>2]=g;j=j+1|0;continue}break}i=i+1|0;continue}break}while(1){if((g|0)>(h|0)){g=x[b+(h<<1)>>1];j=(l+16|0)+(h<<2)|0;u[j+2>>1]=h;u[j>>1]=g;h=h+1|0;g=v[f+1592>>2];continue}break}PH(l+16|0,g,1038);g=v[f+1592>>2];h=((g|0)>1?g:1)-1|0;j=0;o:{while(1){if((h|0)==(j|0)){h=f+838|0;j=0;break o}i=l+16|0;n=x[i+(j<<2)>>1];j=j+1|0;if((n|0)!=x[i+(j<<2)>>1]){continue}break}bc(e,20);break c}while(1){if((g|0)>(j|0)){t[h+j|0]=w[((l+16|0)+(j<<2)|0)+2|0];j=j+1|0;g=v[f+1592>>2];continue}break}q=f+1088|0;j=2;while(1){if((g|0)>(j|0)){v[l+12>>2]=0;v[l+8>>2]=0;g=0;p=(j|0)>0?j:0;i=b+(j<<1)|0;m=65536;n=-1;while(1){if((g|0)!=(p|0)){o=b+(g<<1)|0;h=x[o>>1];if(!((n|0)>=(h|0)|x[i>>1]<=h>>>0)){v[l+12>>2]=g;h=x[o>>1];n=h}if(!((h|0)>=(m|0)|x[i>>1]>=h>>>0)){v[l+8>>2]=g;m=x[o>>1]}g=g+1|0;continue}break}h=q+(j<<1)|0;t[h|0]=v[l+12>>2];t[h+1|0]=v[l+8>>2];j=j+1|0;g=v[f+1592>>2];continue}break}E=(g|0)>(E|0)?g:E;k=k+1|0;continue l}else{b=pc(e,4);t[j+m|0]=b;b=b&255;g=(b|0)>(g|0)?b:g;j=j+1|0;b=w[f|0];continue}}}bc(e,3);break c}b=pc(e,6)+1|0;v[e+264>>2]=b;b=be(e,B(b,24));v[e+396>>2]=b;if(!b){bc(e,3);break c}k=0;Xb(b,0,B(v[e+264>>2],24));p:{q:{r:{while(1){if(v[e+264>>2]>(k|0)){b=v[e+396>>2];h=pc(e,16);u[((k<<1)+e|0)+268>>1]=h;if((h&65535)>>>0>=3){bc(e,20);break c}g=b+B(k,24)|0;M=g,N=pc(e,24),v[M>>2]=N;b=pc(e,24);v[g+4>>2]=b;if(b>>>0<y[g>>2]){bc(e,20);break c}M=g,N=pc(e,24)+1|0,v[M+8>>2]=N;M=g,N=pc(e,6)+1|0,t[M+12|0]=N;b=pc(e,8);t[g+13|0]=b;if(v[e+120>>2]<=(b&255)){break r}f=0;while(1){b=w[g+12|0];if(b>>>0>f>>>0){h=(l+16|0)+f|0;b=pc(e,3);if(pc(e,1)){i=pc(e,5)}else{i=0}t[h|0]=b+(i<<3);f=f+1|0;continue}break}b=be(e,b<<4);v[g+20>>2]=b;if(!b){break q}h=0;while(1){if(w[g+12|0]>h>>>0){b=w[(l+16|0)+h|0];f=0;while(1){if((f|0)!=8){s:{if(b>>>f&1){j=pc(e,8);m=f<<1;i=h<<4;u[m+(i+v[g+20>>2]|0)>>1]=j;if(v[e+120>>2]>u[m+(i+v[g+20>>2]|0)>>1]){break s}bc(e,20);break c}u[(v[g+20>>2]+(h<<4)|0)+(f<<1)>>1]=65535}f=f+1|0;continue}break}h=h+1|0;continue}break}h=be(e,v[(v[e+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);v[g+16>>2]=h;if(!h){bc(e,3);break c}b=0;Xb(h,0,v[(v[e+124>>2]+B(w[g+13|0],2096)|0)+4>>2]<<2);while(1){h=v[e+124>>2]+B(w[g+13|0],2096)|0;if(v[h+4>>2]>(b|0)){f=v[h>>2];j=be(e,f);h=b<<2;v[h+v[g+16>>2]>>2]=j;j=b;if(v[h+v[g+16>>2]>>2]){while(1){if((f|0)>0){f=f-1|0;t[f+v[h+v[g+16>>2]>>2]|0]=(j|0)%w[g+12|0];j=(j|0)/w[g+12|0]|0;continue}break}b=b+1|0;continue}else{bc(e,3);break c}}break}k=k+1|0;continue}break}b=pc(e,6)+1|0;v[e+400>>2]=b;b=be(e,B(b,40));v[e+404>>2]=b;if(!b){bc(e,3);break c}Xb(b,0,B(v[e+400>>2],40));i=0;while(1){if(v[e+400>>2]>(i|0)){b=v[e+404>>2];if(pc(e,16)){bc(e,20);break c}h=b+B(i,40)|0;b=be(e,B(v[e+4>>2],3));v[h+4>>2]=b;if(!b){bc(e,3);break c}if(pc(e,1)){b=pc(e,4)+1|0}else{b=1}t[h+8|0]=b;t:{if(pc(e,1)){b=pc(e,8)+1|0;u[h>>1]=b;f=0;g=v[e+4>>2];if((g|0)<(b&65535)){bc(e,20);break c}while(1){if(x[h>>1]<=f>>>0){break t}g=pc(e,Kl(g-1|0));b=B(f,3);t[b+v[h+4>>2]|0]=g;g=pc(e,Kl(v[e+4>>2]-1|0));t[(b+v[h+4>>2]|0)+1|0]=g;g=v[e+4>>2];b=b+v[h+4>>2]|0;j=w[b|0];if((g|0)<=(j|0)){bc(e,20);break c}b=w[b+1|0];if((b|0)>=(g|0)){bc(e,20);break c}f=f+1|0;if((b|0)!=(j|0)){continue}break}bc(e,20);break c}u[h>>1]=0}if(pc(e,2)){bc(e,20);break c}g=0;b=0;f=0;u:{if(w[h+8|0]>=2){while(1){if(v[e+4>>2]<=(b|0)){break u}f=pc(e,4);j=B(b,3);t[(j+v[h+4>>2]|0)+2|0]=f;b=b+1|0;if(w[(j+v[h+4>>2]|0)+2|0]<w[h+8|0]){continue}break}bc(e,20);break c}while(1){if(v[e+4>>2]<=(f|0)){break u}t[(v[h+4>>2]+B(f,3)|0)+2|0]=0;f=f+1|0;continue}}v:{while(1){if(w[h+8|0]<=g>>>0){break v}pc(e,8);b=g+h|0;M=b,N=pc(e,8),t[M+9|0]=N;f=pc(e,8);t[b+24|0]=f;if(v[e+128>>2]<=w[b+9|0]){bc(e,20);break c}g=g+1|0;if(v[e+264>>2]>(f&255)){continue}break}bc(e,20);break c}i=i+1|0;continue}break}M=e,N=pc(e,6)+1|0,v[M+408>>2]=N;h=e+412|0;j=0;w:{while(1){if(v[e+408>>2]<=(j|0)){break w}b=h+B(j,6)|0;M=b,N=pc(e,1),t[M|0]=N;M=b,N=pc(e,16),u[M+2>>1]=N;M=b,N=pc(e,16),u[M+4>>1]=N;f=pc(e,8);t[b+1|0]=f;if(x[b+2>>1]){bc(e,20);break c}if(x[b+4>>1]){bc(e,20);break c}j=j+1|0;if(v[e+400>>2]>(f&255)){continue}break}bc(e,20);break c}VH(e);v[e+992>>2]=0;h=E<<1;f=0;while(1){if(v[e+4>>2]>(f|0)){b=(f<<2)+e|0;M=b,N=be(e,v[e+116>>2]<<2),v[M+800>>2]=N;M=b,N=be(e,v[e+116>>2]<<1&2147483646),v[M+928>>2]=N;g=be(e,h);v[b+996>>2]=g;j=v[b+800>>2];if(g?!j|!v[b+928>>2]:1){bc(e,3);break c}Xb(j,0,v[e+116>>2]<<2);f=f+1|0;continue}break}f=0;if(!OH(e,0,v[e+112>>2])){break a}if(!OH(e,1,v[e+116>>2])){break a}v[e+104>>2]=v[e+112>>2];h=v[e+116>>2];v[e+108>>2]=h;b=v[e+264>>2];i=(b|0)>0?b:0;b=(h|0)/2|0;g=0;while(1){if((f|0)!=(i|0)){j=v[e+396>>2]+B(f,24)|0;k=v[j+4>>2];n=b>>>0>k>>>0?k:b;k=v[j>>2];j=(n-(b>>>0>k>>>0?k:b)>>>0)/y[j+8>>2]|0;g=(g|0)<(j|0)?j:g;f=f+1|0;continue}break}b=h<<1&2147483646;h=B(v[e+4>>2],(g<<2)+4|0);b=b>>>0>h>>>0?b:h;v[e+12>>2]=b;x:{if(!v[e+80>>2]){break x}h=v[e+92>>2];if((h|0)!=v[e+84>>2]){break p}if(h>>>0>=(b+v[e+88>>2]|0)+1512>>>0){break x}bc(e,3);break c}y:{if(v[e+1380>>2]==-1){v[e+52>>2]=w[e+48|0]?0:v[e+32>>2]-v[e+36>>2]|0;break y}v[e+52>>2]=0}f=1;break a}bc(e,20);break c}bc(e,3);break c}aa(7262,13048,4196,8731);L()}z:{if(f&255){j=vn(e,b);break z}j=be(e,b);v[g+8>>2]=j}if(!j){bc(e,3);break c}i=0;A:{if(!m){f=0;while(1){b=v[k>>2];if((f|0)>=(b|0)){break A}B:{C:{if(w[g+23|0]){if(!pc(e,1)){break C}}b=pc(e,5)+1|0;t[f+j|0]=b;if((b&255)!=32){i=i+1|0;break B}bc(e,20);break c}t[f+j|0]=255}f=f+1|0;continue}}h=pc(e,5);f=0;while(1){b=v[k>>2];if((f|0)>=(b|0)){break A}m=pc(e,Kl(b-f|0));h=h+1|0;if((h|0)>=32){bc(e,20);break c}b=f+m|0;if((b|0)>v[k>>2]){bc(e,20);break c}else{Xb(f+j|0,h,m);f=b;continue}}}D:{E:{F:{if(w[g+23|0]){if(b>>2>(i|0)){break F}if(v[e+16>>2]<(b|0)){v[e+16>>2]=b;b=v[k>>2]}b=be(e,b);v[g+8>>2]=b;if(!b){bc(e,3);break c}qc(b,j,v[k>>2]);_i(e,j,v[k>>2]);j=v[g+8>>2];t[g+23|0]=0;b=v[k>>2]}h=0;i=(b|0)>0?b:0;f=0;while(1){if((f|0)!=(i|0)){h=((w[f+j|0]-11&255)>>>0<244)+h|0;f=f+1|0;continue}break}v[g+2092>>2]=h;b=be(e,b<<2);v[g+32>>2]=b;if(b){m=g+2092|0;f=0;break E}bc(e,3);break c}v[g+2092>>2]=i;m=g+2092|0;G:{if(!i){f=0;h=0;break G}b=be(e,i);v[g+8>>2]=b;if(!b){bc(e,3);break c}b=vn(e,v[m>>2]<<2);v[g+32>>2]=b;if(!b){bc(e,3);break c}f=vn(e,v[m>>2]<<2);if(!f){break D}b=v[k>>2];h=v[m>>2]}b=(h<<3)+b|0;if(b>>>0<=y[e+16>>2]){break E}v[e+16>>2]=b}n=v[k>>2];b=0;h=jb-128|0;jb=h;o=Xb(h,0,128);h=(n|0)>0?n:0;while(1){H:{I:{if((b|0)!=(h|0)){if(w[b+j|0]==255){break I}h=b}if((h|0)==(n|0)){b=1;if(!v[g+2092>>2]){break H}aa(15552,13048,1103,7506);L()}b=h+j|0;i=w[b|0];if(i>>>0<32){MH(g,0,h,0,i,f);q=1;i=w[b|0]+1|0;b=1;J:{while(1){if((b|0)==(i|0)){K:while(1){L:{b=1;h=h+1|0;if((n|0)<=(h|0)){break H}F=h+j|0;i=w[F|0];if((i|0)==255){continue}b=i;if(b>>>0>=32){break L}while(1){if((b|0)<=0){b=0;break H}G=o+(b<<2)|0;p=v[G>>2];if(!p){b=b-1|0;continue}break}v[G>>2]=0;MH(g,Il(p),h,q,i,f);q=q+1|0;i=w[F|0];if((i|0)==(b|0)){continue}while(1){if((b|0)>=(i|0)){continue K}F=o+(i<<2)|0;if(v[F>>2]){break J}v[F>>2]=p+(1<<32-i);i=i-1|0;continue}}break}}else{v[o+(b<<2)>>2]=1<<32-b;b=b+1|0;continue}break}aa(15004,13048,1118,7506);L()}aa(15596,13048,1133,7506);L()}aa(15011,13048,1104,7506);L()}b=b+1|0;continue}break}jb=o+128|0;if(!b){if(w[g+23|0]){_i(e,f,0)}bc(e,20);break c}b=v[m>>2];if(b){b=be(e,(b<<2)+4|0);v[g+2084>>2]=b;if(!b){bc(e,3);break c}b=be(e,(v[m>>2]<<2)+4|0);v[g+2088>>2]=b;if(!b){bc(e,3);break c}v[g+2088>>2]=b+4;v[b>>2]=-1;b=0;i=0;M:{N:{O:{if(w[g+23|0]){while(1){i=v[g+2092>>2];if((i|0)<=(b|0)){break O}h=b<<2;M=h+v[g+2084>>2]|0,N=Il(v[h+v[g+32>>2]>>2]),v[M>>2]=N;b=b+1|0;continue}}while(1){if(v[g+4>>2]>(b|0)){if(LH(w[g+23|0],w[b+j|0])){M=v[g+2084>>2]+(i<<2)|0,N=Il(v[v[g+32>>2]+(b<<2)>>2]),v[M>>2]=N;i=i+1|0}b=b+1|0;continue}break}if(v[g+2092>>2]!=(i|0)){break N}}PH(v[g+2084>>2],i,1039);v[v[g+2084>>2]+(v[g+2092>>2]<<2)>>2]=-1;h=0;b=v[g+(w[g+23|0]?2092:4)>>2];p=(b|0)>0?b:0;P:{while(1){if((h|0)!=(p|0)){b=h;i=w[g+23|0];b=i?v[(b<<2)+f>>2]:b;F=w[b+j|0];Q:{if(!LH(i,F)){break Q}G=h<<2;n=Il(v[G+v[g+32>>2]>>2]);b=v[g+2092>>2];i=0;while(1){if((b|0)>=2){o=b>>>1|0;J=o+i|0;q=n>>>0<y[v[g+2084>>2]+(J<<2)>>2];b=q?o:b-o|0;i=q?i:J;continue}break}b=i<<2;if((n|0)!=v[b+v[g+2084>>2]>>2]){break P}if(w[g+23|0]){v[b+v[g+2088>>2]>>2]=v[f+G>>2];t[v[g+8>>2]+i|0]=F;break Q}v[b+v[g+2088>>2]>>2]=h}h=h+1|0;continue}break}break M}aa(12089,13048,1230,9874);L()}aa(7447,13048,1200,9874);L()}}if(w[g+23|0]){_i(e,f,v[m>>2]<<2);_i(e,v[g+32>>2],v[m>>2]<<2);_i(e,j,v[k>>2]);v[g+32>>2]=0}i=g;b=0;f=0;while(1){if((b|0)!=1024){u[(i+(b<<1)|0)+36>>1]=65535;b=b+1|0;continue}break}b=v[i+(w[i+23|0]?2092:4)>>2];b=(b|0)<32767?b:32767;h=(b|0)>0?b:0;while(1){if((f|0)!=(h|0)){R:{if(w[v[i+8>>2]+f|0]>10){break R}S:{if(w[i+23|0]){b=Il(v[v[i+2084>>2]+(f<<2)>>2]);break S}b=v[v[i+32>>2]+(f<<2)>>2]}while(1){if(b>>>0>1023){break R}u[(i+(b<<1)|0)+36>>1]=f;b=(1<<w[v[i+8>>2]+f|0])+b|0;continue}}f=f+1|0;continue}break}b=pc(e,4);t[i+21|0]=b;b=b&255;if(b>>>0>=3){bc(e,20);break c}if(b){M=i,O=NH(pc(e,32)),z[M+12>>2]=O;M=i,O=NH(pc(e,32)),z[M+16>>2]=O;M=i,N=pc(e,4)+1|0,t[M+20|0]=N;M=i,N=pc(e,1),t[M+22|0]=N;f=v[i>>2];h=v[k>>2];T:{if(w[i+21|0]==1){A=H(ts(+C(C(lp(+C(h|0)))/C(f|0))));U:{if(D(A)<2147483648){b=~~A;break U}b=-2147483648}A=+(f|0);K=H(Nj(+C(C(b|0)+C(1)),A));V:{if(D(K)<2147483648){f=~~K;break V}f=-2147483648}b=((f|0)<=(h|0))+b|0;s=C(b|0);if(Nj(+C(s+C(1)),A)<=+(h|0)){f=-1}else{A=H(Nj(+s,A));W:{if(D(A)<2147483648){f=~~A;break W}f=-2147483648}f=(f|0)>(h|0)?-1:b}if((f|0)>=0){break T}bc(e,20);break c}f=B(f,h)}v[i+24>>2]=f;if(!f){bc(e,20);break c}n=vn(e,f<<1);if(!n){break h}f=0;while(1){j=v[i+24>>2];if((j|0)>(f|0)){b=pc(e,w[i+20|0]);if((b|0)==-1){_i(e,n,v[i+24>>2]<<1);bc(e,20);break c}else{u[n+(f<<1)>>1]=b;f=f+1|0;continue}}break}X:{Y:{if(w[i+21|0]==1){o=w[i+23|0];Z:{if(o){f=v[m>>2];if(f){break Z}break X}f=v[k>>2]}b=be(e,B(v[i>>2],f)<<2);v[i+28>>2]=b;if(!b){_i(e,n,v[i+24>>2]<<1);bc(e,3);break c}h=0;b=v[(o?m:k)>>2];m=(b|0)>0?b:0;q=i+2088|0;s=C(0);while(1){if((h|0)==(m|0)){break Y}g=h;g=o?v[v[q>>2]+(g<<2)>>2]:g;j=v[i>>2];f=0;b=1;while(1){if((f|0)<(j|0)){I=C(s+C(C(C(x[n+(((g>>>0)/(b>>>0)>>>0)%y[i+24>>2]<<1)>>1])*z[i+16>>2])+z[i+12>>2]));z[v[i+28>>2]+(B(h,j)+f<<2)>>2]=I;s=w[i+22|0]?I:s;f=f+1|0;j=v[i>>2];if((f|0)>=(j|0)){continue}k=v[i+24>>2];Sia(k,0,b,0);if(mb){_i(e,n,k<<1);bc(e,20);break c}else{b=B(b,k);continue}}break}h=h+1|0;continue}}b=be(e,j<<2);v[i+28>>2]=b;if(!b){break g}f=0;s=C(0);while(1){j=v[i+24>>2];if((j|0)<=(f|0)){break X}I=C(s+C(C(C(x[n+(f<<1)>>1])*z[i+16>>2])+z[i+12>>2]));z[v[i+28>>2]+(f<<2)>>2]=I;s=w[i+22|0]?I:s;f=f+1|0;continue}}t[i+21|0]=2;j=v[i+24>>2]}_i(e,n,j<<1)}E=E+1|0;continue}break}bc(e,3);break c}bc(e,3);break c}_i(e,n,v[i+24>>2]<<1);bc(e,3);break c}bc(e,20);break c}bc(e,3);break c}t[b+v[v[e+28>>2]+(h<<2)>>2]|0]=0;h=h+1|0;continue}}bc(e,3);break c}bc(e,20)}f=0}jb=l+1024|0;_:{$:{if(!f){v[d>>2]=v[r+104>>2]?1:v[r+108>>2];break $}b=be(r+8|0,1512);if(b){M=c,N=v[qc(b,r+8|0,1512)+32>>2]-a|0,v[M>>2]=N;v[d>>2]=0;break _}}YH(r+8|0);b=0}jb=r+1520|0;return b}function FG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,u=0,x=0,z=0,A=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,O=0;s=jb-48|0;jb=s;a:{if(c>>>0<=2){c=c<<2;I=v[c+78364>>2];J=v[c+78352>>2];while(1){c=v[b+4>>2];b:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break b}c=od(b)}if(Ak(c)){continue}break}o=1;c:{d:{switch(c-43|0){case 0:case 2:break d;default:break c}}o=(c|0)==45?-1:1;c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break c}c=od(b)}e:{f:{while(1){if(t[g+4913|0]==(c|32)){g:{if(g>>>0>6){break g}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break g}c=od(b)}g=g+1|0;if((g|0)!=8){continue}break f}break}if((g|0)!=3){if((g|0)==8){break f}if(!d|g>>>0<4){break e}if((g|0)==8){break f}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(!d|g>>>0<4){break f}c=(c|0)<0;while(1){if(!c){v[b+4>>2]=v[b+4>>2]-1}g=g-1|0;if(g>>>0>3){continue}break}}i=jb-16|0;jb=i;l=(p(C(C(o|0)*C(N))),j(2));b=l&2147483647;h:{if(b-8388608>>>0<=2130706431){r=b<<25;c=(b>>>7|0)+1065353216|0;break h}r=l<<25;c=l>>>7|2147418112;if(b>>>0>=2139095040){break h}r=0;c=0;if(!b){break h}c=b;b=E(b);vf(i,c,0,0,0,b+81|0);k=v[i>>2];h=v[i+4>>2];r=v[i+8>>2];c=v[i+12>>2]^65536|16265-b<<16}v[s>>2]=k;v[s+4>>2]=h;v[s+8>>2]=r;v[s+12>>2]=l&-2147483648|c;jb=i+16|0;k=v[s+8>>2];h=v[s+12>>2];i=v[s>>2];l=v[s+4>>2];break a}i:{j:{k:{if(g){break k}g=0;while(1){if(t[g+9870|0]!=(c|32)){break k}l:{if(g>>>0>1){break l}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break l}c=od(b)}g=g+1|0;if((g|0)!=3){continue}break}break j}m:{switch(g|0){case 0:n:{if((c|0)!=48){break n}g=v[b+4>>2];o:{if((g|0)!=v[b+104>>2]){v[b+4>>2]=g+1;g=w[g|0];break o}g=od(b)}if((g&-33)==88){g=d;c=0;f=jb-432|0;jb=f;p:{q:{d=v[b+4>>2];if((d|0)!=v[b+104>>2]){v[b+4>>2]=d+1;c=w[d|0];break q}d=0;break p}d=1}while(1){r:{s:{t:{u:{v:{w:{x:{y:{if(!d){c=od(b);break y}if((c|0)!=48){l=1073676288;if((c|0)==46){break w}break v}d=v[b+4>>2];if((d|0)==v[b+104>>2]){break x}n=1;v[b+4>>2]=d+1;c=w[d|0]}d=1;continue}n=1;break s}c=v[b+4>>2];z:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break z}c=od(b)}if((c|0)==48){break u}F=1}break t}while(1){c=r;r=c-1|0;u=u-!c|0;F=1;c=v[b+4>>2];A:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break A}c=od(b)}if((c|0)==48){continue}break}n=1}while(1){e=c|32;B:{C:{M=c-48|0;if(M>>>0<10){break C}if(!((c|0)==46|e-97>>>0<6)){d=c;break r}d=46;if((c|0)!=46){break C}if(F){break r}F=1;r=k;u=h;break B}c=(c|0)>57?e-87|0:M;D:{if((h|0)<=0&k>>>0<=7|(h|0)<0){x=c+(x<<4)|0;break D}if(!h&k>>>0<=28){Mg(f+48|0,c);Fd(f+32|0,G,H,i,l,0,0,0,1073414144);G=v[f+32>>2];H=v[f+36>>2];i=v[f+40>>2];l=v[f+44>>2];Fd(f+16|0,v[f+48>>2],v[f+52>>2],v[f+56>>2],v[f+60>>2],G,H,i,l);yg(f,v[f+16>>2],v[f+20>>2],v[f+24>>2],v[f+28>>2],m,q,A,D);A=v[f+8>>2];D=v[f+12>>2];m=v[f>>2];q=v[f+4>>2];break D}if(!c|z){break D}Fd(f+80|0,G,H,i,l,0,0,0,1073610752);yg(f- -64|0,v[f+80>>2],v[f+84>>2],v[f+88>>2],v[f+92>>2],m,q,A,D);A=v[f+72>>2];D=v[f+76>>2];z=1;m=v[f+64>>2];q=v[f+68>>2]}c=k+1|0;h=c?h:h+1|0;k=c;n=1}c=v[b+4>>2];if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0]}else{c=od(b)}continue}}d=0;continue}break}E:{if(!n){c=v[b+116>>2];F:{G:{if((c|0)>0|(c|0)>=0){c=v[b+4>>2];v[b+4>>2]=c-1;if(!g){break G}v[b+4>>2]=c-2;if(!F){break F}v[b+4>>2]=c-3;break F}if(g){break F}}ci(b,0,0)}Oi(f+96|0,+(o|0)*0);m=v[f+96>>2];q=v[f+100>>2];c=v[f+108>>2];b=v[f+104>>2];break E}if((h|0)<=0&k>>>0<=7|(h|0)<0){i=k;l=h;while(1){x=x<<4;c=i+1|0;l=c?l:l+1|0;i=c;if((c|0)!=8|l){continue}break}}H:{I:{J:{if((d&-33)==80){i=EG(b,g);c=mb;l=c;if(i|(c|0)!=-2147483648){break H}if(g){c=v[b+116>>2];if((c|0)>0|(c|0)>=0){break J}break I}m=0;q=0;ci(b,0,0);c=0;b=0;break E}i=0;l=0;if(v[b+116>>2]<0){break H}}v[b+4>>2]=v[b+4>>2]-1}i=0;l=0}if(!x){Oi(f+112|0,+(o|0)*0);m=v[f+112>>2];q=v[f+116>>2];c=v[f+124>>2];b=v[f+120>>2];break E}b=F?r:k;h=(F?u:h)<<2|b>>>30;b=i+(b<<2)|0;d=h+l|0;d=b>>>0<i>>>0?d+1|0:d;k=b-32|0;h=d-(b>>>0<32)|0;b=h;if(k>>>0>0-I>>>0&(b|0)>=0|(b|0)>0){v[115772]=68;Mg(f+160|0,o);Fd(f+144|0,v[f+160>>2],v[f+164>>2],v[f+168>>2],v[f+172>>2],-1,-1,-1,2147418111);Fd(f+128|0,v[f+144>>2],v[f+148>>2],v[f+152>>2],v[f+156>>2],-1,-1,-1,2147418111);m=v[f+128>>2];q=v[f+132>>2];c=v[f+140>>2];b=v[f+136>>2];break E}b=I-226|0;c=b>>31;if((h|0)>=(c|0)&b>>>0<=k>>>0|(c|0)<(h|0)){if((x|0)>=0){while(1){yg(f+416|0,m,q,A,D,0,0,0,-1073807360);c=YR(m,q,A,D,1073610752);b=(c|0)<0;yg(f+400|0,m,q,A,D,b?m:v[f+416>>2],b?q:v[f+420>>2],b?A:v[f+424>>2],b?D:v[f+428>>2]);b=k;k=b-1|0;h=h-!b|0;A=v[f+408>>2];D=v[f+412>>2];m=v[f+400>>2];q=v[f+404>>2];x=x<<1|(c|0)>=0;if((x|0)>=0){continue}break}}d=h-((I>>31)+(k>>>0<I>>>0)|0)|0;b=(k-I|0)+32|0;d=b>>>0<32?d+1|0:d;c=b>>>0<J>>>0&(d|0)<=0|(d|0)<0?(b|0)>0?b:0:J;K:{if((c|0)>=113){Mg(f+384|0,o);r=v[f+392>>2];u=v[f+396>>2];G=v[f+384>>2];H=v[f+388>>2];h=0;b=0;break K}Oi(f+352|0,Dj(1,144-c|0));Mg(f+336|0,o);G=v[f+336>>2];H=v[f+340>>2];r=v[f+344>>2];u=v[f+348>>2];HG(f+368|0,v[f+352>>2],v[f+356>>2],v[f+360>>2],v[f+364>>2],G,H,r,u);K=v[f+376>>2];L=v[f+380>>2];h=v[f+372>>2];b=v[f+368>>2]}c=!(x&1)&((km(m,q,A,D,0,0,0,0)|0)!=0&(c|0)<32);an(f+320|0,c+x|0);Fd(f+304|0,G,H,r,u,v[f+320>>2],v[f+324>>2],v[f+328>>2],v[f+332>>2]);d=b;yg(f+272|0,v[f+304>>2],v[f+308>>2],v[f+312>>2],v[f+316>>2],b,h,K,L);b=c;Fd(f+288|0,G,H,r,u,b?0:m,b?0:q,b?0:A,b?0:D);yg(f+256|0,v[f+288>>2],v[f+292>>2],v[f+296>>2],v[f+300>>2],v[f+272>>2],v[f+276>>2],v[f+280>>2],v[f+284>>2]);yx(f+240|0,v[f+256>>2],v[f+260>>2],v[f+264>>2],v[f+268>>2],d,h,K,L);b=v[f+240>>2];c=v[f+244>>2];d=v[f+248>>2];h=v[f+252>>2];if(!km(b,c,d,h,0,0,0,0)){v[115772]=68}GG(f+224|0,b,c,d,h,k);m=v[f+224>>2];q=v[f+228>>2];c=v[f+236>>2];b=v[f+232>>2];break E}v[115772]=68;Mg(f+208|0,o);Fd(f+192|0,v[f+208>>2],v[f+212>>2],v[f+216>>2],v[f+220>>2],0,0,0,65536);Fd(f+176|0,v[f+192>>2],v[f+196>>2],v[f+200>>2],v[f+204>>2],0,0,0,65536);m=v[f+176>>2];q=v[f+180>>2];c=v[f+188>>2];b=v[f+184>>2]}v[s+16>>2]=m;v[s+20>>2]=q;v[s+24>>2]=b;v[s+28>>2]=c;jb=f+432|0;k=v[s+24>>2];h=v[s+28>>2];i=v[s+16>>2];l=v[s+20>>2];break a}if(v[b+116>>2]<0){break n}v[b+4>>2]=v[b+4>>2]-1}g=b;f=o;x=d;d=0;o=0;e=jb-8976|0;jb=e;K=I+J|0;L=0-K|0;L:{M:{while(1){if((c|0)!=48){N:{if((c|0)!=46){break L}b=v[g+4>>2];if((b|0)==v[g+104>>2]){break N}v[g+4>>2]=b+1;c=w[b|0];break M}}else{b=v[g+4>>2];if((b|0)!=v[g+104>>2]){d=1;v[g+4>>2]=b+1;c=w[b|0]}else{d=1;c=od(g)}continue}break}c=od(g)}n=1;if((c|0)!=48){break L}while(1){b=k;k=b-1|0;h=h-!b|0;b=v[g+4>>2];O:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break O}c=od(g)}if((c|0)==48){continue}break}d=1}v[e+784>>2]=0;P:{Q:{b=(c|0)==46;m=c-48|0;R:{S:{T:{U:{if(b|m>>>0<=9){while(1){V:{if(b&1){if(!n){k=i;h=l;n=1;break V}b=!d;break U}b=i+1|0;l=b?l:l+1|0;i=b;if((o|0)<=2044){F=(c|0)==48?F:i;b=(e+784|0)+(o<<2)|0;if(z){m=(B(v[b>>2],10)+c|0)-48|0}v[b>>2]=m;d=1;c=z+1|0;b=(c|0)==9;z=b?0:c;o=b+o|0;break V}if((c|0)==48){break V}v[e+8960>>2]=v[e+8960>>2]|1;F=18396}b=v[g+4>>2];W:{if((b|0)!=v[g+104>>2]){v[g+4>>2]=b+1;c=w[b|0];break W}c=od(g)}b=(c|0)==46;m=c-48|0;if(b|m>>>0<10){continue}break}}k=n?k:i;h=n?h:l;if(!(!d|(c&-33)!=69)){m=EG(g,x);b=mb;q=b;X:{if(m|(b|0)!=-2147483648){break X}if(!x){break R}m=0;q=0;if(v[g+116>>2]<0){break X}v[g+4>>2]=v[g+4>>2]-1}if(!d){break S}h=h+q|0;b=k+m|0;h=b>>>0<m>>>0?h+1|0:h;k=b;break Q}b=!d;if((c|0)<0){break T}}if(v[g+116>>2]<0){break T}v[g+4>>2]=v[g+4>>2]-1}if(!b){break Q}}v[115772]=28}i=0;l=0;ci(g,0,0);c=0;b=0;break P}b=v[e+784>>2];if(!b){Oi(e,+(f|0)*0);i=v[e>>2];l=v[e+4>>2];c=v[e+12>>2];b=v[e+8>>2];break P}if(!((k|0)!=(i|0)|(h|0)!=(l|0)|(i>>>0>9&(l|0)>=0|(l|0)>0)|(b>>>J|0?(J|0)<=30:0))){Mg(e+48|0,f);an(e+32|0,b);Fd(e+16|0,v[e+48>>2],v[e+52>>2],v[e+56>>2],v[e+60>>2],v[e+32>>2],v[e+36>>2],v[e+40>>2],v[e+44>>2]);i=v[e+16>>2];l=v[e+20>>2];c=v[e+28>>2];b=v[e+24>>2];break P}if(k>>>0>(I|0)/-2>>>0&(h|0)>=0|(h|0)>0){v[115772]=68;Mg(e+96|0,f);Fd(e+80|0,v[e+96>>2],v[e+100>>2],v[e+104>>2],v[e+108>>2],-1,-1,-1,2147418111);Fd(e- -64|0,v[e+80>>2],v[e+84>>2],v[e+88>>2],v[e+92>>2],-1,-1,-1,2147418111);i=v[e+64>>2];l=v[e+68>>2];c=v[e+76>>2];b=v[e+72>>2];break P}b=I-226|0;c=k>>>0<b>>>0;b=b>>31;if(c&(h|0)<=(b|0)|(b|0)>(h|0)){v[115772]=68;Mg(e+144|0,f);Fd(e+128|0,v[e+144>>2],v[e+148>>2],v[e+152>>2],v[e+156>>2],0,0,0,65536);Fd(e+112|0,v[e+128>>2],v[e+132>>2],v[e+136>>2],v[e+140>>2],0,0,0,65536);i=v[e+112>>2];l=v[e+116>>2];c=v[e+124>>2];b=v[e+120>>2];break P}if(z){if((z|0)<=8){b=(e+784|0)+(o<<2)|0;g=v[b>>2];while(1){g=B(g,10);z=z+1|0;if((z|0)!=9){continue}break}v[b>>2]=g}o=o+1|0}Y:{n=k;if((F|0)>(k|0)|(F|0)>8|(k|0)>17){break Y}if((n|0)==9){Mg(e+192|0,f);an(e+176|0,v[e+784>>2]);Fd(e+160|0,v[e+192>>2],v[e+196>>2],v[e+200>>2],v[e+204>>2],v[e+176>>2],v[e+180>>2],v[e+184>>2],v[e+188>>2]);i=v[e+160>>2];l=v[e+164>>2];c=v[e+172>>2];b=v[e+168>>2];break P}if((n|0)<=8){Mg(e+272|0,f);an(e+256|0,v[e+784>>2]);Fd(e+240|0,v[e+272>>2],v[e+276>>2],v[e+280>>2],v[e+284>>2],v[e+256>>2],v[e+260>>2],v[e+264>>2],v[e+268>>2]);Mg(e+224|0,v[(0-n<<2)+78352>>2]);eP(e+208|0,v[e+240>>2],v[e+244>>2],v[e+248>>2],v[e+252>>2],v[e+224>>2],v[e+228>>2],v[e+232>>2],v[e+236>>2]);i=v[e+208>>2];l=v[e+212>>2];c=v[e+220>>2];b=v[e+216>>2];break P}b=(J+B(n,-3)|0)+27|0;c=v[e+784>>2];if(c>>>b|0?(b|0)<=30:0){break Y}Mg(e+352|0,f);an(e+336|0,c);Fd(e+320|0,v[e+352>>2],v[e+356>>2],v[e+360>>2],v[e+364>>2],v[e+336>>2],v[e+340>>2],v[e+344>>2],v[e+348>>2]);Mg(e+304|0,v[(n<<2)+78280>>2]);Fd(e+288|0,v[e+320>>2],v[e+324>>2],v[e+328>>2],v[e+332>>2],v[e+304>>2],v[e+308>>2],v[e+312>>2],v[e+316>>2]);i=v[e+288>>2];l=v[e+292>>2];c=v[e+300>>2];b=v[e+296>>2];break P}while(1){c=o;o=c-1|0;if(!v[(e+784|0)+(o<<2)>>2]){continue}break}b=(n|0)%9|0;Z:{if(!b){z=0;b=0;break Z}z=0;d=(n|0)<0?b+9|0:b;_:{if(!c){b=0;c=0;break _}k=v[(0-d<<2)+78352>>2];l=1e9/(k|0)|0;m=0;g=0;b=0;while(1){h=m;i=(e+784|0)+(g<<2)|0;o=v[i>>2];m=(o>>>0)/(k>>>0)|0;h=h+m|0;v[i>>2]=h;h=!h&(b|0)==(g|0);b=h?b+1&2047:b;n=h?n-9|0:n;m=B(l,o-B(k,m)|0);g=g+1|0;if((g|0)!=(c|0)){continue}break}if(!m){break _}v[(e+784|0)+(c<<2)>>2]=m;c=c+1|0}n=(n-d|0)+9|0}while(1){o=(e+784|0)+(b<<2)|0;g=(n|0)<36;$:{while(1){aa:{if(g){break aa}if((n|0)!=36){break $}if(y[o>>2]<=10384592){break aa}n=36;break $}d=c+2047|0;m=0;while(1){i=d&2047;x=(e+784|0)+(i<<2)|0;d=v[x>>2];l=d>>>3|0;h=d<<29;k=h+m|0;d=l;d=h>>>0>k>>>0?d+1|0:d;h=d;if(!h&k>>>0<1000000001){m=0}else{m=Via(k,h,1e9,0);d=Sia(m,mb,-1e9,-1)+k|0;k=d}v[x>>2]=k;c=(i|0)!=(c-1&2047)?c:(b|0)==(i|0)?c:k?c:i;d=i-1|0;if((b|0)!=(i|0)){continue}break}z=z-29|0;if(!m){continue}break}b=b-1&2047;if((c|0)==(b|0)){d=e+784|0;k=d+((c+2046&2047)<<2)|0;c=c-1&2047;v[k>>2]=v[k>>2]|v[d+(c<<2)>>2]}n=n+9|0;v[(e+784|0)+(b<<2)>>2]=m;continue}break}ba:{ca:while(1){k=c+1&2047;l=(e+784|0)+((c-1&2047)<<2)|0;while(1){h=(n|0)>45?9:1;da:{while(1){d=b;g=0;ea:{while(1){fa:{b=d+g&2047;if((b|0)==(c|0)){break fa}b=v[(e+784|0)+(b<<2)>>2];i=v[(g<<2)+78304>>2];if(b>>>0<i>>>0){break fa}if(b>>>0>i>>>0){break ea}g=g+1|0;if((g|0)!=4){continue}}break}if((n|0)!=36){break ea}k=0;h=0;g=0;i=0;l=0;while(1){b=d+g&2047;if((b|0)==(c|0)){c=c+1&2047;v[((c<<2)+e|0)+780>>2]=0}an(e+768|0,v[(e+784|0)+(b<<2)>>2]);Fd(e+752|0,k,h,i,l,0,0,1342177280,1075633366);yg(e+736|0,v[e+752>>2],v[e+756>>2],v[e+760>>2],v[e+764>>2],v[e+768>>2],v[e+772>>2],v[e+776>>2],v[e+780>>2]);i=v[e+744>>2];l=v[e+748>>2];k=v[e+736>>2];h=v[e+740>>2];g=g+1|0;if((g|0)!=4){continue}break}Mg(e+720|0,f);Fd(e+704|0,k,h,i,l,v[e+720>>2],v[e+724>>2],v[e+728>>2],v[e+732>>2]);i=v[e+712>>2];l=v[e+716>>2];k=0;h=0;m=v[e+704>>2];q=v[e+708>>2];x=z+113|0;o=x-I|0;n=(o|0)<(J|0);b=n?(o|0)>0?o:0:J;if((b|0)<=112){break da}break ba}z=h+z|0;b=c;if((d|0)==(b|0)){continue}break}o=1e9>>>h|0;m=-1<<h^-1;g=0;b=d;while(1){i=g;g=(e+784|0)+(d<<2)|0;x=v[g>>2];i=i+(x>>>h|0)|0;v[g>>2]=i;i=!i&(b|0)==(d|0);b=i?b+1&2047:b;n=i?n-9|0:n;g=B(o,m&x);d=d+1&2047;if((d|0)!=(c|0)){continue}break}if(!g){continue}if((b|0)!=(k|0)){v[(e+784|0)+(c<<2)>>2]=g;c=k;continue ca}v[l>>2]=v[l>>2]|1;continue}break}break}Oi(e+656|0,Dj(1,225-b|0));HG(e+688|0,v[e+656>>2],v[e+660>>2],v[e+664>>2],v[e+668>>2],m,q,i,l);G=v[e+696>>2];H=v[e+700>>2];A=v[e+688>>2];D=v[e+692>>2];Oi(e+640|0,Dj(1,113-b|0));oO(e+672|0,m,q,i,l,v[e+640>>2],v[e+644>>2],v[e+648>>2],v[e+652>>2]);k=v[e+672>>2];h=v[e+676>>2];r=v[e+680>>2];u=v[e+684>>2];yx(e+624|0,m,q,i,l,k,h,r,u);yg(e+608|0,A,D,G,H,v[e+624>>2],v[e+628>>2],v[e+632>>2],v[e+636>>2]);i=v[e+616>>2];l=v[e+620>>2];m=v[e+608>>2];q=v[e+612>>2]}g=d+4&2047;ga:{if((g|0)==(c|0)){break ga}g=v[(e+784|0)+(g<<2)>>2];ha:{if(g>>>0<=499999999){if(!g&(d+5&2047)==(c|0)){break ha}Oi(e+496|0,+(f|0)*.25);yg(e+480|0,k,h,r,u,v[e+496>>2],v[e+500>>2],v[e+504>>2],v[e+508>>2]);r=v[e+488>>2];u=v[e+492>>2];k=v[e+480>>2];h=v[e+484>>2];break ha}if((g|0)!=5e8){Oi(e+592|0,+(f|0)*.75);yg(e+576|0,k,h,r,u,v[e+592>>2],v[e+596>>2],v[e+600>>2],v[e+604>>2]);r=v[e+584>>2];u=v[e+588>>2];k=v[e+576>>2];h=v[e+580>>2];break ha}O=+(f|0);if((d+5&2047)==(c|0)){Oi(e+528|0,O*.5);yg(e+512|0,k,h,r,u,v[e+528>>2],v[e+532>>2],v[e+536>>2],v[e+540>>2]);r=v[e+520>>2];u=v[e+524>>2];k=v[e+512>>2];h=v[e+516>>2];break ha}Oi(e+560|0,O*.75);yg(e+544|0,k,h,r,u,v[e+560>>2],v[e+564>>2],v[e+568>>2],v[e+572>>2]);r=v[e+552>>2];u=v[e+556>>2];k=v[e+544>>2];h=v[e+548>>2]}if((b|0)>111){break ga}oO(e+464|0,k,h,r,u,0,0,0,1073676288);if(km(v[e+464>>2],v[e+468>>2],v[e+472>>2],v[e+476>>2],0,0,0,0)){break ga}yg(e+448|0,k,h,r,u,0,0,0,1073676288);r=v[e+456>>2];u=v[e+460>>2];k=v[e+448>>2];h=v[e+452>>2]}yg(e+432|0,m,q,i,l,k,h,r,u);yx(e+416|0,v[e+432>>2],v[e+436>>2],v[e+440>>2],v[e+444>>2],A,D,G,H);i=v[e+424>>2];l=v[e+428>>2];m=v[e+416>>2];q=v[e+420>>2];ia:{if((-2-K|0)>=(x&2147483647)){break ia}v[e+408>>2]=i;v[e+412>>2]=l&2147483647;v[e+400>>2]=m;v[e+404>>2]=q;Fd(e+384|0,m,q,i,l,0,0,0,1073610752);d=YR(v[e+400>>2],v[e+404>>2],v[e+408>>2],v[e+412>>2],1081081856);c=(d|0)<0;i=c?i:v[e+392>>2];l=c?l:v[e+396>>2];m=c?m:v[e+384>>2];q=c?q:v[e+388>>2];z=((d|0)>=0)+z|0;if((km(k,h,r,u,0,0,0,0)|0)!=0&(c?n:n&(b|0)!=(o|0))?0:(L|0)>=(z+110|0)){break ia}v[115772]=68}GG(e+368|0,m,q,i,l,z);i=v[e+368>>2];l=v[e+372>>2];c=v[e+380>>2];b=v[e+376>>2]}v[s+40>>2]=b;v[s+44>>2]=c;v[s+32>>2]=i;v[s+36>>2]=l;jb=e+8976|0;k=v[s+40>>2];h=v[s+44>>2];i=v[s+32>>2];l=v[s+36>>2];break a;case 3:break j;default:break m}}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}break i}ja:{c=v[b+4>>2];ka:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break ka}c=od(b)}if((c|0)==40){g=1;break ja}h=2147450880;if(v[b+116>>2]<0){break a}v[b+4>>2]=v[b+4>>2]-1;break a}while(1){c=v[b+4>>2];la:{if((c|0)!=v[b+104>>2]){v[b+4>>2]=c+1;c=w[c|0];break la}c=od(b)}if(!(!(c-48>>>0<10|c-65>>>0<26|(c|0)==95)&c-97>>>0>=26)){g=g+1|0;continue}break}h=2147450880;if((c|0)==41){break a}c=v[b+116>>2];if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}ma:{if(d){if(g){break ma}break a}break i}while(1){g=g-1|0;if((c|0)>0|(c|0)>=0){v[b+4>>2]=v[b+4>>2]-1}if(g){continue}break}break a}v[115772]=28;ci(b,0,0)}h=0}v[a>>2]=i;v[a+4>>2]=l;v[a+8>>2]=k;v[a+12>>2]=h;jb=s+48|0}function Dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;d=jb-384|0;jb=d;Ac(b);a:{if(!po(b,d+368|0)){break a}if(!ZQ(d+368|0)){break a}q=ie(d+344|0,b);o=Qb(d+328|0);b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if(!c){v[23296]=0;R(588,d+40|0,q|0);b=v[23296];v[23296]=0;if((b|0)==1){break z}break B}v[23296]=0;R(589,d+40|0,q|0);b=v[23296];v[23296]=0;if((b|0)==1){break A}}b=d+40|0;Ft(o,b);_d(b);v[23296]=0;U(590,b|0,o|0,1413891155);b=v[23296];v[23296]=0;C:{D:{if((b|0)!=1){v[23296]=0;e=Q(591,d+40|0,13970)|0;b=v[23296];v[23296]=0;if((b|0)==1){break D}Ab(d+40|0);if(!c){break b}if(!(e^1)){break C}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;Ab(d+40|0);break c}v[23296]=0;R(234,a|0,4194304);b=v[23296];v[23296]=0;if((b|0)==1){break d}v[a+480208>>2]=12;v[23296]=0;U(590,d+304|0,o|0,1280592212);b=v[23296];v[23296]=0;if((b|0)==1){break e}v[23296]=0;b=T(148,v[d+304>>2])|0;e=v[23296];v[23296]=0;if((e|0)==1){break g}v[23296]=0;U(391,d+304|0,a+1298308|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break g}i=a+484360|0;j=a+484376|0;Hc(Zb(v[i>>2],w[j|0]));k=Qb(d+288|0);t[d+287|0]=0;v[23296]=0;U(592,d+272|0,o|0,1196314451);b=v[23296];v[23296]=0;if((b|0)==1){break i}A=d,C=Eb(v[d+272>>2]),v[A+264>>2]=C;p=d+252|0;r=Eb(v[d+276>>2]);E:{F:{while(1){b=v[d+264>>2];if(!Rb(b,r)){break F}l=ie(d+40|0,b);v[23296]=0;e=Q(593,l|0,d+24|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break E}b=1;if(!(!e|w[d+33|0]!=1)){A=a,C=Xd(w[d+34|0],x[a+480188>>1],127),u[A+480188>>1]=C;v[23296]=0;h=T(594,d+208|0)|0;b=v[23296];v[23296]=0;G:{H:{I:{J:{K:{if((b|0)!=1){b=d+192|0;df(b,d+24|0,9,1);v[23296]=0;R(210,d+160|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break K}b=d+8|0;gc(b,p,10);e=b;b=d+160|0;nl(e,b);yb(b);b=Zb(v[a+484360>>2],w[j|0]);if(uc(v[b>>2],v[b+4>>2])){break H}v[23296]=0;b=T(259,i|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break J}if((b|0)!=255){break I}b=2;break G}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=Zb(v[a+484360>>2],w[j|0])}v[23296]=0;U(5,d+160|0,5,p|0);e=v[23296];v[23296]=0;if((e|0)==1){break n}v[23296]=0;R(260,b|0,d+160|0);b=v[23296];v[23296]=0;if((b|0)==1){break o}zb(d+160|0);v[23296]=0;R(589,d+192|0,l|0);b=v[23296];v[23296]=0;if((b|0)==1){break p}A=d,C=Eb(v[d+192>>2]),v[A+184>>2]=C;n=Eb(v[d+196>>2]);L:{M:{while(1){b=v[d+184>>2];if(!Rb(b,n)){b=0;if(x[d+244>>1]==65535|x[d+246>>1]==65535){break L}b=w[j|0];e=v[a+484360>>2];v[23296]=0;Y(595,Zb(e,b)|0);b=v[23296];v[23296]=0;if((b|0)!=1){v[23296]=0;R(596,k|0,h|0);e=v[23296];v[23296]=0;b=0;if((e|0)!=1){break L}}b=P()|0;O()|0;break m}to(d+160|0,b);yi(d+8|0,v[b>>2],v[b+4>>2]);e=1;N:{g=v[d+8>>2];O:{if((g|0)!=1212960847){b=0;if((g|0)!=1312903248){break O}while(1){if(x[a+480188>>1]<=b>>>0){break O}v[23296]=0;g=W(144,v[d+160>>2],v[d+168>>2],2)|0;f=v[23296];v[23296]=0;if((f|0)!=1){if(!g){break O}v[23296]=0;R(247,d+136|0,d+160|0);g=v[23296];v[23296]=0;P:{Q:{R:{S:{if((g|0)!=1){switch(w[d+136|0]){case 4:break Q;case 2:break R;case 0:break S;default:break P}}break q}g=kd(d+136|0);A=Lb(v[h>>2],b),C=w[g|0]^128,t[A|0]=C;g=d+144|0;Bb(g,v[d+232>>2],b);xg(g,0);break P}A=Lb(v[h>>2],b),C=128,t[A|0]=C;g=d+144|0;Bb(g,v[d+232>>2],b);xg(g,1);break P}A=Lb(v[h>>2],b),C=128,t[A|0]=C;g=d+144|0;Bb(g,v[d+232>>2],b);xg(g,0)}b=b+1|0;continue}break}break q}if(y[d+12>>2]<9){break O}b=0;v[23296]=0;Q(176,d+160|0,2)|0;e=v[23296];v[23296]=0;g=65535;if((e|0)==1){break N}while(1){T:{v[23296]=0;e=W(144,v[d+160>>2],v[d+168>>2],1)|0;f=v[23296];v[23296]=0;U:{V:{W:{X:{Y:{Z:{_:{$:{if((f|0)!=1){if(!e){break T}v[23296]=0;f=T(194,d+160|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break q}e=0;switch(f|0){case 0:break T;case 14:break V;case 13:break W;case 12:break X;case 8:break Y;case 7:break Z;case 4:break _;case 1:break $;default:break O}}break q}e=Zb(v[a+484360>>2],w[j|0]);if(x[d+244>>1]==65535){A=d,C=fl(v[e>>2],v[e+4>>2]),u[A+244>>1]=C}e=fl(v[e>>2],v[e+4>>2]);v[23296]=0;u[d+246>>1]=e;e=Q(597,d+160|0,d+287|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break q}aa:{ba:{switch(e-254|0){case 1:e=65535;break aa;case 0:break ba;default:break aa}}e=65534}f=w[j|0];m=v[a+484360>>2];v[23296]=0;R(472,Zb(m,f)|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break q}g=(g&65535)==65535?b:g;break U}v[23296]=0;e=T(182,d+160|0)|0;f=v[23296];v[23296]=0;ca:{da:{if((f|0)!=1){if(e>>>0>=(g&65535)>>>0){break da}e=x[d+248>>1];break ca}break q}e=e-g|0;u[d+248>>1]=e}_e(Zb(v[a+484360>>2],w[j|0]),e&65535);break U}v[23296]=0;e=T(194,d+160|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break q}t[d+251|0]=e;break U}v[23296]=0;e=T(194,d+160|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break q}t[d+250|0]=e;break U}v[23296]=0;f=Q(568,d+160|0,d+144|0)|0;m=v[23296];v[23296]=0;if((m|0)!=1){if(w[d+144|0]|!f|(w[d+146|0]|w[d+145|0]!=255)){break O}if(w[d+147|0]|w[d+148|0]!=1){break O}if(!w[d+149|0]){break U}break O}break q}v[23296]=0;R(484,d+152|0,d+160|0);e=v[23296];v[23296]=0;ea:{fa:{ga:{ha:{if((e|0)!=1){m=kd(d+152|0);e=v[h>>2];z=ad(e,v[d+212>>2]);f=w[d+152|0];if(z>>>0<=f>>>0){break U}switch(w[Ue(d+152|0)|0]){case 4:break fa;case 2:break ga;case 0:break ha;default:break ea}}break q}A=Lb(e,f),C=w[m|0]^128,t[A|0]=C;e=d+144|0;Bb(e,v[d+232>>2],w[d+152|0]);xg(e,0);break ea}A=Lb(e,f),C=128,t[A|0]=C;e=d+144|0;Bb(e,v[d+232>>2],w[d+152|0]);xg(e,1);break ea}A=Lb(e,f),C=128,t[A|0]=C;e=d+144|0;Bb(e,v[d+232>>2],w[d+152|0]);xg(e,0)}ia:{if(s){break ia}s=0;e=v[k+4>>2];if(!Rp(v[k>>2],e)){break U}f=e-56|0;e=w[d+152|0];if(w[Lb(v[f>>2],e)|0]!=w[Lb(v[h>>2],e)|0]){break ia}Bb(d+144|0,v[f+24>>2],e);e=Cb(v[v[d+144>>2]>>2],v[d+148>>2]);Bb(d+136|0,v[d+232>>2],w[d+152|0]);if((Cb(v[v[d+136>>2]>>2],v[d+140>>2])|0)==(e|0)){break U}}s=1;break U}v[23296]=0;R(247,d+144|0,d+160|0);e=v[23296];v[23296]=0;if((e|0)==1){break q}e=v[d+220>>2];m=ad(e,v[d+224>>2]);f=w[d+144|0];if(m>>>0<=f>>>0){break U}m=kd(d+144|0);A=Lb(e,f),C=(w[m|0]>>>2|0)+1|0,t[A|0]=C}b=b+1|0;continue}break}e=1}Ab(d+160|0);if(!e){break M}rm(d+184|0);continue}break}break q}b=1}_d(d+192|0)}Et(h)}Ab(l);if(!b){vh(d+264|0);continue}break}e=0;if((b|0)!=2){break w}}e=0;Ai(i,0);b=v[k>>2];if(uc(b,v[k+4>>2])){break w}if(!(c&2)){break x}v[23296]=0;U(592,d+160|0,o|0,1347244868);b=v[23296];v[23296]=0;if((b|0)!=1){A=d,C=Eb(v[d+160>>2]),v[A+8>>2]=C;e=a+480190|0;g=d+53|0;h=d+57|0;j=Eb(v[d+164>>2]);l=w[d+287|0];while(1){b=v[d+8>>2];if(!Rb(b,j)){ld(d+160|0);b=v[k>>2];break x}ja:{ka:{la:{if(!l){v[23296]=0;f=Q(598,b|0,d+40|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break ja}if(!f){break ka}f=x[d+92>>1];i=f+1|0;u[d+144>>1]=i;if(f>>>0>3998){break la}A=a,C=x[We(e,d+144|0)>>1],u[A+480190>>1]=C;v[23296]=0;R(599,d+40|0,(B(i&65535,104)+a|0)+484380|0);f=v[23296];v[23296]=0;if((f|0)==1){break ja}f=d+24|0;YQ(f,g);v[23296]=0;R(210,d+192|0,f|0);f=v[23296];v[23296]=0;if((f|0)==1){break y}f=d+192|0;Ec(((x[d+144>>1]<<5)+a|0)+946304|0,f);yb(f);break la}v[23296]=0;f=Q(600,b|0,d+40|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break y}if(!f){break ka}f=x[d+96>>1];i=f+1|0;u[d+144>>1]=i;if(f>>>0>3998){break la}A=a,C=x[We(e,d+144|0)>>1],u[A+480190>>1]=C;v[23296]=0;R(601,d+40|0,(B(i&65535,104)+a|0)+484380|0);f=v[23296];v[23296]=0;if((f|0)==1){break y}f=d+24|0;YQ(f,h);v[23296]=0;R(210,d+192|0,f|0);f=v[23296];v[23296]=0;if((f|0)==1){break y}f=d+192|0;Ec(((x[d+144>>1]<<5)+a|0)+946304|0,f);yb(f)}f=x[d+144>>1];if((f-1&65535)>>>0>3998){break ka}i=_c(d+40|0,8,1,0,2);v[23296]=0;W(207,i|0,(B(f,104)+a|0)+484380|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break ka}break y}vh(d+8|0);continue}break}break y}b=P()|0;O()|0;break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;ld(d+160|0);break j}b=Tz(b,0);v[a+480196>>2]=w[b+43|0];v[a+480204>>2]=B(w[b+42|0],1e4);_e(Zb(v[a+484360>>2],w[a+484376|0]),x[b+40>>1]);b=0;while(1){if(x[a+480188>>1]>b>>>0){e=(b<<5)+a|0;g=e+480280|0;Te(g);h=Tz(v[k>>2],0);A=e+480286|0,C=w[Lb(v[h+12>>2],b)|0],u[A>>1]=C;A=e+480284|0,C=w[Lb(v[h>>2],b)|0],u[A>>1]=C;Bb(d+40|0,v[h+24>>2],b);A=g,C=v[g>>2]&-257|(Cb(v[v[d+40>>2]>>2],v[d+44>>2])?256:0),v[A>>2]=C;b=b+1|0;continue}break}v[23296]=0;b=Q(1,d+192|0,(w[d+287|0]?16950:16823)|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break r}Hb(a+1298344|0,b);zb(b);v[23296]=0;b=Q(1,d+24|0,10029)|0;e=v[23296];v[23296]=0;if((e|0)==1){break s}Hb(a+1298356|0,b);zb(b);v[a+1298404>>2]=5;e=1;if(!(c&1)|!x[a+480188>>1]){break w}v[23296]=0;U(592,d+8|0,o|0,1146045008);b=v[23296];v[23296]=0;if((b|0)==1){break t}b=v[d+12>>2];c=v[d+8>>2];v[23296]=0;l=a+484344|0;R(213,l|0,Df(c,b)&65535);b=v[23296];v[23296]=0;if((b|0)==1){break v}A=d,C=Eb(v[d+8>>2]),v[A+144>>2]=C;r=Eb(v[d+12>>2]);while(1){j=v[d+144>>2];if(!Rb(j,r)){ma:{na:{b=v[k>>2];e=v[k+4>>2];if(Rp(b,e)>>>0<2){break na}j=a+484348|0;g=0;while(1){if(Rp(b,e)>>>0<=g>>>0){break na}i=v[a+484344>>2];n=v[j>>2];h=pj(v[a+484360>>2],g&255);m=v[h>>2];c=Tz(b,g);f=x[c+36>>1];if(oe(i,n,x[dc(m,f)>>1])){v[23296]=0;e=Q(346,h|0,f|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break ma}oa:{if(!s){break oa}b=0;while(1){if(x[a+480188>>1]<=b>>>0){break oa}Bb(d+40|0,v[c+24>>2],b);f=Cb(v[v[d+40>>2]>>2],v[d+44>>2]);h=$b(v[l>>2],e);pa:{if(f){qe(h,yh(ro(Ke(Fe(d+40|0,20,145),0),b&65535)));break pa}qe(h,yh(ro(Ke(Fe(d+40|0,9,w[Lb(v[c>>2],b)|0]),0),b&65535)))}b=b+1|0;continue}}b=d+40|0;qe($b(v[l>>2],e),yh(Ke(Fe(b,16,w[c+43|0]),0)));qe($b(v[l>>2],e),yh(Ke(Fe(b,17,w[c+42|0]),0)));e=v[k+4>>2];b=v[k>>2]}g=g+1|0;continue}}ld(d+8|0);e=1;break w}b=P()|0;O()|0;break u}b=v[j>>2];v[23296]=0;b=T(148,b|0)|0;c=v[23296];v[23296]=0;qa:{ra:{sa:{ta:{ua:{va:{wa:{if((c|0)==1){break wa}v[23296]=0;c=T(145,j|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break wa}if((b|0)!=(c|0)){break qa}b=v[j>>2];v[23296]=0;b=Q(602,b|0,8)|0;c=v[23296];v[23296]=0;if((c|0)==1){break wa}if(!b){break qa}v[23296]=0;i=Q(597,j|0,d+287|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break ra}v[23296]=0;p=T(182,j|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break sa}v[23296]=0;b=W(214,l|0,i|0,p|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break sa}if(!b){break qa}f=0;while(1){if((f|0)==(p|0)){break qa}b=$b(v[l>>2],i);c=Qf(v[b>>2],v[v[b+48>>2]+12>>2],f);v[23296]=0;b=T(182,j|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break va}xa:{if(b>>>0>=3){v[23296]=0;U(178,d+160|0,j|0,b-2|0);b=v[23296];v[23296]=0;if((b|0)==1){break ta}b=d+160|0;h=jc(d+40|0,b);Ab(b);while(1){b=v[h>>2];v[23296]=0;b=W(144,b|0,v[d+48>>2],3)|0;e=v[23296];v[23296]=0;if((e|0)==1){break xa}if(b){v[23296]=0;R(247,d+160|0,h|0);b=v[23296];v[23296]=0;ya:{za:{Aa:{Ba:{if((b|0)!=1){u[d+136>>1]=x[a+480188>>1]-1;A=d,C=w[kd(d+160|0)|0],u[A+264>>1]=C;e=x[Zc(d+136|0,d+264|0)>>1];g=c+B(e,6)|0;b=t[d+160|0];if((b|0)>=0){break ya}v[23296]=0;b=T(194,h|0)|0;n=v[23296];v[23296]=0;if((n|0)==1){break ua}if(w[d+287|0]){break Aa}if((b|0)!=255){break Ba}b=254;break za}break ua}if(b>>>0>128){break za}b=(B(b>>>4|0,12)+(b&15)|0)+13|0;break za}b=b>>>0<85?b+36|0:b}t[g|0]=b;b=w[d+160|0]}if(b&64){v[23296]=0;b=T(194,h|0)|0;n=v[23296];v[23296]=0;if((n|0)==1){break ua}t[g+1|0]=b+1;b=w[d+160|0]}if(b&32){v[23296]=0;b=T(194,h|0)|0;n=v[23296];v[23296]=0;if((n|0)==1){break ua}t[d+136|0]=b;t[g+2|0]=1;t[d+264|0]=127;A=g,C=w[Wb(d+136|0,d+264|0)|0]+1>>>1|0,t[A+4|0]=C;b=w[d+160|0]}if(!(b&16)){continue}v[23296]=0;R(247,d+136|0,h|0);b=v[23296];v[23296]=0;Ca:{Da:{Ea:{Fa:{Ga:{Ha:{Ia:{Ja:{Ka:{La:{Ma:{Na:{Oa:{Pa:{Qa:{Ra:{Sa:{Ta:{Ua:{Va:{Wa:{Xa:{Ya:{Za:{_a:{$a:{ab:{bb:{cb:{db:{eb:{fb:{gb:{hb:{if((b|0)!=1){b=w[kd(d+136|0)|0];t[g+5|0]=b;switch(w[d+136|0]-1|0){case 72:break Da;case 71:break Ea;case 70:break Fa;case 61:break Ga;case 60:break Ha;case 53:break Ia;case 52:break Ja;case 51:break Ka;case 50:break Ma;case 43:break Na;case 42:break Oa;case 41:break Pa;case 40:break Qa;case 31:break Ra;case 30:break Sa;case 23:break Ta;case 22:break Ua;case 21:break Va;case 20:break Wa;case 18:break Xa;case 17:break Ya;case 15:break Za;case 16:break _a;case 14:break $a;case 13:break ab;case 12:break bb;case 11:break cb;case 10:break db;case 3:break eb;case 2:break fb;case 1:break gb;case 0:break hb;default:break Ca}}break ua}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b<<4|15;continue}t[g+5|0]=b<<3|15;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b<<4;continue}t[g+5|0]=b<<3&240;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b|240;continue}t[g+5|0]=b>>>1|240;continue}t[(c+B(e,6)|0)+3|0]=11;if(w[d+287|0]){t[g+5|0]=b&15;continue}if(b>>>0<=1){t[g+5|0]=b|240;continue}t[g+5|0]=b>>>1&15;continue}t[(c+B(e,6)|0)+3|0]=2;A=g,C=Dt(b,w[d+287|0])|240,t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=2;A=g,C=Dt(b,w[d+287|0]),t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=3;A=g,C=Dt(b,w[d+287|0])|240,t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=3;A=g,C=Dt(b,w[d+287|0]),t[A+5|0]=C;continue}t[(c+B(e,6)|0)+3|0]=4;if(w[d+287|0]){continue}t[g+5|0]=(b&252)>>>2;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&1|16;continue}t[(c+B(e,6)|0)+3|0]=6;t[g+5|0]=b&240;continue}t[(c+B(e,6)|0)+3|0]=6;t[g+5|0]=(b&240)>>>4;continue}t[(c+B(e,6)|0)+3|0]=20;continue}t[(c+B(e,6)|0)+3|0]=5;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|48;continue}t[(c+B(e,6)|0)+3|0]=7;t[g+5|0]=b|240;continue}t[(c+B(e,6)|0)+3|0]=7;continue}t[(c+B(e,6)|0)+3|0]=8;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|64;continue}t[(c+B(e,6)|0)+3|0]=10;v[23296]=0;b=T(194,h|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break La}break ua}t[(c+B(e,6)|0)+3|0]=15;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|192;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|208;continue}t[(c+B(e,6)|0)+3|0]=12;b=(b&254)>>>1|0}t[g+5|0]=b;v[23296]=0;Q(176,h|0,1)|0;b=v[23296];v[23296]=0;if((b|0)!=1){continue}break ua}t[(c+B(e,6)|0)+3|0]=14;t[g+5|0]=0;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|176;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|224;continue}t[(c+B(e,6)|0)+3|0]=16;continue}t[(c+B(e,6)|0)+3|0]=17;continue}t[(c+B(e,6)|0)+3|0]=1;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|32;continue}t[(c+B(e,6)|0)+3|0]=20;t[g+5|0]=b&15|128;continue}t[(c+B(e,6)|0)+3|0]=0;continue}break}Ab(h)}f=f+1|0;continue}break}break ua}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;Ab(h);break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}b=P()|0;O()|0;break u}vh(d+144|0);continue}}ld(d+272|0);XQ(k);Ab(d+304|0);break b}b=P()|0;O()|0}ld(d+8|0);break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;break j}b=P()|0;O()|0;Ab(d+160|0);break m}b=P()|0;O()|0;break l}b=P()|0;O()|0;zb(d+160|0);break l}b=P()|0;O()|0;break l}_d(d+192|0)}Et(h)}Ab(l)}ld(d+272|0);break h}b=P()|0;O()|0}XQ(k);break f}b=P()|0;O()|0}Ab(d+304|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0}_d(o);Ab(q);S(b|0);L()}_d(o);Ab(q)}jb=d+384|0;return e|0}function Ega(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=jb-480|0;jb=d;Ac(b);g=d+472|0;e=Au(b,g);if(!e){AS(g)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!e){break k}if(!BS(d+472|0)){break k}if(!c){y=1;break k}F=ie(d+448|0,b);v[23296]=0;R(440,d+432|0,F|0);b=v[23296];v[23296]=0;l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{if((b|0)!=1){v[23296]=0;U(441,d+408|0,d+432|0,20041);b=v[23296];v[23296]=0;if((b|0)==1){break u}v[23296]=0;e=T(166,v[d+408>>2])|0;b=v[23296];v[23296]=0;if((b|0)==1){break m}if(!e){break l}v[23296]=0;e=Q(442,d+408|0,d+312|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break m}if(!e){break l}v[23296]=0;R(234,a|0,16384);b=v[23296];v[23296]=0;if((b|0)==1){break m}v[a+480208>>2]=8;v[23296]=0;e=W(251,a+1074312|0,9,1)|0;b=v[23296];v[23296]=0;if((b|0)==1){break m}v[23296]=0;e=W(251,e|0,114,1)|0;b=v[23296];v[23296]=0;if((b|0)==1){break m}v[23296]=0;e=Q(252,e|0,21)|0;b=v[23296];v[23296]=0;if((b|0)==1){break m}v[23296]=0;Q(252,e|0,30)|0;b=v[23296];v[23296]=0;if((b|0)==1){break m}v[23296]=0;e=Q(1,d+296|0,8198)|0;b=v[23296];v[23296]=0;if((b|0)==1){break r}Hb(a+1298344|0,e);zb(e);v[23296]=0;e=Q(1,d+280|0,10614)|0;b=v[23296];v[23296]=0;if((b|0)==1){break q}Hb(a+1298356|0,e);zb(e);v[23296]=0;i=Q(1,d+264|0,17320)|0;b=v[23296];v[23296]=0;if((b|0)==1){break p}e=14885;b=w[d+476|0];switch(b-16|0){case 1:break n;case 0:break t;default:break s}}f=P()|0;O()|0;break a}f=P()|0;O()|0;break b}e=14866;break n}if(!b){break o}e=21473;break n}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}e=13112}v[23296]=0;g=Q(1,d+248|0,e|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break e}v[23296]=0;U(2,d+208|0,i|0,g|0);b=v[23296];v[23296]=0;if((b|0)==1){break f}e=d+208|0;Hb(a+1298368|0,e);zb(e);zb(g);zb(i);v[a+1298404>>2]=5;b=d+96|0;Ze(b,3,d+312|0);v[23296]=0;R(210,e|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break g}b=d+208|0;Bc(a+1298308|0,b);yb(b);b=d+232|0;tj(b,3,d+344|0);v[23296]=0;R(210,d+96|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break h}v[23296]=0;U(11,d+208|0,5,d+96|0);b=v[23296];v[23296]=0;if((b|0)==1){break i}b=d+208|0;Hb(a+1298320|0,b);zb(b);yb(d+96|0);v[a+480200>>2]=w[d+368|0]+1;G=a,H=Xd(w[d+369|0],1,255),v[G+480196>>2]=H;G=a,H=B(Xd(w[d+370|0],4,255),1e4),v[G+480204>>2]=H;g=v[a+484360>>2];e=a+484376|0;b=w[e|0];v[23296]=0;da(326,Zb(g,b)|0,d+408|0,x[d+364>>1],65535,65535);b=v[23296];v[23296]=0;if((b|0)==1){break m}_e(Zb(v[a+484360>>2],w[e|0]),x[d+366>>1]);u[a+480188>>1]=0;b=0;while(1){if((b|0)==32){v[23296]=0;U(441,d+208|0,d+432|0,17741);b=v[23296];v[23296]=0;if((b|0)!=1){b=d+208|0;g=cd(d+408|0,b);Ab(b);b=v[g>>2];v[23296]=0;e=T(148,b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break m}v[23296]=0;X(317,a+1298332|0,g|0,e|0,0);b=v[23296];v[23296]=0;if((b|0)==1){break m}v[23296]=0;U(441,d+208|0,d+432|0,21321);b=v[23296];v[23296]=0;if((b|0)!=1){b=d+208|0;j=cd(g,b);Ab(b);b=v[j>>2];v[23296]=0;e=T(166,b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break m}v:{w:{if(e){v[23296]=0;U(441,d+208|0,d+432|0,16723);b=v[23296];v[23296]=0;if((b|0)==1){break v}v[23296]=0;i=T(194,j|0)|0;b=v[23296];v[23296]=0;x:{if((b|0)!=1){g=c&2;h=a+480190|0;while(1){if(i>>>0<=(o&255)>>>0){break x}v[23296]=0;m=T(194,j|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break w}if(!m){break x}e=v[j+8>>2];b=v[j>>2];v[23296]=0;e=W(144,b|0,e|0,56)|0;b=v[23296];v[23296]=0;if((b|0)==1){break w}if(!e){break x}if(m>>>0>x[h>>1]){u[h>>1]=m}v[23296]=0;p=B(m,104)+a|0;y=p+484380|0;R(264,y|0,0);b=v[23296];v[23296]=0;if((b|0)==1){break w}kB(y);v[23296]=0;U(300,j|0,((m<<5)+a|0)+946304|0,32);b=v[23296];v[23296]=0;if((b|0)==1){break w}v[23296]=0;R(303,j|0,p+484423|0);b=v[23296];v[23296]=0;if((b|0)==1){break w}y:{if(w[d+476|0]<=15){v[23296]=0;f=T(182,j|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break y}break w}v[23296]=0;f=T(145,j|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break w}}v[p+484404>>2]=f<<1;v[23296]=0;e=T(145,j|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break w}v[y>>2]=e;v[23296]=0;e=T(145,j|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break w}C=p+484384|0;v[C>>2]=e;v[23296]=0;e=T(145,j|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break w}D=p+484388|0;v[D>>2]=e;if(e){b=p+484414|0;u[b>>1]=x[b>>1]|2;v[D>>2]=e+v[C>>2]}v[23296]=0;e=T(194,j|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break w}if(w[d+476|0]<=15){u[p+484410>>1]=e}v[23296]=0;m=T(194,j|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break w}b=p+484414|0;e=x[b>>1];k=8;if(m&1){e=e|1;u[b>>1]=e;v[y>>2]=v[y>>2]>>>1;v[C>>2]=v[C>>2]>>>1;v[D>>2]=v[D>>2]>>>1;k=16}u[b>>1]=e&65531|m<<1&4;b=_c(d+96|0,k,1,0,((m&12)!=0)<<3);z:{if(!g){break z}v[23296]=0;W(207,b|0,y|0,d+208|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break z}break w}o=o+1|0;continue}}break w}Ab(d+208|0)}v[23296]=0;U(441,d+208|0,d+432|0,18761);b=v[23296];v[23296]=0;A:{if((b|0)!=1){b=d+208|0;l=cd(j,b);Ab(b);b=v[l>>2];v[23296]=0;e=T(166,b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break m}if(!e){break A}q=Qb(d+96|0);r=Qb(d+232|0);s=Qb(d+192|0);v[23296]=0;U(441,d+168|0,d+432|0,17750);b=v[23296];v[23296]=0;B:{if((b|0)==1){break B}b=v[d+180>>2];e=d- -64|0;v[e>>2]=v[d+176>>2];v[e+4>>2]=b;v[d+72>>2]=v[d+184>>2];v[23296]=0;b=v[d+172>>2];v[d+56>>2]=v[d+168>>2];v[d+60>>2]=b;R(443,d+56|0,q|0);b=v[23296];v[23296]=0;if((b|0)==1){break B}v[23296]=0;U(441,d+144|0,d+432|0,17744);b=v[23296];v[23296]=0;if((b|0)==1){break B}b=v[d+156>>2];v[d+40>>2]=v[d+152>>2];v[d+44>>2]=b;v[d+48>>2]=v[d+160>>2];v[23296]=0;b=v[d+148>>2];v[d+32>>2]=v[d+144>>2];v[d+36>>2]=b;R(443,d+32|0,r|0);b=v[23296];v[23296]=0;if((b|0)==1){break B}v[23296]=0;U(441,d+120|0,d+432|0,17734);b=v[23296];v[23296]=0;if((b|0)==1){break B}b=v[d+132>>2];v[d+16>>2]=v[d+128>>2];v[d+20>>2]=b;v[d+24>>2]=v[d+136>>2];v[23296]=0;b=v[d+124>>2];v[d+8>>2]=v[d+120>>2];v[d+12>>2]=b;R(443,d+8|0,s|0);b=v[23296];v[23296]=0;if((b|0)==1){break B}v[23296]=0;p=T(194,l|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break B}j=d+208|1;y=a+480190|0;k=0;while(1){if(p>>>0<=(k&255)>>>0){lo(s);lo(r);lo(q);break A}v[23296]=0;R(247,d+80|0,l|0);b=v[23296];v[23296]=0;C:{if((b|0)!=1){A=kd(d+80|0);D:{E:{if(!w[d+80|0]){break E}g=v[l+8>>2];e=v[l>>2];b=w[A|0];v[23296]=0;e=W(144,e|0,g|0,B(b,14)+32|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break B}if(!e){break E}v[23296]=0;n=W(239,a|0,w[d+80|0],0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break B}if(n){break D}}b=w[A|0];v[23296]=0;Q(176,l|0,B(b,14)+32|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break C}break B}v[23296]=0;U(300,l|0,n+492|0,32);b=v[23296];v[23296]=0;if((b|0)==1){break B}C=n+88|0;D=n+68|0;m=n+48|0;h=n+236|0;b=0;o=0;while(1){if(w[A|0]<=(o&255)>>>0){break C}v[23296]=0;R(444,l|0,d+208|0);e=v[23296];v[23296]=0;if((e|0)==1){break B}e=w[d+208|0];F:{if(!e|e>>>0>x[y>>1]){break F}if(w[j|0]>=129){t[j|0]=128}while(1){e=b&255;i=w[d+209|0];if(e>>>0>i>>>0){e=v[q+4>>2];b=v[q>>2];v[23296]=0;X(445,m|0,w[d+211|0],b|0,e|0);b=v[23296];v[23296]=0;if((b|0)==1){break B}e=v[r+4>>2];b=v[r>>2];v[23296]=0;X(445,D|0,w[d+213|0],b|0,e|0);b=v[23296];v[23296]=0;if((b|0)==1){break B}e=v[s+4>>2];b=v[s>>2];v[23296]=0;X(445,C|0,w[d+221|0],b|0,e|0);b=v[23296];v[23296]=0;if((b|0)==1){break B}v[n>>2]=x[d+214>>1]+1>>>1;e=w[d+208|0];G:{if(w[d+211|0]&64){u[(B(e,104)+a|0)+484410>>1]=w[d+210|0];break G}b=(B(e,104)+a|0)+484414|0;u[b>>1]=x[b>>1]|32768}u[d+118>>1]=w[d+212|0]<<1;u[d+116>>1]=254;z=B(e,104)+a|0;G=z+484408|0,H=x[Zc(d+118|0,d+116|0)>>1],u[G>>1]=H;t[z+484418|0]=w[(w[d+219|0]&3)+26500|0];e=z+484419|0;E=w[d+218|0];t[e|0]=E;g=w[d+217|0]+3>>>2|0;t[z+484420|0]=g;t[z+484421|0]=w[d+216|0];b=i+1|0;if(E){g=Bm(Vc(((g<<8|E>>>1)>>>0)/(E>>>0)|0,0))}else{g=255}t[e|0]=g;if(!(w[d+213|0]&64)){break F}e=z+484414|0;u[e>>1]=x[e>>1]|32}else{G=dc(h,e),H=w[d+208|0],u[G>>1]=H;b=b+1|0;continue}break}}o=o+1|0;continue}}break B}k=k+1|0;continue}}f=P()|0;O()|0;lo(s);lo(r);lo(q);break c}f=P()|0;O()|0;break c}y=1;r=Qb(d+232|0);H:{if(!(c&1)){break H}v[23296]=0;U(441,d+208|0,d+432|0,21076);b=v[23296];v[23296]=0;I:{J:{K:{L:{M:{N:{if((b|0)!=1){i=cd(l,d+208|0);b=v[i>>2];v[23296]=0;c=T(166,b|0)|0;b=v[23296];v[23296]=0;O:{P:{Q:{if((b|0)!=1){Ab(d+208|0);if(!c){break O}v[23296]=0;e=T(182,i|0)|0;c=v[23296];v[23296]=0;b=1;if((c|0)==1){break Q}v[23296]=0;g=e+1|0;R(446,r|0,g|0);c=v[23296];v[23296]=0;if((c|0)==1){break Q}while(1){if((b|0)==(g|0)){break O}v[23296]=0;e=T(182,i|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break P}v[23296]=0;U(178,d+96|0,i|0,e|0);c=v[23296];v[23296]=0;if((c|0)==1){break P}c=d+96|0;e=jc(d+208|0,c);cd(Cg(v[r>>2],b),e);Ab(e);b=b+1|0;Ab(c);continue}}f=P()|0;O()|0;Ab(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}v[23296]=0;U(441,d+208|0,d+432|0,16720);b=v[23296];v[23296]=0;if((b|0)==1){break K}n=cd(i,d+208|0);b=v[n>>2];v[23296]=0;c=T(166,b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break L}Ab(d+208|0);if(!c){break N}v[23296]=0;E=T(194,n|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break J}k=0;R:{S:{T:while(1){U:{if(E>>>0<=(k&65535)>>>0){v[23296]=0;Q(143,n|0,1)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break U}break J}o=32;V:{if(w[d+476|0]<16){break V}v[23296]=0;R(447,n|0,d+208|0);b=v[23296];v[23296]=0;if((b|0)==1){break R}o=w[d+208|0];if(o>>>0<=x[a+480188>>1]|o>>>0>32){break V}u[a+480188>>1]=o}b=0;while(1){g=b&65535;if(g>>>0>=o>>>0){k=k+1|0;continue T}v[23296]=0;e=T(182,n|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break S}if(!(!e|g>>>0>31|g>>>0<x[a+480188>>1])){u[a+480188>>1]=b+1}b=b+1|0;continue}}break}v[23296]=0;s=a+484344|0;R(213,s|0,E|0);b=v[23296];v[23296]=0;if((b|0)==1){break J}C=d+208|2;q=0;while(1){if((q|0)==(E|0)){break N}z=Kb(d+96|0);W:{if(w[d+476|0]<16){j=32;i=64;break W}v[23296]=0;R(447,n|0,d+208|0);b=v[23296];v[23296]=0;if((b|0)==1){break M}c=w[d+209|0];j=w[d+208|0];b=d+80|0;df(b,C,16,3);v[23296]=0;R(210,d+192|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break M}b=d+192|0;Bc(z,b);yb(b);i=c+1|0}v[23296]=0;c=W(214,s|0,q&65535,i|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break M}X:{if(!c){v[23296]=0;Q(176,n|0,j<<1)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break X}break M}b=v[s>>2];v[23296]=0;R(268,$b(b,q)|0,z|0);b=v[23296];v[23296]=0;if((b|0)==1){break M}D=i-1|0;p=0;while(1){A=p&65535;if(A>>>0>=j>>>0){break X}v[23296]=0;c=T(182,n|0)|0;b=v[23296];v[23296]=0;Y:{if((b|0)!=1){if(!c){break Y}b=v[r>>2];if(Df(b,v[r+4>>2])>>>0<=c>>>0|A>>>0>=x[a+480188>>1]){break Y}l=Cg(b,c);Ac(l);c=0;Z:while(1){e=c;if(i>>>0<=e>>>0){break Y}c=v[l+8>>2];b=v[l>>2];v[23296]=0;c=W(144,b|0,c|0,1)|0;b=v[23296];v[23296]=0;_:{$:{aa:{ba:{ca:{if((b|0)!=1){if(!c){break Y}b=$b(v[s>>2],q);b=fd(v[b>>2],v[v[b+48>>2]+12>>2],e,A);v[23296]=0;g=T(194,l|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break M}f=g>>>2|0;switch((g&3)-1|0){case 2:break $;case 1:break aa;case 0:break ba;default:break ca}}break M}c=(e+f|0)+1|0;continue}c=0;if(!e){continue}c=$b(v[s>>2],q);h=fd(v[c>>2],v[v[c+48>>2]+12>>2],e-1|0,A);while(1){c=w[h|0]|w[h+1|0]<<8|(w[h+2|0]<<16|w[h+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[h+4|0]|w[h+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;c=e+1|0;if((e|0)==(D|0)){continue Z}b=B(x[a+480188>>1],6)+b|0;g=f&255;e=c;f=f-1|0;if(g){continue}break}continue}if(e>>>0<=f>>>0){break _}c=$b(v[s>>2],q);g=fd(v[c>>2],v[v[c+48>>2]+12>>2],f,A);c=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[b|0]=c;t[b+1|0]=c>>>8;t[b+2|0]=c>>>16;t[b+3|0]=c>>>24;c=w[g+4|0]|w[g+5|0]<<8;t[b+4|0]=c;t[b+5|0]=c>>>8;break _}if(f&1){v[23296]=0;g=T(194,l|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break M}t[b|0]=g>>>0>120?-1:g}if(f&2){v[23296]=0;g=T(194,l|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break M}t[b+1|0]=g}o=0;c=0;da:{if(f&4){v[23296]=0;c=T(194,l|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break da}}k=0;if(f&8){v[23296]=0;h=T(194,l|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break da}k=h>>>4|0;o=h&15}m=0;h=0;if(f&16){v[23296]=0;h=T(194,l|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break da}}if(f&32){v[23296]=0;m=T(194,l|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break da}}f=jb-16|0;jb=f;t[f+14|0]=k;t[f+15|0]=o;t[f+13|0]=h;t[f+12|0]=m;if((k-1&255)>>>0<=5){t[f+14|0]=k+15}xS(f+15|0,f+13|0);xS(f+14|0,f+12|0);ea:{fa:{k=w[f+15|0];ga:{if((k|0)==10){m=w[f+12|0];h=w[f+13|0]&15;t[f+13|0]=h?-1:m;g=w[f+14|0];k=(g|0)==10?0:g;t[f+14|0]=k;g=m|h<<8;break ga}if(w[f+14|0]!=10){break fa}g=w[f+12|0]&15;t[f+12|0]=g?-1:0;g=g<<8}if(g-256>>>0>4294967038){break fa}if(Bi(k)>>>0>=Bi(10)>>>0){break fa}t[b+5|0]=g;t[b+2|0]=15;t[b+3|0]=10;t[b+4|0]=g>>>8;break ea}if(c){t[b+2|0]=1;t[b+4|0]=c+2>>>2}Gu(f+15|0,f+13|0,f+14|0,f+12|0);h=w[f+15|0];ha:{if(!h){break ha}g=w[f+14|0];if(!g){t[f+14|0]=h;t[f+12|0]=w[f+13|0];break ha}if((g|0)==(h|0)&(h|0)!=20){break ha}if(!c){uo(f+8|0,f+15|0,f+13|0,f+14|0,f+12|0);t[b+2|0]=w[f+15|0];t[b+4|0]=w[f+13|0];break ha}if(Bi(h)>>>0<=Bi(g)>>>0){break ha}ah(f+15|0,f+14|0);ah(f+13|0,f+12|0)}t[b+3|0]=w[f+14|0];t[b+5|0]=w[f+12|0]}jb=f+16|0;break _}break M}c=e+1|0;continue}}break M}p=p+1|0;continue}}yb(z);q=q+1|0;continue}}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}v[23296]=0;U(441,d+208|0,d+432|0,20048);b=v[23296];v[23296]=0;ia:{ja:{if((b|0)!=1){g=cd(n,d+208|0);b=v[g>>2];v[23296]=0;c=T(166,b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break ja}Ab(d+208|0);if(!c){break H}e=a+484348|0;while(1){if(!pf(v[a+484344>>2],v[e>>2])){break H}c=v[g+8>>2];b=v[g>>2];v[23296]=0;c=W(144,b|0,c|0,16)|0;b=v[23296];v[23296]=0;if((b|0)==1){break ia}if(!c){break H}v[23296]=0;R(448,g|0,d+208|0);b=v[23296];v[23296]=0;if((b|0)!=1){b=v[a+484344>>2];v[23296]=0;R(449,$b(b,0)|0,d+208|0);b=v[23296];v[23296]=0;if((b|0)!=1){continue}}break}f=P()|0;O()|0;break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;Ab(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0;yb(z);break I}f=P()|0;O()|0;Ab(d+208|0);break I}f=P()|0;O()|0;break I}f=P()|0;O()|0}ld(r);break c}ld(r);break l}f=P()|0;O()|0;Ab(d+208|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}h=(b<<5)+a|0;i=h+480280|0;Te(i);g=t[(b+d|0)+371|0];e=g<<1&254;u[h+480284>>1]=(e|0)==254?256:e;ka:{if((g|0)<0){v[i>>2]=v[i>>2]|1024;break ka}u[a+480188>>1]=b+1}v[23296]=0;R(450,d+408|0,h+480289|0);e=v[23296];v[23296]=0;if((e|0)==1){break j}b=b+1|0;continue}}f=P()|0;O()|0;break c}Ab(d+408|0);_d(d+432|0);Ab(F)}jb=d+480|0;return y|0}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(d+96|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;zb(g);break d}f=P()|0;O()|0}zb(i)}Ab(d+408|0)}_d(d+432|0)}Ab(F);S(f|0);L()}function dia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=jb-240|0;jb=d;Ac(b);e=jb-16|0;jb=e;h=d+216|0;iu(e+8|0,h);g=v[e+12>>2];nc(e,v[b>>2],v[b+8>>2],v[e+8>>2],v[e+12>>2]);j=v[e+4>>2];if((j|0)==(g|0)){ac(b,v[e+12>>2])}jb=e+16|0;e=(g|0)==(j|0);if(!e){FT(h)}a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!e){break n}if(!GT(d+216|0)){break n}if(!c){f=1;break n}Ed(a,1024);Dg(a);v[a+480208>>2]=v[a+480208>>2]|12;Bf(a+1074312|0,21);e=Mb(x[d+232>>1]);if(e){v[a+480204>>2]=B(e,1e4)}e=Mb(x[d+230>>1]);if(e){v[a+480196>>2]=e}if(!w[d+226|0]){xh(a,1)}wu(b,a+1298308|0,cc(v[d+220>>2])-14|0);b=ie(d+112|0,b);v[23296]=0;R(324,d+200|0,b|0);e=v[23296];v[23296]=0;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{if((e|0)!=1){Ab(b);v[23296]=0;U(325,d+112|0,d+200|0,1395544366);b=v[23296];v[23296]=0;if((b|0)==1){break s}v[23296]=0;b=T(262,v[d+112>>2])|0;e=v[23296];v[23296]=0;if((e|0)==1){break y}if(!b){break r}v[23296]=0;b=T(258,d+112|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break y}v[23296]=0;e=T(258,d+112|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break y}v[23296]=0;Q(176,d+112|0,4)|0;f=v[23296];v[23296]=0;if((f|0)==1){break y}f=a+484376|0;g=w[f|0];h=v[a+484360>>2];v[23296]=0;da(326,Zb(h,g)|0,d+112|0,b|0,65535,65535);b=v[23296];v[23296]=0;if((b|0)==1){break y}_e(Zb(v[a+484360>>2],w[f|0]),e);b=d+112|0;Ab(b);v[23296]=0;U(325,b|0,d+200|0,1346458708);b=v[23296];v[23296]=0;if((b|0)==1){break x}v[23296]=0;e=T(262,v[d+112>>2])|0;b=v[23296];v[23296]=0;if((b|0)==1){break w}f=0;b=0;if(!e){break t}v[23296]=0;e=T(258,d+112|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break w}u[a+480188>>1]=e;if((e-33&65535)>>>0<65504){break t}v[23296]=0;b=T(258,d+112|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break w}v[23296]=0;R(213,a+484344|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break w}b=0;v[23296]=0;m=T(266,d+112|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break w}switch(m-841887796|0){case 1:break t;case 0:case 2:break u;default:break v}}a=P()|0;O()|0;Ab(b);break a}a=P()|0;O()|0;Ab(d+112|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ab(d+112|0);break b}if(m){break t}}b=1}Ab(d+112|0);if(!b){break o}v[23296]=0;U(325,d+176|0,d+200|0,1398157625);b=v[23296];v[23296]=0;if((b|0)==1){break d}v[23296]=0;b=T(262,v[d+176>>2])|0;e=v[23296];v[23296]=0;if((e|0)==1){break c}if(!b){break q}v[23296]=0;Q(176,d+176|0,2)|0;b=v[23296];v[23296]=0;if((b|0)==1){break c}v[23296]=0;b=T(266,d+176|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break c}G=a,H=Ie((+(b>>>0)*2.3283064365386963e-10+ +(y[a+480204>>2]/1e4>>>0))*1e4),v[G+480204>>2]=H;b=0;v[23296]=0;Q(327,d+176|0,d+112|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break c}f=x[a+480188>>1];while(1){if((b|0)!=32&(b|0)!=(f|0)){G=d,H=Mb(x[(d+112|0)+(b<<1)>>1]),v[G+48>>2]=H;v[d+32>>2]=180;e=v[td(d+48|0,d+32|0)>>2]-90|0;g=e>>31;G=((b<<5)+a|0)+480284|0,H=Ic(Tia(e<<7|45,g<<7|e>>>25,90,0),mb)+128|0,u[G>>1]=H;b=b+1|0;continue}else{z:{v[23296]=0;Q(176,d+176|0,16)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break z}break c}}break}v[23296]=0;b=W(144,v[d+176>>2],v[d+184>>2],2)|0;e=v[23296];v[23296]=0;if((e|0)==1){break c}A:{if(b){v[23296]=0;b=T(258,d+176|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break A}u[d+48>>1]=b;u[d+32>>1]=256;G=a,H=x[Zc(d+48|0,d+32|0)>>1],v[G+480200>>2]=H}v[23296]=0;Q(176,d+176|0,128)|0;b=v[23296];v[23296]=0;if((b|0)==1){break c}v[23296]=0;b=Q(327,d+176|0,d+48|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){if(!b){break q}e=x[a+480188>>1];b=0;while(1)if((b|0)!=32&(b|0)!=(e|0)){G=d,H=Mb(x[(d+48|0)+(b<<1)>>1]),v[G+32>>2]=H;v[d+16>>2]=128;G=((b<<5)+a|0)+480286|0,H=v[td(d+32|0,d+16|0)>>2]/2&255,u[G>>1]=H;b=b+1|0;continue}else{v[a+480228>>2]=v[a+480228>>2]<<1;break q}}break c}break c}a=P()|0;O()|0;break b}Ab(d+112|0);break p}Ab(d+176|0);v[23296]=0;U(325,d+112|0,d+200|0,1413830740);b=v[23296];v[23296]=0;B:{C:{if((b|0)!=1){v[23296]=0;b=T(262,v[d+112>>2])|0;e=v[23296];v[23296]=0;if((e|0)==1){break e}if(!b){break B}v[23296]=0;R(328,d+112|0,d+48|0);b=v[23296];v[23296]=0;if((b|0)==1){break e}if((Mb(x[d+58>>1])|0)!=65535){break C}v[23296]=0;Q(176,d+112|0,1)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break C}break e}a=P()|0;O()|0;break b}v[23296]=0;b=T(190,d+112|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break e}v[23296]=0;X(317,a+1298332|0,d+112|0,b|0,2);b=v[23296];v[23296]=0;if((b|0)==1){break e}}Ab(d+112|0);v[23296]=0;U(325,d+48|0,d+200|0,1229869908);b=v[23296];v[23296]=0;if((b|0)==1){break h}v[23296]=0;b=T(262,v[d+48>>2])|0;e=v[23296];v[23296]=0;if((e|0)==1){break l}if(b){D:{v[23296]=0;b=T(258,d+48|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break i}E:{F:{b=b<<16>>16;f=b&32767;if(f>>>0>3999){break F}v[23296]=0;e=W(144,v[d+48>>2],v[d+56>>2],B(f,(b>>>14&2)+50|0)|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break g}if(!e){break F}u[a+480190>>1]=f;g=a+480190|0;h=d+130|0;j=(b|0)>=0;b=1;G:{H:{I:{J:{while(1){if(f>>>0<(b&65535)>>>0){v[23296]=0;b=T(258,d+48|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break G}break g}K:{if(j){o=b}else{v[23296]=0;e=T(258,d+48|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break K}o=e+1|0}u[d+16>>1]=o;v[23296]=0;R(329,d+48|0,d+112|0);e=v[23296];v[23296]=0;if((e|0)==1){break J}e=x[d+16>>1];if((e-4e3&65535)>>>0>=61537){G=a,H=x[We(g,d+16|0)>>1],u[G+480190>>1]=H;l=x[d+234>>1]|x[d+236>>1]<<16;v[23296]=0;X(330,d+112|0,(B(e,104)+a|0)+484380|0,cc(l)|0,m|0);e=v[23296];v[23296]=0;if((e|0)==1){break I}e=d+32|0;jl(e,2,h);v[23296]=0;R(210,d+176|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break H}e=d+176|0;Ec(((x[d+16>>1]<<5)+a|0)+946304|0,e);yb(e)}b=b+1|0;continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}if((b|0)!=4){break E}u[d+112>>1]=x[a+480190>>1];u[d+176>>1]=255;h=a+480192|0;b=d+176|0;G=h,H=x[Zc(d+112|0,b)>>1],u[G>>1]=H;v[23296]=0;U(325,b|0,d+200|0,1229278806);b=v[23296];v[23296]=0;if((b|0)==1){break j}L:{M:while(1){v[23296]=0;b=W(144,v[d+48>>2],v[d+56>>2],15)|0;e=v[23296];v[23296]=0;if((e|0)==1){break L}if(b){v[23296]=0;R(331,d+48|0,d+32|0);b=v[23296];v[23296]=0;if((b|0)==1){break k}b=Mb(x[d+32>>1]);if(b>>>0>=x[h>>1]){continue}e=B(b,104)+a|0;t[e+484524|0]=w[d+40|0];f=w[d+39|0];t[e+484523|0]=255;t[e+484525|0]=f;v[23296]=0;b=b+1&65535;e=W(239,a|0,b|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break k}if(!e){continue}G=d,H=Mb(w[d+37|0]|w[d+38|0]<<8),u[G+112>>1]=H;u[d+16>>1]=4095;G=e,H=x[Zc(d+112|0,d+16|0)>>1],v[G>>2]=H;b=w[d+35|0];if((b|0)==255){continue}v[23296]=0;b=Q(143,d+176|0,B(b,34)+2|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break k}if(!b){continue}v[23296]=0;R(332,d+176|0,d+112|0);b=v[23296];v[23296]=0;if((b|0)==1){break k}t[e+60|0]=w[e+60|0]|1;b=x[d+112>>1];v[d+20>>2]=16;v[d+24>>2]=240;G=d,H=Mb(b),v[G+16>>2]=H;b=xB(d+16|0);v[23296]=0;R(278,e+48|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break k}g=v[e+52>>2];f=v[e+48>>2];b=0;while(1){j=re(f,g);if(j>>>0<=b>>>0){b=w[d+36|0];if((b|0)!=255){t[e- -64|0]=b;t[e+63|0]=b;t[e+60|0]=w[e+60|0]|4}if(uc(f,g)){continue M}b=j-1|0;t[e+62|0]=b;t[e+61|0]=b;t[e+60|0]=w[e+60|0]|2;continue M}else{t[d+16|0]=64;j=(d+112|0)+(b<<1)|0;t[d+12|0]=w[j+2|0];l=Wb(d+16|0,d+12|0);i=Db(f,b);t[i+2|0]=w[l|0];u[i>>1]=w[j+3|0];b=b+1|0;continue}}}break}Ab(d+176|0);break D}break k}Ab(d+48|0);break p}}}Ab(d+48|0);v[23296]=0;U(333,d+176|0,d+200|0,1145131092);b=v[23296];v[23296]=0;if((b|0)==1){break m}G=d,H=Eb(v[d+176>>2]),v[G+16>>2]=H;l=a+484344|0;C=c&1;r=d+48|4;D=Eb(v[d+180>>2]);s=(m|0)!=841887798;z=a+480188|0;E=(m|0)!=841887796;while(1){N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{g=v[d+16>>2];if(!Rb(g,D)){ld(d+176|0);v[23296]=0;U(325,d+112|0,d+200|0,1346458702);b=v[23296];v[23296]=0;if((b|0)!=1){break $}a=P()|0;O()|0;break b}v[23296]=0;Q(176,g|0,4)|0;b=v[23296];v[23296]=0;if((b|0)!=1){v[23296]=0;f=T(258,g|0)|0;b=v[23296];v[23296]=0;aa:{if((b|0)!=1){v[23296]=0;j=T(258,g|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break P}j=s?j:(j>>>0)/y[a+480196>>2]|0;if(!C|f>>>0>255){break N}v[23296]=0;b=W(214,l|0,f|0,j|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break P}if(b){break aa}break N}a=P()|0;O()|0;break O}if(!s){h=0;v[23296]=0;Q(176,g|0,4)|0;b=v[23296];v[23296]=0;if((b|0)==1){break P}while(1){A=h&65535;if(A>>>0>=x[z>>1]){break N}v[23296]=0;b=T(258,g|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break _}v[23296]=0;U(178,d+48|0,g|0,b+(b&1)&65535);b=v[23296];v[23296]=0;if((b|0)==1){break Q}b=d+48|0;e=jc(d+112|0,b);Ab(b);v[d+48>>2]=0;v[d+52>>2]=0;n=0;ba:{while(1){b=v[e>>2];v[23296]=0;b=W(144,b|0,v[d+120>>2],6)|0;i=v[23296];v[23296]=0;if((i|0)==1){break ba}i=v[d+48>>2];if(b&i>>>0<j>>>0){b=$b(v[l>>2],f);b=fd(v[b>>2],v[v[b+48>>2]+12>>2],i,A);v[23296]=0;R(334,d+32|0,e|0);i=v[23296];v[23296]=0;ca:{da:{if((i|0)!=1){i=d+32|0;k=kd(i);F=Ue(i);o=Ci(i);p=kc(i);q=t[d+32|0];if((q-1&255)>>>0>95){break da}t[b|0]=q+13;if(!v[d+52>>2]){break ca}t[b+3|0]=19;v[d+12>>2]=15;G=b,H=w[td(r,d+12|0)|0]|208,t[G+5|0]=H;break ca}break R}if((q|0)>=0){break ca}if(v[d+52>>2]){t[b+3|0]=19;v[d+12>>2]=15;G=b,H=w[td(r,d+12|0)|0]|192,t[G+5|0]=H;break ca}t[b|0]=254}if(w[k|0]){t[b+2|0]=1;t[d+12|0]=64;G=b,H=w[Wb(k,d+12|0)|0],t[G+4|0]=H}k=w[F|0];if(k){t[b+1|0]=k}k=w[o|0];if(k|w[p|0]){t[b+3|0]=k;t[b+5|0]=w[p|0];Of(b)}k=d+48|0;b=w[i+5|0];if(b&128){v[23296]=0;i=T(194,e|0)|0;p=v[23296];v[23296]=0;if((p|0)==1){break R}b=i|b<<8&32512}n=b+n|0;pB(k,n,v[a+480196>>2]);continue}break}Ab(e);h=h+1|0;continue}break}break R}h=0;b=$b(v[l>>2],f);b=fd(v[b>>2],v[v[b+48>>2]+12>>2],0,0);ea:while(1){f=0;if((h|0)==(j|0)){break N}while(1){if(x[z>>1]<=(f&65535)>>>0){h=h+1|0;continue ea}v[23296]=0;R(335,d+112|0,g|0);e=v[23296];v[23296]=0;if((e|0)==1){break Z}fa:{if(!E){e=v[d+112>>2];v[d+48>>2]=e;i=d+48|0;n=kd(i);k=Ue(i);i=Ci(i);if(e<<24>>24>0){t[b|0]=(B((e&240)>>>4|0,12)+(e&15)|0)+12}e=w[n|0];if(e>>>0>=4){t[b+2|0]=1;t[b+4|0]=(e>>>2|0)-1;e=w[n|0]}t[b+1|0]=e<<4&48|w[k|0]>>>4;t[b+3|0]=w[k|0]&15;t[b+5|0]=w[i|0];break fa}e=v[d+112>>2];v[d+8>>2]=e;v[d+4>>2]=e;gu(d+4|0,b);G=b,H=w[b+1|0]|w[Lb(d+112|0,0)|0]&48,t[G+1|0]=H}Of(b);e=w[b+3|0];ga:{if(e>>>0>11){break ga}e=1<<e;ha:{if(!(e&2240)){if(!(e&12)){break ga}if(!w[b+5|0]){break ha}break ga}e=w[b+5|0];i=e&240;if(i){t[b+5|0]=i;break ga}if(e){break ga}}t[b+3|0]=0}b=b+6|0;f=f+1|0;continue}}}a=P()|0;O()|0;break O}v[23296]=0;b=T(262,v[d+112>>2])|0;e=v[23296];v[23296]=0;ia:{ja:{ka:{la:{ma:{if((e|0)!=1){if(b){e=Kb(d+48|0);f=a+484348|0;b=0;na:{while(1){oa:{v[23296]=0;g=W(144,v[d+112>>2],v[d+120>>2],1)|0;h=v[23296];v[23296]=0;if((h|0)==1){break oa}if(!g){break na}if(pf(v[a+484344>>2],v[f>>2])>>>0<=b>>>0){break na}v[23296]=0;U(336,d+112|0,e|0,32);g=v[23296];v[23296]=0;if((g|0)==1){break oa}g=v[l>>2];v[23296]=0;R(268,$b(g,b)|0,e|0);g=v[23296];v[23296]=0;if((g|0)==1){break oa}b=b+1|0;continue}break}a=P()|0;O()|0;yb(e);break ma}yb(e)}b=d+112|0;Ab(b);v[23296]=0;U(325,b|0,d+200|0,1414679374);b=v[23296];v[23296]=0;if((b|0)==1){break la}v[23296]=0;b=T(262,v[d+112>>2])|0;e=v[23296];v[23296]=0;if((e|0)==1){break T}if(!b){break ia}e=Kb(d+48|0);f=a+480188|0;b=0;while(1){v[23296]=0;g=W(144,v[d+112>>2],v[d+120>>2],1)|0;h=v[23296];v[23296]=0;if((h|0)==1){break ka}if(!(g&x[f>>1]>b>>>0)){break ja}v[23296]=0;U(336,d+112|0,e|0,32);g=v[23296];v[23296]=0;if((g|0)==1){break ka}wm(((b<<5)+a|0)+480289|0,e);b=b+1|0;continue}}a=P()|0;O()|0}Ab(d+112|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(e);break S}yb(e)}b=d+112|0;Ab(b);v[23296]=0;U(333,b|0,d+200|0,1145129300);b=v[23296];v[23296]=0;if((b|0)==1){break U}G=d,H=Eb(v[d+112>>2]),v[G+48>>2]=H;e=c&2;f=Eb(v[d+116>>2]);g=a+480190|0;pa:{qa:{ra:{sa:{ta:{ua:{while(1){b=v[d+48>>2];if(!Rb(b,f)){ld(d+112|0);b=Kb(d+48|0);if((m|0)!=841887798){break ta}v[23296]=0;c=Q(1,d+112|0,9392)|0;e=v[23296];v[23296]=0;if((e|0)==1){break ua}Hb(b,c);zb(c);break sa}v[23296]=0;c=T(258,b|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break V}va:{if(!(!e|c>>>0>=x[g>>1])){c=B(c,104)+a|0;h=x[c+484518>>1];h=_c(d+176|0,h&1?16:8,h&64?2:1,1,0);v[23296]=0;W(207,h|0,c+484484|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break va}}vh(d+48|0);continue}break}break V}a=P()|0;O()|0;break W}v[23296]=0;U(325,d+112|0,d+200|0,1447383635);c=v[23296];v[23296]=0;wa:{xa:{ya:{za:{Aa:{if((c|0)!=1){v[23296]=0;c=T(262,v[d+112>>2])|0;e=v[23296];v[23296]=0;if((e|0)==1){break ra}if(!c){break xa}v[23296]=0;c=T(266,d+112|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break Aa}v[23296]=0;R(253,d+32|0,4253);e=v[23296];v[23296]=0;if((e|0)==1){break za}v[d+16>>2]=c>>>4;v[23296]=0;v[d+12>>2]=c&15;X(337,d+176|0,d+32|0,d+16|0,d+12|0);c=v[23296];v[23296]=0;if((c|0)==1){break ya}c=d+176|0;Hb(b,c);zb(c);ec(d+32|0);break wa}a=P()|0;O()|0;break W}a=P()|0;O()|0;break X}a=P()|0;O()|0;break X}a=P()|0;O()|0;ec(d+32|0);break X}v[23296]=0;c=Q(1,d+176|0,8427)|0;e=v[23296];v[23296]=0;if((e|0)==1){break Y}Hb(b,c);zb(c)}Ab(d+112|0)}v[23296]=0;c=Q(1,d+32|0,8427)|0;e=v[23296];v[23296]=0;if((e|0)==1){break qa}Hb(a+1298344|0,c);zb(c);v[23296]=0;c=Q(1,d+16|0,10025)|0;e=v[23296];v[23296]=0;if((e|0)==1){break pa}Hb(a+1298356|0,c);zb(c);Hb(a+1298368|0,b);v[a+1298404>>2]=13;zb(b);f=1;break o}a=P()|0;O()|0;break X}a=P()|0;O()|0;break W}a=P()|0;O()|0;break W}a=P()|0;O()|0;break O}a=P()|0;O()|0;break O}a=P()|0;O()|0}Ab(d+112|0)}zb(b);break b}a=P()|0;O()|0;ld(d+112|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}Ab(d+112|0);break b}a=P()|0;O()|0;Ab(e);break O}a=P()|0;O()|0;break O}a=P()|0;O()|0}ld(d+176|0);break b}vh(d+16|0);continue}}f=0}_d(d+200|0)}jb=d+240|0;return f|0}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;Ab(d+176|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break b}a=P()|0;O()|0}Ab(d+48|0);break b}a=P()|0;O()|0;Ab(d+112|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ab(d+176|0)}_d(d+200|0)}S(a|0);L()}function SU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;d=jb-448|0;jb=d;Ac(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{if(!Zh(b,d+440|0)){break F}if(!HB(d+440|0)){break F}if(!c){o=1;break F}p=ie(d+416|0,b);v[23296]=0;R(248,d+400|0,p|0);b=v[23296];v[23296]=0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{if((b|0)!=1){v[23296]=0;U(249,d+224|0,d+400|0,1229866575);b=v[23296];v[23296]=0;if((b|0)==1){break da}v[23296]=0;o=Q(250,d+224|0,d+384|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break fa}Ab(d+224|0);if(!o){break G}v[23296]=0;R(234,a|0,524288);b=v[23296];v[23296]=0;ga:{if((b|0)==1){break ga}Dg(a);v[a+480208>>2]=12;G=a+480188|0,H=Xd(Mb(x[d+392>>1]),1,127),u[G>>1]=H;G=d,H=Mb(x[d+384>>1]),u[G+224>>1]=H;u[d+328>>1]=255;G=a+480192|0,H=x[Zc(d+224|0,d+328|0)>>1],u[G>>1]=H;G=d,H=Mb(x[d+386>>1]),u[G+224>>1]=H;u[d+328>>1]=3999;G=a+480190|0,H=x[Zc(d+224|0,d+328|0)>>1],u[G>>1]=H;v[23296]=0;b=W(251,a+1074312|0,6,1)|0;e=v[23296];v[23296]=0;if((e|0)==1){break ga}v[23296]=0;b=Q(252,b|0,21)|0;e=v[23296];v[23296]=0;if((e|0)==1){break ga}v[23296]=0;Q(252,b|0,13)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break ea}}b=P()|0;O()|0;break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;Ab(d+224|0);break b}v[23296]=0;b=Q(1,d+368|0,9184)|0;e=v[23296];v[23296]=0;if((e|0)==1){break c}Hb(a+1298344|0,b);zb(b);v[23296]=0;b=Q(1,d+352|0,10209)|0;e=v[23296];v[23296]=0;if((e|0)==1){break d}Hb(a+1298356|0,b);zb(b);v[23296]=0;R(253,d+328|0,4297);b=v[23296];v[23296]=0;if((b|0)==1){break e}v[23296]=0;R(254,d+304|0,d+440|4);b=v[23296];v[23296]=0;if((b|0)==1){break g}v[23296]=0;R(254,d+280|0,d+440|5);b=v[23296];v[23296]=0;if((b|0)==1){break i}v[23296]=0;X(99,d+224|0,d+328|0,d+304|0,d+280|0);b=v[23296];v[23296]=0;if((b|0)==1){break j}b=d+224|0;Hb(a+1298368|0,b);zb(b);zb(d+280|0);zb(d+304|0);b=d+328|0;ec(b);v[a+1298404>>2]=13;v[23296]=0;U(249,b|0,d+400|0,1312902469);b=v[23296];v[23296]=0;if((b|0)==1){break k}v[23296]=0;b=T(148,v[d+328>>2])|0;e=v[23296];v[23296]=0;if((e|0)==1){break m}v[23296]=0;g=a+1298308|0;U(255,d+328|0,g|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break m}v[23296]=0;U(249,d+304|0,d+400|0,1397706311);b=v[23296];v[23296]=0;if((b|0)==1){break n}i=a+484360|0;e=a+484376|0;Hc(Zb(v[i>>2],w[e|0]));h=Mb(x[d+388>>1]);ha:{ia:{while(1){if(h>>>0<=(f&65535)>>>0){break ha}v[23296]=0;b=W(144,v[d+304>>2],v[d+312>>2],46)|0;j=v[23296];v[23296]=0;ja:{if((j|0)!=1){if(!b){break ha}v[23296]=0;R(256,d+304|0,d+224|0);b=v[23296];v[23296]=0;if((b|0)!=1){if(!De(g)){break ja}v[23296]=0;R(257,g|0,d+224|0);b=v[23296];v[23296]=0;if((b|0)!=1){break ja}}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}v[23296]=0;j=T(258,d+304|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break ca}b=Zb(v[a+484360>>2],w[e|0]);if(!uc(v[b>>2],v[b+4>>2])){v[23296]=0;b=T(259,i|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break ca}if((b|0)==255){break ha}b=Zb(v[a+484360>>2],w[e|0])}v[23296]=0;U(5,d+280|0,13,d+224|0);l=v[23296];v[23296]=0;if((l|0)!=1){v[23296]=0;R(260,b|0,d+280|0);b=v[23296];v[23296]=0;if((b|0)==1){break ia}zb(d+280|0);b=w[e|0];l=v[a+484360>>2];v[23296]=0;U(261,Zb(l,b)|0,d+304|0,j|0);b=v[23296];v[23296]=0;if((b|0)==1){break ca}f=f+1|0;continue}break}b=P()|0;O()|0;break o}b=P()|0;O()|0;zb(d+280|0);break o}Ai(i,0);v[23296]=0;U(249,d+280|0,d+400|0,1229869908);b=v[23296];v[23296]=0;if((b|0)==1){break ba}v[23296]=0;b=T(262,v[d+280>>2])|0;f=v[23296];v[23296]=0;if((f|0)==1){break p}ka:{if(!b){break ka}g=a+480192|0;f=1;la:{while(1){b=f&65535;if(b>>>0>x[g>>1]){v[23296]=0;U(249,d+200|0,d+400|0,1447382614);b=v[23296];v[23296]=0;if((b|0)!=1){break la}break p}v[23296]=0;R(263,d+280|0,d+224|0);e=v[23296];v[23296]=0;if((e|0)==1){break p}e=x[d+254>>1];v[23296]=0;b=W(239,a|0,b|0,Mb(e)|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break p}ma:{na:{if(!b){break na}if(Mb(x[d+254>>1])>>>0>3999){break na}e=d+112|0;vu(e,2,d+224|0);v[23296]=0;R(210,d+136|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break ma}e=d+136|0;Ec(b+492|0,e);yb(e);i=d+112|0;vu(i,2,d+224|0);v[23296]=0;R(210,e|0,i|0);e=v[23296];v[23296]=0;if((e|0)==1){break p}e=d+136|0;Ec(((Mb(x[d+254>>1])<<5)+a|0)+946304|0,e);yb(e);v[b>>2]=0;G=b,H=Mb(x[d+270>>1])+128&65535,v[G+8>>2]=H;yc(b+8|0,256);t[b+15|0]=w[b+15|0]|1;b=x[d+254>>1];v[23296]=0;b=B(Mb(b),104)+a|0;R(264,b+484380|0,0);e=v[23296];v[23296]=0;if((e|0)==1){break p}G=d,H=Mb(x[d+256>>1]),u[G+136>>1]=H;u[d+112>>1]=64;G=b+484410|0,H=x[Zc(d+136|0,d+112|0)>>1]<<2,u[G>>1]=H;G=b+484404|0,H=cc(x[d+258>>1]|x[d+260>>1]<<16),v[G>>2]=H;e=cc(x[d+266>>1]|x[d+268>>1]<<16);if(!e){break na}i=Mb(x[d+272>>1]);if(!(i&3)){break na}h=e;e=cc(x[d+262>>1]|x[d+264>>1]<<16);v[b+484388>>2]=h+e;v[b+484384>>2]=e;b=b+484414|0;e=x[b>>1];u[b>>1]=e|2;if(!(i&2)){break na}u[b>>1]=e|6}f=f+1|0;continue}break}break p}b=v[d+212>>2];v[d+32>>2]=v[d+208>>2];v[d+36>>2]=b;v[d+40>>2]=v[d+216>>2];v[23296]=0;b=v[d+204>>2];v[d+24>>2]=v[d+200>>2];v[d+28>>2]=b;X(265,d+24|0,0,a|0,0);b=v[23296];v[23296]=0;if((b|0)==1){break p}v[23296]=0;U(249,d+176|0,d+400|0,1346719318);b=v[23296];v[23296]=0;if((b|0)==1){break p}b=v[d+188>>2];v[d+8>>2]=v[d+184>>2];v[d+12>>2]=b;v[d+16>>2]=v[d+192>>2];v[23296]=0;b=v[d+180>>2];v[d>>2]=v[d+176>>2];v[d+4>>2]=b;X(265,d|0,1,a|0,w[d+444|0]>2|0);b=v[23296];v[23296]=0;if((b|0)==1){break p}e=x[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(e|0)){break ka}f=v[((b<<2)+a|0)+900380>>2];if(!(!f|t[f+60|0]&1)){v[f>>2]=32767}b=b+1|0;continue}}Ab(d+280|0);v[23296]=0;U(249,d+224|0,d+400|0,1346458708);b=v[23296];v[23296]=0;if((b|0)==1){break q}v[23296]=0;b=T(166,v[d+224>>2])|0;f=v[23296];v[23296]=0;if((f|0)==1){break s}if(!(!(c&1)|b^1)){v[23296]=0;U(249,d+280|0,d+400|0,1347305805);b=v[23296];v[23296]=0;if((b|0)==1){break t}v[23296]=0;Q(176,d+280|0,1)|0;b=v[23296];v[23296]=0;if((b|0)==1){break v}b=x[d+390>>1];v[23296]=0;l=a+484344|0;R(213,l|0,Mb(b)|0);b=v[23296];v[23296]=0;if((b|0)==1){break v}b=d+112|0;r=b|5;s=b|3;y=b|4;z=b|2;A=b|1;i=Qb(d+160|0);C=a+480188|0;f=0;while(1){if(Mb(x[d+390>>1])>>>0<=f>>>0){ud(i);Ab(d+280|0);if(!(c&4)){break $}f=0;if(!D){break aa}e=x[a+480188>>1];b=0;f=1;while(1){if((b|0)==(e|0)){break aa}g=(b<<5)+a|0;t[g+480288|0]=1;g=g+480280|0;v[g>>2]=v[g>>2]|67108864;b=b+1|0;continue}}v[23296]=0;b=T(258,d+224|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break x}v[23296]=0;e=T(266,d+224|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break y}v[23296]=0;U(178,d+112|0,d+224|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break z}e=d+112|0;g=jc(d+136|0,e);Ab(e);v[23296]=0;e=W(214,l|0,f&65535,b|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break B}oa:{if(e){n=Kb(d+96|0);v[23296]=0;R(267,d+280|0,n|0);e=v[23296];v[23296]=0;if((e|0)==1){break oa}e=v[l>>2];v[23296]=0;R(268,$b(e,f)|0,n|0);e=v[23296];v[23296]=0;if((e|0)==1){break oa}e=0;h=$b(v[l>>2],f);q=Qf(v[h>>2],v[v[h+48>>2]+12>>2],0);Hc(i);E=(b>>>0>1?b:1)-1|0;pa:while(1){b=v[g>>2];v[23296]=0;b=W(144,b|0,v[d+144>>2],1)|0;h=v[23296];v[23296]=0;if((h|0)==1){break C}qa:{if(!b){break qa}v[23296]=0;j=T(194,g|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break C}if(!j){G=d,H=Eb(v[i>>2]),v[G+88>>2]=H;h=Eb(v[i+4>>2]);while(1){b=v[d+88>>2];if(Rb(b,h)){qe($b(v[l>>2],f),Ke(Fe(d+112|0,w[b|0],w[b+1|0]),e));Se(d+88|0);continue}else{Hc(i);if((e|0)==(E|0)){break qa}b=$b(v[l>>2],f);e=e+1|0;q=Qf(v[b>>2],v[v[b+48>>2]+12>>2],e);continue pa}}}wh(d+112|0);h=x[C>>1];v[23296]=0;b=T(194,g|0)|0;k=v[23296];v[23296]=0;ra:{sa:{if((k|0)!=1){h=h>>>0<j>>>0;j=B(j-1|0,6)+q|0;ta:{if(!(b&1)){break ta}v[23296]=0;k=T(194,g|0)|0;m=v[23296];v[23296]=0;if((m|0)==1){break C}m=h?d+112|0:j;if((k|0)!=31){if((k-1&255)>>>0>252){break ta}k=(B(k>>>4|0,12)+(k&15)|0)+13|0}else{k=255}t[m|0]=k}if(!(b&2)){break ra}v[23296]=0;k=T(194,g|0)|0;m=v[23296];v[23296]=0;if((m|0)!=1){break sa}}break C}t[(h?A:j+1|0)|0]=k}if(!(b&60)){continue}t[d+87|0]=0;t[d+86|0]=0;t[d+85|0]=0;t[d+84|0]=0;if(b&4){v[23296]=0;k=T(194,g|0)|0;m=v[23296];v[23296]=0;if((m|0)==1){break C}t[d+86|0]=k}if(b&8){v[23296]=0;k=T(194,g|0)|0;m=v[23296];v[23296]=0;if((m|0)==1){break C}t[d+84|0]=k}if(b&16){v[23296]=0;k=T(194,g|0)|0;m=v[23296];v[23296]=0;if((m|0)==1){break C}t[d+87|0]=k}if(b&32){v[23296]=0;b=T(194,g|0)|0;k=v[23296];v[23296]=0;if((k|0)==1){break C}t[d+85|0]=b}DB(d+87|0,d+85|0);DB(d+86|0,d+84|0);b=w[d+86|0];if(!(w[d+87|0]==13|b?(b|0)!=13:0)){ah(d+87|0,d+86|0);ah(d+85|0,d+84|0)}uo(d+88|0,d+87|0,d+85|0,d+86|0,d+84|0);if(CB(w[d+88|0],w[d+89|0])){b=v[hc(d+80|0,Eb(v[i>>2]))>>2];v[23296]=0;U(269,i|0,b|0,d+88|0);b=v[23296];v[23296]=0;if((b|0)==1){break C}}t[(h?z:j+2|0)|0]=w[d+87|0];t[(h?y:j+4|0)|0]=w[d+85|0];b=w[d+86|0];t[(h?s:j+3|0)|0]=b;t[(h?r:j+5|0)|0]=w[d+84|0];if((b|0)==43){D=1;continue}if((b|0)!=31){continue}F=1;continue}break}yb(n)}Ab(g);f=f+1|0;continue}break}break C}f=0;if(c&4){break aa}break H}b=P()|0;O()|0;break b}b=P()|0;O()|0;break o}b=P()|0;O()|0;break o}v[d+160>>2]=-1778364416;v[d+164>>2]=-16756736;v[23296]=0;U(249,d+280|0,d+400|0,1146310725);b=v[23296];v[23296]=0;if((b|0)==1){break E}v[23296]=0;b=T(262,v[d+280>>2])|0;e=v[23296];v[23296]=0;if((e|0)==1){break D}if(b){v[23296]=0;i=T(258,d+280|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break D}h=a+480188|0;b=0;e=f;while(1){ua:{if((b|0)==(i|0)){v[23296]=0;R(270,d+280|0,d+160|0);b=v[23296];v[23296]=0;if((b|0)!=1){break ua}break D}v[23296]=0;g=T(194,d+280|0)|0;j=v[23296];v[23296]=0;va:{wa:{if((j|0)!=1){if(x[h>>1]<=b>>>0){break va}if(!f){break wa}j=((b<<5)+a|0)+480280|0;v[j>>2]=v[j>>2]&-67108865|((g|0)!=0)<<26;break va}break D}if(g){break va}e=1;t[((b<<5)+a|0)+480288|0]=1}b=b+1|0;continue}break}f=e&1}Ab(d+280|0);if(!f){break $}v[23296]=0;Y(271,a+906300|0);b=v[23296];v[23296]=0;if((b|0)==1){break _}b=a+906324|0;v[b>>2]=655376;v[b+4>>2]=0;b=a+906316|0;v[b>>2]=810369604;v[b+4>>2]=1869112133;v[d+280>>2]=0;f=a+906348|0;DU(a+906332|0,f,d+280|0);v[23296]=0;b=Q(54,d+136|0,9458)|0;e=v[23296];v[23296]=0;if((e|0)==1){break Z}yB(f,b);yb(b);v[23296]=0;b=Q(54,d+112|0,9422)|0;f=v[23296];v[23296]=0;if((f|0)==1){break Y}uu(a+906380|0,b);yb(b);v[23296]=0;b=a+906304|0;R(272,b|0,8);f=v[23296];v[23296]=0;if((f|0)==1){break _}CU(d+280|0,w[d+161|0],w[d+163|0],w[d+165|0],w[d+167|0]);f=v[d+284>>2];b=v[b>>2];e=v[d+280>>2];t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=f;t[b+5|0]=f>>>8;t[b+6|0]=f>>>16;t[b+7|0]=f>>>24}if(!F){break H}f=a+902204|0;b=0;while(1){if((b|0)==32){break H}v[d+88>>2]=B(b,127)>>>5;v[23296]=0;R(273,d+160|0,4054);e=v[23296];v[23296]=0;if((e|0)==1){break X}v[23296]=0;R(274,d+96|0,d+88|0);e=v[23296];v[23296]=0;if((e|0)==1){break W}v[23296]=0;U(275,d+280|0,d+160|0,d+96|0);e=v[23296];v[23296]=0;if((e|0)==1){break V}e=d+280|0;ve(d+72|0,e);Ye(pe(f,b),v[d+72>>2],v[d+76>>2]);yb(e);yb(d+96|0);e=d+160|0;Tb(e);v[23296]=0;R(273,e|0,4036);e=v[23296];v[23296]=0;if((e|0)==1){break T}v[23296]=0;R(274,d+96|0,d+88|0);e=v[23296];v[23296]=0;if((e|0)==1){break S}v[23296]=0;U(275,d+280|0,d+160|0,d+96|0);e=v[23296];v[23296]=0;if((e|0)==1){break R}e=d+280|0;ve(d- -64|0,e);Ye(pe(f,b+32|0),v[d+64>>2],v[d+68>>2]);yb(e);yb(d+96|0);e=d+160|0;Tb(e);v[23296]=0;R(273,e|0,4027);e=v[23296];v[23296]=0;if((e|0)==1){break P}v[23296]=0;R(274,d+96|0,d+88|0);e=v[23296];v[23296]=0;if((e|0)==1){break O}v[23296]=0;U(275,d+280|0,d+160|0,d+96|0);e=v[23296];v[23296]=0;if((e|0)==1){break N}e=d+280|0;ve(d+56|0,e);Ye(pe(f,b- -64|0),v[d+56>>2],v[d+60>>2]);yb(e);yb(d+96|0);e=d+160|0;Tb(e);v[23296]=0;R(273,e|0,4e3);e=v[23296];v[23296]=0;if((e|0)==1){break L}v[23296]=0;R(274,d+96|0,d+88|0);e=v[23296];v[23296]=0;if((e|0)==1){break K}v[23296]=0;U(275,d+280|0,d+160|0,d+96|0);e=v[23296];v[23296]=0;if((e|0)==1){break J}e=d+280|0;ve(d+48|0,e);Ye(pe(f,b+96|0),v[d+48>>2],v[d+52>>2]);b=b+1|0;yb(e);yb(d+96|0);Tb(d+160|0);continue}}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break U}b=P()|0;O()|0;yb(d+96|0)}Tb(d+160|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break Q}b=P()|0;O()|0;yb(d+96|0)}Tb(d+160|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break M}b=P()|0;O()|0;yb(d+96|0)}Tb(d+160|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0;break I}b=P()|0;O()|0;yb(d+96|0)}Tb(d+160|0);break r}v[23296]=0;U(249,d+280|0,d+400|0,1397575756);b=v[23296];v[23296]=0;xa:{if((b|0)!=1){v[23296]=0;b=T(166,v[d+280>>2])|0;f=v[23296];v[23296]=0;if((f|0)!=1){ya:{f=1;if(!(c&2)|b^1){break xa}c=a+480190|0;while(1){e=f&65535;if(e>>>0>x[c>>1]){break xa}v[23296]=0;b=T(266,d+280|0)|0;g=v[23296];v[23296]=0;za:{if((g|0)!=1){v[23296]=0;g=T(266,d+280|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break ya}if(!(b&7)){break za}e=(B(e,104)+a|0)+484380|0;v[e>>2]=g;b=_c(d+160|0,b&4?32:b&2?16:8,1,1,0);v[23296]=0;W(207,b|0,e|0,d+280|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break za}break ya}break ya}f=f+1|0;continue}}}b=P()|0;O()|0;Ab(d+280|0);break r}b=P()|0;O()|0;break r}Ab(d+280|0);Ab(d+224|0);Ab(d+304|0);Ab(d+328|0)}_d(d+400|0);Ab(p)}jb=d+448|0;return o|0}b=P()|0;O()|0;break r}b=P()|0;O()|0;Ab(d+280|0);break r}b=P()|0;O()|0;yb(n);break A}b=P()|0;O()|0}Ab(g);break w}b=P()|0;O()|0;break w}b=P()|0;O()|0;break w}b=P()|0;O()|0}ud(i);break u}b=P()|0;O()|0}Ab(d+280|0);break r}b=P()|0;O()|0;break r}b=P()|0;O()|0}Ab(d+224|0);break o}b=P()|0;O()|0;break o}b=P()|0;O()|0;Ab(d+280|0)}Ab(d+304|0);break l}b=P()|0;O()|0;break l}b=P()|0;O()|0}Ab(d+328|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;zb(d+280|0);break h}b=P()|0;O()|0}zb(d+304|0);break f}b=P()|0;O()|0}ec(d+328|0);break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0}_d(d+400|0)}Ab(p);S(b|0);L()}function Zda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,V=0,X=0;e=jb-496|0;jb=e;Ac(b);k=jb-16|0;jb=k;m=e+288|0;lQ(k+8|0,m);f=v[k+12>>2];o=b;nc(k,v[b>>2],v[b+8>>2],v[k+8>>2],v[k+12>>2]);b=v[k+4>>2];if((b|0)==(f|0)){ac(o,v[k+12>>2])}jb=k+16|0;b=(b|0)==(f|0);if(!b){kQ(m)}a:{if(!b){break a}if(!mQ(e+288|0)){break a}if(!c){d=1;break a}Ed(a,134217728);b=e+8|0;sg(b,3936);v[23296]=0;U(625,e+120|0,b|0,x[e+292>>1]);b=v[23296];v[23296]=0;b:{c:{d:{e:{f:{g:{if((b|0)!=1){b=e+120|0;Hb(a+1298344|0,b);zb(b);ec(e+8|0);b=Vb(b,8876);Hb(a+1298356|0,b);zb(b);v[a+480188>>2]=4;v[a+1298404>>2]=13;V=a,X=Mb(x[e+424>>1]),v[V+480196>>2]=X;b=x[e+428>>1];v[a+480260>>2]=56;v[a+480264>>2]=13696;V=a,X=jQ(Mb(b)),v[V+480204>>2]=X;tq(Zb(v[a+484360>>2],w[a+484376|0]),e+296|0,w[e+294|0]);r=a+480190|0;i=a+480188|0;p=Qb(e+272|0);z=Qb(e+256|0);h:{i:{j:{k:{while(1){if(Mb(x[e+488>>1])>>>0<=(l&65535)>>>0){break k}v[23296]=0;b=T(258,o|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break g}u[e+232>>1]=b;if((b-4e3&65535)>>>0<=61536){break c}d=Mb(x[e+490>>1]);if((Mb(x[e+292>>1])|0)==2){v[23296]=0;b=T(266,o|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break h}d=b-2|0}v[23296]=0;U(178,e+8|0,o|0,d|0);b=v[23296];v[23296]=0;if((b|0)==1){break i}b=e+8|0;k=jc(e+120|0,b);Ab(b);C=x[We(r,e+232|0)>>1];u[r>>1]=C;v[23296]=0;m=B(x[e+232>>1],104)+a|0;f=m+484380|0;R(264,f|0,1);b=v[23296];v[23296]=0;l:{m:{n:{if((b|0)==1){break n}if(Mb(x[e+292>>1])>>>0>1){break m}v[23296]=0;R(626,k|0,m+484423|0);b=v[23296];v[23296]=0;if((b|0)==1){break n}v[23296]=0;Q(176,k|0,1)|0;b=v[23296];v[23296]=0;if((b|0)==1){break n}v[23296]=0;U(311,k|0,((x[e+232>>1]<<5)+a|0)+946304|0,30);b=v[23296];v[23296]=0;if((b|0)!=1){break l}}f=P()|0;O()|0;break f}b=Kb(e+8|0);v[23296]=0;U(336,k|0,b|0,257);d=v[23296];v[23296]=0;o:{p:{if((d|0)==1){break p}ze(m+484423|0,b);v[23296]=0;Q(176,k|0,1)|0;d=v[23296];v[23296]=0;if((d|0)==1){break p}v[23296]=0;U(336,k|0,b|0,31);d=v[23296];v[23296]=0;if((d|0)==1){break p}Ec(((x[e+232>>1]<<5)+a|0)+946304|0,b);if(!(t[e+128|0]&1)){break o}v[23296]=0;Q(176,k|0,1)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break o}}f=P()|0;O()|0;yb(b);break f}yb(b)}v[23296]=0;R(627,k|0,e+8|0);b=v[23296];v[23296]=0;q:{if((b|0)==1){break q}h=jb-16|0;jb=h;d=cc(w[e+8|0]|w[e+9|0]<<8|(w[e+10|0]<<16|w[e+11|0]<<24));v[f>>2]=d;t[h+15|0]=w[e+12|0];t[h+14|0]=64;V=f,X=w[Wb(h+15|0,h+14|0)|0]<<2,u[V+30>>1]=X;g=cc(w[e+14|0]|w[e+15|0]<<8|(w[e+16|0]<<16|w[e+17|0]<<24));v[f+4>>2]=g;b=cc(w[e+14|0]|w[e+15|0]<<8|(w[e+16|0]<<16|w[e+17|0]<<24))+cc(w[e+18|0]|w[e+19|0]<<8|(w[e+20|0]<<16|w[e+21|0]<<24))|0;v[f+8>>2]=b;if(d>>>0<=g>>>0){g=d-1|0;v[f+4>>2]=g}if(b>>>0>d>>>0){v[f+8>>2]=d;b=d}r:{if(b>>>0<g>>>0){v[f+4>>2]=0;v[f+8>>2]=0;break r}if(b>>>0<=g>>>0){break r}u[f+34>>1]=x[f+34>>1]|2;V=Db(f+68|0,0),X=g,v[V>>2]=X}jb=h+16|0;s:{t:{switch(Mb(x[e+292>>1])|0){case 2:t[m+484417|0]=w[e+26|0]<<3;break;case 0:break s;default:break t}}v[23296]=0;R(202,z|0,C|0);b=v[23296];v[23296]=0;if((b|0)==1){break q}v[23296]=0;R(628,p|0,C|0);b=v[23296];v[23296]=0;if((b|0)==1){break q}f=Hd(v[p>>2],x[e+232>>1]-1|0);Hc(f);v[23296]=0;b=T(258,o|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break j}d=v[o+8>>2];h=v[o>>2];v[23296]=0;d=W(144,h|0,d|0,b<<3)|0;h=v[23296];v[23296]=0;if((h|0)==1){break j}if(d){v[23296]=0;R(629,f|0,b|0);d=v[23296];v[23296]=0;if((d|0)==1){break j}d=0;v[e+248>>2]=0;if(!(!(w[m+484414|0]&2)|b)){b=v[m+484384>>2];v[e+240>>2]=b;d=v[m+484388>>2];v[23296]=0;v[e+244>>2]=d-b;R(630,f|0,e+240|0);b=v[23296];v[23296]=0;if((b|0)!=1){break s}f=P()|0;O()|0;break f}while(1){if(b>>>0<=(d&65535)>>>0){break s}v[23296]=0;m=T(266,o|0)|0;h=v[23296];v[23296]=0;u:{if((h|0)==1){break u}v[23296]=0;v[e+240>>2]=m;m=T(266,o|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break u}v[23296]=0;v[e+244>>2]=m;R(630,f|0,e+240|0);m=v[23296];v[23296]=0;if((m|0)==1){break u}d=d+1|0;continue}break}f=P()|0;O()|0;break f}Ab(k);break c}Ab(k);l=l+1|0;continue}break}f=P()|0;O()|0;break f}v:{w:{x:{y:{if(Mb(x[e+292>>1])){A=w[e+295|0];u[e+238>>1]=4;D=128;break y}v[23296]=0;D=T(258,o|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){f=P()|0;O()|0;break e}b=x[e+292>>1];A=w[e+295|0];u[e+238>>1]=4;if(!Mb(b)){break x}}d=v[o+8>>2];f=0;while(1){z:{if((f&65535)>>>0>=D>>>0){break z}v[23296]=0;b=T(258,o|0)|0;k=v[23296];v[23296]=0;if((k|0)==1){break w}if((b|0)==65535){break z}v[23296]=0;A=T(258,o|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break w}v[23296]=0;b=T(258,o|0)|0;k=v[23296];v[23296]=0;if((k|0)==1){break w}u[e+238>>1]=b;if(b>>>0>127){break c}V=i,X=x[We(i,e+238|0)>>1],u[V>>1]=X;v[23296]=0;Q(176,o|0,B(b,A)<<2)|0;b=v[23296];v[23296]=0;if((b|0)==1){break w}f=f+1|0;continue}break}v[23296]=0;Q(143,o|0,d|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break v}}b=x[i>>1];v[23296]=0;E=Q(631,e+240|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){J=a+484344|0;N=c&1;F=Mb(x[e+426>>1]);b=0;k=0;while(1){A:{B:{C:{D:{if((b&65535)>>>0>=D>>>0){break D}E:{if(!Mb(x[e+292>>1])){d=x[e+238>>1];f=b;break E}v[23296]=0;f=T(258,o|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break A}if((f|0)==65535){break D}v[23296]=0;A=T(258,o|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break A}v[23296]=0;d=T(258,o|0)|0;m=v[23296];v[23296]=0;if((m|0)==1){break A}u[e+238>>1]=d}m=v[o+8>>2];h=v[o>>2];v[23296]=0;g=d&65535;G=A&65535;d=G<<2;m=W(144,h|0,m|0,B(g,d)|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break A}if(!m){break D}if(!N){break C}v[23296]=0;K=f&65535;f=W(214,J|0,K|0,G|0)|0;m=v[23296];v[23296]=0;if((m|0)==1){break A}if(!f){break C}s=0;F:while(1){if((s|0)==(G|0)){break B}f=0;d=$b(v[J>>2],K);i=Qf(v[d>>2],v[v[d+48>>2]+12>>2],s);H=0;m=0;G:{H:{I:{switch((F&3)-1|0){case 0:m=!(s&3);break H;case 1:m=!(s&1);break H;case 2:break I;default:break G}}m=(s&3)!=3}}while(1){if(x[e+238>>1]<=f>>>0){s=s+1|0;continue F}d=v[E>>2];v[23296]=0;R(335,e+232|0,o|0);h=v[23296];v[23296]=0;if((h|0)==1){break A}h=B(f,9)+d|0;d=e+232|0;g=kd(d);q=Ue(d);l=i+B(f,6)|0;t[l+1|0]=w[e+232|0];j=w[g|0];t[l|0]=j;g=w[Ci(d)|0];t[l+5|0]=g;n=l+5|0;if(j){t[l|0]=j+25;t[h+8|0]=0;t[h|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[h+3|0]=0;t[h+4|0]=0;t[h+5|0]=0;t[h+6|0]=0;t[h+7|0]=0;g=w[n|0]}j=g&255;q=w[q|0];J:{if(q>>>0>=240){d=j|(q&15)<<8;if(d){V=n,X=io(+(jQ(d)>>>0)/1e4),t[V|0]=X;t[l+3|0]=17;break J}t[l+3|0]=0;break J}I=j>>>4|0;M=j<<4;d=I|M;K:{switch(q|0){case 0:d=i+B(f,6)|0;if(g&255){t[d+3|0]=1;break J}t[d+3|0]=0;break J;case 1:t[(i+B(f,6)|0)+3|0]=2;break J;case 2:t[(i+B(f,6)|0)+3|0]=3;break J;case 3:t[e+228|0]=15;V=h,X=w[Wb(n,e+228|0)|0]|16,t[V|0]=X;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(i+B(f,6)|0)+3|0]=0;break J;case 4:t[e+228|0]=15;V=h,X=w[Wb(n,e+228|0)|0]|32,t[V|0]=X;t[h+7|0]=0;t[h+1|0]=0;t[h+2|0]=0;t[(i+B(f,6)|0)+3|0]=0;break J;case 5:t[h+7|0]=0;t[h+2|0]=0;t[h+1|0]=g;t[h|0]=0;t[(i+B(f,6)|0)+3|0]=0;break J;case 6:t[h+7|0]=0;t[h+2|0]=g;t[h|0]=0;t[h+1|0]=0;t[(i+B(f,6)|0)+3|0]=0;break J;case 7:t[(i+B(f,6)|0)+3|0]=23;k=0;break J;case 8:t[(i+B(f,6)|0)+3|0]=0;k=d;break J;case 9:t[(i+B(f,6)|0)+3|0]=19;t[e+228|0]=15;V=n,X=w[Wb(n,e+228|0)|0]|16,t[V|0]=X;break J;case 10:t[(i+B(f,6)|0)+3|0]=19;t[e+228|0]=15;V=n,X=w[Wb(n,e+228|0)|0]|32,t[V|0]=X;break J;case 11:t[h+3|0]=d;t[(i+B(f,6)|0)+3|0]=0;break J;case 12:d=i+B(f,6)|0;t[d+4|0]=g;t[d+2|0]=1;t[h+3|0]=0;t[d+3|0]=0;break J;case 13:q=i+B(f,6)|0;L:{M:{if(j&240){t[(i+B(f,6)|0)+2|0]=4;d=(g&240)>>>4|0;break M}if(!(j&15)){break L}t[(i+B(f,6)|0)+2|0]=3;d=g&15}t[q+4|0]=d}t[h+3|0]=0;t[(i+B(f,6)|0)+3|0]=0;break J;case 14:t[(i+B(f,6)|0)+3|0]=19;t[n|0]=!(g&255);break J;case 15:t[(i+B(f,6)|0)+3|0]=16;t[n|0]=(g&240)>>>4;F=g&15;break J;case 16:t[h+5|0]=0;t[h+4|0]=g;t[(i+B(f,6)|0)+3|0]=0;break J;case 17:t[h+6|0]=j&15?g:0;t[(i+B(f,6)|0)+3|0]=0;break J;case 18:t[(i+B(f,6)|0)+3|0]=14;break J;case 19:t[h+8|0]=0;t[h+7|0]=g;t[h+2|0]=0;t[h|0]=0;t[h+1|0]=0;t[(i+B(f,6)|0)+3|0]=0;break J;case 20:t[(i+B(f,6)|0)+3|0]=12;break J;case 22:d=w[l+1|0];N:{if(!d){break N}j=v[p>>2];if(wd(j,v[p+4>>2])>>>0<d>>>0){break N}g=g-1|0;t[n|0]=g;v[23296]=0;T(632,e+120|0)|0;q=v[23296];v[23296]=0;if((q|0)==1){break A}v[e+228>>2]=9;d=Hd(j,d-1|0);V=e,X=wd(v[d>>2],v[d+4>>2]),v[V+116>>2]=X;if(y[Ib(e+228|0,e+116|0)>>2]<=(g&255)>>>0){break N}d=i+B(f,6)|0;t[d+2|0]=15;t[d+4|0]=w[n|0]}t[(i+B(f,6)|0)+3|0]=0;break J;case 23:d=w[l+1|0];O:{if(!d){break O}j=v[p>>2];if(wd(j,v[p+4>>2])>>>0<d>>>0){break O}g=g-1|0;t[n|0]=g;d=Hd(j,d-1|0);j=v[d>>2];q=wd(j,v[d+4>>2]);d=g&255;if(q>>>0<=d>>>0){break O}d=Hd(j,d);g=x[d+8>>1];P:{if(g){break P}g=0;j=x[r>>1];if(!Sh(j)){break P}g=j+1|0;u[r>>1]=g;u[d+8>>1]=g}t[l+1|0]=g}t[(i+B(f,6)|0)+3|0]=0;break J;case 24:d=w[l+1|0];Q:{if(!d){break Q}j=v[p>>2];if(wd(j,v[p+4>>2])>>>0<d>>>0){break Q}g=g-1|0;t[n|0]=g;v[23296]=0;T(632,e+8|0)|0;q=v[23296];v[23296]=0;if((q|0)==1){break A}v[e+228>>2]=9;d=Hd(j,d-1|0);V=e,X=wd(v[d>>2],v[d+4>>2]),v[V+116>>2]=X;if(y[Ib(e+228|0,e+116|0)>>2]>(g&255)>>>0){d=i+B(f,6)|0;t[d+2|0]=15;t[d+4|0]=w[n|0]}d=dc(v[z>>2],w[l+1|0]-1|0);g=x[d>>1];R:{if(g){break R}g=0;j=x[r>>1];if(!Sh(j)){break R}g=j+1|0;u[r>>1]=g;u[d>>1]=g}t[l+1|0]=g}t[(i+B(f,6)|0)+3|0]=0;break J;case 25:d=w[l+1|0];S:{if(!d){break S}j=v[p>>2];if(wd(j,v[p+4>>2])>>>0<d>>>0){break S}g=g-1|0;t[n|0]=g;d=Hd(j,d-1|0);j=v[d>>2];q=wd(j,v[d+4>>2]);d=g&255;if(q>>>0<=d>>>0){break S}d=Hd(j,d);g=x[d+10>>1];T:{if(g){break T}g=0;j=x[r>>1];if(!Sh(j)){break T}g=j+1|0;u[r>>1]=g;u[d+10>>1]=g}t[l+1|0]=g}t[(i+B(f,6)|0)+3|0]=0;break J;case 29:t[(i+B(f,6)|0)+3|0]=11;t[n|0]=d;if(j&15){t[n|0]=M|15;break J}if((g&255)>>>0<16){break J}t[n|0]=I|240;break J;case 32:if(j&240){t[h+3|0]=I;t[(i+B(f,6)|0)+3|0]=0;break J}t[(i+B(f,6)|0)+3|0]=19;t[n|0]=g&15|192;break J;case 33:t[(i+B(f,6)|0)+3|0]=19;t[e+228|0]=15;V=n,X=w[Wb(n,e+228|0)|0]|208,t[V|0]=X;break J;case 34:t[(i+B(f,6)|0)+3|0]=19;t[e+228|0]=15;V=n,X=w[Wb(n,e+228|0)|0]|144,t[V|0]=X;break J;case 73:t[(i+B(f,6)|0)+3|0]=10;break J;case 78:if((g&112|128)==224){t[(i+B(f,6)|0)+3|0]=19;break J}t[(i+B(f,6)|0)+3|0]=0;break J;case 79:d=i+B(f,6)|0;if((g&255)>>>0<=31){t[d+3|0]=16;F=0;break J}t[d+3|0]=17;break J;default:break K}}t[(i+B(f,6)|0)+3|0]=0}j=0;g=w[h+3|0];if(!(w[l+2|0]|!g)){U:{if(g>>>0>=16){t[l+2|0]=5;g=g>>>4|0;break U}t[l+2|0]=6}t[l+4|0]=g;j=1}V:{if(w[l+3|0]){break V}d=w[h+1|0];W:{if(d){t[l+3|0]=2;break W}d=w[h+2|0];if(d){t[l+3|0]=3;break W}d=w[h|0];if(d){t[l+3|0]=19;break W}d=w[h+7|0];if(d){t[l+3|0]=4;t[h+8|0]=d;break W}d=w[h+4|0];if(d){t[l+3|0]=5;t[h+5|0]=d;break W}d=w[h+3|0];if(!(!d|j)){t[l+3|0]=11;t[n|0]=d;if(d&15){d=d|-16;break W}if(!(d&240)){break V}d=d|15;break W}d=w[h+6|0];if(d){t[l+3|0]=8;break W}if(m){t[l+3|0]=20;m=0;d=97;break W}m=0;if(H){break V}d=k&255;if(!d){break V}t[l+3|0]=24;t[n|0]=k;if(k&15){d=k|-16}else{if(!(d&240)){H=1;break V}d=k|15}H=1}t[n|0]=d}f=f+1|0;continue}}}v[a+480228>>2]=256/x[a+480188>>1];j=1;xh(a,1);if(Mb(x[e+292>>1])){X:{while(1){b=v[o+8>>2];d=v[o>>2];v[23296]=0;b=W(144,d|0,b|0,2)|0;d=v[23296];v[23296]=0;if((d|0)==1){break A}if(!b){break X}v[23296]=0;b=T(258,o|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break A}if((b|0)==65535){break X}v[23296]=0;Q(176,o|0,2)|0;b=v[23296];v[23296]=0;if((b|0)==1){break A}v[23296]=0;b=T(266,o|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){v[23296]=0;Q(176,o|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){continue}}break}break A}v[23296]=0;Q(176,o|0,34)|0;b=v[23296];v[23296]=0;if((b|0)==1){break A}}Y:{if(!(c&2)){break Y}while(1){b=j&65535;if(b>>>0>C>>>0){break Y}Z:{d=(B(b,104)+a|0)+484380|0;if(!v[d>>2]){break Z}c=_c(e+232|0,8,1,0,0);v[23296]=0;W(207,c|0,d|0,o|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break A}c=v[p>>2];if(wd(c,v[p+4>>2])>>>0<b>>>0){break Z}g=b-1|0;m=Hd(c,g);c=0;b=0;i=jb-112|0;jb=i;_:{h=v[d>>2];if(!Ud(h,v[d+20>>2])){break _}n=v[m>>2];k=wd(n,v[m+4>>2]);if(k>>>0<2){break _}f=go(i+8|0,d);v[f+20>>2]=0;v[f>>2]=0;$:{while(1){if((c|0)==(k|0)){break $}aa:{l=Hd(n,c);r=v[l>>2];if(r>>>0>=h>>>0){break aa}l=v[l+4>>2];if(l>>>0>h-r>>>0|268435456-l>>>0<b>>>0){break aa}b=b+l|0;v[f>>2]=b;c=c+1|0;continue}break}k=c}if(!Bg(f)){break _}l=f+68|0;b=0;c=0;while(1){if((c|0)==(k|0)){hm(d);b=go(d,f);v[b+4>>2]=0;v[b+8>>2]=v[b>>2];u[b+34>>1]=x[b+34>>1]|2;break _}n=v[f+20>>2]+b|0;r=v[d+20>>2];h=Hd(v[m>>2],c);qc(n,r+v[h>>2]|0,v[h+4>>2]);v[h>>2]=b;if(c-10>>>0>=4294967287){V=Db(l,c-1|0),X=b,v[V>>2]=X}c=c+1|0;b=v[h+4>>2]+b|0;continue}}jb=i+112|0;b=x[dc(v[z>>2],g)>>1];if(b){Oz(d,(B(b,104)+a|0)+484380|0,0,v[d>>2],0)}b=Hd(v[p>>2],g);V=e,X=Eb(v[b>>2]),v[V+232>>2]=X;c=Eb(v[b+4>>2]);while(1){b=v[e+232>>2];if(!Rb(b,c)){break Z}k=x[b+8>>1];if(k){Oz(d,(B(k,104)+a|0)+484380|0,v[b>>2],v[b+4>>2],1)}k=x[b+10>>1];if(k){Oz(d,(B(k,104)+a|0)+484380|0,v[b>>2],v[b+4>>2],0)}$p(e+232|0);continue}}j=j+1|0;continue}}Bt(E);d=1;break b}v[23296]=0;Q(176,o|0,B(d,x[e+238>>1])|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break B}break A}b=b+1|0;continue}break}f=P()|0;O()|0;Bt(E);break e}f=P()|0;O()|0;break e}f=P()|0;O()|0;break e}f=P()|0;O()|0;break e}f=P()|0;O()|0;break f}f=P()|0;O()|0;break e}f=P()|0;O()|0;break e}f=P()|0;O()|0;ec(e+8|0);break d}f=P()|0;O()|0;break e}Ab(k)}ud(z);hQ(p)}S(f|0);L()}d=0}ud(z);hQ(p)}jb=e+496|0;return d|0}function ida(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=jb-592|0;jb=d;Ac(b);a:{if(!SA(b,d+512|0)){break a}if(!zP(d+512|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Vc(yP(d+512|0),mb))){break a}b:{if(!c){break b}Ed(a,4);Dg(a);t[a+1074368|0]=4;k=Kb(d+496|0);c:{d:{e:{f:{l=d+550|0;g:{if(!(Pb(l,17616,20)|v[d+572>>2]!=276)){if(x[d+570>>1]<260){break g}e=UA(d+529|0,0,20)?1154:34;break e}if(!Pb(l,17595,20)){e=1;break e}g=d- -64|0;tj(g,3,l);v[23296]=0;R(210,d+104|0,g|0);g=v[23296];v[23296]=0;h:{i:{if((g|0)!=1){v[23296]=0;U(11,d+208|0,5,d+104|0);g=v[23296];v[23296]=0;if((g|0)==1){break i}g=d+208|0;Hb(k,g);zb(g);yb(d+104|0);if(Pb(l,17433,8)){break h}e=1048;break e}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(d+104|0);break c}if(!Pb(l,17333,12)){e=16;if(!Pb(d+562|0,17637,8)){break e}t[a+1074368|0]=5;break e}if(Pb(l,11515,20)){break f}}e=48;break e}if(!Pb(l,26928,15)){v[23296]=0;g=Q(252,a+1074312|0,54)|0;e=v[23296];v[23296]=0;C=1;if((e|0)==1){break d}v[23296]=0;Q(252,g|0,51)|0;g=v[23296];v[23296]=0;e=16;if((g|0)==1){break d}break e}j:{if(Pb(l,26944,14)){if(Pb(l,26959,14)){break j}}v[23296]=0;g=Q(252,a+1074312|0,57)|0;e=v[23296];v[23296]=0;if((e|0)==1){break d}v[23296]=0;Q(252,g|0,51)|0;g=v[23296];v[23296]=0;e=16;if((g|0)!=1){break e}break d}e=Pb(l,17421,11)?16:256}g=d+104|0;s=d+529|0;tj(g,3,s);v[23296]=0;R(210,d+208|0,g|0);g=v[23296];v[23296]=0;k:{l:{m:{n:{o:{p:{q:{if((g|0)!=1){g=d+208|0;Bc(a+1298308|0,g);yb(g);v[a+480260>>2]=1;v[a+480264>>2]=31999;_e(Zb(v[a+484360>>2],w[a+484376|0]),x[d+578>>1]);u[a+480188>>1]=x[d+580>>1];u[d+208>>1]=x[d+584>>1];u[d+104>>1]=255;F=a+480192|0,G=x[Zc(g,d+104|0)>>1],u[F>>1]=G;g=x[d+588>>1];if(g){v[a+480196>>2]=g}g=x[d+590>>1];if(g){g=B(g,1e4);g=g>>>0<1e7?g:1e7;v[a+480204>>2]=g>>>0>32e4?g:32e4}g=x[d+586>>1];v[a+480208>>2]=g<<4&16|g<<3&32768;f=w[a+484376|0];n=v[a+484360>>2];v[23296]=0;da(326,Zb(n,f)|0,b|0,x[d+576>>1],65535,65535);f=v[23296];v[23296]=0;if((f|0)==1){break d}f=g>>>12&1?(e|0)==34?146:e:e;if(!(x[d+576>>1]|f&1024)){g=w[a+484376|0];e=v[a+484360>>2];v[23296]=0;Y(682,Zb(e,g)|0);g=v[23296];v[23296]=0;if((g|0)==1){break d}}v[23296]=0;Q(143,b|0,v[d+572>>2]+60|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}if(x[d+570>>1]>=260){v[23296]=0;U(683,b|0,d+512|0,a|0);g=v[23296];v[23296]=0;if((g|0)==1){break d}}t[d+495|0]=0;z=c&2;D=d+122|0;o=d+241|0;n=Qb(d+480|0);E=a+480192|0;p=1;g=-1;while(1){e=p&65535;if(e>>>0>x[E>>1]){if(!(!(f&2)|q&255)){f=UA(s,0,20)?f|16:f}if(x[d+570>>1]>259){break o}if(c&3){v[23296]=0;U(683,b|0,d+512|0,a|0);c=v[23296];v[23296]=0;if((c|0)==1){break n}}if(!z){break o}o=a+480190|0;e=1;while(1){c=e&65535;if(c>>>0>x[o>>1]){break o}i=v[n>>2];v[23296]=0;W(207,Db(i,c-1|0)|0,(B(c,104)+a|0)+484380|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){e=e+1|0;continue}break}f=P()|0;O()|0;break k}v[23296]=0;i=T(145,b|0)|0;h=v[23296];v[23296]=0;r:{s:{if((h|0)!=1){ng(b,4);v[23296]=0;U(684,b|0,d+208|0,(i?i:263)|0);i=v[23296];v[23296]=0;if((i|0)==1){break p}t:{if((f|0)==1){i=v[d+208>>2];if((i|0)!=263){f=16;if((i|0)!=245){break t}v[a+1074308>>2]=16777381;v[23296]=0;f=Q(1,d+192|0,13208)|0;i=v[23296];v[23296]=0;if((i|0)!=1){Hb(k,f);zb(f);f=17;break t}f=P()|0;O()|0;break k}v[a+1074308>>2]=16777395;v[23296]=0;f=Q(1,d+176|0,13123)|0;i=v[23296];v[23296]=0;if((i|0)!=1){Hb(k,f);zb(f);f=17;break t}f=P()|0;O()|0;break k}if(w[d+235|0]|w[d+236|0]<<8){break t}i=v[d+208>>2];if(!(!(f&2)|(w[d+237|0]|w[d+238|0]<<8|(w[d+239|0]<<16|w[d+240|0]<<24))|(i|0)!=263)){f=f|16;break t}if(!(!(f&256)|(i|0)==29)){f=f&-257;break t}if(!(f&160)){break t}f=(i|0)==33?f:0}v[23296]=0;i=W(239,a|0,e|0,0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break p}if(!i){break r}i=((e<<2)+a|0)+900380|0;e=v[i>>2];v[23296]=0;R(685,d+208|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break p}e=w[d+234|0];u:{if((g|0)==-1){g=e;break u}if(!(f&32)|(e|0)==(g|0)){break u}f=f&-161|128}e=w[d+235|0]|w[d+236|0]<<8;if(!e){break r}v[23296]=0;h=w[d+455|0];j=w[d+451|0]|w[d+452|0]<<8;m=w[d+450|0];r=w[d+449|0];U(686,d+160|0,a|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break q}f=h|(j|(m|r))?f&-4:f;i=v[i>>2]+236|0;e=12;h=v[d+160>>2];j=Nc(h,v[d+164>>2]);v:{while(1){w:{if((e|0)==108){if(x[d+570>>1]>259){Hc(n)}e=0;v[23296]=0;i=Q(687,d+144|0,w[d+235|0]|w[d+236|0]<<8)|0;h=v[23296];v[23296]=0;if((h|0)!=1){break w}f=P()|0;O()|0;break v}m=dc(i,e);if(j>>>0>x[m>>1]){F=m,G=x[dc(h,x[dc(i,e)>>1])>>1],u[F>>1]=G}e=e+1|0;continue}break}x:{y:{z:{A:{while(1){h=w[d+235|0]|w[d+236|0]<<8;if(e>>>0>=h>>>0){e=0;if(x[d+570>>1]<=259){break s}B:{while(1){if(e>>>0>=h>>>0){break s}j=w[Db(v[n>>2],e)+3|0];h=v[Db(v[i>>2],e)>>2];v[23296]=0;U(178,d- -64|0,b|0,((j|0)==10?(h+1>>>1|0)+16|0:h)|0);h=v[23296];v[23296]=0;if((h|0)!=1){j=d- -64|0;h=jc(d+104|0,j);Ab(j);j=v[d+160>>2];if(!(!z|Nc(j,v[d+164>>2])>>>0<=e>>>0)){m=x[dc(j,e)>>1];j=Db(v[n>>2],e);j=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);v[23296]=0;v[d+56>>2]=j;v[d>>2]=j;j=fa(688,(B(m,104)+a|0)+484380|0,d|0,h|0,d+495|0)|0;m=v[23296];v[23296]=0;if((m|0)==1){break B}A=j^1|A}Ab(h);e=e+1|0;h=w[d+235|0]|w[d+236|0]<<8;continue}break}f=P()|0;O()|0;break x}f=P()|0;O()|0;Ab(h);break x}v[23296]=0;R(689,b|0,d+104|0);h=v[23296];v[23296]=0;if((h|0)==1){break y}h=d- -64|0;j=w[d+118|0];C:{if(!(j&48|w[d+121|0]!=173)){_c(h,8,1,0,10);break C}_c(h,j&16?16:8,j&32?3:1,0,2)}v[23296]=0;R(690,n|0,h|0);h=v[23296];v[23296]=0;if((h|0)!=1){F=Db(v[i>>2],e),G=v[d+104>>2],v[F>>2]=G;m=w[d+121|0];h=v[d+160>>2];if(Nc(h,v[d+164>>2])>>>0>e>>>0){j=x[dc(h,e)>>1];v[23296]=0;h=(B(j,104)+a|0)+484380|0;R(691,d+104|0,h|0);r=v[23296];v[23296]=0;if((r|0)==1){break A}t[h+38|0]=w[o+202|0];t[h+39|0]=w[o+203|0];t[h+40|0]=w[o+204|0];t[h+41|0]=w[o+205|0];h=d+88|0;jl(h,3,D);v[23296]=0;R(210,d- -64|0,h|0);h=v[23296];v[23296]=0;if((h|0)==1){break z}h=d- -64|0;Ec(((j<<5)+a|0)+946304|0,h);yb(h);f=(w[d+118|0]&3)==3?(f&2)>>>1|0?f|4:f:f}q=m|q;e=e+1|0;continue}break}f=P()|0;O()|0;break x}f=P()|0;O()|0;break x}f=P()|0;O()|0;break x}f=P()|0;O()|0}vc(i)}ud(d+160|0);break k}f=P()|0;O()|0;break k}vc(i);ud(d+160|0)}p=p+1|0;continue}}f=P()|0;O()|0;break c}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}D:{if(!(A&1)){break D}v[23296]=0;c=Q(1,d+104|0,16448)|0;e=v[23296];v[23296]=0;E:{if((e|0)!=1){e=v[a+1298464>>2];v[23296]=0;U(353,e|0,2,c|0);e=v[23296];v[23296]=0;if((e|0)==1){break E}zb(c);break D}f=P()|0;O()|0;break k}f=P()|0;O()|0;zb(c);break k}v[23296]=0;c=Q(348,b|0,5519)|0;e=v[23296];v[23296]=0;if((e|0)==1){break n}if(c){v[23296]=0;c=T(145,b|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break n}v[23296]=0;X(317,a+1298332|0,b|0,c|0,0);c=v[23296];v[23296]=0;if((c|0)==1){break n}f=f|16}v[23296]=0;o=Q(348,b|0,13932)|0;c=v[23296];v[23296]=0;if((c|0)==1){break l}if(o){v[23296]=0;c=T(145,b|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break l}v[23296]=0;e=a+901404|0;U(692,b|0,e|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break l}TA(e);f=f|16}v[23296]=0;c=Q(348,b|0,13698)|0;e=v[23296];v[23296]=0;if((e|0)==1){break l}if(!c){break m}v[23296]=0;c=T(145,b|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){u[d+208>>1]=c>>>5;F=d,G=pf(v[a+484344>>2],v[a+484348>>2]),u[F+64>>1]=G;c=x[Zc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break m}v[23296]=0;R(518,b|0,d+208|0);i=v[23296];v[23296]=0;F:{if((i|0)==1){break F}i=v[a+484344>>2];v[23296]=0;R(519,$b(i,e)|0,d+208|0);i=v[23296];v[23296]=0;if((i|0)==1){break F}e=e+1|0;continue}break}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[23296]=0;c=Q(348,b|0,13703)|0;e=v[23296];v[23296]=0;if((e|0)==1){break l}G:{if(!c){break G}v[23296]=0;c=T(145,b|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){u[d+208>>1]=(c>>>0)/20;u[d+64>>1]=x[a+480188>>1];c=x[Zc(d+208|0,d- -64|0)>>1];e=0;while(1){if((c|0)==(e|0)){f=f|16;break G}v[23296]=0;U(359,b|0,((e<<5)+a|0)+480289|0,20);i=v[23296];v[23296]=0;if((i|0)!=1){e=e+1|0;continue}break}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}c=v[b+8>>2];e=v[b>>2];v[23296]=0;c=W(144,e|0,c|0,8)|0;e=v[23296];v[23296]=0;if((e|0)==1){break l}H:{I:{J:{K:{if(c){c=v[b+8>>2];v[23296]=0;Q(360,a|0,b|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break K}f=(c|0)==v[b+8>>2]?f:f|16}L:{if(!(f&16)){break L}if(f&4){v[a+1074308>>2]=17367040;v[23296]=0;c=Q(1,d+208|0,14539)|0;e=v[23296];v[23296]=0;if((e|0)!=1){Hb(k,c);zb(c);break L}f=P()|0;O()|0;break k}if(!(f&2)){break L}v[a+1074308>>2]=18219008;v[23296]=0;c=Q(1,d+208|0,14696)|0;e=v[23296];v[23296]=0;if((e|0)==1){break J}Hb(k,c);zb(c)}M:{N:{O:{P:{Q:{R:{S:{if(!Pb(l,17433,8)){v[23296]=0;c=Q(693,d- -64|0,d+558|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break S}v[23296]=0;U(11,d+160|0,1,c|0);e=v[23296];v[23296]=0;if((e|0)==1){break R}v[23296]=0;e=T(694,d+160|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break Q}v[a+1074308>>2]=e;zb(d+160|0);t[a+1074368|0]=y[a+1074308>>2]<19007257?4:5;yb(c);f=24}if(!(!v[a+1074308>>2]|f&8)){t[a+1074368|0]=0;du(a+1074312|0)}c=f&32;T:{if(!c){break T}t[a+1074368|0]=5;if(!o){eq(a+901404|0)}if(x[d+570>>1]<260){break T}v[23296]=0;W(251,a+1074312|0,4,1)|0;e=v[23296];v[23296]=0;if((e|0)==1){break l}}if(!gh(v[k+4>>2],w[k+11|0])){break M}if(!(f&256)|q&255|g+1>>>0>1){break N}v[23296]=0;c=Q(1,d+160|0,8210)|0;g=v[23296];v[23296]=0;if((g|0)==1){break O}Hb(k,c);zb(c);break M}f=P()|0;O()|0;break k}f=P()|0;O()|0;break P}f=P()|0;O()|0;zb(d+160|0)}yb(c);break k}f=P()|0;O()|0;break k}if(c){v[23296]=0;c=Q(1,d+160|0,11927)|0;g=v[23296];v[23296]=0;if((g|0)!=1){Hb(k,c);zb(c);break M}f=P()|0;O()|0;break k}v[23296]=0;c=Q(1,d+160|0,9642)|0;g=v[23296];v[23296]=0;if((g|0)==1){break I}Hb(k,c);zb(c)}t[d+55|0]=0;U:{if(x[a+480192>>1]){v[23296]=0;c=Q(369,a|0,b|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break U}t[d+55|0]=c}v[23296]=0;X(370,a|0,b|0,1,d+55|0);b=v[23296];v[23296]=0;if((b|0)==1){break U}e=v[a+1074308>>2];V:{W:{X:{Y:{Z:{_:{$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{if(w[d+55|0]){if(e>>>0>18284543){break ha}v[a+1074308>>2]=18284544;break ha}if(e>>>0<18284544){break ga}}v[23296]=0;b=Q(1,d+40|0,17433)|0;c=v[23296];v[23296]=0;if((c|0)==1){break fa}c=v[a+1074308>>2];v[23296]=0;R(695,d+24|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break ea}v[23296]=0;U(2,d+88|0,b|0,d+24|0);c=v[23296];v[23296]=0;if((c|0)==1){break da}c=d+88|0;Hb(k,c);zb(c);zb(d+24|0);zb(b);e=v[a+1074308>>2]}ia:{if(e-1>>>0>19005952){break ia}b=v[a+484344>>2];f=v[a+484348>>2];if(!oe(b,f,254)){b=w[a+484376|0];c=v[a+484360>>2];v[23296]=0;Y(696,Zb(c,b)|0);b=v[23296];v[23296]=0;if((b|0)==1){break U}f=v[a+484348>>2];b=v[a+484344>>2]}if(oe(b,f,255)){break ia}fA(Zb(v[a+484360>>2],w[a+484376|0]),255,65535)}v[23296]=0;R(697,d+24|0,4063);b=v[23296];v[23296]=0;if((b|0)==1){break ba}b=x[d+570>>1];v[d+20>>2]=b>>>8;v[23296]=0;v[d+4>>2]=b&255;R(380,d+8|0,d+4|0);b=v[23296];v[23296]=0;if((b|0)==1){break aa}v[23296]=0;X(366,d+88|0,d+24|0,d+20|0,d+8|0);b=v[23296];v[23296]=0;if((b|0)==1){break $}c=d+88|0;b=Hb(a+1298344|0,c);zb(c);zb(d+8|0);ec(d+24|0);Hb(a+1298368|0,k);v[a+1298404>>2]=C?8:v[a+1074308>>2]?8:5;if(!w[d+495|0]){break W}Hb(a+1298380|0,b);v[23296]=0;c=Q(1,d+88|0,15065)|0;g=v[23296];v[23296]=0;if((g|0)==1){break Z}Hb(b,c);zb(c);v[23296]=0;b=Q(1,d+24|0,9993)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Y}Hb(a+1298356|0,b);zb(b);v[23296]=0;b=Q(1,d+8|0,9994)|0;c=v[23296];v[23296]=0;if((c|0)==1){break X}Hb(a+1298392|0,b);break V}f=P()|0;O()|0;break k}f=P()|0;O()|0;break ca}f=P()|0;O()|0;zb(d+24|0)}zb(b);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break _}f=P()|0;O()|0;zb(d+8|0)}ec(d+24|0);break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}v[23296]=0;b=Q(1,d+88|0,9994)|0;c=v[23296];v[23296]=0;if((c|0)==1){break H}Hb(a+1298356|0,b)}zb(b);vc(n);zb(k);break b}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0;break k}f=P()|0;O()|0}vc(n);break c}f=P()|0;O()|0}zb(k);S(f|0);L()}e=1}jb=d+592|0;return e|0}function iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=jb-336|0;jb=e;Ac(b);a:{b:{c:{if(!Gt(b,e+240|0)){break c}if(!HQ(e+240|0)){break c}if(!Ob(v[b>>2],v[b+8>>2],Vc(GQ(e+240|0),mb))){break c}if(!c){l=1;break c}Ed(a,2);v[a+480260>>2]=64;v[a+480264>>2]=32767;j=Kb(e+224|0);d=x[e+280>>1];i=(d|0)==20479?x[e+294>>1]:d-16464|0;d:{e:{f:{g:{h:{i:{switch(d>>>12|0){case 0:if((d|0)!=520){break d}v[23296]=0;d=Q(1,e+208|0,12167)|0;g=v[23296];v[23296]=0;if((g|0)!=1){Hb(j,d);break e}b=P()|0;O()|0;break a;case 1:j:{if(x[e+302>>1]|(d|0)!=4896){break j}if(!(x[e+278>>1]&65455|(w[e+292|0]|w[e+272|0]&15))){k:{if(t[e+291|0]<0){v[a+1074308>>2]=18219008;v[23296]=0;d=Q(1,e+208|0,14609)|0;f=v[23296];v[23296]=0;if((f|0)!=1){break k}b=P()|0;O()|0;break a}v[a+1074308>>2]=16777216;v[23296]=0;d=Q(1,e+208|0,13208)|0;f=v[23296];v[23296]=0;if((f|0)==1){break h}}Hb(j,d);zb(d);v[23296]=0;f=1;W(251,a+1074312|0,81,1)|0;d=v[23296];v[23296]=0;g=1;if((d|0)!=1){break d}break b}if(w[e+293|0]|(w[e+292|0]|x[e+278>>1])){break j}v[23296]=0;d=Q(1,e+208|0,9378)|0;g=v[23296];v[23296]=0;if((g|0)!=1){Hb(j,d);break e}b=P()|0;O()|0;break a}v[23296]=0;d=Q(1,e+208|0,8412)|0;f=v[23296];v[23296]=0;k=1;if((f|0)!=1){Hb(j,d);zb(d);break f}b=P()|0;O()|0;break a;case 2:v[23296]=0;d=Q(1,e+208|0,6734)|0;f=v[23296];v[23296]=0;g=1;if((f|0)!=1){Hb(j,d);zb(d);break f}b=P()|0;O()|0;break a;case 3:l:{m:{n:{o:{if(d>>>0<=12820){v[23296]=0;f=Q(1,e+208|0,8459)|0;g=v[23296];v[23296]=0;if((g|0)!=1){Hb(j,f);zb(f);break o}b=P()|0;O()|0;break a}v[23296]=0;R(378,e+208|0,3976);f=v[23296];v[23296]=0;if((f|0)==1){break n}v[23296]=0;v[e+192>>2]=x[e+280>>1]-12820;U(379,e+48|0,e+208|0,e+192|0);f=v[23296];v[23296]=0;if((f|0)==1){break m}f=e+48|0;Hb(j,f);zb(f);ec(e+208|0)}f=x[e+280>>1];if(f>>>0<12807){break g}g=v[e+296>>2];if(g){break l}break g}b=P()|0;O()|0;break a}b=P()|0;O()|0;ec(e+208|0);break a}f=PC(f,g);g=sq(e+48|0);v[g+44>>2]=f;v[23296]=0;R(381,a+1298408|0,g|0);f=v[23296];v[23296]=0;if((f|0)!=1){break g}b=P()|0;O()|0;break a;case 4:p:{q:{if((d|0)==16640){v[23296]=0;f=Q(1,e+208|0,8258)|0;g=v[23296];v[23296]=0;if((g|0)!=1){Hb(j,f);zb(f);f=81;break q}b=P()|0;O()|0;break a}v[23296]=0;U(382,e+48|0,d|0,x[e+294>>1]);f=v[23296];v[23296]=0;r:{if((f|0)!=1){f=e+48|0;Hb(j,f);zb(f);v[a+480260>>2]=1;if((i|0)<4201){break r}v[23296]=0;W(251,a+1074312|0,7,1)|0;g=v[23296];v[23296]=0;f=38;if((g|0)==1){break b}break q}b=P()|0;O()|0;break a}f=38;if((i|0)<2386){break p}}v[23296]=0;W(251,a+1074312|0,f|0,1)|0;f=v[23296];v[23296]=0;if((f|0)==1){break b}}h=(d|0)!=16640;g=1;f=0;break d;case 5:d=d&4095;v[a+1074308>>2]=d<<16|(d>>>0>296?x[e+294>>1]:0)&65535;v[23296]=0;d=Q(1,e+208|0,17433)|0;f=v[23296];v[23296]=0;s:{t:{u:{if((f|0)!=1){f=v[a+1074308>>2];v[23296]=0;R(128,e+192|0,f|0);f=v[23296];v[23296]=0;if((f|0)==1){break u}f=0;v[23296]=0;U(2,e+48|0,d|0,e+192|0);g=v[23296];v[23296]=0;if((g|0)==1){break t}g=e+48|0;Hb(j,g);zb(g);zb(e+192|0);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break s}b=P()|0;O()|0;zb(e+192|0)}zb(d);break a;case 6:v[23296]=0;d=Q(1,e+208|0,8258)|0;h=v[23296];v[23296]=0;if((h|0)!=1){Hb(j,d);zb(d);v[23296]=0;W(251,a+1074312|0,81,1)|0;d=v[23296];v[23296]=0;h=0;if((d|0)==1){break b}break d}b=P()|0;O()|0;break a;case 7:v[23296]=0;d=Q(1,e+208|0,8270)|0;g=v[23296];v[23296]=0;if((g|0)!=1){Hb(j,d);break e}b=P()|0;O()|0;break a;default:break i}}if((d|0)!=51712){break d}v[23296]=0;d=Q(1,e+208|0,9177)|0;g=v[23296];v[23296]=0;if((g|0)!=1){Hb(j,d);break e}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}v[23296]=0;f=W(251,a+1074312|0,7,1)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}v[23296]=0;f=W(251,f|0,23,1)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}v[23296]=0;f=W(251,f|0,38,1)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}v[23296]=0;W(251,f|0,107,1)|0;f=v[23296];v[23296]=0;if((f|0)==1){break b}g=1;v[a+480260>>2]=1;f=0;if(d>>>0>12820){break d}}v[23296]=0;Y(617,e+192|0);d=v[23296];v[23296]=0;v:{w:{x:{if((d|0)!=1){d=x[e+280>>1];v[e+160>>2]=d>>>8&15;v[23296]=0;v[e+136>>2]=d&255;R(380,e+176|0,e+136|0);d=v[23296];v[23296]=0;if((d|0)==1){break x}f=0;v[23296]=0;da(618,e+48|0,e+192|0,j|0,e+160|0,e+176|0);d=v[23296];v[23296]=0;if((d|0)==1){break w}d=e+48|0;Hb(j,d);zb(d);zb(e+176|0);ec(e+192|0);break d}b=P()|0;O()|0;break a}b=P()|0;O()|0;break v}b=P()|0;O()|0;zb(e+176|0)}ec(e+192|0);break a}zb(d);g=0}v[23296]=0;d=Q(1,e+192|0,14870)|0;m=v[23296];v[23296]=0;y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{if((m|0)!=1){Hb(a+1298344|0,d);zb(d);v[23296]=0;d=Q(1,e+176|0,10366)|0;m=v[23296];v[23296]=0;if((m|0)==1){break H}Hb(a+1298356|0,d);zb(d);m=Hb(a+1298368|0,j);v[a+1298404>>2]=v[a+1074308>>2]?8:5;if(g){v[23296]=0;d=Q(252,a+1074312|0,77)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}v[23296]=0;d=Q(252,d|0,78)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}v[23296]=0;d=Q(252,d|0,79)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}v[23296]=0;d=Q(252,d|0,80)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}v[23296]=0;d=Q(252,d|0,82)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}v[23296]=0;d=Q(252,d|0,96)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}v[23296]=0;Q(252,d|0,113)|0;d=v[23296];v[23296]=0;if((d|0)==1){break b}}d=x[e+280>>1];g=d&61440;if(g>>>0>=4097){f=(g|0)!=12288|d>>>0>12819|f}v[23296]=0;d=a+901404|0;Y(619,d|0);g=v[23296];v[23296]=0;if((g|0)==1){break b}if(!f){eq(d)}d=e+160|0;el(d,1,e+240|0);v[23296]=0;R(210,e+48|0,d|0);d=v[23296];v[23296]=0;if((d|0)==1){break C}d=e+48|0;Bc(a+1298308|0,d);yb(d);d=x[e+278>>1];if(d&16){v[a+480208>>2]=v[a+480208>>2]|65536}if(d&1){v[a+480208>>2]=v[a+480208>>2]|131072}o=x[e+280>>1];if(!(d&64?0:(o|0)!=4864)){v[a+480208>>2]=v[a+480208>>2]|2}d=w[e+289|0];v[a+480196>>2]=d;if(!d){break G}if((d|0)!=255){break F}if(k){break G}d=w[e+290|0];f=d>>>0<33;g=B(d,1e4);k=0;d=32e4;break D}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}v[a+480196>>2]=6;d=w[e+290|0];f=d>>>0<33;g=B(d,1e4);break E}d=w[e+290|0];f=d>>>0<33;g=B(d,1e4)}d=32e4;if(!k){break D}d=125e4}v[a+480204>>2]=f?d:g;t[e+48|0]=w[e+288|0];t[e+160|0]=64;d=w[Wb(e+48|0,e+160|0)|0];v[a+480200>>2]=d<<2;if(!(d|o>>>0>4895)){v[a+480200>>2]=256}g=w[e+291|0];I:{if(!(x[e+282>>1]!=1|g>>>0>7)){v[e+48>>2]=(g<<4)+16;v[e+160>>2]=127;f=v[td(e+48|0,e+160|0)>>2];break I}f=32;if((g|16)==18){break I}d=g&127;f=48;if(!d){break I}v[e+48>>2]=d;v[e+160>>2]=16;f=v[Ne(e+48|0,e+160|0)>>2]}v[a+480228>>2]=f;d=0;o=v[a+1074308>>2]!=0|g<<24>>24<0;if(!o){H=a,I=Vc(Via(f<<3|5,f>>>29|0,11,0),mb),v[H+480228>>2]=I}r=a+480188|0;u[r>>1]=4;v[a+480232>>2]=h?(i|0)<3299?64:36:36;f=Cc(e+152|0);while(1){if((d|0)==32){d=a+480188|0;if(!x[d>>1]){u[d>>1]=1}d=w[a+484376|0];g=v[a+484360>>2];v[23296]=0;da(326,Zb(g,d)|0,b|0,x[e+272>>1],255,254);d=v[23296];v[23296]=0;if((d|0)!=1){o=Qb(e+160|0);v[23296]=0;W(205,b|0,o|0,x[e+274>>1])|0;d=v[23296];v[23296]=0;if((d|0)!=1){r=Qb(e+136|0);v[23296]=0;W(205,b|0,r|0,x[e+276>>1])|0;d=v[23296];v[23296]=0;J:{if((d|0)!=1){if(w[e+293|0]!=252){break B}d=0;v[23296]=0;R(620,b|0,e+48|0);g=v[23296];v[23296]=0;if((g|0)==1){break J}while(1){if((d|0)==32){break B}g=w[(e+48|0)+d|0];K:{if(!(g&32)){break K}if(k){tk(e+32|0,f,d);if(Cb(v[v[e+32>>2]>>2],v[e+36>>2])){break K}}u[((d<<5)+a|0)+480284>>1]=(((g&15)<<8|8)>>>0)/15}d=d+1|0;continue}}break A}break A}b=P()|0;O()|0;break z}b=P()|0;O()|0;break a}g=(d<<5)+a|0;i=g+480280|0;Te(i);h=w[(d+e|0)+304|0];p=h&127;L:{if((h|0)!=255){h=h<<24>>24;u[r>>1]=d+1;if(o){u[g+480284>>1]=h&8?204:51}if((h|0)>=0){break L}}v[i>>2]=1024}if((p-16&255)>>>0<=13){u[g+480284>>1]=128;g=e+48|0;tk(g,f,d);nm(g)}d=d+1|0;continue}}b=P()|0;O()|0;break a}u[e+48>>1]=x[e+274>>1];u[e+32>>1]=3999;f=x[Zc(e+48|0,e+32|0)>>1];u[a+480190>>1]=f;i=c&2;p=e+96|0;d=0;g=0;h=0;M:{N:{O:{while(1){if((f&65535)>>>0<=d>>>0){if(!k){break N}if(!(!(g&1)|h&65535)&x[e+280>>1]!=4864){break O}v[23296]=0;d=h&65535;f=W(251,a+1074312|0,79,d>>>0>1|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break A}v[23296]=0;d=d>>>0<2;f=W(251,f|0,107,d|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break A}v[23296]=0;W(251,f|0,38,d|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break A}v[23296]=0;d=h&65535;Q(121,m|0,(d>>>0>1?16994:17001)|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break A}if(d>>>0<2){break N}v[a+480228>>2]=48;break N}f=dc(v[o>>2],d);f=w[f|0]|w[f+1|0]<<8;v[23296]=0;f=Q(143,b|0,f<<4)|0;n=v[23296];v[23296]=0;if((n|0)==1){break M}P:{Q:{if(!f){break Q}v[23296]=0;f=Q(621,b|0,e+48|0)|0;n=v[23296];v[23296]=0;if((n|0)==1){break M}if(!f){break Q}v[23296]=0;f=d+1|0;n=(B(f,104)+a|0)+484380|0;U(622,e+48|0,n|0,k|0);l=v[23296];v[23296]=0;if((l|0)==1){break M}l=e+16|0;el(l,1,p);v[23296]=0;R(210,e+32|0,l|0);l=v[23296];v[23296]=0;if((l|0)==1){break P}l=((f<<5)+a|0)+946304|0;f=e+32|0;Ec(l,f);yb(f);if(w[e+48|0]>1){break Q}R:{if(!i|!v[e+64>>2]){break R}f=EQ(e+48|0);v[23296]=0;f=Q(143,b|0,f|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break A}if(!f){break R}f=e+32|0;DQ(f,w[e+78|0],w[e+79|0],x[e+282>>1]==1);v[23296]=0;W(207,f|0,n|0,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break A}g=1}h=x[e+88>>1]|h}d=d+1|0;f=x[a+480190>>1];continue}break}break A}v[23296]=0;d=Q(1,e+48|0,9642)|0;f=v[23296];v[23296]=0;if((f|0)==1){break A}Hb(m,d);zb(d)}l=1;if(!(c&1)){break y}c=x[e+280>>1];u[e+32>>1]=x[e+276>>1];u[e+16>>1]=255;s=x[Zc(e+32|0,e+16|0)>>1];v[23296]=0;k=a+484344|0;R(213,k|0,s|0);d=v[23296];v[23296]=0;if((d|0)==1){break M}y=c>>>0<4896;c=e+32|0;C=c|5;D=c|3;z=c|4;E=c|2;F=c|1;G=a+480188|0;h=0;p=0;n=0;while(1){if((h|0)==(s|0)){if(!y){break y}a=x[a+480188>>1];if((a|0)>(n+p|0)|(a|0)<=(p-n|0)){break y}d=pf(v[k>>2],v[k+4>>2])-1&65535;b=0;S:{if(pf(v[k>>2],v[k+4>>2])>>>0<=d>>>0){break S}while(1){c=b&65535;if(c>>>0>d>>>0){break S}a=Pf(v[k>>2],c);f=v[a>>2];if(Rb(f,v[a+4>>2])){a=Eb(f);f=Eb(v[Pf(v[k>>2],c)+4>>2]);c=jb-16|0;jb=c;v[c+8>>2]=a;while(1){if(Rb(a,f)){if(w[a+3|0]==31){t[a+3|0]=20;t[a+5|0]=w[a+5|0]|128}a=v[kk(c+8|0)>>2];continue}break}jb=c+16|0}b=b+1|0;continue}}break y}v[23296]=0;c=W(214,k|0,h&65535,64)|0;d=v[23296];v[23296]=0;if((d|0)==1){break M}T:{if(!c){break T}c=dc(v[r>>2],h);c=w[c|0]|w[c+1|0]<<8;if(!c){break T}v[23296]=0;c=Q(143,b|0,c<<4)|0;d=v[23296];v[23296]=0;if((d|0)==1){break M}if(!c){break T}v[23296]=0;Q(176,b|0,2)|0;c=v[23296];v[23296]=0;if((c|0)==1){break M}d=0;c=$b(v[k>>2],h);c=Qf(v[c>>2],v[v[c+48>>2]+12>>2],0);while(1){if(d>>>0>63){break T}f=d;v[23296]=0;m=T(194,b|0)|0;d=v[23296];v[23296]=0;U:{if((d|0)!=1){if(m){break U}d=64;if(f>>>0>62){continue}c=$b(v[k>>2],h);d=f+1|0;c=Qf(v[c>>2],v[v[c+48>>2]+12>>2],d);continue}break A}g=m&31;d=B(g,6)+c|0;q=Th(e+32|0);i=g>>>0<x[G>>1];A=i?d:q;if(m&32){v[23296]=0;R(247,e+16|0,b|0);g=v[23296];v[23296]=0;V:{W:{X:{if((g|0)!=1){q=kd(e+16|0);g=w[e+16|0];if(g>>>0>239){break X}g=CQ((B(g>>>4|0,12)+(g&15)|0)+13|0);break W}break A}Y:{switch(g-254|0){case 0:break W;case 1:break Y;default:break V}}g=0}t[A|0]=g}t[(i?d+1|0:F)|0]=w[q|0]}Z:{if(!(m&64)){break Z}v[23296]=0;q=T(194,b|0)|0;g=v[23296];v[23296]=0;_:{if((g|0)!=1){g=i?d+2|0:E;q=q<<24>>24;t[e+16|0]=q;if((q|0)>-64){break _}t[g|0]=2;t[(i?d+4|0:z)|0]=w[e+16|0]^128;break Z}break A}t[g|0]=1;t[e+15|0]=64;H=i?d+4|0:z,I=w[Wb(e+16|0,e+15|0)|0],t[H|0]=I}$:{if(!(m&128)){break $}v[23296]=0;R(247,e+16|0,b|0);g=v[23296];v[23296]=0;aa:{ba:{if((g|0)!=1){g=i?d+3|0:D;t[g|0]=w[e+16|0];d=i?d+5|0:C;H=d,I=w[kd(e+16|0)|0],t[H|0]=I;RA(A,0);i=w[g|0];if((i|0)==10){break aa}if((i|0)==31){break ba}if((i|0)!=20){break $}g=w[d|0];if((g&240)!=160|x[e+280>>1]>4895){break $}t[d|0]=g&15^136;break $}break A}d=w[d|0];if(d>>>0>15){y=0;break $}if(d>>>0<=7){n=n+1|0;break $}p=((d|0)!=8)+p|0;break $}if(w[d|0]|x[e+280>>1]>4865){break $}t[g|0]=37}d=f;continue}}h=h+1|0;continue}}}b=P()|0;O()|0;ud(r)}ud(o);break a}ud(r);ud(o);zb(j)}jb=e+336|0;return l|0}b=P()|0;O()|0}zb(j);S(b|0);L()}function Jd(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=jb-16|0;jb=l;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(a>>>0<=244){f=v[115804];h=a>>>0<11?16:a+11&-8;c=h>>>3|0;b=f>>>c|0;if(b&3){c=c+((b^-1)&1)|0;a=c<<3;b=a+463256|0;d=v[a+463264>>2];a=v[d+8>>2];l:{if((b|0)==(a|0)){m=463216,n=Wia(-2,c)&f,v[m>>2]=n;break l}v[a+12>>2]=b;v[b+8>>2]=a}a=d+8|0;b=c<<3;v[d+4>>2]=b|3;b=b+d|0;v[b+4>>2]=v[b+4>>2]|1;break a}k=v[115806];if(k>>>0>=h>>>0){break k}if(b){a=2<<c;a=(0-a|a)&b<<c;b=(0-a&a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;d=(c|a)+(b>>>a|0)|0;a=d<<3;b=a+463256|0;g=v[a+463264>>2];a=v[g+8>>2];m:{if((b|0)==(a|0)){f=Wia(-2,d)&f;v[115804]=f;break m}v[a+12>>2]=b;v[b+8>>2]=a}v[g+4>>2]=h|3;c=g+h|0;a=d<<3;d=a-h|0;v[c+4>>2]=d|1;v[a+g>>2]=d;if(k){b=(k&-8)+463256|0;e=v[115809];a=1<<(k>>>3);n:{if(!(a&f)){v[115804]=a|f;a=b;break n}a=v[b+8>>2]}v[b+8>>2]=e;v[a+12>>2]=e;v[e+12>>2]=b;v[e+8>>2]=a}a=g+8|0;v[115809]=c;v[115806]=d;break a}j=v[115805];if(!j){break k}b=(0-j&j)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;b=v[((c|a)+(b>>>a|0)<<2)+463520>>2];e=(v[b+4>>2]&-8)-h|0;c=b;while(1){o:{a=v[c+16>>2];if(!a){a=v[c+20>>2];if(!a){break o}}c=(v[a+4>>2]&-8)-h|0;d=c>>>0<e>>>0;e=d?c:e;b=d?a:b;c=a;continue}break}i=v[b+24>>2];d=v[b+12>>2];if((d|0)!=(b|0)){a=v[b+8>>2];v[a+12>>2]=d;v[d+8>>2]=a;break b}c=b+20|0;a=v[c>>2];if(!a){a=v[b+16>>2];if(!a){break j}c=b+16|0}while(1){g=c;d=a;c=a+20|0;a=v[c>>2];if(a){continue}c=d+16|0;a=v[d+16>>2];if(a){continue}break}v[g>>2]=0;break b}h=-1;if(a>>>0>4294967231){break k}a=a+11|0;h=a&-8;j=v[115805];if(!j){break k}e=0-h|0;f=0;p:{if(h>>>0<256){break p}f=31;if(h>>>0>16777215){break p}a=a>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;f=(a<<1|h>>>a+21&1)+28|0}c=v[(f<<2)+463520>>2];q:{r:{s:{if(!c){a=0;break s}a=0;b=h<<((f|0)==31?0:25-(f>>>1|0)|0);while(1){t:{g=(v[c+4>>2]&-8)-h|0;if(g>>>0>=e>>>0){break t}d=c;e=g;if(e){break t}e=0;a=c;break r}g=v[c+20>>2];c=v[((b>>>29&4)+c|0)+16>>2];a=g?(g|0)==(c|0)?a:g:a;b=b<<1;if(c){continue}break}}if(!(a|d)){d=0;a=2<<f;a=(0-a|a)&j;if(!a){break k}b=(a&0-a)-1|0;a=b>>>12&16;c=a;b=b>>>a|0;a=b>>>5&8;c=c|a;b=b>>>a|0;a=b>>>2&4;c=c|a;b=b>>>a|0;a=b>>>1&2;c=c|a;b=b>>>a|0;a=b>>>1&1;a=v[((c|a)+(b>>>a|0)<<2)+463520>>2]}if(!a){break q}}while(1){b=(v[a+4>>2]&-8)-h|0;c=b>>>0<e>>>0;e=c?b:e;d=c?a:d;b=v[a+16>>2];if(b){a=b}else{a=v[a+20>>2]}if(a){continue}break}}if(!d|v[115806]-h>>>0<=e>>>0){break k}f=v[d+24>>2];b=v[d+12>>2];if((d|0)!=(b|0)){a=v[d+8>>2];v[a+12>>2]=b;v[b+8>>2]=a;break c}c=d+20|0;a=v[c>>2];if(!a){a=v[d+16>>2];if(!a){break i}c=d+16|0}while(1){g=c;b=a;c=a+20|0;a=v[c>>2];if(a){continue}c=b+16|0;a=v[b+16>>2];if(a){continue}break}v[g>>2]=0;break c}c=v[115806];if(c>>>0>=h>>>0){d=v[115809];b=c-h|0;u:{if(b>>>0>=16){v[115806]=b;a=d+h|0;v[115809]=a;v[a+4>>2]=b|1;v[c+d>>2]=b;v[d+4>>2]=h|3;break u}v[115809]=0;v[115806]=0;v[d+4>>2]=c|3;a=c+d|0;v[a+4>>2]=v[a+4>>2]|1}a=d+8|0;break a}i=v[115807];if(i>>>0>h>>>0){b=i-h|0;v[115807]=b;c=v[115810];a=c+h|0;v[115810]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;j=h+47|0;b=j;if(v[115922]){c=v[115924]}else{v[115925]=-1;v[115926]=-1;v[115923]=4096;v[115924]=4096;v[115922]=l+12&-16^1431655768;v[115927]=0;v[115915]=0;c=4096}g=b+c|0;e=0-c|0;c=g&e;if(c>>>0<=h>>>0){break a}d=v[115914];if(d){b=v[115912];f=b+c|0;if(d>>>0<f>>>0|b>>>0>=f>>>0){break a}}if(w[463660]&4){break f}v:{w:{d=v[115810];if(d){a=463664;while(1){b=v[a>>2];if(b>>>0<=d>>>0&d>>>0<b+v[a+4>>2]>>>0){break w}a=v[a+8>>2];if(a){continue}break}}b=fp(0);if((b|0)==-1){break g}f=c;d=v[115923];a=d-1|0;if(a&b){f=(c-b|0)+(a+b&0-d)|0}if(f>>>0<=h>>>0|f>>>0>2147483646){break g}d=v[115914];if(d){a=v[115912];e=a+f|0;if(d>>>0<e>>>0|a>>>0>=e>>>0){break g}}a=fp(f);if((b|0)!=(a|0)){break v}break e}f=e&g-i;if(f>>>0>2147483646){break g}b=fp(f);if((b|0)==(v[a>>2]+v[a+4>>2]|0)){break h}a=b}if(!((a|0)==-1|h+48>>>0<=f>>>0)){b=v[115924];b=b+(j-f|0)&0-b;if(b>>>0>2147483646){b=a;break e}if((fp(b)|0)!=-1){f=b+f|0;b=a;break e}fp(0-f|0);break g}b=a;if((a|0)!=-1){break e}break g}d=0;break b}b=0;break c}if((b|0)!=-1){break e}}v[115915]=v[115915]|4}if(c>>>0>2147483646){break d}b=v[23217];c=c+3&-4;a=b+c|0;x:{y:{if(!c|a>>>0>b>>>0){if(Mw()>>>0>=a>>>0){break y}if(xa(a|0)|0){break y}a=v[23217]}else{a=b}v[115772]=48;b=-1;break x}v[23217]=a}if(Mw()>>>0<a>>>0){if(!(xa(a|0)|0)){break d}}v[23217]=a;if((b|0)==-1|(a|0)==-1|a>>>0<=b>>>0){break d}f=a-b|0;if(f>>>0<=h+40>>>0){break d}}a=v[115912]+f|0;v[115912]=a;if(a>>>0>y[115913]){v[115913]=a}z:{A:{B:{g=v[115810];if(g){a=463664;while(1){d=v[a>>2];c=v[a+4>>2];if((d+c|0)==(b|0)){break B}a=v[a+8>>2];if(a){continue}break}break A}a=v[115808];if(!(a>>>0<=b>>>0?a:0)){v[115808]=b}a=0;v[115917]=f;v[115916]=b;v[115812]=-1;v[115813]=v[115922];v[115919]=0;while(1){d=a<<3;c=d+463256|0;v[d+463264>>2]=c;v[d+463268>>2]=c;a=a+1|0;if((a|0)!=32){continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[115807]=c;a=a+b|0;v[115810]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[115811]=v[115926];break z}if(w[a+12|0]&8|d>>>0>g>>>0|b>>>0<=g>>>0){break A}v[a+4>>2]=c+f;a=g+8&7?-8-g&7:0;c=a+g|0;v[115810]=c;b=v[115807]+f|0;a=b-a|0;v[115807]=a;v[c+4>>2]=a|1;v[(b+g|0)+4>>2]=40;v[115811]=v[115926];break z}if(y[115808]>b>>>0){v[115808]=b}d=b+f|0;c=463664;C:{while(1){if((d|0)!=v[c>>2]){a=463664;c=v[c+8>>2];if(c){continue}break C}break}a=463664;if(w[c+12|0]&8){break C}v[c>>2]=b;v[c+4>>2]=v[c+4>>2]+f;j=(b+8&7?-8-b&7:0)+b|0;v[j+4>>2]=h|3;d=d+(d+8&7?-8-d&7:0)|0;i=h+j|0;a=d-i|0;D:{if((d|0)==(g|0)){v[115810]=i;a=v[115807]+a|0;v[115807]=a;v[i+4>>2]=a|1;break D}if(v[115809]==(d|0)){v[115809]=i;a=v[115806]+a|0;v[115806]=a;v[i+4>>2]=a|1;v[a+i>>2]=a;break D}e=v[d+4>>2];if((e&3)==1){f=e&-8;E:{if(e>>>0<=255){b=e>>>3|0;e=v[d+8>>2];c=v[d+12>>2];if((c|0)==(e|0)){m=463216,n=v[115804]&Wia(-2,b),v[m>>2]=n;break E}v[e+12>>2]=c;v[c+8>>2]=e;break E}h=v[d+24>>2];b=v[d+12>>2];F:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break F}G:{e=d+20|0;c=v[e>>2];if(c){break G}e=d+16|0;c=v[e>>2];if(c){break G}b=0;break F}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break E}e=v[d+28>>2];c=(e<<2)+463520|0;H:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break H}m=463220,n=v[115805]&Wia(-2,e),v[m>>2]=n;break E}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break E}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break E}v[b+20>>2]=c;v[c+24>>2]=b}d=d+f|0;e=v[d+4>>2];a=a+f|0}v[d+4>>2]=e&-2;v[i+4>>2]=a|1;v[a+i>>2]=a;if(a>>>0<=255){b=(a&-8)+463256|0;c=v[115804];a=1<<(a>>>3);I:{if(!(c&a)){v[115804]=a|c;a=b;break I}a=v[b+8>>2]}v[b+8>>2]=i;v[a+12>>2]=i;v[i+12>>2]=b;v[i+8>>2]=a;break D}e=31;if(a>>>0<=16777215){b=a>>>8|0;e=b+1048320>>>16&8;b=b<<e;d=b+520192>>>16&4;b=b<<d;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(d|e))|0;e=(b<<1|a>>>b+21&1)+28|0}v[i+28>>2]=e;v[i+16>>2]=0;v[i+20>>2]=0;d=(e<<2)+463520|0;J:{c=v[115805];b=1<<e;K:{if(!(c&b)){v[115805]=b|c;v[d>>2]=i;v[i+24>>2]=d;break K}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[d>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break J}b=e>>>29|0;e=e<<1;d=c+(b&4)|0;b=v[d+16>>2];if(b){continue}break}v[d+16>>2]=i;v[i+24>>2]=c}v[i+12>>2]=i;v[i+8>>2]=i;break D}a=v[c+8>>2];v[a+12>>2]=i;v[c+8>>2]=i;v[i+24>>2]=0;v[i+12>>2]=c;v[i+8>>2]=a}a=j+8|0;break a}while(1){L:{c=v[a>>2];if(c>>>0<=g>>>0){e=c+v[a+4>>2]|0;if(e>>>0>g>>>0){break L}}a=v[a+8>>2];continue}break}d=f-40|0;a=b+8&7?-8-b&7:0;c=d-a|0;v[115807]=c;a=a+b|0;v[115810]=a;v[a+4>>2]=c|1;v[(b+d|0)+4>>2]=40;v[115811]=v[115926];a=(e+(e-39&7?39-e&7:0)|0)-47|0;c=a>>>0<g+16>>>0?g:a;v[c+4>>2]=27;a=v[115919];v[c+16>>2]=v[115918];v[c+20>>2]=a;a=v[115917];v[c+8>>2]=v[115916];v[c+12>>2]=a;v[115918]=c+8;v[115917]=f;v[115916]=b;v[115919]=0;a=c+24|0;while(1){v[a+4>>2]=7;b=a+8|0;a=a+4|0;if(b>>>0<e>>>0){continue}break}if((c|0)==(g|0)){break z}v[c+4>>2]=v[c+4>>2]&-2;e=c-g|0;v[g+4>>2]=e|1;v[c>>2]=e;if(e>>>0<=255){b=(e&-8)+463256|0;c=v[115804];a=1<<(e>>>3);M:{if(!(c&a)){v[115804]=a|c;a=b;break M}a=v[b+8>>2]}v[b+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=b;v[g+8>>2]=a;break z}a=31;if(e>>>0<=16777215){a=e>>>8|0;d=a+1048320>>>16&8;a=a<<d;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|d))|0;a=(a<<1|e>>>a+21&1)+28|0}v[g+28>>2]=a;v[g+16>>2]=0;v[g+20>>2]=0;b=(a<<2)+463520|0;N:{d=v[115805];c=1<<a;O:{if(!(d&c)){v[115805]=c|d;v[b>>2]=g;break O}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);d=v[b>>2];while(1){b=d;if((e|0)==(v[b+4>>2]&-8)){break N}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;d=v[c+16>>2];if(d){continue}break}v[c+16>>2]=g}v[g+24>>2]=b;v[g+12>>2]=g;v[g+8>>2]=g;break z}a=v[b+8>>2];v[a+12>>2]=g;v[b+8>>2]=g;v[g+24>>2]=0;v[g+12>>2]=b;v[g+8>>2]=a}a=v[115807];if(a>>>0<=h>>>0){break d}b=a-h|0;v[115807]=b;c=v[115810];a=c+h|0;v[115810]=a;v[a+4>>2]=b|1;v[c+4>>2]=h|3;a=c+8|0;break a}a=0;v[115772]=48;break a}P:{if(!f){break P}c=v[d+28>>2];a=(c<<2)+463520|0;Q:{if(v[a>>2]==(d|0)){v[a>>2]=b;if(b){break Q}j=Wia(-2,c)&j;v[115805]=j;break P}v[f+(v[f+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break P}}v[b+24>>2]=f;a=v[d+16>>2];if(a){v[b+16>>2]=a;v[a+24>>2]=b}a=v[d+20>>2];if(!a){break P}v[b+20>>2]=a;v[a+24>>2]=b}R:{if(e>>>0<=15){a=e+h|0;v[d+4>>2]=a|3;a=a+d|0;v[a+4>>2]=v[a+4>>2]|1;break R}v[d+4>>2]=h|3;f=d+h|0;v[f+4>>2]=e|1;v[e+f>>2]=e;if(e>>>0<=255){b=(e&-8)+463256|0;c=v[115804];a=1<<(e>>>3);S:{if(!(c&a)){v[115804]=a|c;a=b;break S}a=v[b+8>>2]}v[b+8>>2]=f;v[a+12>>2]=f;v[f+12>>2]=b;v[f+8>>2]=a;break R}a=31;if(e>>>0<=16777215){a=e>>>8|0;g=a+1048320>>>16&8;a=a<<g;c=a+520192>>>16&4;a=a<<c;b=a+245760>>>16&2;a=(a<<b>>>15|0)-(b|(c|g))|0;a=(a<<1|e>>>a+21&1)+28|0}v[f+28>>2]=a;v[f+16>>2]=0;v[f+20>>2]=0;b=(a<<2)+463520|0;T:{c=1<<a;U:{if(!(c&j)){v[115805]=c|j;v[b>>2]=f;break U}a=e<<((a|0)==31?0:25-(a>>>1|0)|0);h=v[b>>2];while(1){b=h;if((v[b+4>>2]&-8)==(e|0)){break T}c=a>>>29|0;a=a<<1;c=(c&4)+b|0;h=v[c+16>>2];if(h){continue}break}v[c+16>>2]=f}v[f+24>>2]=b;v[f+12>>2]=f;v[f+8>>2]=f;break R}a=v[b+8>>2];v[a+12>>2]=f;v[b+8>>2]=f;v[f+24>>2]=0;v[f+12>>2]=b;v[f+8>>2]=a}a=d+8|0;break a}V:{if(!i){break V}c=v[b+28>>2];a=(c<<2)+463520|0;W:{if(v[a>>2]==(b|0)){v[a>>2]=d;if(d){break W}m=463220,n=Wia(-2,c)&j,v[m>>2]=n;break V}v[i+(v[i+16>>2]==(b|0)?16:20)>>2]=d;if(!d){break V}}v[d+24>>2]=i;a=v[b+16>>2];if(a){v[d+16>>2]=a;v[a+24>>2]=d}a=v[b+20>>2];if(!a){break V}v[d+20>>2]=a;v[a+24>>2]=d}X:{if(e>>>0<=15){a=e+h|0;v[b+4>>2]=a|3;a=a+b|0;v[a+4>>2]=v[a+4>>2]|1;break X}v[b+4>>2]=h|3;d=b+h|0;v[d+4>>2]=e|1;v[d+e>>2]=e;if(k){c=(k&-8)+463256|0;g=v[115809];a=1<<(k>>>3);Y:{if(!(a&f)){v[115804]=a|f;a=c;break Y}a=v[c+8>>2]}v[c+8>>2]=g;v[a+12>>2]=g;v[g+12>>2]=c;v[g+8>>2]=a}v[115809]=d;v[115806]=e}a=b+8|0}jb=l+16|0;return a|0}function L5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;g=jb-32|0;jb=g;a:{b:{c:{d:{e:{if(ne(b,21473)){Kb(a);break e}if(ne(b,9785)){b=jb-128|0;jb=b;f=Kb(a);v[23296]=0;Y(122,b+96|0);a=v[23296];v[23296]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[23296]=0;v[b+64>>2]=0;R(1001,b+80|0,b- -64|0);a=v[23296];v[23296]=0;if((a|0)==1){break p}v[23296]=0;a=Q(753,f|0,b+80|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break o}yb(b+80|0);v[23296]=0;a=Q(889,a|0,16590)|0;c=v[23296];v[23296]=0;q:{if((c|0)==1){break q}v[23296]=0;v[b+64>>2]=6;R(1001,b+80|0,b- -64|0);c=v[23296];v[23296]=0;if((c|0)==1){break n}v[23296]=0;a=Q(753,a|0,b+80|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break m}yb(b+80|0);v[23296]=0;a=Q(889,a|0,16590)|0;c=v[23296];v[23296]=0;if((c|0)==1){break q}v[23296]=0;v[b+64>>2]=4;R(1001,b+80|0,b- -64|0);c=v[23296];v[23296]=0;if((c|0)==1){break l}v[23296]=0;a=Q(753,a|0,b+80|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break k}c=b+80|0;yb(c);v[23296]=0;c=Q(54,c|0,15029)|0;d=v[23296];v[23296]=0;if((d|0)==1){break j}d=Fb(c);yb(c);if(!d){break i}v[23296]=0;Q(889,a|0,15029)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break i}}a=P()|0;O()|0;break h}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+80|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+80|0);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(b+80|0);break h}a=P()|0;O()|0;break h}c=Qb(b- -64|0);r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{d=v[b+108>>2];if(d){v[23296]=0;v[b+16>>2]=d;R(1001,b+32|0,b+16|0);d=v[23296];v[23296]=0;if((d|0)==1){break D}v[23296]=0;U(915,b+48|0,8866,b+32|0);d=v[23296];v[23296]=0;if((d|0)==1){break C}v[23296]=0;R(171,c|0,b+48|0);d=v[23296];v[23296]=0;if((d|0)==1){break B}yb(b+48|0);yb(b+32|0)}if(!Rd(w[b+112|0])){break x}v[23296]=0;d=Q(54,b+48|0,12628)|0;e=v[23296];v[23296]=0;if((e|0)==1){break z}v[23296]=0;R(171,c|0,d|0);e=v[23296];v[23296]=0;if((e|0)==1){break y}yb(d);break w}a=P()|0;O()|0;break r}a=P()|0;O()|0;break A}a=P()|0;O()|0;yb(b+48|0)}yb(b+32|0);break r}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(d);break r}if(!Rd(w[b+113|0])){break w}v[23296]=0;d=Q(54,b+48|0,12399)|0;e=v[23296];v[23296]=0;if((e|0)==1){break v}v[23296]=0;R(171,c|0,d|0);e=v[23296];v[23296]=0;if((e|0)==1){break u}yb(d)}if(Rd(w[b+114|0])){break t}break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(d);break r}v[23296]=0;d=Q(54,b+32|0,10992)|0;e=v[23296];v[23296]=0;E:{if((e|0)!=1){v[23296]=0;R(171,c|0,d|0);e=v[23296];v[23296]=0;if((e|0)==1){break E}yb(d);break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;yb(d);break r}if(uc(v[c>>2],v[c+4>>2])){break f}v[23296]=0;a=Q(889,a|0,16620)|0;d=v[23296];v[23296]=0;if((d|0)!=1){v[23296]=0;d=Q(54,b|0,16590)|0;e=v[23296];v[23296]=0;F:{G:{H:{if((e|0)!=1){v[23296]=0;U(1002,b+16|0,c|0,d|0);e=v[23296];v[23296]=0;if((e|0)==1){break H}v[23296]=0;Q(753,a|0,b+16|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break G}yb(b+16|0);yb(d);break f}a=P()|0;O()|0;break r}a=P()|0;O()|0;break F}a=P()|0;O()|0;yb(b+16|0)}yb(d);break r}a=P()|0;O()|0}Me(c)}qf(b+96|0)}yb(f);break a}Me(c);qf(b+96|0);jb=b+128|0;break e}if(ne(b,8050)){v[g>>2]=0;op(a,g);break e}if(ne(b,8028)){v[g>>2]=6;op(a,g);break e}if(ne(b,10712)){v[g>>2]=4;op(a,g);break e}if(ne(b,10488)){Vb(a,15029);break e}if(ne(b,11261)){b=Vb(g,15029);c=Fb(b);v[23296]=0;Q(54,a|0,(c?15625:15234)|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break d}yb(b);break e}if(ne(b,7330)){b=jb-48|0;jb=b;VD(b+16|0);v[23296]=0;Y(139,b|0);c=v[23296];v[23296]=0;I:{J:{K:{L:{if((c|0)!=1){v[23296]=0;U(140,b+32|0,b+16|0,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break L}v[23296]=0;R(962,a|0,b+32|0);a=v[23296];v[23296]=0;if((a|0)==1){break K}zb(b+32|0);zb(b);zb(b+16|0);jb=b+48|0;break e}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;zb(b+32|0)}zb(b)}zb(b+16|0);break a}if(ne(b,9801)){b=jb-16|0;jb=b;e=jb-16|0;jb=e;v[e+8>>2]=101;c=jb-112|0;jb=c;f=Qb(c+96|0);M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{$:{d=v[e+8>>2];if(d&1){v[23296]=0;R(128,c- -64|0,19923969);d=v[23296];v[23296]=0;if((d|0)==1){break $}v[23296]=0;R(112,f|0,c- -64|0);d=v[23296];v[23296]=0;if((d|0)==1){break _}zb(c- -64|0);d=v[e+8>>2]}if(!(d&4)){break Y}v[23296]=0;d=ga(129)|0;h=v[23296];v[23296]=0;if((h|0)==1){break X}if(!d){break Z}break Y}d=P()|0;O()|0;break N}d=P()|0;O()|0;zb(c- -64|0);break N}v[23296]=0;Y(130,c- -64|0);d=v[23296];v[23296]=0;aa:{if((d|0)!=1){v[23296]=0;R(112,f|0,c- -64|0);d=v[23296];v[23296]=0;if((d|0)==1){break aa}zb(c- -64|0);break Y}d=P()|0;O()|0;break N}d=P()|0;O()|0;zb(c- -64|0);break N}ba:{d=v[e+8>>2];if(!(d&32)){break ba}v[23296]=0;Y(122,c- -64|0);d=v[23296];v[23296]=0;ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{la:{ma:{na:{oa:{pa:{qa:{ra:{sa:{ta:{ua:{if((d|0)!=1){v[23296]=0;R(131,c+48|0,c- -64|0);d=v[23296];v[23296]=0;if((d|0)==1){break da}d=gh(v[c+52>>2],w[c+59|0]);zb(c+48|0);if(!d){v[23296]=0;Y(132,c+32|0);d=v[23296];v[23296]=0;if((d|0)==1){break ua}v[23296]=0;R(131,c+16|0,c- -64|0);d=v[23296];v[23296]=0;if((d|0)==1){break ta}v[23296]=0;U(133,c+48|0,c+32|0,c+16|0);d=v[23296];v[23296]=0;if((d|0)==1){break sa}v[23296]=0;R(112,f|0,c+48|0);d=v[23296];v[23296]=0;if((d|0)==1){break ra}zb(c+48|0);zb(c+16|0);ec(c+32|0)}d=Oo(c- -64|0);if(!gh(v[d+4>>2],w[d+11|0])){v[23296]=0;Y(134,c+32|0);h=v[23296];v[23296]=0;if((h|0)==1){break oa}v[23296]=0;U(135,c+48|0,c+32|0,d|0);d=v[23296];v[23296]=0;if((d|0)==1){break na}v[23296]=0;R(112,f|0,c+48|0);d=v[23296];v[23296]=0;if((d|0)==1){break ma}zb(c+48|0);ec(c+32|0)}v[23296]=0;R(136,c+48|0,c- -64|0);d=v[23296];v[23296]=0;if((d|0)==1){break ka}d=gh(v[c+52>>2],w[c+59|0]);zb(c+48|0);if(!d){v[23296]=0;Y(132,c+32|0);d=v[23296];v[23296]=0;if((d|0)==1){break ja}v[23296]=0;R(136,c+16|0,c- -64|0);d=v[23296];v[23296]=0;if((d|0)==1){break ia}v[23296]=0;U(133,c+48|0,c+32|0,c+16|0);d=v[23296];v[23296]=0;if((d|0)==1){break ha}v[23296]=0;R(112,f|0,c+48|0);d=v[23296];v[23296]=0;if((d|0)==1){break ga}zb(c+48|0);zb(c+16|0);ec(c+32|0)}qf(c- -64|0);d=v[e+8>>2];break ba}d=P()|0;O()|0;break N}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break pa}d=P()|0;O()|0;break qa}d=P()|0;O()|0;zb(c+48|0)}zb(c+16|0)}ec(c+32|0);break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break la}d=P()|0;O()|0;zb(c+48|0)}ec(c+32|0);break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break ca}d=P()|0;O()|0;break ea}d=P()|0;O()|0;break fa}d=P()|0;O()|0;zb(c+48|0)}zb(c+16|0)}ec(c+32|0);break ca}d=P()|0;O()|0}qf(c- -64|0);break N}va:{if(!(d&64)){break va}v[23296]=0;d=ga(129)|0;h=v[23296];v[23296]=0;if((h|0)==1){break X}if(d){break va}d=c- -64|0;Kb(d);v[23296]=0;R(112,f|0,d|0);d=v[23296];v[23296]=0;if((d|0)==1){break O}zb(c- -64|0)}if(w[e+8|0]&128){v[23296]=0;Y(137,c- -64|0);d=v[23296];v[23296]=0;if((d|0)==1){break W}v[23296]=0;R(112,f|0,c- -64|0);d=v[23296];v[23296]=0;if((d|0)==1){break V}zb(c- -64|0)}v[23296]=0;h=Q(1,c- -64|0,21473)|0;d=v[23296];v[23296]=0;if((d|0)==1){break U}v[23296]=0;U(138,c|0,f|0,h|0);d=v[23296];v[23296]=0;if((d|0)==1){break T}v[23296]=0;Y(139,c+48|0);d=v[23296];v[23296]=0;if((d|0)==1){break S}v[23296]=0;U(140,b|0,c|0,c+48|0);d=v[23296];v[23296]=0;if((d|0)==1){break R}zb(c+48|0);zb(c);zb(h);xl(f);jb=c+112|0;break M}d=P()|0;O()|0;break N}d=P()|0;O()|0;break N}d=P()|0;O()|0;zb(c- -64|0);break N}d=P()|0;O()|0;break N}d=P()|0;O()|0;break P}d=P()|0;O()|0;break Q}d=P()|0;O()|0;zb(c+48|0)}zb(c)}zb(h);break N}d=P()|0;O()|0;zb(c- -64|0)}xl(f);S(d|0);L()}jb=e+16|0;v[23296]=0;R(962,a|0,b|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}if(ne(b,10417)){b=jb-48|0;jb=b;mr(b);v[23296]=0;R(131,b+32|0,b|0);c=v[23296];v[23296]=0;wa:{xa:{if((c|0)!=1){v[23296]=0;R(962,a|0,b+32|0);a=v[23296];v[23296]=0;if((a|0)==1){break xa}zb(b+32|0);qf(b);jb=b+48|0;break e}a=P()|0;O()|0;break wa}a=P()|0;O()|0;zb(b+32|0)}qf(b);break a}if(ne(b,11224)){b=jb-32|0;jb=b;mr(b);v[23296]=0;R(962,a|0,Oo(b)|0);a=v[23296];v[23296]=0;if((a|0)!=1){qf(b);jb=b+32|0;break e}a=P()|0;O()|0;qf(b);break a}if(ne(b,9814)){b=jb-48|0;jb=b;mr(b+16|0);c=v[b+28>>2];ya:{if(c){v[23296]=0;v[b+12>>2]=c;R(1001,a|0,b+12|0);a=v[23296];v[23296]=0;if((a|0)!=1){break ya}a=P()|0;O()|0;qf(b+16|0);break a}Kb(a)}qf(b+16|0);jb=b+48|0;break e}if(ne(b,12618)){mr(g);b=w[g+16|0];v[23296]=0;Q(54,a|0,(Rd(b)?15234:15625)|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){qf(g);break e}a=P()|0;O()|0;qf(g);break a}if(ne(b,9830)){mr(g);b=w[g+17|0];v[23296]=0;Q(54,a|0,(Rd(b)?15234:15625)|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){qf(g);break e}a=P()|0;O()|0;qf(g);break a}if(ne(b,12071)){mr(g);b=w[g+18|0];v[23296]=0;Q(54,a|0,(Rd(b)?15234:15625)|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){qf(g);break e}a=P()|0;O()|0;qf(g);break a}if(ne(b,12373)){b=jb-16|0;jb=b;c=jb-32|0;jb=c;d=Kb(b);v[23296]=0;Y(122,c|0);f=v[23296];v[23296]=0;za:{Aa:{Ba:{if((f|0)!=1){v[23296]=0;R(123,d|0,Oo(c)|0);f=v[23296];v[23296]=0;if((f|0)==1){break Ba}qf(c);jb=c+32|0;break za}a=P()|0;O()|0;break Aa}a=P()|0;O()|0;qf(c)}zb(d);break a}v[23296]=0;R(962,a|0,b|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}if(ne(b,8171)){b=jb-16|0;jb=b;c=jb-48|0;jb=c;d=Kb(b);v[23296]=0;R(125,c+16|0,4096);f=v[23296];v[23296]=0;Ca:{Da:{Ea:{Fa:{Ga:{if((f|0)!=1){v[c+12>>2]=15;v[c+8>>2]=0;v[23296]=0;v[c+4>>2]=0;da(126,c+32|0,c+16|0,c+12|0,c+8|0,c+4|0);f=v[23296];v[23296]=0;if((f|0)==1){break Ga}v[23296]=0;Q(87,d|0,c+32|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break Fa}zb(c+32|0);ec(c+16|0);jb=c+48|0;break Ca}a=P()|0;O()|0;break Da}a=P()|0;O()|0;break Ea}a=P()|0;O()|0;zb(c+32|0)}ec(c+16|0)}zb(d);S(a|0);L()}v[23296]=0;R(962,a|0,b|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}if(ne(b,6783)){b=jb-16|0;jb=b;Rm(b,0,19419);v[23296]=0;R(962,a|0,b|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}if(ne(b,6416)){b=jb-48|0;jb=b;c=Vb(b+16|0,17480);v[23296]=0;R(1003,b|0,2);d=v[23296];v[23296]=0;Ha:{Ia:{Ja:{Ka:{if((d|0)!=1){v[23296]=0;U(2,b+32|0,c|0,b|0);d=v[23296];v[23296]=0;if((d|0)==1){break Ka}v[23296]=0;R(962,a|0,b+32|0);a=v[23296];v[23296]=0;if((a|0)==1){break Ja}zb(b+32|0);zb(b);zb(c);jb=b+48|0;break e}a=P()|0;O()|0;break Ha}a=P()|0;O()|0;break Ia}a=P()|0;O()|0;zb(b+32|0)}zb(b)}zb(c);break a}if(ne(b,11247)){b=jb-16|0;jb=b;Rm(b,0,17819);v[23296]=0;R(962,a|0,b|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}if(ne(b,10424)){b=jb-16|0;jb=b;jr(b,0);v[23296]=0;R(962,a|0,b|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}if(ne(b,10399)){b=jb-16|0;jb=b;jr(b,2);v[23296]=0;R(962,a|0,b|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}if(ne(b,10384)){b=jb-16|0;jb=b;jr(b,3);v[23296]=0;R(962,a|0,b|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(b);jb=b+16|0;break e}break b}Kb(a)}jb=g+32|0;break c}a=P()|0;O()|0;yb(b);break a}return}a=P()|0;O()|0;zb(b)}S(a|0);L()}function N9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;g=jb-48|0;jb=g;c=v[a+1074308>>2];if(!(c>>>0>18285125|(c|0)==18284544)){Bf(a+1074312|0,0)}j=a+1074308|0;c=g+32|0;h=a+1074312|0;Bb(c,h,0);d=Cb(v[v[g+32>>2]>>2],v[g+36>>2]);b=a+480180|0;e=v[b>>2];Bb(c,h,0);o=d&(e&16777248)!=0;C=Cb(v[v[g+32>>2]>>2],v[g+36>>2]);D=v[b>>2];a:{c=v[a+1074308>>2];if(c>>>0>18874367){break a}i=a+480192|0;e=1;while(1){b:{d=e&65535;if(d>>>0<=x[i>>1]){d=v[((d<<2)+a|0)+900380>>2];if(!d){break b}v[g+32>>2]=B(w[d+20|0],100)>>>6;v[g+16>>2]=100;F=d,G=v[Ib(g+32|0,g+16|0)>>2],t[F+20|0]=G;c:{if(o){if(c>>>0>=18350080){break b}k=t[d+26|0];t[d+26|0]=((k>>31|1)+k|0)/2;if(c>>>0>18285313){break b}break c}c=t[d+26|0];t[d+26|0]=((c>>31|1)+c|0)/2}VA(Ei(d,2),v[b>>2]);c=v[a+1074308>>2];d:{if(c>>>0<18284544){break d}if(c>>>0>18285135){break b}if(!w[d+34|0]){break d}if(!nj(w[d+31|0])){break d}Nb(h,2,1);c=v[j>>2];if(c>>>0>18285135){break b}}if(!(w[d+24|0]|(w[d+23|0]|(w[d+19|0]|w[d+20|0])))){break b}Nb(h,1,1)}e:{if(!(v[a+480180>>2]&16777248)|y[j>>2]>18285313&o){break e}d=x[a+480190>>1]+1&65535;b=1;while(1){if((b|0)==(d|0)){break e}c=B(b,104)+a|0;e=c+484419|0;if(!(w[e|0]|!(w[c+484421|0]|w[c+484420|0]))){t[e|0]=255}b=b+1|0;continue}}d=a+901404|0;i=Az(d);while(1){if((d|0)!=(i|0)){c=d;k=ao(c);while(1){if((c|0)!=(k|0)){b=w[c|0];f:{g:{if((b-97&255)>>>0<=5){f=b-32|0;break g}if(!(b-88>>>0<2|b-120>>>0<2)){f=99;if((b|0)==75|(b|0)==107){break g}break f}f=122}t[c|0]=f}c=c+1|0;continue}break}d=d+32|0;continue}break}c=v[a+1074308>>2];break a}e=e+1|0;continue}}h:{i:{j:{if((c|0)==18874368|c>>>0>18874895){break j}if(!(v[a+480180>>2]&16777252)){break i}i=x[a+480192>>1]+1&65535;d=0;b=1;while(1){if((b|0)==(i|0)){if(!d){break j}Nb(h,3,1);c=v[j>>2]}else{e=v[((b<<2)+a|0)+900380>>2];if(!(!e|!w[e+31|0])){t[e+33|0]=13;d=1}b=b+1|0;continue}break}}if((c|0)==19005440|c>>>0>19006225){break h}}if(!(v[a+480180>>2]&16777248)){break h}Bb(g+32|0,h,0);if(!Cb(v[v[g+32>>2]>>2],v[g+36>>2])){Bb(g+16|0,h,1);if(!Cb(v[v[g+16>>2]>>2],v[g+20>>2])){break h}}d=x[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(d|0)){break h}c=v[((b<<2)+a|0)+900380>>2];if(!(!c|!w[c+19|0]|!(t[c+80|0]&1))){t[c+19|0]=0}b=b+1|0;continue}}k:{l:{m:{n:{o:{if(y[j>>2]>19007232){break o}c=a+946300|0;b=a+906300|0;while(1){if((b|0)==(c|0)){break o}d=g+16|0;e=b+80|0;lM(d,e);v[23296]=0;X(223,g+32|0,0,8,d|0);d=v[23296];v[23296]=0;if((d|0)==1){break n}yb(g+16|0);d=g+32|0;uu(e,d);b=b+160|0;yb(d);continue}}p:{q:{r:{if(v[a+480180>>2]!=4){break r}d=v[j>>2];if(d>>>0<19007257){break p}if(d>>>0>19071235){break q}if(w[a+1074368|0]!=4){break r}qy(a,5)}d=v[j>>2]}if(d>>>0>19202054){break m}c=19202048;if((d|0)==19202048){break l}}i=x[a+480192>>1]+1&65535;c=1;while(1){if((c|0)==(i|0)){break m}e=v[((c<<2)+a|0)+900380>>2];s:{if(!e|!w[e+20|0]|!w[e+31|0]){break s}b=e+236|0;k=hq(b);while(1){if((b|0)!=(k|0)){m=x[b>>1];b=b+2|0;if(!m){continue}break s}break}t[e+20|0]=0}c=c+1|0;continue}}a=P()|0;O()|0;yb(g+16|0);S(a|0);L()}c=d;if(c>>>0>19267583){break k}}e=!o;i=x[a+480192>>1]+1&65535;b=1;while(1){if((b|0)==(i|0)){break k}d=v[((b<<2)+a|0)+900380>>2];t:{if(!d){break t}c=t[d+26|0];t[d+26|0]=((c>>31|1)+c|0)/2;c=v[j>>2];if(!(e|c>>>0<18350080)){break t}t[d+19|0]=w[d+19|0]+3>>>2}b=b+1|0;continue}}u:{if(c>>>0>19398673){break u}d=x[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break u}e=v[((e<<2)+a|0)+900380>>2];if(!e|w[e+65|0]==255){b=b+1|0;continue}else{Nb(h,94,1);c=v[j>>2]}break}}v:{if(c>>>0>19399427){break v}d=x[a+480192>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break v}e=v[((e<<2)+a|0)+900380>>2];if(!e|w[e+36|0]>1){b=b+1|0;continue}else{Nb(h,101,1);c=v[j>>2]}break}}w:{if(c>>>0>19923027){break w}d=x[a+480190>>1];b=1;while(1){c=b&65535;if(c>>>0>d>>>0){break w}c=B(c,104)+a|0;if(!Ud(v[c+484380>>2],v[c+484400>>2])|!(w[c+484414|0]&20)){b=b+1|0;continue}else{Nb(h,116,1)}break}}c=jb-16|0;jb=c;u[g+12>>1]=0;v[g+8>>2]=a;Bb(c+8|0,a+1074312|0,0);F=g,G=Cb(v[v[c+8>>2]>>2],v[c+12>>2]),t[F+14|0]=G;jb=c+16|0;q=v[g+8>>2];r=v[g+12>>2];c=a+484344|0;z=c;A=pf(v[c>>2],v[c+4>>2])-1&65535;e=0;k=jb-32|0;jb=k;x:{if(pf(v[c>>2],v[c+4>>2])>>>0<=A>>>0){break x}while(1){c=e&65535;if(c>>>0>A>>>0){break x}d=Pf(v[z>>2],c);b=v[d>>2];if(Rb(b,v[d+4>>2])){b=Eb(b);E=Eb(v[Pf(v[z>>2],c)+4>>2]);v[k+24>>2]=q;v[k+28>>2]=r;v[k+8>>2]=q;v[k+12>>2]=r;i=k+8|0;p=jb-16|0;jb=p;v[p+8>>2]=b;while(1){if(Rb(b,E)){m=jb-16|0;jb=m;s=x[i+4>>1];c=s+1|0;u[i+4>>1]=c;l=v[i>>2];u[i+4>>1]=x[l+480188>>1]>(c&65535)>>>0?c:0;y:{if(Sg(w[b|0])){break y}d=v[l+1074308>>2];z:{l=v[l+480180>>2];A:{B:{if((l|0)==2){if(d>>>0>18415615){break B}if(w[b+3|0]!=23){break A}nf(b+5|0,64);break A}if(l&16777248){C:{D:{if(d>>>0>=18285314){if(w[i+6|0]){break D}c=0;f=0;if(d>>>0>18874367){break C}}E:{switch(w[b+3|0]-20|0){case 3:nf(b+5|0,128);break D;case 0:break E;default:break D}}c=w[b+5|0];if((c|0)!=208){if((c|0)!=192){break D}t[b|0]=254;t[b+3|0]=0;break D}t[b+3|0]=0}F:{G:{if(d>>>0>=18350080){if(w[i+6|0]){break G}c=0;f=0;if(d>>>0>18874367){break C}}f=w[b+3|0];n=f-6&255;c=0;if(n>>>0>23){break F}c=8388643>>>n&1;break F}c=0;f=0;if(d>>>0>18874367){break C}f=w[b+3|0];c=0}f=(f|0)==24|(f|0)==22}H:{if(!(f?1:c)){break H}f=w[b+5|0];c=f&15;if(!c|(c|0)==15){break H}f=f&240;if(!f|(f|0)==240){break H}t[b+5|0]=w[b+3|0]==24?f:c}I:{if((d|0)==19005440|d>>>0>19005699){break I}c=x[v[i>>2]+480192>>1];if(w[i+6|0]|(!c|c>>>0>=w[b+1|0])){break I}t[b+4|0]=0;t[b+2|0]=1}if(w[b+3|0]!=18|w[b+5|0]!=17){break B}if(d>>>0>19468801){break z}Bb(m+8|0,v[i>>2]+1074312|0,22);if(!Cb(v[v[m+8>>2]>>2],v[m+12>>2])|v[v[i>>2]+480208>>2]&4){break B}t[b+5|0]=0;break B}if((l|0)!=4){break B}J:{if((!w[i+6|0]|d>>>0<18285314)&d>>>0<18874368){break J}if(d>>>0>19137025){break z}if(w[b+3|0]!=23|w[b+5|0]<65){break J}t[b+3|0]=0}K:{L:{M:{if(!(w[i+6|0]|d>>>0>18874367?d>>>0>=18415616:0)){c=w[b+2|0];if(w[b+3|0]!=10|(c|0)!=11){break M}t[b+3|0]=0;c=11;break M}if(d>>>0>18874639){break L}c=w[b+2|0]}if((c|0)!=11|w[b+3|0]!=4){break K}c=w[b+4|0];if(!(c|w[i+6|0])){break K}f=w[b+5|0];if(!f){break K}t[b+2|0]=0;F=b,G=ju(f+(c<<4)|0),t[F+5|0]=G;break K}if(d>>>0>19007240){break z}}if(w[b+5|0]|w[b+3|0]!=16){break B}t[b+3|0]=0}if(d>>>0>18874367){break z}}c=w[b+3|0];n=w[b+5|0]&240;N:{O:{if((c|0)!=28|(n|0)!=96){f=0}else{if(!w[i+6|0]|(l|0)!=4){break O}f=d>>>0<18350080}if(!(f|(c|0)==20&(n|0)==96)){break N}}c=B(s,-6)+b|0;while(1){if(b>>>0>c>>>0){if(!((w[c+3|0]|8)!=28|(w[c+5|0]&240)!=96)){t[c+3|0]=0}c=c+6|0;continue}break}c=w[b+3|0]}if((c|0)!=20|(w[b+5|0]&240)!=224){break z}c=B(s,-6)+b|0;while(1){if(b>>>0<=c>>>0){break z}if(!(w[c+3|0]!=20|(w[c+5|0]&240)!=224)){t[c+3|0]=0}c=c+6|0;continue}}c=b+2|0;f=w[b+2|0];P:{if((f|0)==8){if((d|0)==19333120|d>>>0>19333174){break y}l=w[b+4|0];d=w[b+3|0];if(!(!l|(d|0)!=7)){t[b+3|0]=11;break y}Q:{switch(d-5|0){default:if((d|0)!=26){break y}break;case 1:break y;case 2:break P;case 0:break Q}}f=w[b+5|0];if(!(f&15)){t[b+3|0]=5;t[b+5|0]=f|l&15;break P}R:{switch(d-5|0){case 1:break y;case 0:case 2:break P;default:break R}}if((d|0)==26){break P}break y}S:{if(!((l|0)==16777216|(f|0)!=15)){if(w[b+3|0]){break S}t[b+3|0]=10;t[b+5|0]=w[b+4|0]<<3;break P}if((f|0)!=15){break y}}if(w[b+3|0]!=10|d>>>0>19922963){break y}c=w[b+5|0]?c:w[b+4|0]?b+3|0:c}t[c|0]=0}jb=m+16|0;b=v[kk(p+8|0)>>2];continue}break}c=v[i+4>>2];v[k+16>>2]=v[i>>2];v[k+20>>2]=c;jb=p+16|0}e=e+1|0;continue}}v[g+32>>2]=q;v[g+36>>2]=r;jb=k+32|0;T:{c=y[a+1074308>>2]<19267584;if(c&o){b=41872;while(1){if((b|0)==42216){break T}c=v[j>>2];d=v[b+4>>2];Nb(h,v[b>>2],c>>>0>=d>>>0|(c|0)==(d&-65536));b=b+8|0;continue}}if(!(c&((D|0)==4&C))){break T}b=42224;while(1){if((b|0)==42464){break T}Nb(h,v[b>>2],y[j>>2]>=y[b+4>>2]);b=b+8|0;continue}}U:{V:{c=v[a+480180>>2];if(c&16777248){b=42464;while(1){if((b|0)==42520){break V}c=v[j>>2];d=v[b+4>>2];e=d&-65536;if(!(c>>>0>=e>>>0&(c>>>0<=e>>>0|c>>>0>=d>>>0))){Bf(h,v[b>>2])}b=b+8|0;continue}}b=42592;e=42528;W:{switch(c-2|0){case 2:while(1){if((e|0)==42592){break V}if(y[j>>2]<y[e+4>>2]){Bf(h,v[e>>2])}e=e+8|0;continue};case 0:break W;default:break U}}while(1){if((b|0)==42680){break V}if(y[j>>2]<y[b+4>>2]){Bf(h,v[b>>2])}b=b+8|0;continue}}c=v[a+480180>>2]}X:{if((c|0)==4){b=v[j>>2];if(b>>>0>18415615){break X}Nb(h,98,1)}b=v[j>>2]}e=8;if(b-19333159>>>0<=33){b=0;while(1){if((b|0)!=5){c=b+77|0;Bb(g+32|0,h,c);Bf(Nb(h,b+86|0,Cb(v[v[g+32>>2]>>2],v[g+36>>2])),c);b=b+1|0;continue}break}b=v[j>>2]}Y:{if(b>>>0>=18284544){if(b>>>0>18874627){break Y}e=6;if((b|0)==18874368){break Y}}Nb(h,e,1)}c=v[a+1074308>>2];Z:{if(w[a+480208|0]&16){if(c>>>0<=19136511){Bf(h,7);break Z}if(!(v[a+480180>>2]&16777248)|c>>>0>19267583){break Z}Nb(h,7,1);break Z}if((c|0)==19922944|c>>>0>19922997){break Z}Bf(h,7)}Bb(g+32|0,h,31);_:{if(!Cb(v[v[g+32>>2]>>2],v[g+36>>2])){break _}c=v[j>>2];if(c>>>0<19071234|c>>>0>19398722){break _}d=x[a+480192>>1];b=1;while(1){c=b&65535;if(c>>>0>d>>>0){break _}$:{c=v[((c<<2)+a|0)+900380>>2];if(!c){break $}e=w[c+65|0];if(!(w[c+60|0]&4)|(e|0)==255|e>>>0<=w[c- -64|0]){break $}Nb(h,97,1);break _}b=b+1|0;continue}}c=v[a+480180>>2];aa:{if(!(c&16777218)){break aa}d=x[a+480190>>1];b=1;while(1){e=b&65535;if(e>>>0>d>>>0){break aa}b=b+1|0;if(!(w[(B(e,104)+a|0)+484415|0]&2)){continue}break}ba:{ca:{da:{if(!(!x[a+480192>>1]|(c|0)!=16777216)){b=v[j>>2];if(b>>>0<19398688){break ca}if(b>>>0>19464277){break da}Nb(h,109,1)}b=v[j>>2]}if((b|0)==19922944|b>>>0>19922996){break ba}}Bf(h,111);b=v[j>>2]}c=v[a+480180>>2];if(!((c|0)!=2|b>>>0>19464191)){Nb(h,108,1);break aa}if((c|0)==2){break aa}Bf(h,108)}ea:{if(!(v[a+480180>>2]&16777252)|v[j>>2]-19333186>>>0>589827){break ea}c=a+946300|0;b=a+906300|0;while(1){if((b|0)==(c|0)){break ea}fa:{if((w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24))!=1146637647|(w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24))!=-271958638){break fa}if((ad(v[b+4>>2],v[b+8>>2])|0)!=32){break fa}a=Vb(g+32|0,16671);uu(b+80|0,a);yb(a)}b=b+160|0;continue}}jb=g+48|0}function JV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a:{n=Ah(b,13672);if(!n){break a}o=a+480192|0;b:while(1){if(!Ob(v[b>>2],v[b+8>>2],6)){break a}c:{f=qg(b);d:{if((f|0)==(Am(13491)|0)){break d}c=w[21449]|w[21450]<<8|(w[21451]<<16|w[21452]<<24);if(!(f&1616928864)|f&-2139062144){break d}if((c|0)!=(f|0)){break c}}ng(b,4);break a}l=1;c=Fg(b);while(1){d=l&65535;if(d>>>0>x[o>>1]){continue b}d=v[((d<<2)+a|0)+900380>>2];if(d){e:{g=0;if((Am(16574)|0)==(f|0)){ac(b,c);break e}e=jb-48|0;jb=e;f:{if(!d){break f}g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{_:{switch(f-1349079874|0){default:if((f|0)==1095062094){break v}if((f|0)==1095126087){break s}if((f|0)==1129524782){break B}if((f|0)==1145263150){break Y}if((f|0)==1145979182){break X}if((f|0)==1179463214){break z}if((f|0)==1851469358){break F}if((f|0)==1179931728){break n}$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{if((f|0)!=1196830254){if((f|0)==1229341486){break U}if((f|0)==1229345326){break T}if((f|0)==1264266798){break G}if((f|0)==1296182830){break S}if((f|0)==1296248366){break Q}if((f|0)==1297100334){break R}if((f|0)==1297110852){break q}if((f|0)==1298747438){break D}if((f|0)==1313692462){break H}if((f|0)==1313751342){break Z}if((f|0)==1345203758){break ja}if((f|0)==1346711086){break l}if((f|0)==1346720334){break w}if((f|0)==1346722606){break J}if((f|0)==1346784327){break t}if((f|0)==1347175726){break da}if((f|0)==1347179310){break ea}if((f|0)==1347437358){break O}if((f|0)==1347441454){break P}if((f|0)==1347443502){break M}if((f|0)==1347628590){break W}if((f|0)==1347633710){break ca}if((f|0)==1347634478){break ba}if((f|0)==1347703884){break o}if((f|0)==1347831112){break y}if((f|0)==1347833672){break x}if((f|0)==1349076270){break k}if((f|0)==1349076315){break I}if((f|0)==1349078085){break $}if((f|0)==1349078099){break aa}if((f|0)==1349079131){break L}if((f|0)==1378758190){break p}if((f|0)==1381183022){break A}if((f|0)==1447374382){break m}if((f|0)==1447383630){break u}if((f|0)==1447385902){break K}if((f|0)==1447447623){break r}if((f|0)==1447839022){break ha}if((f|0)==1447842606){break ia}if((f|0)==1448106798){break N}if((f|0)==1448226350){break C}if((f|0)==1448291886){break V}if((f|0)==1448297006){break ga}if((f|0)==1448297774){break fa}if((f|0)!=1682320942){if((f|0)==1718508334){break E}if((f|0)!=1179594286|c>>>0>4){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Zu(b,c),v[p>>2]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+15|0]=q;break g}if(c>>>0>4){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Zu(b,c),v[p+4>>2]=q;break g}if(c>>>0>4){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=Zu(b,c),v[p+8>>2]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+61|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+62|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+63|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d- -64|0,q=zd(b,c),t[p|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+81|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+82|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+83|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+84|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+101|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+102|0]=q;break g;case 0:if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+103|0]=q;break g;case 3:break _;case 1:case 2:break f}}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+104|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+16|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+17|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+18|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+19|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+20|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+21|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+22|0]=q;break g}if(c>>>0>2){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=NC(b,c),u[p+28>>1]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+30|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+31|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=MC(b,c),t[p+26|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+27|0]=q;break g}Yd(e,b,c);i=jc(e+24|0,e);Ab(e);j=Ei(d,0);h=v[j>>2];while(1){if(re(h,v[j+4>>2])>>>0<=g>>>0){Ab(i);break g}v[23296]=0;k=T(185,i|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break j}h=v[j>>2];p=Db(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}}Yd(e,b,c);i=jc(e+24|0,e);Ab(e);j=Ei(d,1);h=v[j>>2];while(1){if(re(h,v[j+4>>2])>>>0<=g>>>0){Ab(i);break g}v[23296]=0;k=T(185,i|0)|0;h=v[23296];v[23296]=0;if((h|0)!=1){h=v[j>>2];p=Db(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Yd(e,b,c);i=jc(e+24|0,e);Ab(e);j=Ei(d,2);h=v[j>>2];while(1){if(re(h,v[j+4>>2])>>>0<=g>>>0){Ab(i);break g}v[23296]=0;k=T(185,i|0)|0;h=v[23296];v[23296]=0;if((h|0)!=1){h=v[j>>2];p=Db(h,g),q=k,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Yd(e,b,c);i=jc(e+24|0,e);Ab(e);j=Ei(d,0);h=v[j>>2];while(1){if(re(h,v[j+4>>2])>>>0<=g>>>0){Ab(i);break g}v[23296]=0;k=T(186,i|0)|0;h=v[23296];v[23296]=0;if((h|0)!=1){h=v[j>>2];p=Db(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Yd(e,b,c);i=jc(e+24|0,e);Ab(e);j=Ei(d,1);h=v[j>>2];while(1){if(re(h,v[j+4>>2])>>>0<=g>>>0){Ab(i);break g}v[23296]=0;k=T(186,i|0)|0;h=v[23296];v[23296]=0;if((h|0)!=1){h=v[j>>2];p=Db(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}Yd(e,b,c);i=jc(e+24|0,e);Ab(e);j=Ei(d,2);h=v[j>>2];while(1){if(re(h,v[j+4>>2])>>>0<=g>>>0){Ab(i);break g}v[23296]=0;k=T(186,i|0)|0;h=v[23296];v[23296]=0;if((h|0)!=1){h=v[j>>2];p=Db(h,g),q=k,t[p+2|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>128){break f}h=d+108|0;Yd(e,b,c);i=jc(e+24|0,e);Ab(e);while(1){if((g|0)==128){Ab(i);break g}v[23296]=0;j=T(186,i|0)|0;k=v[23296];v[23296]=0;if((k|0)!=1){p=Lb(h,g),q=j,t[p|0]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>256){break f}h=d+236|0;Yd(e,b,c);i=jc(e+24|0,e);Ab(e);while(1){if((g|0)==128){Ab(i);break g}v[23296]=0;j=T(185,i|0)|0;k=v[23296];v[23296]=0;if((k|0)!=1){p=dc(h,g),q=j,u[p>>1]=q;g=g+1|0;continue}break}g=P()|0;O()|0;break i}if(c>>>0>32){break f}j=d+492|0;Yd(e,b,c);i=jc(e+24|0,e);Ab(e);h=Kb(e);while(1){if((c|0)==(g|0)){break h}v[23296]=0;k=T(187,i|0)|0;m=v[23296];v[23296]=0;ka:{if((m|0)==1){break ka}v[23296]=0;Q(188,h|0,k|0)|0;k=v[23296];v[23296]=0;if((k|0)==1){break ka}g=g+1|0;continue}break}g=P()|0;O()|0;yb(h);break i}if(c>>>0>32){break f}j=d+524|0;Yd(e,b,c);i=jc(e+24|0,e);Ab(e);h=Kb(e);la:{while(1){if((c|0)!=(g|0)){v[23296]=0;k=T(187,i|0)|0;m=v[23296];v[23296]=0;if((m|0)==1){break la}v[23296]=0;Q(188,h|0,k|0)|0;k=v[23296];v[23296]=0;if((k|0)==1){break la}g=g+1|0;continue}break}Ec(j,h);yb(h);Ab(i);break g}g=P()|0;O()|0;yb(h);break i}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+34|0]=q;break g}if(c>>>0>2){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=NC(b,c),u[p+12>>1]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+23|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+24|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+25|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+35|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+36|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+105|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+85|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+65|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+100|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+80|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=zd(b,c),t[p+60|0]=q;break g}if(c>>>0>1){break f}if(!Ob(v[b>>2],v[b+8>>2],c)){break f}p=d,q=MC(b,c),t[p+33|0]=q;break g}g=1;i=zo(b,c);if(!yo(i)){break f}t[d+14|0]=i;break f}p=d,q=B(Wu(b,c),1e4)+(y[d+40>>2]%1e4|0)|0,v[p+40>>2]=q;break g}h=(Wu(b,c)>>>0)%1e4|0;g=v[d+40>>2];v[d+40>>2]=h+g-(g>>>0)%1e4;break g}v[e+24>>2]=240;p=e,q=zo(b,c),v[p>>2]=q;dh(d+48|0,v[Ib(e+24|0,e)>>2]);break g}v[e+24>>2]=240;p=e,q=zo(b,c),v[p>>2]=q;dh(d+68|0,v[Ib(e+24|0,e)>>2]);break g}v[e+24>>2]=240;p=e,q=zo(b,c),v[p>>2]=q;dh(d+88|0,v[Ib(e+24|0,e)>>2]);break g}g=P()|0;O()|0}Ab(i);S(g|0);L()}Ec(j,h);yb(h);Ab(i)}g=1}jb=e+48|0;if(!g){ac(b,c);break e}if((Am(16579)|0)==(f|0)){e=w[d+15|0];t[d+15|0]=0;t[d+100|0]=w[d+100|0]&224|(e>>>5&4|e>>>6&1);t[d+60|0]=e>>>1&2|(e<<1&4|(w[d+60|0]&240|e&1));t[d+80|0]=w[d+80|0]&240|(e>>>4&2|(e>>>2&4|e>>>3&1))}}}l=l+1|0;continue}}}return n|0}function bV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-304|0;jb=e;Ac(b);if(Hq(b,17646)){o=Kb(e+288|0);v[23296]=0;f=Q(218,b|0,o|0)|0;g=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{if((g|0)!=1){if(!f){break a}v[23296]=0;f=Q(233,b|0,e+280|0)|0;g=v[23296];v[23296]=0;g:{if((g|0)==1){break g}if(!f){break a}if(!WB(w[e+280|0],w[e+281|0])){break a}f=Vc(VB(e+280|0),mb);g=v[b+8>>2];m=v[b>>2];v[23296]=0;f=W(144,m|0,g|0,f|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break g}if(!f){break a}if(!c){break b}v[23296]=0;R(234,a|0,4096);d=v[23296];v[23296]=0;if((d|0)==1){break g}v[23296]=0;R(235,a+1298308|0,o|0);d=v[23296];v[23296]=0;if((d|0)==1){break g}d=w[e+282|0];u[a+480188>>1]=32;u[a+480192>>1]=d;xh(a,1);v[23296]=0;d=Q(1,e+264|0,9378)|0;f=v[23296];v[23296]=0;h:{i:{j:{k:{l:{m:{n:{o:{p:{if((f|0)!=1){Hb(a+1298344|0,d);zb(d);v[23296]=0;d=Q(1,e+248|0,7011)|0;f=v[23296];v[23296]=0;if((f|0)==1){break p}Hb(a+1298356|0,d);zb(d);v[23296]=0;Y(236,e+48|0);d=v[23296];v[23296]=0;if((d|0)==1){break o}t[e+216|0]=w[e+281|0];v[23296]=0;t[e+8|0]=w[e+280|0];R(237,e+232|0,e+8|0);d=v[23296];v[23296]=0;if((d|0)==1){break n}v[23296]=0;X(238,e+96|0,e+48|0,e+216|0,e+232|0);d=v[23296];v[23296]=0;if((d|0)==1){break m}d=e+96|0;Hb(a+1298368|0,d);zb(d);zb(e+232|0);ec(e+48|0);v[a+1298404>>2]=5;if(w[e+280|0]<2){break i}u[e+96>>1]=8192;v[23296]=0;d=T(182,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break k}u[e+48>>1]=d;r=a,s=B(x[We(e+96|0,e+48|0)>>1],1e4)>>>8|0,v[r+480204>>2]=s;v[23296]=0;t[e+96|0]=1;d=T(194,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break j}t[e+48|0]=d;r=a,s=w[ef(e+96|0,e+48|0)|0],v[r+480196>>2]=s;v[23296]=0;Q(176,b|0,3)|0;d=v[23296];v[23296]=0;if((d|0)!=1){v[23296]=0;d=T(182,b|0)|0;f=v[23296];v[23296]=0;if((f|0)!=1){break h}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break l}b=P()|0;O()|0;zb(e+232|0)}ec(e+48|0);break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}t[e+96|0]=32;v[23296]=0;d=T(194,b|0)|0;f=v[23296];v[23296]=0;q:{if((f|0)!=1){t[e+48|0]=d;r=a,s=B(w[ef(e+96|0,e+48|0)|0],1e4),v[r+480204>>2]=s;v[23296]=0;t[e+96|0]=1;d=T(194,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break q}t[e+48|0]=d;r=a,s=w[ef(e+96|0,e+48|0)|0],v[r+480196>>2]=s;v[23296]=0;d=T(194,b|0)|0;f=v[23296];v[23296]=0;if((f|0)!=1){break h}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}v[a+480208>>2]=d>>>2&16|12;m=Qb(e+232|0);p=e+96|12;n=Qb(e+216|0);h=a+480190|0;i=1;while(1){r:{s:{d=i&65535;if(d>>>0>x[a+480192>>1]){break s}v[23296]=0;f=W(239,a|0,d|0,0)|0;d=v[23296];v[23296]=0;t:{if((d|0)==1){break t}if(!f){break s}v[23296]=0;d=Q(228,b|0,f+492|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break t}if(!d){break s}v[23296]=0;k=T(194,b|0)|0;d=v[23296];v[23296]=0;u:{v:{w:{if((d|0)!=1){Xb(e+96|0,0,120);if(!k){break r}x:{if(w[e+280|0]){v[23296]=0;d=Q(240,b|0,e+96|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break w}if(!d){break r}if(w[e+280|0]){break x}}d=gc(e+88|0,p,96);g=v[d+4>>2];d=v[d>>2];v[23296]=0;_m(153,e+48|0,b,d,g);d=v[23296];v[23296]=0;if((d|0)==1){break v}if(!v[e+52>>2]){break r}}g=f+236|0;d=0;break u}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}while(1){if((d|0)!=120){r=dc(g,d),s=(w[(e+96|0)+d|0]+x[h>>1]|0)+1|0,u[r>>1]=s;d=d+1|0;continue}break}v[23296]=0;d=f+48|0;U(241,e+8|0,d|0,b|0);g=v[23296];v[23296]=0;if((g|0)==1){break e}v[23296]=0;g=f+68|0;U(241,e+32|0,g|0,b|0);j=v[23296];v[23296]=0;if((j|0)==1){break e}v[23296]=0;j=f+88|0;U(241,e+80|0,j|0,b|0);l=v[23296];v[23296]=0;if((l|0)==1){break e}v[23296]=0;R(242,b|0,e+72|0);l=v[23296];v[23296]=0;if((l|0)==1){break f}v[f>>2]=(w[e+73|0]|w[e+74|0]<<8)&4095;l=w[e+73|0]|w[e+74|0]<<8;Bu(w[e+75|0]|w[e+76|0]<<8,d,0);Bu(w[e+75|0]|w[e+76|0]<<8,g,1);Bu(w[e+75|0]|w[e+76|0]<<8,j,2);r=e,s=Eb(v[d>>2]),v[r+48>>2]=s;l=l>>>12&3;q=Eb(v[f+52>>2]);while(1){d=v[e+48>>2];if(Rb(d,q)){t[e+44|0]=64;t[e+70|0]=((w[d+2|0]<<6)- -64>>>0)/127;r=d,s=w[Wb(e+44|0,e+70|0)|0],t[r+2|0]=s;Ce(e+48|0);continue}else{r=e,s=Eb(v[g>>2]),v[r+48>>2]=s;d=Eb(v[f+72>>2])}break}while(1){g=v[e+48>>2];if(Rb(g,d)){t[e+44|0]=64;t[e+70|0]=((w[g+2|0]<<6)+128>>>0)/255;r=g,s=w[Wb(e+44|0,e+70|0)|0],t[r+2|0]=s;Ce(e+48|0);continue}break}r=e,s=Eb(v[j>>2]),v[r+48>>2]=s;j=1<<l;l=Eb(v[f+92>>2]);while(1){d=v[e+48>>2];if(Rb(d,l)){g=d;d=t[d+2|0];d=Sia(d^-128,d>>31^-1,j,0);f=mb;y:{if((f|0)>=-1&d>>>0>=4294967292|(f|0)>=0){d=d+4|0;f=d>>>0<4?f+1|0:f;d=((f&7)<<29|d>>>3)&536870911;f=0;break y}f=0-((d>>>0>3)+f|0)|0;d=3-d|0;f=((f&7)<<29|d>>>3)&536870911;d=0-f|0;f=0-((f|0)!=0)|0}r=g,s=Ic(d,f)^128,t[r+2|0]=s;Ce(e+48|0);continue}else{f=x[h>>1]+1|0;u[e+70>>1]=f;d=0;f=f&65535;g=4e3-f|0;g=g>>>0>4e3?0:g;z:{A:{B:{while(1){if((d|0)==(k|0)){break A}if((d|0)==(g|0)){v[23296]=0;Q(176,b|0,20)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break A}b=P()|0;O()|0;break d}v[23296]=0;j=d+f|0;Q(228,b|0,((j<<5)+a|0)+946304|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break z}v[23296]=0;R(243,b|0,e+48|0);l=v[23296];v[23296]=0;C:{if((l|0)==1){break C}v[23296]=0;R(244,e+48|0,(B(j,104)+a|0)+484380|0);j=v[23296];v[23296]=0;if((j|0)==1){break C}v[23296]=0;u[e+44>>1]=w[e+72|0]|d<<8&32512|((w[e+67|0]&3)!=0)<<15;R(245,n|0,e+44|0);j=v[23296];v[23296]=0;if((j|0)==1){break B}d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[23296]=0;R(245,m|0,e+70|0);d=v[23296];v[23296]=0;if((d|0)!=1){v[e+48>>2]=3999;v[e+44>>2]=k+x[h>>1];r=h,s=v[td(e+48|0,e+44|0)>>2],u[r>>1]=s;break r}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}}}b=P()|0;O()|0;break d}d=Kb(e+96|0);v[23296]=0;f=Q(218,b|0,d|0)|0;g=v[23296];v[23296]=0;D:{E:{F:{G:{H:{if((g|0)!=1){I:{if(f){v[23296]=0;U(11,e+48|0,7,d|0);f=v[23296];v[23296]=0;if((f|0)==1){break I}f=e+48|0;Hb(a+1298320|0,f);zb(f)}yb(d);d=0;J:{while(1){if((d|0)==32){v[23296]=0;d=Q(246,b|0,e+32|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break G}if(!d){break F}d=v[e+32>>2];if(d>>>0<12){break H}f=v[b+8>>2];g=v[b>>2];v[23296]=0;d=W(144,g|0,f|0,d-11|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break G}if(d){break J}break H}f=(d<<5)+a|0;Te(f+480280|0);v[23296]=0;R(219,b|0,f+480289|0);f=v[23296];v[23296]=0;if((f|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}d=v[e+32>>2]-11|0;v[e+80>>2]=d;h=Qb(e+96|0);v[23296]=0;U(222,b|0,h|0,d|0);d=v[23296];v[23296]=0;K:{if((d|0)!=1){v[e+48>>2]=50529027;d=e+48|0;r=e,s=B(v[Ib(e+80|0,d)>>2],85),v[r+72>>2]=s;g=Kb(d);v[e+8>>2]=v[e+36>>2];d=v[Ib(e+72|0,e+8|0)>>2];v[23296]=0;R(45,g|0,d|0);d=v[23296];v[23296]=0;L:{if((d|0)==1){break L}d=0;M:{while(1){f=v[e+80>>2];if(f>>>0<=d>>>0){break M}i=v[h>>2];k=w[Lb(i,d)|0];j=f;f=d+1|0;if(!((k|0)!=255|j-f>>>0<2)){f=t[Lb(i,f)|0];i=w[Lb(i,d+2|0)|0];r=e,s=oh(g),v[r+8>>2]=s;k=v[Gf(e+24|0,e+8|0)>>2];v[23296]=0;X(225,g|0,k|0,i|0,f|0);f=v[23296];v[23296]=0;if((f|0)!=1){d=d+3|0;continue}break L}v[23296]=0;R(46,g|0,k<<24>>24);i=v[23296];v[23296]=0;d=f;if((i|0)!=1){continue}break}break L}v[23296]=0;X(223,e+8|0,5,7,g|0);d=v[23296];v[23296]=0;if((d|0)!=1){N:{f=e+8|0;d=Bc(g,f);yb(f);f=Jc(d);i=Fb(d);v[23296]=0;da(224,a+1298332|0,f|0,i|0,74,0);f=v[23296];v[23296]=0;if((f|0)==1){break N}yb(d);fc(h);break H}}}b=P()|0;O()|0;yb(g);break K}b=P()|0;O()|0}fc(h);break d}}b=P()|0;O()|0;yb(d);break d}d=w[a+484376|0];f=v[a+484360>>2];v[23296]=0;U(226,Zb(f,d)|0,b|0,w[e+285|0]|w[e+286|0]<<8);d=v[23296];v[23296]=0;if((d|0)==1){break G}i=c&1;if(i){v[23296]=0;R(213,a+484344|0,w[e+283|0]|w[e+284|0]<<8);d=v[23296];v[23296]=0;if((d|0)==1){break G}}h=a+484344|0;f=b;d=0;while(1){O:{if((w[e+283|0]|w[e+284|0]<<8)>>>0>d>>>0){b=v[f+8>>2];g=v[f>>2];v[23296]=0;b=W(144,g|0,b|0,4)|0;g=v[23296];v[23296]=0;if((g|0)==1){break D}if(b){break O}}if(!(c&2)){break F}d=0;c=a+480190|0;while(1){b=x[c>>1];if(d>>>0>=b>>>0){d=0;f=a+480190|0;while(1){if(b>>>0<=d>>>0){break F}c=x[dc(v[n>>2],d)>>1];g=c&255;P:{if(!g){break P}h=v[m>>2];g=g-1&65535;if(Nc(h,v[m+4>>2])>>>0<=g>>>0){break P}j=b;b=x[dc(h,g)>>1]+(c>>>8&127)&65535;if(j>>>0<b>>>0){break P}b=B(b,104);g=b+a|0;c=g+484380|0;h=v[c>>2];if(!Ud(h,v[g+484400>>2])){break P}g=b;b=a+484380|0;g=g+b|0;i=x[g+34>>1];b=b+B(d+1|0,104)|0;v[b>>2]=h;u[b+34>>1]=x[b+34>>1]&65534|i&1;if(!Bg(b)){break P}qc(v[b+20>>2],v[g+20>>2],uj(v[c>>2],x[c+34>>1]))}d=d+1|0;b=x[f>>1];continue}}b=x[dc(v[n>>2],d)>>1];if(b&255){d=d+1|0;continue}d=d+1|0;g=B(d,104)+a|0;b=_c(e+96|0,u[g+484414>>1]&1?16:8,1,0,b<<16>>16>=0?0:6);v[23296]=0;W(207,b|0,g+484380|0,f|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){continue}break}b=P()|0;O()|0;break d}v[23296]=0;b=T(145,f|0)|0;g=v[23296];v[23296]=0;Q:{R:{S:{T:{if((g|0)!=1){v[23296]=0;U(178,e+48|0,f|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break T}b=e+48|0;g=jc(e+96|0,b);Ab(b);if(!i){break R}v[23296]=0;b=T(194,g|0)|0;k=v[23296];v[23296]=0;if((k|0)==1){break Q}v[23296]=0;Q(176,g|0,1)|0;k=v[23296];v[23296]=0;if((k|0)==1){break Q}v[23296]=0;b=W(214,h|0,d&65535,b+1|0)|0;k=v[23296];v[23296]=0;if((k|0)==1){break Q}if(!b){break R}v[23296]=0;b=Q(220,g|0,e+48|0)|0;k=v[23296];v[23296]=0;if((k|0)==1){break E}if(!b){break S}b=v[h>>2];v[23296]=0;R(221,$b(b,d)|0,e+48|0);b=v[23296];v[23296]=0;if((b|0)!=1){break S}break E}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=v[h>>2];v[23296]=0;U(227,$b(b,d)|0,1,g|0);b=v[23296];v[23296]=0;if((b|0)==1){break E}}Ab(g);d=d+1|0;continue}break}break E}b=P()|0;O()|0;break d}ud(n);ud(m);break b}b=P()|0;O()|0;Ab(g);break d}b=P()|0;O()|0;break d}i=i+1|0;continue}}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0}ud(n);ud(m)}yb(o);S(b|0);L()}d=1}yb(o)}jb=e+304|0;return d|0}function nia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;e=jb-368|0;jb=e;Ac(b);g=e+344|0;f=ZB(b,g);if(!f){Eu(g)}a:{b:{c:{d:{e:{if(!f){break e}if(!NT(e+344|0)){break e}if(!Ob(v[b>>2],v[b+8>>2],Vc(72,0))){break e}if(!c){d=1;break e}Ed(a,1);v[a+480208>>2]=v[a+480208>>2]&-25231361|16842752;g=w[e+353|0];u[a+480190>>1]=63;u[a+480188>>1]=g;f:{g:{while(1){if((g&65535)>>>0<=d>>>0){h:{Xb(e+272|0,0,64);d=1;i:{while(1){j:{g=d&65535;if(g>>>0>x[a+480190>>1]){dC(b,a+1298308|0);g=e+264|0;d=jb-16|0;jb=d;k:{if(!Ob(v[b>>2],v[b+8>>2],8)){t[d|0]=0;Yh(g,8,d);break k}Km(d+8|0,g);qd(d,b,v[d+8>>2],v[d+12>>2])}jb=d+16|0;n=Qb(e+248|0);g=x[e+354>>1];if(!g){break i}d=0;v[23296]=0;g=W(307,b|0,n|0,B(g,w[e+353|0])<<1)|0;f=v[23296];v[23296]=0;if((f|0)!=1){break j}g=P()|0;O()|0;break a}f=(B(g,104)+a|0)+484380|0;pd(f,1);i=g+(e+272|0)|0;g=Ee(b);t[i|0]=g;if(g<<24>>24>=0){A=f,C=LT(b)<<1,v[A>>2]=C}d=d+1|0;continue}break}if(!g){break f}}d=v[n>>2];ic(e+240|0,d,ad(d,v[n+4>>2])>>>1|0);m=Qb(e+224|0);v[23296]=0;R(308,m|0,x[e+356>>1]<<8);d=v[23296];v[23296]=0;if((d|0)==1){break h}d=0;l:{m:{n:{while(1){g=d&65535;d=x[e+356>>1];if(g>>>0>=d>>>0){break m}v[e+176>>2]=d-g;v[e+120>>2]=2e3;d=e+176|0;f=v[td(d,e+120|0)>>2];d=Qb(d);v[23296]=0;f=W(307,b|0,d|0,f<<8)|0;h=v[23296];v[23296]=0;if((h|0)==1){break l}if(!f){break n}f=hc(e+216|0,Eb(v[m+4>>2]));h=Eb(v[d>>2]);j=Eb(v[e+180>>2]);f=v[f>>2];v[23296]=0;X(309,m|0,f|0,h|0,j|0);f=v[23296];v[23296]=0;if((f|0)!=1){fc(d);d=g+2e3|0;continue}break}break c}fc(d);d=0;break g}ke(e+200|0,v[m>>2],v[m+4>>2]);Og(e+208|0,v[e+200>>2],v[e+204>>2]);p=a+484376|0;d=w[p|0];g=v[a+484360>>2];v[23296]=0;R(310,Zb(g,d)|0,x[e+354>>1]);d=v[23296];v[23296]=0;if((d|0)==1){break d}q=a+484344|0;s=c&1;j=0;while(1){if(x[e+354>>1]<=j>>>0){h=c&2;g=1;o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{while(1){c=g&65535;if(c>>>0>x[a+480190>>1]){break v}v[23296]=0;d=w[c+(e+272|0)|0];U(311,b|0,((c<<5)+a|0)+946304|0,d&63);f=v[23296];v[23296]=0;if((f|0)==1){break t}A:{B:{if(d<<24>>24<0){break B}v[23296]=0;d=T(312,b|0)|0;f=v[23296];v[23296]=0;C:{D:{E:{F:{G:{H:{I:{J:{if((f|0)==1){break J}c=B(c,104)+a|0;f=c+484392|0;v[f>>2]=d<<1;v[23296]=0;d=T(312,b|0)|0;j=v[23296];v[23296]=0;if((j|0)==1){break I}if(d>>>0>=2){v[c+484396>>2]=v[f>>2]+(d<<1);d=c+484414|0;u[d>>1]=x[d>>1]|8}v[23296]=0;d=T(194,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break s}t[e+40|0]=d;t[e+144|0]=64;A=c+484410|0,C=w[Wb(e+40|0,e+144|0)|0]<<2,u[A>>1]=C;v[23296]=0;d=T(194,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break J}t[c+484417|0]=d<<4;c=c+484380|0;kB(c);if(!v[c>>2]){break B}v[23296]=0;f=T(194,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break D}d=0;switch(f|0){case 4:case 5:break C;case 2:case 3:break F;case 1:break G;case 0:break H;default:break g}}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}if(h){f=Qb(e+40|0);j=v[b+8>>2];i=v[b>>2];k=v[c>>2];v[23296]=0;j=W(144,i|0,j|0,k|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break r}if(!j){break w}d=v[c>>2];v[23296]=0;U(313,b|0,f|0,d|0);d=v[23296];v[23296]=0;if((d|0)==1){break r}A=e,C=Eb(v[f>>2]),v[A+144>>2]=C;j=Eb(v[e+44>>2]);while(1){d=v[e+144>>2];if(Rb(d,j)){i=d;d=w[d|0];t[i|0]=d<<7|(d^-1)<<24>>>25;Be(e+144|0);continue}break}ke(e+168|0,v[f>>2],v[e+44>>2]);d=v[$d(e+160|0)>>2];v[23296]=0;d=wg(314,e+176|0,v[e+168>>2],v[e+172>>2],d,v[e+164>>2]);j=v[23296];v[23296]=0;K:{if((j|0)!=1){j=_c(e+144|0,16,1,0,16);v[23296]=0;W(207,j|0,c|0,d|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break K}Ab(d);fc(f);break B}g=P()|0;O()|0;break o}g=P()|0;O()|0;Ab(d);break o}c=v[c>>2];break E}f=Qb(e+40|0);d=v[c>>2];v[23296]=0;U(315,e+144|0,b|0,d|0);d=v[23296];v[23296]=0;L:{M:{N:{if((d|0)!=1){d=e+144|0;j=pm(f,d);fc(d);if(h){ke(e+112|0,v[j>>2],v[e+44>>2]);d=v[$d(e+104|0)>>2];v[23296]=0;d=wg(314,e+120|0,v[e+112>>2],v[e+116>>2],d,v[e+108>>2]);i=v[23296];v[23296]=0;if((i|0)==1){break N}i=_c(e+144|0,8,1,0,2);v[23296]=0;W(207,i|0,c|0,d|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break M}Ab(d)}fc(j);break B}g=V(30320)|0;if((O()|0)!=(ea(30320)|0)){break L}_(g|0)|0;d=0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)!=1){break u}g=P()|0;O()|0;break L}g=P()|0;O()|0;break L}g=P()|0;O()|0;Ab(d)}fc(f);break b}if(h){d=_c(e+40|0,(f|0)==2?8:16,1,0,0);v[23296]=0;W(207,d|0,c|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break B}g=P()|0;O()|0;break b}c=B(v[c>>2],f-1|0)}v[23296]=0;Q(176,b|0,c|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break B}}g=P()|0;O()|0;break b}j=Qb(e+40|0);d=v[c>>2];v[23296]=0;U(316,e+144|0,b|0,d|0);d=v[23296];v[23296]=0;O:{P:{if((d|0)!=1){i=e+144|0;d=pm(j,i);fc(i);if(!h){break O}if((f|0)!=5){break P}A=e,C=Eb(v[d>>2]),v[A+144>>2]=C;k=Eb(v[e+44>>2]);while(1){i=v[e+144>>2];if(!Rb(i,k)){break P}l=i;i=w[i|0];t[l|0]=w[(i>>>7|0)+26209|0]^i;Be(e+144|0);continue}}g=V(30320)|0;if((O()|0)!=(ea(30320)|0)){break x}_(g|0)|0;d=0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)!=1){break A}g=P()|0;O()|0;break x}ke(e+72|0,v[d>>2],v[e+44>>2]);i=v[$d(e- -64|0)>>2];v[23296]=0;i=wg(314,e+80|0,v[e+72>>2],v[e+76>>2],i,v[e+68>>2]);k=v[23296];v[23296]=0;if((k|0)==1){break z}f=(f|0)==5;f=_c(e+144|0,f?16:8,1,0,f?16:1);v[23296]=0;W(207,f|0,c|0,i|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break y}Ab(i)}fc(d)}g=g+1|0;continue}break}fc(j);break g}g=P()|0;O()|0;break x}g=P()|0;O()|0;Ab(i)}fc(j);break b}fc(f);break g}Q:{R:{S:{T:{U:{V:{W:{d=x[e+358>>1]|w[e+360|0]<<16;if(d){c=Qb(e+144|0);v[23296]=0;b=W(307,b|0,c|0,d|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break q}if(!b){break U}ke(e+32|0,v[c>>2],v[c+4>>2]);b=$d(e+24|0);g=v[b+4>>2];b=v[b>>2];v[23296]=0;b=wg(314,e+40|0,v[e+32>>2],v[e+36>>2],b,g);g=v[23296];v[23296]=0;if((g|0)==1){break W}v[23296]=0;X(317,a+1298332|0,b|0,d|0,1);d=v[23296];v[23296]=0;if((d|0)==1){break V}Ab(b);fc(c)}v[23296]=0;Y(318,e+8|0);b=v[23296];v[23296]=0;if((b|0)==1){break T}v[23296]=0;U(201,e+144|0,e+8|0,w[e+352|0]);b=v[23296];v[23296]=0;if((b|0)==1){break S}b=e+144|0;Hb(a+1298344|0,b);zb(b);ec(e+8|0);v[23296]=0;b=Q(1,b|0,9988)|0;c=v[23296];v[23296]=0;if((c|0)==1){break R}Hb(a+1298356|0,b);zb(b);v[23296]=0;b=Q(1,e+8|0,5062)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Q}Hb(a+1298368|0,b);zb(b);v[a+1298404>>2]=10;d=1;break g}g=P()|0;O()|0;break p}g=P()|0;O()|0;Ab(b);break p}fc(c);d=0;break g}g=P()|0;O()|0;break b}g=P()|0;O()|0;ec(e+8|0);break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}fc(f);break g}g=P()|0;O()|0;break b}g=P()|0;O()|0;break b}g=P()|0;O()|0;break o}g=P()|0;O()|0}fc(c);break b}fc(f);break b}A=dc(v[Zb(v[a+484360>>2],w[p|0])>>2],j),C=j,u[A>>1]=C;X:{Y:{if(!s){break Y}v[23296]=0;r=j&65535;d=W(214,q|0,r|0,64)|0;g=v[23296];v[23296]=0;if((g|0)==1){break X}if(!d){break Y}f=x[a+480188>>1];i=0;while(1){d=f&65535;if(d>>>0<=i>>>0){break Y}d=dc(v[e+240>>2],B(d,j)+i|0);d=w[d|0]|w[d+1|0]<<8;Z:{if(d>>>0>=x[e+356>>1]){break Z}g=0;y=0-i|0;z=d<<8;d=$b(v[q>>2],j);d=fd(v[d>>2],v[v[d+48>>2]+12>>2],0,i&65535);while(1){if((g|0)==64){break Z}lq(e+176|0,v[e+208>>2],v[e+212>>2],(g<<2)+z|0,4);f=v[e+176>>2];h=Lb(f,0);o=w[h|0]&63;t[d|0]=o?o+48|0:0;k=Lb(f,1);t[d+1|0]=w[k|0]<<2&60|w[h|0]>>>6;h=w[k|0];l=Lb(f,2);k=w[Lb(f,3)|0];l=w[l|0];f=k<<4|l>>>4;u[e+40>>1]=f;h=l<<2&60|h>>>6;_:{if(!(w[Lb(e+264|0,h>>>3|0)|0]>>>(h&7)&1)|!(f?1:h)){break _}t[d+5|0]=f;t[d+3|0]=h;l=k>>>4|0;t[d+4|0]=l;$:{aa:{ba:{ca:{da:{ea:{fa:{ga:{ha:{ia:{ja:{ka:{switch(h|0){case 0:case 1:case 2:case 32:case 33:case 34:t[d+3|0]=h&15;Of(d);if(!w[d+4|0]){break _}t[d+2|0]=h>>>0<32?3:4;break _;case 9:t[d+3|0]=10;t[d+5|0]=f>>>1;if(f>>>0<512){break _}t[d+2|0]=15;t[d+4|0]=k>>>5;break _;case 10:case 42:if(f>>>0>254){break ja}t[d+3|0]=h&15;break;case 50:break aa;case 48:break ba;case 43:break ca;case 47:break da;case 17:case 18:case 26:case 27:break ea;case 22:case 25:case 28:case 29:case 30:break fa;case 16:case 19:case 20:case 21:case 23:case 31:break ga;case 13:break ha;case 11:case 15:break ia;case 3:case 4:case 5:case 6:case 7:case 12:break ka;default:break $}}Of(d);break _}t[d+3|0]=19;t[d+5|0]=l|(h>>>0<32?16:32);if(k&15){t[d+2|0]=3;t[d+4|0]=(f&240)>>>4;break _}t[d+2|0]=4;t[d+4|0]=f&15;break _}t[d+3|0]=(h|0)==11?12:16;A=d,C=ju(f),t[A+5|0]=C;break _}t[d+3|0]=14;if((f&255)>>>0<64){break _}t[d+5|0]=0;break _}t[d+3|0]=19;t[d+5|0]=f&15|h<<4;break _}t[d+3|0]=19;u[e+120>>1]=15;A=d,C=w[Zc(e+40|0,e+120|0)|0]|h<<4,t[A+5|0]=C;break _}t[d+3|0]=19;if(f&255){t[d+5|0]=f&15|((h|0)==17?16:(h|0)==26?16:32);if(!(k&240)){break _}t[d+2|0]=h>>>0>25?6:5;break _}t[d+5|0]=l|(h>>>0>25?-80:-96);break _}if(!f){break $}t[d+3|0]=17;v[e+120>>2]=8;v[e+80>>2]=f+4;A=d,C=xi(v[Ne(e+120|0,e+80|0)>>2]/8|0),t[A+5|0]=C;break _}t[d+3|0]=14;k=B(y,6)+d|0;o=x[a+480188>>1];f=0;while(1){if((f|0)==(o|0)){break _}h=k+B(f,6)|0;if(!w[h+3|0]){t[h+3|0]=12;A=h,C=ju(r),t[A+5|0]=C}f=f+1|0;continue}}t[d+3|0]=9;h=f&7;if(h){t[d+5|0]=w[h+26201|0];break _}h=f>>>4|0;if((h|0)==128){break $}t[d+5|0]=h;if(!(f&2048)){t[d+5|0]=h^128;break _}t[d+5|0]=h^-1;break _}t[d+5|0]=0;t[d+3|0]=0;if(!o){t[d|0]=255;break _}t[d+3|0]=25;break _}t[d+3|0]=0}g=g+1|0;f=x[a+480188>>1];d=B(f,6)+d|0;continue}}i=i+1|0;continue}}j=j+1|0;continue}break}g=P()|0;O()|0;break b}break c}}else{iB(a,d&65535);u[((d<<5)+a|0)+480284>>1]=(d&3)-1>>>0<2?64:192;d=d+1|0;g=x[a+480188>>1];continue}break}g=P()|0;O()|0;break b}fc(m)}fc(n)}jb=e+368|0;return d|0}g=P()|0;O()|0;break b}g=P()|0;O()|0;fc(d)}fc(m)}fc(n);S(g|0);L()}function d4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=jb-32|0;jb=g;d=Vb(g+16|0,11458);h=Qg(c,d);yb(d);a:{b:{c:{d:{e:{if(h){Mk(a,v[b+24>>2]+1298356|0);break e}d=Vb(g+16|0,10864);h=Qg(c,d);yb(d);if(h){Mk(a,v[b+24>>2]+1298344|0);break e}d=Vb(g+16|0,11288);h=Qg(c,d);yb(d);if(h){Mk(a,v[b+24>>2]+1298392|0);break e}d=Vb(g+16|0,10856);h=Qg(c,d);yb(d);if(h){Mk(a,v[b+24>>2]+1298380|0);break e}d=Vb(g+16|0,8161);h=Qg(c,d);yb(d);if(h){c=g+16|0;d=v[v[b+24>>2]+480184>>2];b=32624;f:{g:{while(1){if((b|0)==32672){break g}if((d|0)!=v[b>>2]){b=b+12|0;continue}break}Rm(c,0,v[b+8>>2]);break f}Kb(c)}v[23296]=0;R(962,a|0,c|0);a=v[23296];v[23296]=0;if((a|0)==1){break d}zb(g+16|0);break e}d=Vb(g+16|0,10841);h=Qg(c,d);yb(d);if(h){f=v[v[b+24>>2]+480184>>2];c=jb+-64|0;jb=c;b=32624;e=hg(c+48|0);j=g+16|0;d=Kb(j);while(1){if((b|0)!=32672){if((f|0)==v[b>>2]){h=v[b+4>>2];v[23296]=0;h=Q(1,c+32|0,h|0)|0;i=v[23296];v[23296]=0;h:{i:{j:{k:{l:{m:{if((i|0)!=1){v[23296]=0;U(798,c+24|0,e|0,h|0);i=v[23296];v[23296]=0;if((i|0)==1){break k}if(!w[c+28|0]){break h}if(!gh(v[d+4>>2],w[d+11|0])){v[23296]=0;i=Q(1,c+8|0,17591)|0;k=v[23296];v[23296]=0;if((k|0)==1){break m}v[23296]=0;Q(87,d|0,i|0)|0;k=v[23296];v[23296]=0;if((k|0)==1){break l}zb(i)}v[23296]=0;Q(87,d|0,h|0)|0;i=v[23296];v[23296]=0;if((i|0)!=1){break h}b=P()|0;O()|0;break j}b=P()|0;O()|0;break i}b=P()|0;O()|0;break j}b=P()|0;O()|0;zb(i);break j}b=P()|0;O()|0}zb(h)}zb(d);SL(e);S(b|0);L()}zb(h)}b=b+12|0;continue}break}SL(e);jb=c- -64|0;v[23296]=0;R(962,a|0,j|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(g+16|0);break e}c=P()|0;O()|0;zb(g+16|0);break a}d=Vb(g+16|0,8227);h=Qg(c,d);yb(d);if(h){Mk(a,v[b+24>>2]+1298368|0);break e}d=Vb(g+16|0,5581);h=Qg(c,d);yb(d);if(h){Mk(a,v[b+24>>2]+1298320|0);break e}d=Vb(g+16|0,11862);h=Qg(c,d);yb(d);if(h){c=g+16|0;Rh(c,v[b+24>>2]+1298308|0);b=v[b+24>>2];v[23296]=0;U(956,a|0,b|0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){yb(g+16|0);break e}c=P()|0;O()|0;yb(g+16|0);break a}d=Vb(g+16|0,11231);h=Qg(c,d);yb(d);if(h){c=v[b+24>>2]+1298408|0;b=v[c+4>>2];n:{if(!uc(v[c>>2],b)){b=b-48|0;if(xd(v[b+12>>2])){break n}}Kb(a);break e}o=g+16|0;j=jb-144|0;jb=j;qc(j+96|0,b,44);e=v[b+44>>2];if(e){qc(j+44|0,b,44);h=jb-16|0;jb=h;b=Nw(v[j+64>>2]+1900|0,v[j+60>>2]+1|0,v[j+56>>2])-Nw(1970,1,1)|0;b=Sia(b,b>>31,86400,0);c=B(v[j+52>>2],3600);b=b+c|0;d=mb+(c>>31)|0;d=b>>>0<c>>>0?d+1|0:d;c=B(v[j+48>>2],60);i=c;b=c+b|0;c=(c>>31)+d|0;c=b>>>0<i>>>0?c+1|0:c;d=v[j+44>>2];i=d;b=d+b|0;d=(d>>31)+c|0;c=tn(h+8|0,b,b>>>0<i>>>0?d+1|0:d);b=v[c>>2];i=v[c+4>>2];jb=h+16|0;h=j+88|0;d=2147483647;m=ge(+(e>>>0)/18.2);c=-1;o:{if(m>=0x8000000000000000){break o}d=-2147483648;c=0;if(m<=-0x8000000000000000){break o}if(D(m)<0x8000000000000000){d=D(m)>=1?~~(m>0?F(H(m*2.3283064365386963e-10),4294967295):I((m-+(~~m>>>0>>>0))*2.3283064365386963e-10))>>>0:0;c=~~m>>>0;break o}c=0}d=d+i|0;c=b+c|0;d=c>>>0<b>>>0?d+1|0:d;b=tn(h,c,d);i=v[b+4>>2];h=v[b>>2];k=jb-16|0;jb=k;v[k+12>>2]=0;v[k+8>>2]=0;v[k+4>>2]=0;b=Nw(1970,1,1)+Tia(h,i,86400,0)|0;f=b>>31;d=Sia(b,f,1e4,0)+14780|0;c=mb;e=d;c=d>>>0<14780?c+1|0:c;l=Tia(d,c,-14609700,-1)+b|0;d=f+mb|0;d=b>>>0>l>>>0?d+1|0:d;n=Tia(e,c,365242500,0);l=n+l|0;d=mb+d|0;d=l>>>0<n>>>0?d+1|0:d;n=Tia(e,c,-146097e4,-1);l=n+l|0;d=mb+d|0;d=l>>>0<n>>>0?d+1|0:d;c=Tia(e,c,3652425,0);e=mb;n=e;p=l;l=Sia(c,e,-365,-1);e=p+l|0;d=mb+d|0;d=e>>>0<l>>>0?d+1|0:d;if(!((d|0)>0|(d|0)>=0)){d=n-!c|0;c=c-1|0;e=Sia(c,d,-365,-1)+b|0;d=f+mb|0;d=b>>>0>e>>>0?d+1|0:d;b=e;e=(c|0)/-4|0;b=b+e|0;d=(e>>31)+d|0;d=b>>>0<e>>>0?d+1|0:d;e=b;b=(c|0)/100|0;f=b;e=e+b|0;b=(b>>31)+d|0;b=e>>>0<f>>>0?b+1|0:b;d=(c|0)/-400|0;f=d;e=d+e|0;d=(d>>31)+b|0;d=e>>>0<f>>>0?d+1|0:d}f=c;b=Sia(e,d,100,0)+52|0;c=mb;b=Tia(b,b>>>0<52?c+1|0:c,3060,0);c=b+2|0;d=(c|0)/12|0;v[k+12>>2]=f+d;v[k+8>>2]=(c+B(d,-12)|0)+1;b=Sia(b,mb,306,0)+5|0;d=mb;b=Tia(b,b>>>0<5?d+1|0:d,-10,-1)+e|0;v[k+4>>2]=b+1;v[j+136>>2]=0;v[j+128>>2]=0;v[j+132>>2]=0;v[j+120>>2]=0;v[j+124>>2]=0;v[j+116>>2]=v[k+12>>2]-1900;v[j+112>>2]=v[k+8>>2]-1;b=v[k+4>>2];q=j,r=Uia(Tia(h,i,3600,0),mb,24),v[q+104>>2]=r;v[j+108>>2]=b;b=Tia(h,i,60,0);c=mb;q=j,r=Uia(b,c,60),v[q+100>>2]=r;b=Sia(b,c,-60,0)+h|0;v[j+96>>2]=b;jb=k+16|0}c=qc(j,j+96|0,44);b=jb-176|0;jb=b;h=Kb(b+160|0);v[23296]=0;d=Q(1,b+144|0,13324)|0;e=v[23296];v[23296]=0;p:{q:{r:{s:{t:{if((e|0)!=1){e=v[c+20>>2];if(!e){break q}v[23296]=0;v[b+112>>2]=e+1900;R(86,b+128|0,b+112|0);e=v[23296];v[23296]=0;if((e|0)!=1){v[23296]=0;i=Q(87,h|0,b+128|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break t}zb(b+128|0);f=v[c+16>>2];if(f>>>0>11){break q}v[23296]=0;e=Q(1,b+112|0,16618)|0;j=v[23296];v[23296]=0;u:{v:{w:{x:{y:{z:{if((j|0)!=1){v[23296]=0;v[b+80>>2]=f+1;R(88,b+96|0,b+80|0);f=v[23296];v[23296]=0;if((f|0)==1){break z}v[23296]=0;U(2,b+128|0,e|0,b+96|0);f=v[23296];v[23296]=0;if((f|0)==1){break y}v[23296]=0;i=Q(87,i|0,b+128|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break x}zb(b+128|0);zb(b+96|0);zb(e);if(v[c+12>>2]-32>>>0>=4294967265){break u}break q}a=P()|0;O()|0;break s}a=P()|0;O()|0;break v}a=P()|0;O()|0;break w}a=P()|0;O()|0;zb(b+128|0)}zb(b+96|0)}zb(e);break s}v[23296]=0;e=Q(1,b+96|0,16618)|0;f=v[23296];v[23296]=0;A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((f|0)!=1){v[23296]=0;R(88,b+80|0,c+12|0);f=v[23296];v[23296]=0;if((f|0)==1){break Z}v[23296]=0;U(2,b+128|0,e|0,b+80|0);f=v[23296];v[23296]=0;if((f|0)==1){break Y}v[23296]=0;i=Q(87,i|0,b+128|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break X}zb(b+128|0);zb(b+80|0);zb(e);j=v[c>>2];e=v[c+8>>2];f=v[c+4>>2];if(!(j|(e|f))|e>>>0>23|f>>>0>59){break q}v[23296]=0;e=Q(1,b+128|0,13484)|0;f=v[23296];v[23296]=0;if((f|0)==1){break U}v[23296]=0;i=Q(87,i|0,e|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break T}zb(e);if(v[c+32>>2]>0){v[23296]=0;e=Q(1,b+80|0,15408)|0;f=v[23296];v[23296]=0;if((f|0)==1){break S}Hb(d,e);zb(e)}v[23296]=0;R(88,b+32|0,c+8|0);e=v[23296];v[23296]=0;if((e|0)==1){break R}v[23296]=0;e=Q(1,b+16|0,14489)|0;f=v[23296];v[23296]=0;if((f|0)==1){break Q}v[23296]=0;U(2,b+48|0,b+32|0,e|0);f=v[23296];v[23296]=0;if((f|0)==1){break P}v[23296]=0;R(88,b|0,c+4|0);f=v[23296];v[23296]=0;if((f|0)==1){break O}v[23296]=0;U(2,b- -64|0,b+48|0,b|0);f=v[23296];v[23296]=0;if((f|0)==1){break N}v[23296]=0;i=Q(87,i|0,b- -64|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break M}zb(b- -64|0);zb(b);zb(b+48|0);zb(e);zb(b+32|0);if(j>>>0<62){break H}v[23296]=0;U(89,o|0,i|0,d|0);e=v[23296];v[23296]=0;if((e|0)==1){break G}break p}a=P()|0;O()|0;break s}a=P()|0;O()|0;break V}a=P()|0;O()|0;break W}a=P()|0;O()|0;zb(b+128|0)}zb(b+80|0)}zb(e);break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;zb(e);break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;break I}a=P()|0;O()|0;break J}a=P()|0;O()|0;break K}a=P()|0;O()|0;break L}a=P()|0;O()|0;zb(b- -64|0)}zb(b)}zb(b+48|0)}zb(e)}zb(b+32|0);break s}v[23296]=0;e=Q(1,b+48|0,14489)|0;f=v[23296];v[23296]=0;if((f|0)==1){break F}v[23296]=0;R(88,b+32|0,c|0);f=v[23296];v[23296]=0;if((f|0)==1){break E}v[23296]=0;U(2,b- -64|0,e|0,b+32|0);f=v[23296];v[23296]=0;if((f|0)==1){break D}v[23296]=0;i=Q(87,i|0,b- -64|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break C}zb(b- -64|0);zb(b+32|0);zb(e);v[23296]=0;Q(87,i|0,d|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break q}}a=P()|0;O()|0;break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;break A}a=P()|0;O()|0;break B}a=P()|0;O()|0;zb(b- -64|0)}zb(b+32|0)}zb(e);break s}a=P()|0;O()|0;break s}a=P()|0;O()|0;break r}a=P()|0;O()|0;zb(b+128|0)}zb(d)}zb(h);S(a|0);L()}Sc(o,h)}zb(d);zb(h);jb=b+176|0;jb=c+144|0;v[23296]=0;R(962,a|0,o|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(g+16|0);break e}c=P()|0;O()|0;zb(g+16|0);break a}d=Vb(g+16|0,12063);h=Qg(c,d);yb(d);if(h){c=g+16|0;pP(c,v[b+24>>2]+1298332|0);_:{if(!De(c)){break _}d=v[v[b+24>>2]+480180>>2];$:{aa:{if((d|0)==33554432){break aa}c=1;if((d|0)==32){break $}if((d|0)==16384){break aa}if((d|0)==16777216){break $}}c=2}ba:{switch(c-1|0){case 0:v[23296]=0;R(963,g|0,b|0);c=v[23296];v[23296]=0;if((c|0)!=1){Bc(g+16|0,g);yb(g);break _}break b;case 1:break ba;default:break _}}if(De(g+16|0)){v[23296]=0;R(964,g|0,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}Bc(g+16|0,g);yb(g)}if(!De(g+16|0)){break _}v[23296]=0;R(963,g|0,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}Bc(g+16|0,g);yb(g)}b=v[b+24>>2];v[23296]=0;U(956,a|0,b|0,g+16|0);a=v[23296];v[23296]=0;if((a|0)!=1){yb(g+16|0);break e}break b}d=Vb(g+16|0,5433);h=Qg(c,d);yb(d);if(h){c=g+16|0;pP(c,v[b+24>>2]+1298332|0);b=v[b+24>>2];v[23296]=0;U(956,a|0,b|0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){yb(g+16|0);break e}c=P()|0;O()|0;yb(g+16|0);break a}e=c;c=Vb(g+16|0,7253);d=Qg(e,c);yb(c);if(d){a=Kb(a);q=g,r=Eb(v[b+68>>2]),v[q+16>>2]=r;b=Eb(v[b+72>>2]);c=1;while(1){d=v[g+16>>2];if(!Rb(d,b)){break e}if(!(c&1)){v[23296]=0;Q(889,a|0,21443)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}}v[23296]=0;Q(753,a|0,d|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}$p(g+16|0);c=0;continue}}Vb(a,21473)}jb=g+32|0;return}c=P()|0;O()|0;zb(g+16|0);break a}c=P()|0;O()|0;yb(a);break a}c=P()|0;O()|0;yb(g+16|0)}S(c|0);L()}function CG(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,D=0,E=0,F=0,G=0,H=C(0),I=0;e=jb-144|0;jb=e;d=Xb(e,0,144);v[d+76>>2]=-1;v[d+44>>2]=a;v[d+32>>2]=1065;v[d+84>>2]=a;x=c;a=0;h=jb-304|0;jb=h;a:{b:{c:{d:{if(v[d+4>>2]){break d}Jw(d);if(v[d+4>>2]){break d}break c}g=w[b|0];if(!g){break a}e:{f:{g:{h:{while(1){i:{c=g&255;j:{if(Ak(c)){while(1){g=b;b=b+1|0;if(Ak(w[g+1|0])){continue}break}ci(d,0,0);while(1){b=v[d+4>>2];k:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break k}b=od(d)}if(Ak(b)){continue}break}b=v[d+4>>2];c=v[d+116>>2];if((c|0)>0|(c|0)>=0){b=b-1|0;v[d+4>>2]=b}b=b-v[d+44>>2]|0;c=b>>31;i=b;e=n+v[d+124>>2]|0;b=m+v[d+120>>2]|0;e=b>>>0<m>>>0?e+1|0:e;f=b;b=i+b|0;i=c+e|0;m=b;n=b>>>0<f>>>0?i+1|0:i;break j}l:{m:{n:{if((c|0)==37){c=w[b+1|0];if((c|0)==42){break n}if((c|0)!=37){break m}}ci(d,0,0);o:{if(w[b|0]==37){while(1){c=v[d+4>>2];p:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;g=w[c|0];break p}g=od(d)}if(Ak(g)){continue}break}b=b+1|0;break o}c=v[d+4>>2];if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;g=w[c|0];break o}g=od(d)}if(w[b|0]!=(g|0)){b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}if((g|0)>=0){break a}f=0;if(y){break a}break c}c=v[d+4>>2]-v[d+44>>2]|0;g=c>>31;f=c;c=n+v[d+124>>2]|0;e=m+v[d+120>>2]|0;c=e>>>0<m>>>0?c+1|0:c;i=e;e=f+e|0;f=c+g|0;m=e;n=e>>>0<i>>>0?f+1|0:f;g=b;break j}l=0;b=b+2|0;break l}if(!(!Mj(c)|w[b+2|0]!=36)){e=jb-16|0;v[e+12>>2]=x;c=c-48|0;c=(c>>>0>1?(c<<2)-4|0:0)+x|0;v[e+8>>2]=c+4;l=v[c>>2];b=b+3|0;break l}l=v[x>>2];x=x+4|0;b=b+1|0}c=0;while(1){e=w[b|0];if(Mj(e)){b=b+1|0;c=(B(c,10)+e|0)-48|0;continue}break}r=0;if((e|0)==109){o=0;r=(l|0)!=0;e=w[b+1|0];b=b+1|0;a=0}g=b+1|0;k=3;f=r;q:{r:{switch((e&255)-65|0){case 39:e=b+2|0;b=w[b+1|0]==104;g=b?e:g;k=b?-2:-1;break q;case 43:e=b+2|0;b=w[b+1|0]==108;g=b?e:g;k=b?3:1;break q;case 51:case 57:k=1;break q;case 11:k=2;break q;case 41:break q;case 0:case 2:case 4:case 5:case 6:case 18:case 23:case 26:case 32:case 34:case 35:case 36:case 37:case 38:case 40:case 45:case 46:case 47:case 50:case 52:case 55:break r;default:break e}}k=0;g=b}b=w[g|0];e=(b&47)==3;D=e?1:k;p=e?b|32:b;s:{if((p|0)==91){break s}t:{if((p|0)!=110){if((p|0)!=99){break t}c=(c|0)>1?c:1;break s}DG(l,D,m,n);break j}ci(d,0,0);while(1){b=v[d+4>>2];u:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;b=w[b|0];break u}b=od(d)}if(Ak(b)){continue}break}b=v[d+4>>2];e=v[d+116>>2];if((e|0)>0|(e|0)>=0){b=b-1|0;v[d+4>>2]=b}b=b-v[d+44>>2]|0;f=b>>31;j=b;e=n+v[d+124>>2]|0;b=m+v[d+120>>2]|0;e=b>>>0<m>>>0?e+1|0:e;i=b;b=j+b|0;n=e+f|0;n=b>>>0<i>>>0?n+1|0:n;m=b}j=c;s=c>>31;ci(d,c,s);b=v[d+4>>2];v:{if((b|0)!=v[d+104>>2]){v[d+4>>2]=b+1;break v}if((od(d)|0)<0){break f}}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}b=16;w:{x:{y:{z:{A:{switch(p-88|0){default:b=p-65|0;if(b>>>0>6|!(1<<b&113)){break w}case 9:case 13:case 14:case 15:FG(h+8|0,d,D,0);b=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]!=(0-b|0)|v[d+124>>2]!=(0-((b>>31)+((b|0)!=0)|0)|0)){break y}break g;case 3:case 11:case 27:if((p|16)==115){Xb(h+32|0,-1,257);t[h+32|0]=0;if((p|0)!=115){break x}t[h+65|0]=0;t[h+46|0]=0;u[h+42>>1]=0;u[h+44>>1]=0;break x}e=w[g+1|0];f=(e|0)==94;Xb(h+32|0,f,257);t[h+32|0]=0;b=f?g+2|0:g+1|0;B:{C:{D:{g=w[(f?2:1)+g|0];if((g|0)!=45){if((g|0)==93){break D}k=(e|0)!=94;break B}k=(e|0)!=94;t[h+78|0]=k;break C}k=(e|0)!=94;t[h+126|0]=k}b=b+1|0}g=b;while(1){e=w[g|0];E:{if((e|0)!=45){if(!e){break f}if((e|0)==93){break x}break E}e=45;f=w[g+1|0];if(!f|(f|0)==93){break E}i=g+1|0;b=w[g-1|0];F:{if(f>>>0<=b>>>0){e=f;break F}while(1){b=b+1|0;t[b+(h+32|0)|0]=k;e=w[i|0];if(e>>>0>b>>>0){continue}break}}g=i}t[(e+h|0)+33|0]=k;g=g+1|0;continue};case 23:b=8;break z;case 12:case 29:b=10;break z;case 1:case 2:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 22:case 25:case 26:case 28:case 30:case 31:break w;case 0:case 24:case 32:break z;case 17:break A}}b=0}j=0;i=0;e=0;f=0;s=0;E=jb-16|0;jb=E;G:{if((b|0)==1){v[115772]=28;break G}while(1){c=v[d+4>>2];H:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break H}c=od(d)}if(Ak(c)){continue}break}I:{J:{switch(c-43|0){case 0:case 2:break J;default:break I}}s=(c|0)==45?-1:0;c=v[d+4>>2];if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break I}c=od(d)}K:{L:{M:{N:{if(!((b|0)!=0&(b|0)!=16|(c|0)!=48)){c=v[d+4>>2];O:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break O}c=od(d)}if((c&-33)==88){b=16;c=v[d+4>>2];P:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break P}c=od(d)}if(w[c+78033|0]<16){break M}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}ci(d,0,0);break G}if(b){break N}b=8;break M}b=b?b:10;if(b>>>0>w[c+78033|0]){break N}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}ci(d,0,0);v[115772]=28;break G}if((b|0)!=10){break M}e=c-48|0;if(e>>>0<=9){b=0;while(1){b=B(b,10)+e|0;f=b>>>0<429496729;c=v[d+4>>2];Q:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break Q}c=od(d)}e=c-48|0;if(f&e>>>0<=9){continue}break}j=b}R:{if(e>>>0>9){break R}k=Sia(j,0,10,0);f=mb;b=e;while(1){c=v[d+4>>2];S:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break S}c=od(d)}e=c-48|0;q=e>>>0>9;j=b+k|0;i=j>>>0<b>>>0?f+1|0:f;if((i|0)==429496729&j>>>0>=2576980378|i>>>0>429496729|q){break R}k=Sia(j,i,10,0);f=mb;b=e;if((f|0)==-1&k>>>0<=(b^-1)>>>0|(f|0)!=-1){continue}break}b=10;break L}b=10;if(e>>>0<=9){break L}break K}if(b-1&b){f=w[c+78033|0];if(f>>>0<b>>>0){while(1){e=B(b,e)+f|0;j=e>>>0<119304647;c=v[d+4>>2];T:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break T}c=od(d)}f=w[c+78033|0];if(j&f>>>0<b>>>0){continue}break}j=e}if(b>>>0<=f>>>0){break L}while(1){k=Sia(j,i,b,0);e=mb;f=f&255;if((e|0)==-1&(f^-1)>>>0<k>>>0){break L}c=f+k|0;e=c>>>0<f>>>0?e+1|0:e;j=c;i=e;c=v[d+4>>2];U:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break U}c=od(d)}f=w[c+78033|0];if(b>>>0<=f>>>0){break L}mf(E,b,0,0,0,j,i,0,0);if(!(v[E+8>>2]|v[E+12>>2])){continue}break}break L}k=t[(B(b,23)>>>5&7)+78289|0];e=w[c+78033|0];if(e>>>0<b>>>0){while(1){f=f<<k|e;j=f>>>0<134217728;c=v[d+4>>2];V:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break V}c=od(d)}e=w[c+78033|0];if(j&e>>>0<b>>>0){continue}break}j=f}if(b>>>0<=e>>>0){break L}f=k;q=f&31;if((f&63)>>>0>=32){f=0;q=-1>>>q|0}else{f=-1>>>q|0;q=f|(1<<q)-1<<32-q}if(!f&j>>>0>q>>>0){break L}while(1){c=k&31;F=e&255;if((k&63)>>>0>=32){e=j<<c;c=0}else{e=(1<<c)-1&j>>>32-c|i<<c;c=j<<c}j=F|c;i=e;c=v[d+4>>2];W:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break W}c=od(d)}e=w[c+78033|0];if(b>>>0<=e>>>0){break L}if((f|0)==(i|0)&j>>>0<=q>>>0|f>>>0>i>>>0){continue}break}}if(w[c+78033|0]>=b>>>0){break K}while(1){c=v[d+4>>2];X:{if((c|0)!=v[d+104>>2]){v[d+4>>2]=c+1;c=w[c|0];break X}c=od(d)}if(w[c+78033|0]<b>>>0){continue}break}v[115772]=68;j=-1;i=-1;s=0}b=v[d+116>>2];if((b|0)>0|(b|0)>=0){v[d+4>>2]=v[d+4>>2]-1}b=s;c=b^j;j=c-b|0;e=b>>31;i=(e^i)-((b>>>0>c>>>0)+e|0)|0}jb=E+16|0;b=v[d+4>>2]-v[d+44>>2]|0;if(v[d+120>>2]==(0-b|0)&v[d+124>>2]==(0-((b>>31)+((b|0)!=0)|0)|0)){break g}if(!(!l|(p|0)!=112)){v[l>>2]=j;break w}DG(l,D,j,i);break w}if(!l){break w}b=v[h+16>>2];c=v[h+20>>2];e=v[h+8>>2];f=v[h+12>>2];Y:{switch(D|0){case 0:G=l,H=aF(e,f,b,c),z[G>>2]=H;break w;case 1:G=l,I=uw(e,f,b,c),A[G>>3]=I;break w;case 2:break Y;default:break w}}v[l>>2]=e;v[l+4>>2]=f;v[l+8>>2]=b;v[l+12>>2]=c;break w}i=(p|0)==99;c=i?c+1|0:31;Z:{if((D|0)==1){e=l;if(r){e=Jd(c<<2);if(!e){break h}}v[h+296>>2]=0;v[h+300>>2]=0;b=0;while(1){a=e;_:{while(1){e=v[d+4>>2];$:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break $}e=od(d)}if(!w[(e+h|0)+33|0]){break _}t[h+27|0]=e;e=Jr(h+28|0,h+27|0,1,h+296|0);if((e|0)==-2){continue}o=0;if((e|0)==-1){break f}if(a){v[(b<<2)+a>>2]=v[h+28>>2];b=b+1|0}if(!((b|0)==(c|0)&r)){continue}break}f=1;b=c;c=b<<1|1;e=Yr(a,c<<2);if(e){continue}break e}break}o=0;c=a;if(h+296|0?v[h+296>>2]:0){break f}break Z}if(r){b=0;e=Jd(c);if(!e){break h}while(1){a=e;while(1){e=v[d+4>>2];aa:{if((e|0)!=v[d+104>>2]){v[d+4>>2]=e+1;e=w[e|0];break aa}e=od(d)}if(!w[(e+h|0)+33|0]){c=0;o=a;break Z}t[a+b|0]=e;b=b+1|0;if((c|0)!=(b|0)){continue}break}f=1;b=c;c=b<<1|1;e=Yr(a,c);if(e){continue}break}o=a;a=0;break e}b=0;if(l){while(1){a=v[d+4>>2];ba:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break ba}a=od(d)}if(w[(a+h|0)+33|0]){t[b+l|0]=a;b=b+1|0;continue}else{c=0;a=l;o=a;break Z}}}while(1){a=v[d+4>>2];ca:{if((a|0)!=v[d+104>>2]){v[d+4>>2]=a+1;a=w[a|0];break ca}a=od(d)}if(w[(a+h|0)+33|0]){continue}break}a=0;o=0;c=0}e=v[d+4>>2];f=v[d+116>>2];if((f|0)>0|(f|0)>=0){e=e-1|0;v[d+4>>2]=e}f=e-v[d+44>>2]|0;k=f;e=f+v[d+120>>2]|0;f=v[d+124>>2]+(f>>31)|0;f=e>>>0<k>>>0?f+1|0:f;if(!(f|e)|((e|0)!=(j|0)|(f|0)!=(s|0))&(p|0)==99){break i}if(r){v[l>>2]=a}da:{if(i){break da}if(c){v[(b<<2)+c>>2]=0}if(!o){o=0;break da}t[b+o|0]=0}a=c}b=v[d+4>>2]-v[d+44>>2]|0;e=b>>31;i=b;c=n+v[d+124>>2]|0;b=m+v[d+120>>2]|0;c=b>>>0<m>>>0?c+1|0:c;f=b;b=i+b|0;e=c+e|0;m=b;n=b>>>0<f>>>0?e+1|0:e;y=((l|0)!=0)+y|0}b=g+1|0;g=w[g+1|0];if(g){continue}break a}break}a=c;break g}f=1;o=0;a=0;break e}f=r;break b}f=r}if(y){break b}}y=-1}if(!f){break a}Jb(o);Jb(a)}jb=h+304|0;jb=d+144|0;return y}function Hda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;l=jb-208|0;jb=l;if(!wt(a)){e=l+48|0;qc(e,a,128);f=l+176|0;df(f,e,128,2);e=l+192|0;Gc(e,f);Ec(b+492|0,e);yb(e)}u[c+34>>1]=x[c+34>>1]&65489;i=l+192|0;f=jb-32|0;jb=f;a:{b:{switch(w[a+128|0]-4|0){default:v[f+28>>2]=0;co(i,0,f+28|0);break a;case 0:case 4:break b}}t[f+28|0]=w[a+129|0];t[f+24|0]=100;e=f+24|0;k=w[Wb(f+28|0,e)|0];t[f+24|0]=w[a+130|0];t[f+20|0]=100;e=w[Wb(e,f+20|0)|0];v[f+28>>2]=e;c:{if(w[a+140|0]&16){h=Mb(w[a+150|0]|w[a+151|0]<<8);o=Mb(w[a+152|0]|w[a+153|0]<<8);j=v[c>>2];r=+(j>>>0)/6553600;k=jq(r*+((h|k<<16)>>>0));v[f+24>>2]=j-k;s=f,y=jq(r*+((o|e<<16)>>>0)),v[s+20>>2]=y;s=f,y=v[Ib(f+24|0,f+20|0)>>2],v[s+28>>2]=y;break c}h=v[c>>2];o=v[c+20>>2];if(!Ud(h,o)){break c}j=h>>>7|0;k=B(j,(k<<7>>>0)/100|0);v[f+24>>2]=h-k;v[f+20>>2]=B(j,(e<<7>>>0)/100|0);e=v[Ib(f+24|0,f+20|0)>>2];j=x[c+34>>1];h=B(Gd(j),h);d:{if(j&1){ic(f+8|0,o,h);o=v[f+8>>2];j=Gd(x[c+34>>1]);h=o+(B(j,e+k|0)<<1)|0;n=u[o+(B(k,j)<<1)>>1];j=0-j<<1;while(1){e:{f:{if(e){p=u[h>>1]-n|0;o=p>>31;if((o^p)-o>>>0>=1536){break f}}else{e=0}break e}e=e-1|0;h=h+j|0;continue}break}break d}ic(f,o,h);o=v[f>>2];j=Gd(x[c+34>>1]);n=0-j|0;h=o+B(j,e+k|0)|0;j=t[o+B(k,j)|0];while(1){g:{h:{if(e){p=t[h|0]-j|0;o=p>>31;if((o^p)-o>>>0>=6){break h}}else{e=0}break g}e=e-1|0;h=h+n|0;continue}break}}v[f+28>>2]=e}co(i,k,f+28|0)}jb=f+32|0;o=kc(i);if(!(!v[o>>2]|w[a+128|0]!=4)){u[c+34>>1]=x[c+34>>1]|2;e=v[l+192>>2];v[c+4>>2]=e;v[c+8>>2]=e+v[o>>2]}e=w[a+134|0];if((e-1&255)>>>0<=198){t[l+48|0]=e;t[l+176|0]=100;e=(w[Wb(l+48|0,l+176|0)|0]<<7>>>0)/100|0}else{e=128}t[l+47|0]=e;t[l+48|0]=64;e=l+47|0;f=l+48|0;s=c,y=w[ef(e,f)|0]>>>1|0,u[s+32>>1]=y;t[l+48|0]=64;s=b,y=w[Wb(e,f)|0],v[s+4>>2]=y;v[c+24>>2]=40460;iq(c,+t[a+139|0]/12+ +(0-w[a+143|0]|0)+ +t[a+138|0]/1536);t[b+34|0]=w[a+142|0]&2?2:1;if(w[a+142|0]&2){Dm(b,127,1);Cm(b,0,1)}i:{if(!Ud(v[c>>2],v[c+20>>2])){break i}b=w[a+140|0];if(b&1){b=v[c>>2];e=v[c+20>>2];j:{if(!Ud(b,e)|b>>>0<2){break j}k:{l:{switch(mk(x[c+34>>1])-1|0){case 3:f=0;i=b>>>1|0;while(1){if((f|0)!=(i|0)){oc(e+(f<<2)|0,e+(b+(f^-1)<<2)|0);f=f+1|0;continue}break};break k;case 1:f=0;i=b>>>1|0;while(1){if((f|0)!=(i|0)){fy(e+(f<<1)|0,e+(b+(f^-1)<<1)|0);f=f+1|0;continue}break};break k;case 0:break l;default:break j}}f=0;i=b>>>1|0;while(1){if((f|0)!=(i|0)){ah(e+f|0,e+(b+(f^-1)|0)|0);f=f+1|0;continue}break}}mj(c,d)}b=w[a+140|0]}if(b&4){m:{e=v[c>>2];b=v[c+20>>2];if(!Ud(e,b)){break m}f=x[c+34>>1];e=B(Gd(f),e);n:{o:{switch(Hm(f)-1|0){case 1:f=0;while(1){if((e|0)!=(f|0)){i=b+(f<<1)|0;u[i>>1]=x[i>>1]^-1;f=f+1|0;continue}break};break n;case 0:break o;default:break m}}f=0;while(1){if((e|0)!=(f|0)){i=b+f|0;t[i|0]=w[i|0]^-1;f=f+1|0;continue}break}}mj(c,d)}}g=w[a+170|0]!=2|w[a+171|0]>100?g:w[a+172|0]<101;b=x[c+34>>1];if(!(!(w[a+141|0]?1:g|w[a+160|0]!=0)|b&1)){e=vt(v[c>>2],Gd(b)<<1&254);if(!e){break i}b=e;i=v[c>>2];h=x[c+34>>1];k=B(Gd(h),i);f=v[c+20>>2];h=uj(i,h);i=jb-16|0;jb=i;v[i+12>>2]=k;yc(i+12|0,h);h=v[i+12>>2];while(1){if(h){u[b>>1]=t[f|0]<<8;f=f+1|0;b=b+2|0;h=h-1|0;continue}break}jb=i+16|0;u[c+34>>1]=x[c+34>>1]|1;SP(c,e,v[c>>2],d)}p:{if(t[a+141|0]>=0){break p}ic(l+48|0,v[c+20>>2],B(v[c>>2],Gd(x[c+34>>1])));f=v[l+52>>2];e=v[l+48>>2];q:while(1){if((0-t[a+141|0]|0)<=(m|0)){break p}k=u[e>>1];i=dc(e,f);b=e;while(1)if((b|0)==(i|0)){m=m+1|0;continue q}else{k=id(u[b>>1]-id(k,1)|0,1);u[b>>1]=k;b=b+2|0;continue}}}r:{if(!g){break r}ic(l+48|0,v[c+20>>2],B(v[c>>2],Gd(x[c+34>>1])));g=v[l+52>>2];b=(g|0)/2|0;m=b>>31;n=b;b=w[a+172|0];i=w[a+171|0];e=i;f=0-(b>>>0<e>>>0)|0;b=b-e|0;h=b<<24;e=n+h|0;b=(f<<24|b>>>8)+m|0;b=Ic(Tia(e,e>>>0<h>>>0?b+1|0:b,g,g>>31),mb);f=b;k=f>>31;b=i<<24;m=b;e=b>>31;b=v[l+48>>2];i=dc(b,g);while(1){if((b|0)==(i|0)){break r}g=u[b>>1];g=Sia(m,e,g,g>>31)+838860800|0;h=mb;s=b,y=Ic(Tia(g,g>>>0<838860800?h+1|0:h,1677721600,0),mb),u[s>>1]=y;b=b+2|0;e=e+k|0;g=f+m|0;e=g>>>0<f>>>0?e+1|0:e;m=g;continue}}s:{if(!w[a+160|0]){break s}ic(l+176|0,v[c+20>>2],B(v[c>>2],Gd(x[c+34>>1])));b=w[a+163|0];m=w[a+162|0];k=0;e=v[l+180>>2];f=0;h=0;if(w[a+161|0]>=2){g=(e|0)/2|0;f=g>>31;i=f;f=w[a+164|0];h=0-(m>>>0>f>>>0)|0;f=f-m|0;n=f<<23;j=n+g|0;f=(h<<23|f>>>9)+i|0;f=j>>>0<n>>>0?f+1|0:f;n=e>>31;f=Ic(Tia(j,f,e,n),mb);h=w[a+165|0];p=0-(b>>>0>h>>>0)|0;j=h-b|0;h=p<<23|j>>>9;j=g+(j<<23)|0;i=h+i|0;h=Ic(Tia(j,g>>>0>j>>>0?i+1|0:i,e,n),mb)}g=b<<23;m=m<<23;i=(l+48|0)+((w[a+160|0]&2)<<2)|0;b=v[l+176>>2];j=dc(b,e);e=0;while(1){if((b|0)==(j|0)){break s}n=(u[b>>1]>>1)-e|0;v[l+56>>2]=n;p=n;n=(m|0)/8388608|0;k=id(B(p,n),8)+k|0;v[l+52>>2]=k;e=id(B(k,n),6)+e|0;e=id(id(B(e,(g|0)/8388608|0),6)+e|0,2);v[l+48>>2]=e;s=b,y=Xc(v[i>>2]),u[s>>1]=y;b=b+2|0;g=h+g|0;m=f+m|0;continue}}t:{if(t[a+141|0]<=0){break t}ic(l+48|0,v[c+20>>2],B(v[c>>2],Gd(x[c+34>>1])));m=0;f=v[l+52>>2];e=v[l+48>>2];u:while(1){if(t[a+141|0]<=(m|0)){break t}k=u[e>>1];g=dc(e,f);b=e;while(1)if((b|0)==(g|0)){m=m+1|0;continue u}else{k=((u[b>>1]<<1)+k|0)/3|0;u[b>>1]=k;b=b+2|0;continue}}}b=v[c+20>>2];f=x[c+34>>1];e=B(v[c>>2],Gd(f));v:{if(f&1){ic(l+32|0,b,e);h=jb-16|0;jb=h;b=v[l+32>>2];k=dc(b,v[l+36>>2]);j=jb-16|0;jb=j;v[j+12>>2]=b;q=h+8|0;f=co(q,b,j+12|0);w:{if((b|0)==(k|0)){break w}e=b+2|0;if((k|0)==(e|0)){break w}s=(Yj(x[e>>1],x[v[f>>2]>>1])?0:4)+f|0,y=e,v[s>>2]=y;m=f+4|0;while(1){i=e;g=e+2|0;if((k|0)!=(g|0)){e=i+4|0;if((k|0)==(e|0)){v[j+12>>2]=k;e=x[i+2>>1];if(!Yj(e,x[v[f>>2]>>1])){f=m;if(Yj(e,x[v[f>>2]>>1])){break w}}v[f>>2]=g;break w}n=x[v[f>>2]>>1];p=x[e>>1];i=x[i+2>>1];x:{if(Yj(p,i)){if(Yj(p,n)){v[f>>2]=e}if(Yj(i,x[v[m>>2]>>1])){continue}break x}if(Yj(i,n)){v[f>>2]=g}g=e;if(Yj(p,x[v[m>>2]>>1])){continue}}v[m>>2]=g;continue}break}v[j+12>>2]=i}jb=j+16|0;v[h+4>>2]=0-u[v[h+8>>2]>>1];s=h,y=u[v[kc(q)>>2]>>1],v[s>>2]=y;y:{e=v[Ne(h+4|0,h)>>2];if((e|0)>32766|!e){break y}while(1){if((b|0)==(k|0)){break y}u[b>>1]=(B(u[b>>1],32767)|0)/(e|0);b=b+2|0;continue}}break v}ic(l+24|0,b,e);h=jb-16|0;jb=h;b=v[l+24>>2];k=Lb(b,v[l+28>>2]);j=jb-16|0;jb=j;v[j+12>>2]=b;q=h+8|0;f=co(q,b,j+12|0);z:{if((b|0)==(k|0)){break z}e=b+1|0;if((k|0)==(e|0)){break z}s=(Zk(w[e|0],w[v[f>>2]])?0:4)+f|0,y=e,v[s>>2]=y;m=f+4|0;while(1){i=e;g=e+1|0;if((k|0)!=(g|0)){e=i+2|0;if((k|0)==(e|0)){v[j+12>>2]=k;e=w[i+1|0];if(!Zk(e,w[v[f>>2]])){f=m;if(Zk(e,w[v[f>>2]])){break z}}v[f>>2]=g;break z}n=w[v[f>>2]];p=w[e|0];i=w[i+1|0];A:{if(Zk(p,i)){if(Zk(p,n)){v[f>>2]=e}if(Zk(i,w[v[m>>2]])){continue}break A}if(Zk(i,n)){v[f>>2]=g}g=e;if(Zk(p,w[v[m>>2]])){continue}}v[m>>2]=g;continue}break}v[j+12>>2]=i}jb=j+16|0;v[h+4>>2]=0-t[v[h+8>>2]];s=h,y=t[v[kc(q)>>2]],v[s>>2]=y;B:{e=v[Ne(h+4|0,h)>>2];if((e|0)>126|!e){break B}while(1){if((b|0)==(k|0)){break B}t[b|0]=(B(t[b|0],127)|0)/(e|0);b=b+1|0;continue}}}jb=h+16|0;C:{if((w[a+134|0]-101&255)>>>0>98){break C}f=x[c+34>>1];e=B(v[c>>2],Gd(f));b=v[c+20>>2];if(f&1){g=l+16|0;v[g>>2]=b;v[g+4>>2]=(b+(e<<1)|0)-b>>1;b=(3276800-(w[a+134|0]<<14)|0)/100|0;m=0-b|0;f=32768-b|0;e=v[g>>2];i=dc(e,v[g+4>>2]);while(1){if((e|0)!=(i|0)){g=u[e>>1];D:{if((g|0)>(b|0)){n=f+((B(b,g-b|0)|0)/(f|0)|0)|0;break D}n=((B(b,b+g|0)|0)/(f|0)|0)-f|0;if((g|0)<(m|0)){break D}n=(B(f,g)|0)/(b|0)|0}s=e,y=Xc(n),u[s>>1]=y;e=e+2|0;continue}break}break C}g=jn(l+8|0,b,b+e|0);e=v[g>>2];b=(3276800-(w[a+134|0]<<14)|0)/100|0;m=0-b|0;f=32768-b|0;i=Lb(e,v[g+4>>2]);while(1){if((e|0)!=(i|0)){g=t[e|0]<<8;E:{if((g|0)>(b|0)){n=f+((B(b,g-b|0)|0)/(f|0)|0)|0;break E}n=((B(b,b+g|0)|0)/(f|0)|0)-f|0;if((g|0)<(m|0)){break E}n=(B(f,g)|0)/(b|0)|0}s=e,y=RR((n|0)/256|0),t[s|0]=y;e=e+1|0;continue}break}}RP(c);if(w[a+128|0]!=8){break i}b=w[a+131|0];if(!b){break i}e=v[o>>2];if(!e){break i}s=Db(c+68|0,0),y=v[l+192>>2]+B(e,b+1|0)|0,v[s>>2]=y;b=v[l+192>>2];v[c+12>>2]=b;v[c+16>>2]=b+v[o>>2];m=v[o>>2];g=w[a+131|0];if(m>>>0>268435456/(g>>>0)>>>0){break i}f=v[c>>2];e=B(g,m);if(f>>>0>268435456-e>>>0){break i}f=e+f|0;e=mk(x[c+34>>1]);h=vt(f,e);if(!h){break i}i=b+B(m,g+1|0)|0;v[c>>2]=f;b=h;h=v[c+20>>2];g=v[l+192>>2];m=qc(b,h,B(e,g+v[o>>2]|0));k=h+B(e,g)|0;a=w[a+131|0];b=0;while(1){if((a|0)==(b|0)){qc(m+B(e,i)|0,h+B(e,g+v[o>>2]|0)|0,B(e,f-i|0));SP(c,m,f,d)}else{b=b+1|0;j=v[o>>2];qc(m+B(e,g+B(b,j)|0)|0,k,B(e,j));continue}break}}jb=l+208|0}function o9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-784|0;jb=d;Ac(b);a:{b:{c:{d:{e:{f:{if(!Zh(b,d+776|0)){break f}if(!KL(v[d+776>>2],v[d+780>>2])){break f}if(!wA(b,d+768|0)){break f}g=v[d+768>>2];if(!JL(g)){break f}f=1313423693;if((g|0)!=1179012417){f=1414090313;if((g|0)!=538987841){break f}}m=ie(d+744|0,b);j=Qb(d+728|0);g:{h:{i:{j:{k:{l:{m:{if(!c){v[23296]=0;X(804,d+136|0,m|0,((g|0)==1179012417?1:2)|0,f|0);b=v[23296];v[23296]=0;if((b|0)!=1){break m}a=P()|0;O()|0;break a}v[23296]=0;U(805,d+136|0,m|0,((g|0)==1179012417?1:2)|0);b=v[23296];v[23296]=0;if((b|0)==1){break l}}b=d+136|0;Ft(j,b);_d(b);v[23296]=0;U(806,d+704|0,j|0,f|0);b=v[23296];v[23296]=0;if((b|0)!=1){v[23296]=0;b=T(166,v[d+704>>2])|0;e=v[23296];v[23296]=0;if((e|0)==1){break k}e=0;if(!b){break g}v[23296]=0;b=Q(807,d+704|0,d+624|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break k}if(!b){break g}b=w[d+689|0];if(!b){break g}v[23296]=0;e=W(144,v[d+704>>2],v[d+712>>2],b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break k}if(!c|e^1){break g}v[23296]=0;R(234,a|0,8388608);b=v[23296];v[23296]=0;if((b|0)==1){break k}v[a+480208>>2]=w[d+688|0]<<4&16^28;u[d+136>>1]=w[d+689|0];u[d+496>>1]=127;p=a,q=x[Zc(d+136|0,d+496|0)>>1],u[p+480188>>1]=q;v[a+480196>>2]=w[d+690|0];v[a+480204>>2]=B(w[d+691|0],1e4);v[a+480200>>2]=w[d+696|0]<<1;v[23296]=0;R(124,a+1298344|0,((g|0)==1179012417?16789:16755)|0);b=v[23296];v[23296]=0;if((b|0)==1){break k}v[23296]=0;b=Q(1,d+608|0,13108)|0;e=v[23296];v[23296]=0;if((e|0)==1){break i}Hb(a+1298356|0,b);zb(b);v[a+1298404>>2]=5;b=d+496|0;Zz(b,2,d+624|0);v[23296]=0;R(210,d+136|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break j}k=(g|0)!=1179012417;b=d+136|0;Bc(a+1298308|0,b);yb(b);l=(g|0)==1179012417;b=0;while(1){n:{o:{p:{if(x[a+480188>>1]<=b>>>0){b=Eb(v[j>>2]);f=Eb(v[j+4>>2]);e=jb-16|0;jb=e;v[e+8>>2]=b;while(1){q:{if(!Rb(b,f)){break q}if(aU(1380209231,v[b>>2],v[b+4>>2])){break q}b=v[rm(e+8|0)>>2];continue}break}jb=e+16|0;if(Rb(b,Eb(v[j+4>>2]))){break p}break h}f=(b<<5)+a|0;h=f+480280|0;Te(h);v[23296]=0;e=T(194,d+704|0)|0;n=v[23296];v[23296]=0;r:{s:{if((n|0)!=1){if(l){break r}if(e>>>0<129){break s}break o}a=P()|0;O()|0;break b}u[f+480284>>1]=e<<1;break n}if(e<<24>>24<0){break o}v[d+136>>2]=e<<2;v[d+496>>2]=256;p=f+480284|0,q=v[td(d+136|0,d+496|0)>>2],u[p>>1]=q;break n}v[23296]=0;U(806,d+136|0,j|0,1380209231);b=v[23296];v[23296]=0;t:{if((b|0)!=1){v[23296]=0;b=T(194,d+136|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break t}e=w[a+484376|0];f=v[a+484360>>2];v[23296]=0;da(326,Zb(f,e)|0,d+136|0,b+1&255,255,254);b=v[23296];v[23296]=0;if((b|0)==1){break t}Ab(d+136|0);break h}a=P()|0;O()|0;break b}a=P()|0;O()|0;Ab(d+136|0);break b}v[h>>2]=1024}b=b+1|0;continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}u:{if(!(c&1)){break u}u[d+56>>1]=0;v[23296]=0;U(808,d+560|0,j|0,1414807888);b=v[23296];v[23296]=0;if((b|0)==1){break c}b=v[d+564>>2];e=v[d+560>>2];v[23296]=0;f=a+484344|0;R(213,f|0,Df(e,b)&65535);b=v[23296];v[23296]=0;v:{if((b|0)!=1){p=d,q=Eb(v[d+560>>2]),v[p+88>>2]=q;l=Eb(v[d+564>>2]);w:{x:{y:{z:{A:{while(1){b=v[d+88>>2];if(!Rb(b,l)){k=a+484348|0;b=0;break w}b=ie(d+136|0,b);v[23296]=0;e=T(194,b|0)|0;h=v[23296];v[23296]=0;if((h|0)!=1){v[23296]=0;u[d+480>>1]=e;e=T(145,b|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break A}v[23296]=0;U(178,d+496|0,b|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break z}e=jc(d+584|0,d+496|0);v[23296]=0;h=v[e+12>>2];v[d+8>>2]=v[e+8>>2];v[d+12>>2]=h;v[d+16>>2]=v[e+16>>2];h=v[e+4>>2];v[d>>2]=v[e>>2];v[d+4>>2]=h;X(809,d|0,x[d+480>>1],k|0,a|0);e=v[23296];v[23296]=0;if((e|0)==1){break y}Ab(d+496|0);p=d,q=x[We(d+56|0,d+480|0)>>1],u[p+56>>1]=q;Ab(b);vh(d+88|0);continue}break}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;break x}a=P()|0;O()|0;Ab(d+496|0)}Ab(b);break v}while(1){e=b&65535;if(e>>>0>=x[d+56>>1]){ld(d+560|0);break u}B:{if(!oe(v[a+484344>>2],v[k>>2],e)){v[23296]=0;W(214,f|0,e|0,64)|0;e=v[23296];v[23296]=0;if((e|0)==1){break B}}b=b+1|0;continue}break}a=P()|0;O()|0;break v}a=P()|0;O()|0}ld(d+560|0);break b}C:{if((g|0)==1179012417){v[23296]=0;U(808,d+88|0,j|0,1414745673);b=v[23296];v[23296]=0;if((b|0)==1){break d}p=d,q=Eb(v[d+88>>2]),v[p+120>>2]=q;f=c&2;k=d+504|0;l=Eb(v[d+92>>2]);g=a+480190|0;while(1){b=v[d+120>>2];if(!Rb(b,l)){ld(d+88|0);break C}c=ie(d+560|0,b);v[23296]=0;b=Q(810,c|0,d+136|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){D:{if(!b){break D}b=w[d+137|0];if((b|0)==255){break D}v[23296]=0;e=W(239,a|0,b+1|0,0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break e}if(!e){break D}h=x[g>>1];b=0;v[23296]=0;U(811,d+136|0,e|0,h|0);e=v[23296];v[23296]=0;if((e|0)==1){break e}while(1){if(w[d+166|0]<=b>>>0){break D}E:{if(!Sh(x[g>>1])){break E}v[23296]=0;e=Q(812,c|0,d+496|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break e}if(!e){break E}e=x[g>>1]+1|0;u[g>>1]=e;if(v[d+496>>2]!=1347240275){break E}h=d+480|0;el(h,2,k);v[23296]=0;R(210,d+56|0,h|0);h=v[23296];v[23296]=0;F:{if((h|0)!=1){e=e&65535;h=d+56|0;Ec(((e<<5)+a|0)+946304|0,h);yb(h);v[23296]=0;e=(B(e,104)+a|0)+484380|0;U(813,d+496|0,d+136|0,e|0);h=v[23296];v[23296]=0;if((h|0)==1){break e}if(!f){break F}h=d+56|0;IL(h,x[d+534>>1]);v[23296]=0;W(207,h|0,e|0,c|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break E}break e}break e}h=x[e+34>>1];e=v[e>>2];v[23296]=0;Q(176,c|0,uj(e,h)|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break e}}b=b+1|0;continue}}Ab(c);vh(d+120|0);continue}break}break e}v[23296]=0;U(808,d+480|0,j|0,1179011410);b=v[23296];v[23296]=0;if((b|0)!=1){p=d,q=Eb(v[d+480>>2]),v[p+472>>2]=q;k=c&2;l=d+496|4;h=Eb(v[d+484>>2]);e=a+480190|0;G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{while(1){b=v[d+472>>2];if(!Rb(b,h)){ld(d+480|0);break C}c=ie(d+560|0,b);v[23296]=0;b=T(145,c|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break P}Q:{R:{if((b|0)!=538986817){break R}v[23296]=0;b=Q(814,c|0,d+464|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break O}if(!(b&v[d+464>>2]==1414745673)){break R}v[23296]=0;b=Q(815,c|0,d+136|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break N}if(!b){break R}b=w[d+141|0];if((b|0)==255){break R}v[23296]=0;b=W(239,a|0,b+1|0,0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break M}if(!b){break R}g=x[e>>1];v[23296]=0;U(816,d+136|0,b|0,g|0);b=v[23296];v[23296]=0;if((b|0)==1){break M}v[23296]=0;U(805,d+496|0,c|0,2);b=v[23296];v[23296]=0;if((b|0)==1){break Q}v[23296]=0;U(808,d+120|0,d+496|0,1179011410);b=v[23296];v[23296]=0;if((b|0)==1){break L}_d(d+496|0);p=d,q=Eb(v[d+120>>2]),v[p+112>>2]=q;n=Eb(v[d+124>>2]);S:{T:{while(1){b=v[d+112>>2];if(!Rb(b,n)){break S}b=ie(d+88|0,b);v[23296]=0;g=T(145,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break K}U:{V:{if((g|0)!=538989377){break V}g=x[e>>1];if(!Sh(g)){break V}f=x[d+460>>1];u[d+460>>1]=f-1;if(!f){Ab(b);break S}i=g+1|0;u[e>>1]=i;v[23296]=0;g=Q(814,b|0,d+80|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break J}if(!(g&v[d+80>>2]==1347240275)){break T}v[23296]=0;U(178,d+496|0,b|0,v[d+84>>2]);g=v[23296];v[23296]=0;W:{if((g|0)!=1){f=d+496|0;g=jc(d+56|0,f);Ab(f);v[23296]=0;f=Q(817,g|0,f|0)|0;o=v[23296];v[23296]=0;if((o|0)==1){break U}if(f){break W}Ab(g);Ab(b);break S}a=P()|0;O()|0;break H}f=d+24|0;Ze(f,2,l);v[23296]=0;R(210,d+40|0,f|0);f=v[23296];v[23296]=0;if((f|0)==1){break I}f=i&65535;i=d+40|0;Ec(((f<<5)+a|0)+946304|0,i);yb(i);v[23296]=0;f=(B(f,104)+a|0)+484380|0;U(818,d+496|0,d+136|0,f|0);i=v[23296];v[23296]=0;if((i|0)==1){break U}X:{if(!k){break X}v[23296]=0;Q(143,g|0,v[d+496>>2]+4|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break U}i=d+40|0;IL(i,x[d+536>>1]);v[23296]=0;W(207,i|0,f|0,g|0)|0;f=v[23296];v[23296]=0;if((f|0)!=1){break X}break I}Ab(g)}Ab(b);vh(d+112|0);continue}break}break I}Ab(b)}ld(d+120|0)}Ab(c);vh(d+472|0);continue}break}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;break G}a=P()|0;O()|0;_d(d+496|0);break G}a=P()|0;O()|0;break H}a=P()|0;O()|0;break H}a=P()|0;O()|0;Ab(g)}Ab(b);ld(d+120|0)}Ab(c);ld(d+480|0);break b}a=P()|0;O()|0;break b}e=1}Ab(d+704|0);_d(j);Ab(m)}jb=d+784|0;return e|0}a=P()|0;O()|0;Ab(c);ld(d+88|0);break b}a=P()|0;O()|0;break b}a=P()|0;O()|0}Ab(d+704|0)}_d(j);Ab(m);S(a|0);L()}function xia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;e=jb+-64|0;jb=e;Ac(a);a:{b:{if(b>>>0<=2){C=e,D=Ee(a),t[C+56|0]=D;ac(a,2);C=e,D=Fg(a),u[C+58>>1]=D;C=e,D=qg(a),v[C+60>>2]=D;break b}pq(a,e+56|0);if(b>>>0>5){break a}}t[e+57|0]=0}c:{n=d+484344|0;s=Xd(x[e+58>>1],1,1024);m=qB(n,s);if((m|0)==65535){break c}b=$b(v[d+484344>>2],m);g=Qf(v[b>>2],v[v[b+48>>2]+12>>2],0);f=x[d+480188>>1];u[e>>1]=f-1;u[e+40>>1]=w[e+56|0];y=x[Zc(e,e+40|0)>>1];h=y+1|0;b=h&65535;f=b>>>0<f>>>0?f:b;while(1)if((b|0)==(f|0)){t[c+13|0]=w[e+57|0]>>>4;b=w[c+12|0];t[e|0]=0;b=(b|0)!=0;p=um(e+40|0,h,e);z=d+480188|0;d:while(1){if((l|0)==(s|0)){fc(p);break c}e:{d=Lb(v[p>>2],0);f=w[d|0];f:{g:{if(!f){v[23296]=0;d=T(194,a|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break e}d=d<<24>>24;if((d|0)<0){v[23296]=0;f=T(194,a|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break e}C=Lb(v[p>>2],0),D=f,t[C|0]=D}t[e|0]=0;h:{i:{d=d&63;if(!d){break i}v[23296]=0;j=T(194,a|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break h}t[e|0]=j;j:{k:{switch(d-1|0){case 0:t[c+12|0]=0;t[e+36|0]=1;C=c,D=w[ef(e+36|0,e)|0],t[C+14|0]=D;t[c+15|0]=0;break j;case 1:if(!j){break i}t[c+15|0]=j;t[c+12|0]=1;b=w[c+13|0];if(!b){break j}t[c+14|0]=B(B(b,j),15);break j;case 2:t[c+13|0]=j>>>4;if(j>>>0>=16){b=w[c+12|0];j=0;v[e+36>>2]=0;v[e+32>>2]=0;o=0;if(!b){break f}break g}j=0;t[c+12|0]=0;v[e+36>>2]=0;v[e+32>>2]=0;o=0;if(!(b&1)){break f}break g;case 3:o=0;v[e+36>>2]=0;v[e+32>>2]=0;if(b&1){break g}break f;case 5:if(!j){break i}d=(w[c+12|0]?15:14)+c|0;b=w[d|0];t[d|0]=b>>>0<256-j>>>0?b+j|0:-1;break j;case 6:break k;default:break i}}if(!j){break i}d=(w[c+12|0]?15:14)+c|0;b=w[d|0];t[d|0]=b>>>0>j+1>>>0?b-j|0:1}j=0;v[e+36>>2]=0;v[e+32>>2]=0;break g}j=0;v[e+36>>2]=0;v[e+32>>2]=0;o=0;if(!(b&1)){break f}break g}break e}t[d|0]=f-1;j=0;v[e+36>>2]=0;v[e+32>>2]=0;o=0;if(!(b&1)){break f}}b=w[c+13|0];d=w[c+12|0];if(d){o=0;if(!b){break f}}l:{if(d){v[e>>2]=1;v[e+28>>2]=B(b,w[c+15|0])<<1;d=v[Ne(e,e+28|0)>>2];break l}d=B(w[c+14|0],30)+30|0}b=255;f=0;while(1){m:{if(!b){b=0;break m}g=B(b,d);f=(g|0)/48|0;if(g-1536>>>0<10752){break m}b=b-1|0;continue}break}v[e+36>>2]=b;v[e+32>>2]=f;he(e+32|0,32,255);o=1;v[e>>2]=1;C=c,D=v[Ne(e,e+36|0)>>2],t[C+16|0]=D}q=l-1|0;r=1;b=$b(v[n>>2],m);b=fd(v[b>>2],v[v[b+48>>2]+12>>2],l,1);while(1){h=r&65535;if(h>>>0>y>>>0){if(o){qe($b(v[n>>2],m),yh(ro(Ke(Fe(e,17,w[e+32|0]),l),0)));qe($b(v[n>>2],m),yh(Ke(Fe(e,16,w[e+36|0]),l)))}if(j&240){qe($b(v[n>>2],m),hU(Ke(Fe(e,20,j>>>4|224),l)))}b=j&15;if(b){qe($b(v[n>>2],m),hU(Ke(Fe(e,20,Xd((B(b,w[c+16|0])>>>0)/15&255,1,15)|96),l)))}l=l+1|0;b=0;continue d}n:{o:{p:{q:{r:{d=Lb(v[p>>2],h);f=w[d|0];if(!f){v[23296]=0;k=T(194,a|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break e}if(k&128){v[23296]=0;d=T(194,a|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break e}C=Lb(v[p>>2],h),D=d,t[C|0]=D}A=1;if(k&64){v[23296]=0;d=T(194,a|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break e}t[b+1|0]=d;A=!d}if(!(k&32)){d=w[b|0];break r}v[23296]=0;d=T(194,a|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break e}t[b|0]=d;if((d-1&255)>>>0<=107){d=qo(d+24|0);t[b|0]=d;C=Dd(v[c>>2],h),D=d,t[C+1|0]=D;d=w[b|0];break o}if((d+127&255)>>>0<=107){d=qo((d&127)+24|0);C=Dd(v[c>>2],h),D=d,t[C|0]=D;t[b|0]=0;break q}if((d|0)!=255){break r}d=254;break p}t[d|0]=f-1;break n}if(d&255){break o}}if(!w[b+1|0]){d=0;break o}d=w[Dd(v[c>>2],h)+1|0];t[b+1|0]=0}t[b|0]=d}if(Uc(d)){C=Dd(v[c>>2],h),D=0,t[C+5|0]=D}t[e+28|0]=0;t[e+27|0]=0;t[e+26|0]=0;t[e+25|0]=0;t[e+24|0]=0;t[e+23|0]=0;s:{if(k&16){t[b+2|0]=1;v[23296]=0;d=T(194,a|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break s}t[b+4|0]=d+2>>>2}f=0;d=0;t:{if(!(k&8)){break t}v[23296]=0;d=T(194,a|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break s}v[23296]=0;g=T(194,a|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break s}t[e+25|0]=g;u:{v:{switch(d-1|0){case 1:t[b|0]=255;break u;case 2:d=Dd(v[c>>2],h);t[b|0]=w[d+1|0];t[d+5|0]=0;break u;case 3:d=nu(g,w[c+16|0]);t[e+25|0]=d;w:{if(d){t[e+28|0]=20;t[e+25|0]=d|208;d=20;break w}t[e+28|0]=0;d=0}if(w[b|0]){break t}g=Dd(v[c>>2],h);t[b|0]=w[g+1|0];t[g+5|0]=0;break t;case 4:t[e|0]=1;C=e,D=nu(g,w[c+16|0]),t[C+22|0]=D;C=e,D=w[ef(e,e+22|0)|0],t[C+25|0]=D;t[e+28|0]=15;C=Dd(v[c>>2],h),D=0,t[C+5|0]=D;d=20;break t;case 5:case 6:case 7:case 8:x:{if(!l){break x}if((d|0)==w[Dd(v[c>>2],h)+4|0]){break x}if(!qe($b(v[n>>2],m),qm(ro(Ke(Fe(e,20,(d+122|160)&255),q),h)))){break x}C=Dd(v[c>>2],h),D=d,t[C+4|0]=D}t[e+28|0]=10;d=Dd(v[c>>2],h);if(!w[b|0]){t[b|0]=w[d+1|0]}t[d+5|0]=0;d=20;break t;case 9:d=20;t[e+28|0]=20;g=Dd(v[c>>2],h);i=w[g+5|0];t[e+25|0]=i?-98:-97;t[g+5|0]=i^1;break t;case 0:break v;default:break u}}t[b|0]=254}d=0;t[e+28|0]=0}y:{if(!(k&4)){break y}v[23296]=0;g=T(194,a|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break s}v[23296]=0;t[e+27|0]=g;g=T(194,a|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break s}t[e+24|0]=g;z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{i=w[e+27|0];switch(i-1|0){case 11:break B;case 10:break C;case 7:case 8:case 9:break D;case 6:break E;case 5:break F;case 3:case 4:break G;case 2:break H;case 1:break I;case 0:break J;default:break A}}pB(e,g<<24>>24<<3,128);g=w[b|0];if(Uc(g)){C=b,D=qo(g+v[e>>2]|0),t[C|0]=D}t[e+27|0]=35;t[e+24|0]=w[e+4|0]^128;break y}f=nu(g,w[c+16|0]);t[e+24|0]=f;if(f){t[e+27|0]=20;t[e+24|0]=f|208;f=1;break y}t[e+27|0]=0;f=1;break y}f=1;break z}f=1;g=gU(g,w[c+16|0],1);t[e+27|0]=(i|0)==4?2:3;t[e+24|0]=g;break y}if(!w[b|0]){C=b,D=w[Dd(v[c>>2],h)|0],t[C|0]=D;g=w[e+24|0]}f=gU(g&255,w[c+16|0],0);t[e+27|0]=4;t[e+24|0]=f;f=1;break y}C=b,D=qo(g+25|0),t[C|0]=D;t[e+24|0]=255;t[e+27|0]=4;f=1;break y}K:{if(!l){break K}if((i|0)==w[Dd(v[c>>2],h)+2|0]){break K}if(!qe($b(v[n>>2],m),qm(ro(Ke(Fe(e,20,(i-8|48)&255),q),h)))){break K}C=Dd(v[c>>2],h),D=w[e+27|0],t[C+2|0]=D}t[e+27|0]=5;C=e,D=oB(w[e+24|0],w[c+16|0]),t[C+24|0]=D;f=1;break y}f=w[c+16|0];t[e+27|0]=18;C=e,D=fU(g,f),t[C+24|0]=D;f=1;break y}f=nu(g,w[c+16|0]);t[e+24|0]=f;if(f){t[e+27|0]=20;t[e+24|0]=f|192;f=1;break y}t[e+27|0]=0;t[b|0]=254;f=1;break y}f=0}t[e+27|0]=f}g=0;L:{if(!(k&2)){break L}v[23296]=0;k=T(194,a|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break s}v[23296]=0;t[e+26|0]=k;k=T(194,a|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break s}t[e+23|0]=k;M:{N:{O:{P:{Q:{R:{S:{i=w[e+26|0];switch(i-1|0){case 9:break N;case 7:case 8:break O;case 6:break P;case 3:case 4:case 5:break Q;case 2:break R;case 0:case 1:break S;default:break M}}g=1;h=eU(k,w[c+16|0],(i|0)==1);t[e+26|0]=11;t[e+23|0]=h;break L}g=w[c+16|0];t[e+26|0]=18;C=e,D=fU(k,g),t[C+23|0]=D;g=1;break L}T:{if(!l){break T}if((i|0)==w[Dd(v[c>>2],h)+3|0]){break T}if(!qe($b(v[n>>2],m),qm(ro(Ke(Fe(e,20,(i-4|64)&255),q),h)))){break T}C=Dd(v[c>>2],h),D=w[e+26|0],t[C+3|0]=D}t[e+26|0]=8;C=e,D=oB(w[e+23|0],w[c+16|0]),t[C+23|0]=D;g=1;break L}t[e+26|0]=9;break L}g=eU(k,w[c+16|0],(i|0)==8);t[e+26|0]=29;t[e+23|0]=g;g=1;break L}t[e+26|0]=27;C=e,D=oB(k,w[c+16|0]),t[C+23|0]=D;g=1;break L}t[e+26|0]=0}if(f){dU(b,l,x[z>>1],w[e+27|0],e+24|0)}if(g){dU(b,l,x[z>>1],w[e+26|0],e+23|0)}U:{if(!A){break U}if(!Uc(w[b|0])){break U}f=w[e+27|0];if(!f){t[e+24|0]=255;t[e+27|0]=4;break U}if(w[e+26|0]|(f|0)==4){break U}t[e+23|0]=255;t[e+26|0]=4}V:{if(w[b+2|0]!=1){break V}W:{if(!w[e+27|0]){t[e+27|0]=13;t[e+24|0]=w[b+4|0];break W}if(w[e+26|0]){break V}t[e+26|0]=13;t[e+23|0]=w[b+4|0]}t[b+2|0]=0}uo(e,e+27|0,e+24|0,e+26|0,e+23|0);X:{if(w[b+2|0]){break X}f=w[e+27|0];if(!f){break X}t[b+2|0]=f;t[b+4|0]=w[e+24|0]}Y:{if(d){uo(e,e+26|0,e+23|0,e+28|0,e+25|0);Z:{if(w[b+2|0]){break Z}d=w[e+26|0];if(!d){break Z}t[b+2|0]=d;t[b+4|0]=w[e+23|0]}f=e+25|0;d=w[e+28|0];break Y}f=e+23|0;d=w[e+26|0];if(!d){break n}}t[b+3|0]=d;t[b+5|0]=w[f|0];break n}break e}b=b+6|0;r=r+1|0;continue}}break}a=P()|0;O()|0;fc(p);S(a|0);L()}else{t[g+B(b,6)|0]=254;b=b+1|0;continue}}jb=e- -64|0;return m|0}function HW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0;e=jb-1456|0;jb=e;Ac(b);No(a);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if(!ir(b,e+1432|0)){break n}if(!QD(e+1432|0)){break n}if(!c){j=1;break n}if(!hr(v[b>>2],x[e+1450>>1]|x[e+1452>>1]<<16)){break n}if(!hr(v[b>>2],(x[e+1450>>1]|x[e+1452>>1]<<16)+(x[e+1444>>1]<<2)|0)){break n}yv(a);z=e,A=xv(),v[z+56>>2]=A;c=e+56|0;wv(Cj(v[a+4>>2])+32|0,c);gr(c);l=v[Cj(v[a+4>>2])+32>>2];v[e+1428>>2]=x[e+1446>>1]|x[e+1448>>1]<<16;z=e,A=Ig(v[b>>2]),v[z+1168>>2]=A;v[e+1128>>2]=214748364;d=e+1168|0;z=e,A=B(v[Ib(d,e+1128|0)>>2],20),v[z+56>>2]=A;gn(l,v[Ib(e+1428|0,c)>>2]);Xb(d,0,256);r=Qb(e+1152|0);o:{while(1){j=x[e+1444>>1]<=s>>>0;if(!j){v[23296]=0;c=Q(143,b|0,(x[e+1450>>1]|x[e+1452>>1]<<16)+(s<<2)|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break m}if(!c){break o}c=v[b+8>>2];d=v[b>>2];v[23296]=0;c=W(144,d|0,c|0,4)|0;d=v[23296];v[23296]=0;if((d|0)==1){break m}if(!c){break o}v[23296]=0;c=T(145,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break l}v[23296]=0;d=Q(143,b|0,c|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break l}if(!d){break o}v[23296]=0;d=Q(146,b|0,e+1128|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break k}if(!d){break o}v[23296]=0;d=W(147,b|0,r|0,x[e+1140>>1])|0;f=v[23296];v[23296]=0;if((f|0)==1){break k}if(!d){break o}f=v[r>>2];g=v[b>>2];v[23296]=0;d=x[e+1140>>1];g=T(148,g|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break j}h=c+20|0;if(g>>>0<=h+(d<<3)>>>0){break o}c=d?f:0;f=x[e+1140>>1];g=h+(f<<3)|0;d=0;h=x[e+1142>>1];p:{if(!(h&1)){while(1){if(d>>>0>=f>>>0){break p}if(!c){break o}f=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23296]=0;f=fa(149,h|0,f|0,l|0,v[e+1428>>2])|0;h=v[23296];v[23296]=0;if((h|0)==1){break i}if(!f){break o}v[23296]=0;f=Q(143,b|0,g|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break i}if(!f){break o}f=gc(e+1120|0,Lb(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24)),w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24));h=v[f+4>>2];f=v[f>>2];v[23296]=0;_m(150,e+56|0,b,f,h);f=v[23296];v[23296]=0;if((f|0)==1){break h}if(v[e+60>>2]!=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))){break o}d=d+1|0;c=c+8|0;f=x[e+1140>>1];continue}}q:{r:{s:{t:{u:{if(h&4){if(!c){break o}d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23296]=0;d=fa(149,f|0,d|0,l|0,v[e+1428>>2])|0;f=v[23296];v[23296]=0;if((f|0)==1){break g}if(!d){break o}m=Lb(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));k=(w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))&-2;if(!k){break o}v[23296]=0;f=x[e+1146>>1];d=Q(143,b|0,g+x[e+1144>>1]|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break f}if(!d){break o}d=v[b+8>>2];g=v[b>>2];v[23296]=0;d=W(144,g|0,d|0,v[e+1132>>2]-x[e+1144>>1]|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break f}if(!d){break o}v[23296]=0;U(151,e+32|0,b|0,v[e+1132>>2]-x[e+1144>>1]|0);d=v[23296];v[23296]=0;if((d|0)==1){break b}d=e+32|0;g=fr(e+56|0,d);Ab(d);q=0;n=0;v:{w:{x:{while(1){h=0;y:{while(1){if(x[e+1140>>1]<=(n&65535)>>>0){break x}v[23296]=0;d=Q(152,g|0,f+1|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break y}i=f&15;o=x[(i<<1)+25824>>1];z:{A:{if(o>>>0<=d>>>0){v[23296]=0;i=w[i+25872|0];p=Q(152,g|0,i|0)|0;u=v[23296];v[23296]=0;if((u|0)==1){break y}d=p+(d-o<<i)|0;if((d|0)!=(f|0)){f=d&15;break z}v[23296]=0;d=Q(152,g|0,4)|0;i=v[23296];v[23296]=0;if((i|0)==1){break y}if((d|0)==15){v[23296]=0;i=Q(152,g|0,1)|0;d=v[23296];v[23296]=0;if((d|0)==1){break y}d=65535;if(!i){break A}Ab(g);break p}d=d+65520|0}if(d>>>0>65535){break z}}d=d&1?0-(d+1>>>1|0)|0:d>>>1|0;p=h+m|0;i=x[e+1142>>1];B:{if(i&2){q=d+q|0;d=q;break B}d=i&512?d:d^32768}o=d>>>8|0;i=i&1024;t[p+1|0]=i?d:o;t[p|0]=i?o:d;h=h+2|0}if(h>>>0<k>>>0){continue}break}n=n+1|0;if(n>>>0>=x[e+1140>>1]){break r}d=(n<<3)+c|0;h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);k=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);v[23296]=0;h=fa(149,h|0,k|0,l|0,v[e+1428>>2])|0;k=v[23296];v[23296]=0;if((k|0)==1){break y}if(!h){break t}k=(w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24))&-2;if(!k){break u}m=Lb(v[l>>2],w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));continue}break}j=V(30320)|0;if((O()|0)!=(ea(30320)|0)){break v}_(j|0)|0;v[23296]=0;Z(17);c=v[23296];v[23296]=0;if((c|0)==1){break w}}Ab(g);break p}j=P()|0;O()|0}Ab(g);break a}if(!c){break o}d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23296]=0;d=fa(149,f|0,d|0,l|0,v[e+1428>>2])|0;f=v[23296];v[23296]=0;if((f|0)==1){break e}if(!d){break o}q=Lb(v[l>>2],w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24));if(x[e+1144>>1]>256){break o}m=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=x[e+1146>>1];v[23296]=0;d=Q(143,b|0,g|0)|0;g=v[23296];v[23296]=0;C:{D:{if((g|0)!=1){if(!d){break o}d=gc(e+24|0,e+1168|0,x[e+1144>>1]);g=v[d+4>>2];d=v[d>>2];v[23296]=0;_m(153,e+56|0,b,d,g);d=v[23296];v[23296]=0;if((d|0)==1){break D}d=x[e+1144>>1];if(d>>>0>y[e+60>>2]){break o}g=v[b+8>>2];h=v[b>>2];v[23296]=0;d=W(144,h|0,g|0,v[e+1132>>2]-d|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){break C}}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}if(!d){break o}v[23296]=0;U(151,e+32|0,b|0,v[e+1132>>2]-x[e+1144>>1]|0);d=v[23296];v[23296]=0;if((d|0)==1){break c}d=e+32|0;g=fr(e+56|0,d);Ab(d);k=0;n=0;E:{F:{G:{while(1){h=0;H:{while(1){if(x[e+1140>>1]<=(k&65535)>>>0){break G}v[23296]=0;d=Q(152,g|0,f+1|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break H}i=f&7;o=w[i+25856|0];I:{J:{if(o>>>0<=d>>>0){v[23296]=0;i=w[i+25864|0];p=Q(152,g|0,i|0)|0;u=v[23296];v[23296]=0;if((u|0)==1){break H}d=p+(d-o<<i)|0;if((d|0)!=(f|0)){f=d&7;break I}v[23296]=0;d=Q(152,g|0,3)|0;i=v[23296];v[23296]=0;if((i|0)==1){break H}if((d|0)==7){v[23296]=0;i=Q(152,g|0,1)|0;d=v[23296];v[23296]=0;if((d|0)==1){break H}d=255;if(!i){break J}Ab(g);break p}d=d+248|0}if(d>>>0>255){break I}}d=w[(e+1168|0)+d|0];i=d+n|0;p=d;d=x[e+1142>>1]&2;t[h+q|0]=d?i:p;n=d?i:n;h=h+1|0}if(h>>>0<m>>>0){continue}break}k=k+1|0;if(k>>>0>=x[e+1140>>1]){break q}d=(k<<3)+c|0;h=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);v[23296]=0;h=fa(149,h|0,m|0,l|0,v[e+1428>>2])|0;m=v[23296];v[23296]=0;if((m|0)==1){break H}if(!h){break s}m=w[d+4|0]|w[d+5|0]<<8|(w[d+6|0]<<16|w[d+7|0]<<24);q=Lb(v[l>>2],w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24));continue}break}j=V(30320)|0;if((O()|0)!=(ea(30320)|0)){break E}_(j|0)|0;v[23296]=0;Z(17);c=v[23296];v[23296]=0;if((c|0)==1){break F}}Ab(g);break p}j=P()|0;O()|0}Ab(g);break a}Ab(g);break o}Ab(g);break o}Ab(g);break o}Ab(g);break p}Ab(g)}s=s+1|0;continue}break}ke(e+8|0,v[l>>2],v[l+4>>2]);Og(e+16|0,v[e+8>>2],v[e+12>>2]);b=$d(e);c=v[b+4>>2];b=v[b>>2];v[23296]=0;b=wg(154,e+56|0,v[e+16>>2],v[e+20>>2],b,c);c=v[23296];v[23296]=0;if((c|0)==1){break d}cd(Cj(v[a+4>>2])+12|0,b);Ab(b)}je(r)}jb=e+1456|0;return j|0}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0;break a}j=P()|0;O()|0}je(r);S(j|0);L()}function bt(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;h=jb-32|0;jb=h;v[h+28>>2]=c;a:{if((c|0)<=0){break a}k=v[b+656>>2];if(!(!k|v[a+480180>>2]!=16777216)){m=v[k+44>>2]!=0}i=v[b+104>>2];b:{c:{d:{if(!k){j=c;break d}if((c|0)>128){break c}j=c-1|0;l=x[dc(k+236|0,j)>>1];e:{if((l-1&65535)>>>0<=3998){i=(B(l,104)+a|0)+484380|0;break e}Bb(h+16|0,a+1074312|0,43);if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break e}if(!Sj(v[b+656>>2])){break a}}j=w[Lb(k+108|0,j)|0];v[h+28>>2]=j}if(j>>>0<121){break b}c=j}f:{if(!(v[a+480180>>2]&16777248?(c|0)!=255:0)){Qn(a,b);if(d){break f}Bb(h+16|0,a+1074312|0,100);if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])|!(w[a+480208|0]&4)|!w[b+789|0]){break f}v[b+88>>2]=v[b+88>>2]&-6145;break f}if(!x[a+480192>>1]){break f}v[b+88>>2]=v[b+88>>2]|4096}g:{if((c|0)!=254){break g}d=v[b+88>>2];c=a+480180|0;if(!(!(d&512)|v[c>>2]!=2)){v[b+88>>2]=d|2048;break g}v[b+88>>2]=d|2101248;h:{if(v[c>>2]&16777248){if(!x[a+480192>>1]){break h}Bb(h+16|0,a+1074312|0,50);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break h}}v[b+688>>2]=0}Bb(h+16|0,a+1074312|0,50);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){v[b+8>>2]=0;v[b+12>>2]=0}v[b+696>>2]=0}Bb(h+16|0,a+1074312|0,20);if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break a}t[b+797|0]=0;t[b+802|0]=0;break a}i:{j:{k:{if(m){if(d){l=w[b+797|0];if(l){break k}}v[b+708>>2]=0}if(d){break j}if(!(!(v[a+480180>>2]&1048588)|!i)){u[b+770>>1]=t[i+36|0];u[b+772>>1]=t[i+37|0]}if(i){Bb(h+16|0,a+1074312|0,24);l=0;o=1;if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break i}v[b+704>>2]=v[i+24>>2];break i}i=0;l=0;break i}l=B((v[v[k+44>>2]+36>>2]<<16>>16)+1|0,(j<<16>>16)-(l<<16>>16)|0)-v[b+852>>2]|0;v[b+708>>2]=l;v[b+852>>2]=0-l}o=(i|0)!=0;l=1;if(qi(v[b+8>>2],v[b+12>>2])){break i}l=a+1074312|0;Bb(h+16|0,l,54);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){v[b+700>>2]=0;break a}Bb(h+16|0,l,39);l=(Cb(v[v[h+16>>2]>>2],v[h+20>>2])^-1)&d}l:{if(om(v[a+480180>>2])){v[h+28>>2]=u[b+770>>1]+j;he(h+28|0,12,131);break l}oR(h+28|0)}j=a+1074312|0;Bb(h+16|0,j,34);m:{if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){d=qo(c);break m}d=v[h+28>>2]}t[b+797|0]=d;t[b+851|0]=w[b+851|0]&183|64;if(!(v[a+480180>>2]&16777250?0:l)){t[b+803|0]=0}d=Rg(a,v[h+28>>2],u[b+772>>1],v[b+704>>2]);t[b+831|0]=0;Bb(h+16|0,j,48);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){mN(a,b,k,i)}Bb(h+16|0,j,115);if(!(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])|!k|!w[k+26|0])){if(!x[b+784>>1]){u[b+784>>1]=x[b+692>>1]+1}lN(b+692|0,c,w[k+26|0],w[k+27|0])}n:{if(e^1|l){break n}v[b+776>>2]=0;v[b+780>>2]=0;if(!k){break n}Bb(h+16|0,j,29);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){t[b+798|0]=w[k+16|0]}if(!(w[k+60|0]&8)){hj(b+724|0)}if(!(w[k+80|0]&8)){hj(b+732|0)}if(!(w[k+100|0]&8)){hj(b+740|0)}if(w[k+20|0]){c=_s(Pn(a));n=w[k+20|0];Bb(h+16|0,j,28);n=((B(c,n)<<16>>16)/64<<16)+65536>>16;o:{if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){c=v[b+752>>2];break o}c=(v[b+688>>2]+1|0)/2|0}u[b+776>>1]=(B(c,n)|0)/199}p:{if(!w[k+19|0]){break p}q=b,r=(B(_s(Pn(a)),w[k+19|0])<<16>>16)/32|0,u[q+778>>1]=r;Bb(h+16|0,j,28);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])|x[b+784>>1]){break p}u[b+784>>1]=x[b+692>>1]+1}c=w[k+23|0];if(c){n=_s(Pn(a));p=w[b+837|0];t[b+796|0]=p+1;u[b+780>>1]=(B(p,(B(c,n+1|0)<<16>>16)/128<<16>>16)+1|0)/128}c=w[k+24|0];if(!c){break n}n=_s(Pn(a));p=w[b+838|0];t[b+795|0]=p+1;u[b+782>>1]=(B(p,(B(c,n+1|0)<<16>>16)/128<<16>>16)+1|0)/128}if(!o){break a}c=0;q:{r:{if(!d){break r}if(!(v[b+700>>2]?l:0)){v[b+700>>2]=d}s:{t:{if(!m){if(!l){Bb(h+16|0,j,69);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break t}Bb(h+8|0,j,46);if(Cb(v[v[h+8>>2]>>2],v[h+12>>2])|v[a+480180>>2]==1){break t}}v[b+708>>2]=d;t[b+851|0]=w[b+851|0]&239}if(!l){break t}if(v[b+76>>2]|w[a+480180|0]&2){break s}}v[b+104>>2]=i;d=v[i>>2];v[b+84>>2]=d;v[b+76>>2]=d;v[b+80>>2]=0;v[b>>2]=0;v[b+4>>2]=0;u:{v:{if(!(v[a+480208>>2]&2097152)){Bb(h+16|0,j,96);if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break v}}if(w[b+789|0]){break v}v[h+16>>2]=v[b+76>>2]-1;q=b,r=v[Ib(b+660|0,h+16|0)>>2],v[q+4>>2]=r;break u}v[b+660>>2]=0}m=x[i+34>>1];d=m&1023;o=d|v[b+88>>2]&-525056;v[b+88>>2]=o;w:{x:{if(m&8){v[b+80>>2]=v[i+12>>2];m=v[i+16>>2];v[b+88>>2]=(d&16?o|4:o&-524295)|2;v[b+84>>2]=m;if(y[b+76>>2]>m>>>0){break x}break w}if(!(d&2)){break w}v[b+80>>2]=v[i+4>>2];m=v[i+8>>2];v[b+84>>2]=m;if(y[b+76>>2]<=m>>>0){break w}}v[b+76>>2]=m}Bb(h+16|0,j,83);if(!(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])|v[b+80>>2])){d=v[i>>2];v[b+84>>2]=d;v[b+76>>2]=d}d=v[b+88>>2];y:{if(!(d&128)){break y}i=v[b+76>>2];if(!i){break y}v[b+4>>2]=i-1;v[b+88>>2]=d|128}z:{if(w[b+822|0]>3){break z}Bb(h+16|0,j,21);A:{B:{C:{if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){i=v[a+480180>>2];if(!(i&16777248)){break C}m=16;if(v[a+480208>>2]&4){break B}break A}i=v[a+480180>>2]}m=32;if((i|0)==16){break A}}if(i&67633152){break z}m=0}t[b+819|0]=m}Bb(h+16|0,j,21);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])|w[b+825|0]>3){break s}t[b+820|0]=0}i=v[b>>2];if(y[b+76>>2]<=y[b+4>>2]){d=v[b+80>>2];v[b>>2]=i;v[b+4>>2]=d}if(!l){break r}c=1;if(!(v[a+480180>>2]&17301536)|(v[b+696>>2]?0:w[b+89|0]&16)){break r}d=1;if(!(w[a+480208|0]&8)){break q}d=1;if(!w[b+789|0]){break q}}if(!(v[b+696>>2]|(!(v[a+480180>>2]&17301536)|!(w[b+89|0]&16)))){Vl(b);Bb(h+16|0,j,21);if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){t[b+818|0]=0;v[b+756>>2]=0}v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}D:{if(!c){i=w[b+789|0];break D}i=w[b+789|0];if(!(w[a+480208|0]&8)){break D}d=1;if(!(i&255)){break q}}if(!(i&255?0:v[a+480180>>2]&1048580)){v[b+696>>2]=65536;v[b+88>>2]=v[b+88>>2]&-4097}d=c}Bb(h+16|0,j,40);E:{F:{if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){if(d){if(!(!(w[a+480208|0]&8)|!w[b+789|0])){v[b+88>>2]=v[b+88>>2]&-4196353;i=1;break E}v[b+88>>2]=v[b+88>>2]&-4194305;i=1;break E}c=v[b+88>>2]&-4196353;break F}c=v[b+88>>2]&-4196353;v[b+88>>2]=c;i=1;if(d){break E}}u[b+842>>1]=65535;v[b+88>>2]=c&-6326273|2097152;Bb(h+16|0,j,23);G:{if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break G}Bb(h+8|0,j,22);if(Cb(v[v[h+8>>2]>>2],v[h+12>>2])){break G}Bb(h+16|0,j,52);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break G}Bb(h+8|0,j,71);if(Cb(v[v[h+8>>2]>>2],v[h+12>>2])){break G}t[b+839|0]=0;t[b+808|0]=0}if(e){t[b+818|0]=0;v[b+756>>2]=0}v[b+20>>2]=0;v[b+24>>2]=0;c=v[a+480208>>2]&8192;H:{I:{if(k){i=1;d=w[k+22|0];J:{if(!Uf(d)){i=!(c>>>13|0);break J}q=b,r=Qq(d),t[q+838|0]=r}c=w[k+21|0];if(Uf(c)){q=b,r=Qq(c),t[q+837|0]=r;break I}if(i){break I}c=(i|0)!=0;break H}v[b+776>>2]=0;v[b+780>>2]=0;c=!c;break H}c=1;d=w[k+25|0];if((d|0)==255){break H}t[b+845|0]=d}K:{if(w[b+837|0]>=127){Bb(h+16|0,j,36);if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break K}}if(!c){break K}if((Gp(a,b,1,256)|0)<0|!(w[b+89|0]&2)){break K}c=v[a+1298300>>2];if(!xd(c)|(g|0)==65535){break K}Kp(c,g,w[b+837|0]>>>1|0,1)}i=0;if(!(w[b+89|0]&2)){break E}if(!xd(v[a+1298300>>2])|(g|0)==65535){break E}Bb(h+16|0,j,111);if(Cb(v[v[h+16>>2]>>2],v[h+20>>2])){Uj(v[a+1298300>>2],g);break E}Bb(h+16|0,j,110);if(!Cb(v[v[h+16>>2]>>2],v[h+20>>2])){break E}jz(v[a+1298300>>2],g,0,1,0)}c=v[b+88>>2];if(f){c=c&-1025;v[b+88>>2]=c}L:{M:{if(w[a+24618|0]&16?c&1024:0){break M}a=v[b+104>>2];if(!(f?1:!a|!(w[a+35|0]&4))){break M}a=v[b+656>>2];if(!a|!(w[a+15|0]&2)){break L}}if(f){break L}v[b+700>>2]=0}if(i){break a}u[b+136>>1]=0;v[b+132>>2]=4194304;v[b+112>>2]=0;v[b+116>>2]=0}jb=h+32|0}function eP(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;l=jb-336|0;jb=l;m=i&65535;p=d;q=e&65535;s=(e^i)&-2147483648;k=h;z=i>>>16&32767;A=e>>>16&32767;a:{b:{if(z-32767>>>0>4294934529&A-32767>>>0>=4294934530){break b}j=e&2147483647;if(!(!d&(j|0)==2147418112?!(b|c):j>>>0<2147418112)){o=d;s=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;s=i|32768;b=f;c=g;break a}if(!(b|d|(j^2147418112|c))){if(!(f|h|(e^2147418112|g))){b=0;c=0;s=2147450880;break a}s=s|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){b=0;c=0;break a}if(!(b|d|(c|j))){b=!(f|h|(e|g));o=b?0:o;s=b?2147450880:s;b=0;c=0;break a}if(!(f|h|(e|g))){s=s|2147418112;b=0;c=0;break a}if((j|0)==65535|j>>>0<65535){i=b;d=!(p|q);h=d<<6;j=E(d?b:p)+32|0;b=E(d?c:q);b=h+((b|0)==32?j:b)|0;vf(l+320|0,i,c,p,q,b-15|0);n=16-b|0;p=v[l+328>>2];q=v[l+332>>2];c=v[l+324>>2];b=v[l+320>>2]}if(e>>>0>65535){break b}d=!(k|m);e=d<<6;h=E(d?f:k)+32|0;d=E(d?g:m);d=e+((d|0)==32?h:d)|0;vf(l+304|0,f,g,k,m,d-15|0);n=(d+n|0)-16|0;k=v[l+312>>2];m=v[l+316>>2];f=v[l+304>>2];g=v[l+308>>2]}e=m|65536;B=e;C=k;d=k;k=e<<15|d>>>17;d=d<<15|g>>>17;h=0-d|0;e=k;i=1963258675-(e+((d|0)!=0)|0)|0;mf(l+288|0,d,e,0,0,h,i,0,0);j=v[l+296>>2];mf(l+272|0,0-j|0,0-(v[l+300>>2]+((j|0)!=0)|0)|0,0,0,h,i,0,0);h=v[l+280>>2];i=h<<1|v[l+276>>2]>>>31;h=v[l+284>>2]<<1|h>>>31;mf(l+256|0,i,h,0,0,d,e,0,0);j=h;h=v[l+264>>2];mf(l+240|0,i,j,0,0,0-h|0,0-(v[l+268>>2]+((h|0)!=0)|0)|0,0,0);h=v[l+248>>2];i=h<<1|v[l+244>>2]>>>31;h=v[l+252>>2]<<1|h>>>31;mf(l+224|0,i,h,0,0,d,e,0,0);j=h;h=v[l+232>>2];mf(l+208|0,i,j,0,0,0-h|0,0-(v[l+236>>2]+((h|0)!=0)|0)|0,0,0);h=v[l+216>>2];i=h<<1|v[l+212>>2]>>>31;h=v[l+220>>2]<<1|h>>>31;mf(l+192|0,i,h,0,0,d,e,0,0);e=h;h=v[l+200>>2];mf(l+176|0,i,e,0,0,0-h|0,0-(v[l+204>>2]+((h|0)!=0)|0)|0,0,0);i=d;h=v[l+184>>2];d=h<<1|v[l+180>>2]>>>31;e=d-1|0;h=(v[l+188>>2]<<1|h>>>31)-!d|0;mf(l+160|0,i,k,0,0,e,h,0,0);d=f;j=g<<15|d>>>17;mf(l+144|0,d<<15,j,0,0,e,h,0,0);k=v[l+172>>2];m=v[l+160>>2];D=v[l+152>>2];d=m+D|0;i=v[l+164>>2];j=i+v[l+156>>2]|0;j=d>>>0<D>>>0?j+1|0:j;m=(i|0)==(j|0)&d>>>0<m>>>0|i>>>0>j>>>0;i=m+v[l+168>>2]|0;k=i>>>0<m>>>0?k+1|0:k;m=!j&d>>>0>1|(j|0)!=0;i=m+i|0;k=i>>>0<m>>>0?k+1|0:k;mf(l+112|0,e,h,0,0,0-i|0,0-(((i|0)!=0)+k|0)|0,0,0);mf(l+128|0,1-d|0,0-((d>>>0>1)+j|0)|0,0,0,e,h,0,0);J=(A-z|0)+n|0;e=v[l+116>>2];x=e;d=v[l+112>>2];j=e<<1|d>>>31;m=d<<1;n=j;d=j;h=v[l+140>>2];u=h;e=v[l+136>>2];j=h<<1|e>>>31;i=e<<1|v[l+132>>2]>>>31;h=i+m|0;j=d+j|0;j=h>>>0<i>>>0?j+1|0:j;i=h;e=j;j=j-(h>>>0<13927)|0;r=j;k=q|65536;M=k;D=p;j=p;k=k<<1|j>>>31;p=j<<1|c>>>31;d=0;j=d|k;q=j;w=Sia(r,d,j,0);d=mb;t=d;j=b;d=c<<1|j>>>31;z=j<<1;A=d;h=h-13927|0;j=(e|0)==(r|0)&h>>>0<i>>>0|e>>>0>r>>>0;e=(e|0)==(n|0)&i>>>0<m>>>0|e>>>0<n>>>0;d=v[l+120>>2];k=v[l+124>>2]<<1|d>>>31;i=d<<1;m=j;n=e;e=u>>>31|0;d=e+(x>>>31|i)|0;j=k;j=d>>>0<e>>>0?j+1|0:j;e=d;d=n+d|0;j=d>>>0<e>>>0?j+1|0:j;e=d;d=m+d|0;k=d>>>0<e>>>0?j+1|0:j;e=d;d=d-1|0;F=k-!e|0;G=0;i=Sia(A,o,F,G);e=i+w|0;k=mb+t|0;k=e>>>0<i>>>0?k+1|0:k;m=(k|0)==(t|0)&e>>>0<w>>>0|k>>>0<t>>>0;w=d;i=Sia(d,0,p,0);d=i+e|0;j=mb+k|0;j=d>>>0<i>>>0?j+1|0:j;n=d;i=j;e=(j|0)==(k|0)&d>>>0<e>>>0|j>>>0<k>>>0;d=m+e|0;k=0;k=d>>>0<e>>>0?1:k;e=Sia(q,o,F,G);d=e+d|0;j=mb+k|0;u=d;d=d>>>0<e>>>0?j+1|0:j;m=Sia(q,o,w,o);k=mb;x=Sia(F,G,p,o);e=x+m|0;j=mb+k|0;j=e>>>0<x>>>0?j+1|0:j;x=e;e=j;j=(k|0)==(j|0)&m>>>0>x>>>0|j>>>0<k>>>0;m=u+e|0;d=d+j|0;j=m;m=j>>>0<e>>>0?d+1|0:d;u=j;e=0;d=e+n|0;j=i+x|0;j=d>>>0<e>>>0?j+1|0:j;e=j;k=(j|0)==(i|0)&d>>>0<n>>>0|i>>>0>j>>>0;i=u+k|0;j=m;u=i;i=i>>>0<k>>>0?j+1|0:j;n=d;m=e;x=h;h=Sia(h,0,p,o);e=mb;t=Sia(r,o,A,o);d=t+h|0;j=mb+e|0;j=d>>>0<t>>>0?j+1|0:j;e=(e|0)==(j|0)&d>>>0<h>>>0|e>>>0>j>>>0;h=j;H=u;t=e;I=z&-2;k=Sia(w,o,I,0);e=k+d|0;j=mb+j|0;j=e>>>0<k>>>0?j+1|0:j;u=e;k=e;e=j;h=(j|0)==(h|0)&d>>>0>k>>>0|h>>>0>j>>>0;d=t+h|0;k=0;k=d>>>0<h>>>0?1:k;j=d;h=n+d|0;d=k+m|0;d=h>>>0<j>>>0?d+1|0:d;t=h;j=h;h=d;k=(d|0)==(m|0)&j>>>0<n>>>0|d>>>0<m>>>0;d=H+k|0;j=i;N=d;n=d>>>0<k>>>0?j+1|0:j;K=Sia(q,o,x,o);H=mb;i=Sia(F,G,I,o);d=i+K|0;j=mb+H|0;j=d>>>0<i>>>0?j+1|0:j;F=d;k=Sia(r,o,p,o);i=d+k|0;m=j;d=j+mb|0;d=i>>>0<k>>>0?d+1|0:d;L=i;j=Sia(A,o,w,o);i=i+j|0;k=mb+d|0;G=i;k=i>>>0<j>>>0?k+1|0:k;i=k;w=0;O=(d|0)==(k|0)&G>>>0<L>>>0|d>>>0>k>>>0;j=(d|0)==(m|0)&F>>>0>L>>>0|d>>>0<m>>>0;d=j+((m|0)==(H|0)&F>>>0<K>>>0|m>>>0<H>>>0)|0;k=0;d=O+d|0;m=i|0;k=m+t|0;j=(d|w)+h|0;w=k;d=k;j=d>>>0<m>>>0?j+1|0:j;m=j;h=(h|0)==(j|0)&d>>>0<t>>>0|h>>>0>j>>>0;d=h+N|0;j=n;H=d;h=d>>>0<h>>>0?j+1|0:j;t=Sia(r,o,I,o);r=mb;k=Sia(A,o,x,o);d=k+t|0;j=mb+r|0;j=d>>>0<k>>>0?j+1|0:j;n=0;k=(j|0)==(r|0)&d>>>0<t>>>0|j>>>0<r>>>0;r=j;d=j+u|0;j=(k|n)+e|0;n=d;j=d>>>0<r>>>0?j+1|0:j;u=(e|0)==(j|0)&d>>>0<u>>>0|e>>>0>j>>>0;i=0;e=i+d|0;d=j;k=G+d|0;k=e>>>0<i>>>0?k+1|0:k;e=(d|0)==(k|0)&e>>>0<n>>>0|d>>>0>k>>>0;d=u+e|0;j=0;j=d>>>0<e>>>0?1:j;e=d;d=d+w|0;j=j+m|0;j=d>>>0<e>>>0?j+1|0:j;e=j;j=(m|0)==(j|0)&d>>>0<w>>>0|j>>>0<m>>>0;i=j+H|0;k=h;h=i;k=h>>>0<j>>>0?k+1|0:k;i=k;c:{if((k|0)==131071|k>>>0<131071){mf(l+80|0,d,e,h,i,f,g,C,B);j=b<<17;b=0;c=v[l+88>>2];n=b-c|0;k=v[l+80>>2];m=v[l+84>>2];D=(k|m)!=0;r=n-D|0;n=(j-(v[l+92>>2]+(b>>>0<c>>>0)|0)|0)-(n>>>0<D>>>0)|0;b=k;k=0-k|0;m=0-(((b|0)!=0)+m|0)|0;b=J+16382|0;break c}k=h<<31;d=(e&1)<<31|d>>>1;e=e>>>1|k;h=(i&1)<<31|h>>>1;i=i>>>1|0;mf(l+96|0,d,e,h,i,f,g,C,B);q=0;m=v[l+104>>2];n=q-m|0;k=v[l+96>>2];p=v[l+100>>2];z=(k|p)!=0;r=n-z|0;n=((b<<16)-(v[l+108>>2]+(m>>>0>q>>>0)|0)|0)-(n>>>0<z>>>0)|0;j=k;k=0-j|0;m=0-(((j|0)!=0)+p|0)|0;z=b;A=c;p=D;q=M;b=J+16383|0}if((b|0)>=32767){s=s|2147418112;b=0;c=0;break a}d:{if((b|0)>0){c=r;j=n<<1|c>>>31;r=c<<1|m>>>31;n=j;p=h;q=i&65535|b<<16;j=m<<1|k>>>31;b=k<<1;break d}if((b|0)<=-113){b=0;c=0;break a}fm(l- -64|0,d,e,h,i,1-b|0);vf(l+48|0,z,A,p,q,b+112|0);d=v[l+64>>2];e=v[l+68>>2];p=v[l+72>>2];q=v[l+76>>2];mf(l+32|0,f,g,C,B,d,e,p,q);c=v[l+40>>2];i=c<<1;c=v[l+44>>2]<<1|c>>>31;b=v[l+56>>2];h=v[l+36>>2];n=h>>>31|i;i=b-n|0;n=v[l+60>>2]-((b>>>0<n>>>0)+c|0)|0;c=v[l+32>>2];k=h<<1|c>>>31;c=c<<1;j=v[l+52>>2];b=v[l+48>>2];h=(k|0)==(j|0)&c>>>0>b>>>0|j>>>0<k>>>0;r=i-h|0;n=n-(h>>>0>i>>>0)|0;h=b;b=h-c|0;j=j-((c>>>0>h>>>0)+k|0)|0}mf(l+16|0,f,g,C,B,3,0,0,0);mf(l,f,g,C,B,5,0,0,0);h=d;m=p;p=d&1;c=b+p|0;d=0;k=j+d|0;k=b>>>0>c>>>0?k+1|0:k;i=c;c=k;g=(k|0)==(g|0)&i>>>0>f>>>0|g>>>0<k>>>0;d=(d|0)==(k|0)&i>>>0<p>>>0|d>>>0>k>>>0;b=d+r|0;j=n;j=b>>>0<d>>>0?j+1|0:j;f=b;d=b;b=j;g=(d|0)==(C|0)&(j|0)==(B|0)?g:(B|0)==(j|0)&d>>>0>C>>>0|j>>>0>B>>>0;d=h+g|0;k=e;k=d>>>0<g>>>0?k+1|0:k;g=(e|0)==(k|0)&d>>>0<h>>>0|e>>>0>k>>>0;e=m+g|0;j=q;j=e>>>0<g>>>0?j+1|0:j;g=e;e=d;m=g;d=v[l+20>>2];h=(d|0)==(c|0)&y[l+16>>2]<i>>>0|c>>>0>d>>>0;d=v[l+28>>2];g=v[l+24>>2];h=j>>>0<2147418112&((f|0)==(g|0)&(b|0)==(d|0)?h:(d|0)==(b|0)&g>>>0<f>>>0|b>>>0>d>>>0);g=e+h|0;d=k;d=g>>>0<h>>>0?d+1|0:d;h=(d|0)==(k|0)&e>>>0>g>>>0|d>>>0<k>>>0;e=m+h|0;k=e>>>0<h>>>0?j+1|0:j;h=e;e=v[l+4>>2];i=(e|0)==(c|0)&y[l>>2]<i>>>0|c>>>0>e>>>0;c=v[l+12>>2];e=v[l+8>>2];c=k>>>0<2147418112&((e|0)==(f|0)&(b|0)==(c|0)?i:(c|0)==(b|0)&e>>>0<f>>>0|b>>>0>c>>>0);b=c+g|0;j=b>>>0<c>>>0?d+1|0:d;c=j;f=(d|0)==(j|0)&b>>>0<g>>>0|d>>>0>j>>>0;e=h+f|0;d=k;o=e|o;s=s|(e>>>0<f>>>0?d+1|0:d)}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=o;v[a+12>>2]=s;jb=l+336|0}function Bia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-304|0;jb=e;Ac(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if(!kU(b,e+232|0)){break p}if(!lU(e+232|0)){break p}if(!c){d=1;break p}Ed(a,131072);d=jb-16|0;jb=d;i=e+136|0;f=Vb(d,3913);Sc(i,f);zb(f);jb=d+16|0;v[23296]=0;U(291,e+184|0,i|0,e+232|4);d=v[23296];v[23296]=0;q:{if((d|0)!=1){d=e+184|0;Hb(a+1298344|0,d);zb(d);i=e+136|0;ec(i);f=Vb(d,11004);Hb(a+1298356|0,f);zb(f);v[a+1298404>>2]=5;vu(i,3,e+245|0);Gc(d,i);Bc(a+1298308|0,d);yb(d);f=e+112|0;tj(f,3,e+275|0);Gc(i,f);v[23296]=0;U(11,d|0,5,i|0);d=v[23296];v[23296]=0;if((d|0)==1){break b}d=e+184|0;Hb(a+1298320|0,d);zb(d);yb(e+136|0);d=sq(d);o=d,p=Xd(w[e+295|0],1,31),v[o+12>>2]=p;o=d,p=Xd(w[e+296|0],1,12)-1|0,v[o+16>>2]=p;v[d+20>>2]=w[e+297|0];i=a+1298408|0;Hc(i);iU(i,d);g=e+144|0;i=Qb(e+168|0);r:{s:{t:{while(1){d=v[b+8>>2];f=v[b>>2];v[23296]=0;d=W(144,f|0,d|0,8)|0;f=v[23296];v[23296]=0;u:{v:{w:{x:{y:{if((f|0)!=1){if(!d){break r}v[23296]=0;R(292,b|0,e+72|0);d=v[23296];v[23296]=0;if((d|0)==1){break y}d=v[e+76>>2];z:{l=w[e+236|0];switch(l-3|0){case 1:break x;case 0:break z;default:break w}}f=2;if(v[e+72>>2]!=1431389523){break v}break u}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}f=4;if(v[e+72>>2]!=1431389523){break v}break u}f=0;if(l>>>0>7){break u}}d=v[e+72>>2]==1146113363?-1:d;f=0}l=v[e+76>>2];v[e+136>>2]=v[e+72>>2];v[e+140>>2]=l;v[23296]=0;U(178,e+112|0,b|0,d|0);d=v[23296];v[23296]=0;if((d|0)==1){break t}jc(g,e+112|0);v[23296]=0;R(293,i|0,e+136|0);d=v[23296];v[23296]=0;if((d|0)==1){break s}Md(e+136|0);Ab(e+112|0);v[23296]=0;Q(176,b|0,f|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){continue}break}b=P()|0;O()|0;break c}b=P()|0;O()|0;break c}b=P()|0;O()|0;Md(e+136|0);Ab(e+112|0);break c}v[23296]=0;l=T(162,e+136|0)|0;b=v[23296];v[23296]=0;A:{B:{C:{if((b|0)!=1){v[23296]=0;U(294,e+112|0,i|0,1431389523);b=v[23296];v[23296]=0;if((b|0)==1){break C}d=e+112|0;b=cd(l,d);Ab(d);u[e+110>>1]=0;u[e+108>>1]=65534;if(w[e+236|0]<3){break A}v[23296]=0;d=T(182,b|0)|0;f=v[23296];v[23296]=0;if((f|0)!=1){break B}break e}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}u[e+110>>1]=d;if(w[e+236|0]<4){break A}v[23296]=0;d=T(182,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break e}u[e+108>>1]=w[e+236|0]==4?d?d:-2:d}d=w[a+484376|0];f=v[a+484360>>2];v[23296]=0;g=T(190,b|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break e}v[23296]=0;U(226,Zb(f,d)|0,b|0,g>>>1|0);d=v[23296];v[23296]=0;if((d|0)==1){break e}d=Zb(v[a+484360>>2],w[a+484376|0]);d=sB(v[d>>2],v[d+4>>2]);ug(e+110|0,d);ug(e+108|0,d);v[23296]=0;U(294,e+112|0,i|0,1414807888);d=v[23296];v[23296]=0;if((d|0)==1){break h}d=e+112|0;b=cd(b,d);Ab(d);d=v[b>>2];v[23296]=0;d=T(166,d|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break e}if(!(c&1)|d^1){break q}v[23296]=0;R(295,b|0,e+8|0);d=v[23296];v[23296]=0;if((d|0)==1){break i}o=a+480188|0,p=Xd(w[e+10|0],1,32)+1|0,u[o>>1]=p;v[23296]=0;d=Q(206,e+96|0,x[e+8>>1])|0;f=v[23296];v[23296]=0;if((f|0)==1){break j}o=e,p=Eb(v[d>>2]),v[o+48>>2]=p;g=Eb(v[d+4>>2]);D:{E:{while(1){h=v[e+48>>2];if(!Rb(h,g)){f=x[a+480188>>1];v[23296]=0;f=Q(296,e+112|0,f|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){g=a+484376|0;h=Zb(v[a+484360>>2],w[g|0]);h=fl(v[h>>2],v[h+4>>2]);v[23296]=0;k=a+484344|0;R(213,k|0,h|0);h=v[23296];v[23296]=0;if((h|0)==1){break g}g=Zb(v[a+484360>>2],w[g|0]);o=e,p=Eb(v[g>>2]),v[o+72>>2]=p;h=Eb(v[g+4>>2]);F:{while(1){G:{g=v[e+72>>2];if(!Rb(g,h)){g=w[a+484376|0];h=v[a+484360>>2];v[23296]=0;j=Zb(h,g);h=x[e+108>>1];g=Q(297,j|0,h|0)|0;j=v[23296];v[23296]=0;if((j|0)!=1){break G}break g}j=v[d>>2];n=Df(j,v[d+4>>2]);m=x[g>>1];if(n>>>0>m>>>0){v[23296]=0;j=fa(298,Cg(j,m)|0,w[e+236|0],f|0,a|0)|0;m=v[23296];v[23296]=0;if((m|0)==1){break F}u[g>>1]=j}Se(e+72|0);continue}break}H:{if(!g){break H}g=Zb(v[a+484360>>2],w[a+484376|0]);j=x[e+110>>1];if(!j){if(sB(v[g>>2],v[g+4>>2])>>>0<=h>>>0){break H}}g=$b(v[k>>2],x[dc(v[g>>2],h)>>1]);qe(g,qm(Ke(Fe(e+72|0,12,j&255),v[g+12>>2]-1|0)))}gk(f);ld(d);break q}break g}b=P()|0;O()|0;break f}v[23296]=0;f=w[e+236|0]<3?9:8;Q(176,b|0,f-4|0)|0;k=v[23296];v[23296]=0;if((k|0)!=1){v[23296]=0;k=T(145,b|0)|0;j=v[23296];v[23296]=0;if((j|0)==1){break E}ng(b,f);v[23296]=0;U(178,e+72|0,b|0,f+k|0);f=v[23296];v[23296]=0;if((f|0)==1){break D}j=h;f=e+72|0;h=jc(e+112|0,f);cd(j,h);Ab(h);Ab(f);vh(e+48|0);continue}break}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;ec(e+136|0);break a}v[23296]=0;U(294,e+72|0,i|0,1196641603);d=v[23296];v[23296]=0;if((d|0)==1){break n}d=e+72|0;b=cd(b,d);Ab(d);d=v[b>>2];v[23296]=0;d=T(166,d|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break e}if(d){v[23296]=0;Q(176,b|0,1)|0;d=v[23296];v[23296]=0;if((d|0)==1){break e}v[23296]=0;d=T(190,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break e}v[23296]=0;da(299,a+1298332|0,b|0,d|0,40,0);d=v[23296];v[23296]=0;if((d|0)==1){break e}}v[23296]=0;U(294,e+72|0,i|0,1146113363);d=v[23296];v[23296]=0;if((d|0)==1){break k}v[23296]=0;U(294,e+48|0,i|0,1229999443);d=v[23296];v[23296]=0;if((d|0)==1){break o}d=e+48|0;b=cd(b,d);Ab(d);v[23296]=0;d=T(194,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break m}h=a+480190|0;u[h>>1]=d;k=!(c&2);f=1;I:{while(1){J:{c=f&65535;if(c>>>0>(d&65535)>>>0){break I}d=30;K:{L:{M:{if(w[e+236|0]>=2){v[23296]=0;d=T(194,b|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break M}}v[23296]=0;U(300,b|0,((c<<5)+a|0)+946304|0,d|0);d=v[23296];v[23296]=0;if((d|0)==1){break M}v[23296]=0;R(301,b|0,e+32|0);d=v[23296];v[23296]=0;if((d|0)==1){break L}v[23296]=0;g=B(c,104)+a|0;j=g+484380|0;R(302,e+32|0,j|0);c=v[23296];v[23296]=0;if((c|0)==1){break L}d=w[e+236|0];if(d>>>0>=8){v[23296]=0;R(303,b|0,g+484423|0);c=v[23296];v[23296]=0;if((c|0)==1){break L}d=w[e+236|0]}v[23296]=0;Q(176,b|0,((d&255)>>>0>1?6:2)|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break L}v[23296]=0;c=T(145,e+72|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){v[23296]=0;U(178,e+8|0,e+72|0,c|0);c=v[23296];v[23296]=0;if((c|0)!=1){break K}}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}d=e+8|0;c=jc(e+48|0,d);Ab(d);d=v[c>>2];v[23296]=0;d=T(166,d|0)|0;m=v[23296];v[23296]=0;if((m|0)!=1){N:{if(k|d^1){break N}d=_c(e+8|0,u[g+484414>>1]&1?16:8,1,0,(w[e+47|0]&12)==4?7:0);v[23296]=0;W(207,d|0,j|0,c|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break N}break J}Ab(c);f=f+1|0;d=x[h>>1];continue}}break}b=P()|0;O()|0;Ab(c);break l}Dg(a);v[a+480204>>2]=12e5;v[a+480208>>2]=24;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+480228>>2]=48;v[a+480232>>2]=48;v[23296]=0;d=1;W(251,a+1074312|0,114,1)|0;a=v[23296];v[23296]=0;if((a|0)==1){break m}Ab(e+72|0);Ab(b);_d(i)}jb=e+304|0;return d|0}b=P()|0;O()|0;break l}b=P()|0;O()|0;break d}b=P()|0;O()|0}Ab(e+72|0);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;gk(f)}ld(d);break d}b=P()|0;O()|0}Ab(l)}_d(i);break a}b=P()|0;O()|0;yb(e+136|0)}S(b|0);L()}function Uea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0;d=jb-1344|0;jb=d;Ac(b);f=jb-16|0;jb=f;iR(f+8|0,d+232|0);e=v[f+12>>2];nc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);j=v[f+4>>2];if((j|0)==(e|0)){ac(b,v[f+12>>2])}jb=f+16|0;a:{if((e|0)!=(j|0)){break a}if(!kR(d+232|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Vc(jR(v[d+1336>>2]),mb))){break a}if(!c){m=1;break a}Ac(b);b=ie(d+232|0,b);v[23296]=0;R(569,d+216|0,b|0);f=v[23296];v[23296]=0;b:{c:{d:{e:{f:{g:{h:{i:{if((f|0)!=1){Ab(b);v[23296]=0;U(570,d+200|0,d+216|0,1196314451);b=v[23296];v[23296]=0;if((b|0)==1){break i}v[23296]=0;U(570,d+184|0,d+216|0,1280331091);b=v[23296];v[23296]=0;if((b|0)==1){break h}if(uc(v[d+200>>2],v[d+204>>2])){break b}if(!uc(v[d+184>>2],v[d+188>>2])){break g}break b}c=P()|0;O()|0;Ab(b);break d}c=P()|0;O()|0;break e}c=P()|0;O()|0;break f}v[23296]=0;R(234,a|0,1);b=v[23296];v[23296]=0;j:{k:{l:{m:{n:{if((b|0)!=1){Dg(a);v[a+480188>>2]=4;v[a+480208>>2]=25231360;D=d,E=Eb(v[d+184>>2]),v[D+48>>2]=E;g=c&2;m=Eb(v[d+188>>2]);f=a+480190|0;o:{p:{while(1){e=v[d+48>>2];if(!Rb(e,m)){break p}b=x[f>>1];if(!Sh(b)){break p}b=b+1|0;u[f>>1]=b;v[23296]=0;b=B(b&65535,104)+a|0;j=b+484380|0;R(264,j|0,1);i=v[23296];v[23296]=0;q:{r:{if((i|0)!=1){v[23296]=0;i=Q(571,e|0,d+232|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break r}if(!i){break c}if(Ht(d+232|0)){break q}break c}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}v[23296]=0;i=Q(54,d+168|0,d+232|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break o}Ec(((x[f>>1]<<5)+a|0)+946304|0,i);yb(i);i=v[d+268>>2];v[j>>2]=i;v[b+484388>>2]=i;v[b+484384>>2]=v[d+264>>2];i=b+484414|0;u[i>>1]=x[i>>1]|2;u[b+484410>>1]=255;s:{if(g){b=_c(d+16|0,8,1,0,0);v[23296]=0;W(207,b|0,j|0,e|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break s}}vh(d+48|0);continue}break}c=P()|0;O()|0;break j}D=d,E=Eb(v[d+200>>2]),v[D+160>>2]=E;q=a+484344|0;A=c&1;s=a+484360|0;C=Eb(v[d+204>>2]);l=a+484376|0;p=a+480190|0;y=a+484380|0;z=a+946304|0;c=1;m=1;while(1){t:{u:{v:{w:{x:{y:{b=v[d+160>>2];if(!Rb(b,C)){break y}if(!(c&1)){v[23296]=0;c=T(259,s|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break x}if(!c){break y}}Hc(Zb(v[a+484360>>2],w[l|0]));v[23296]=0;c=Q(572,b|0,d+232|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break w}if(!(c&!x[d+1318>>1])|v[d+1320>>2]-5>>>0<4294967292){break c}c=w[l|0];f=v[a+484360>>2];v[23296]=0;U(5,d+48|0,5,d+232|0);e=v[23296];v[23296]=0;if((e|0)==1){break k}v[23296]=0;R(260,Zb(f,c)|0,d+48|0);c=v[23296];v[23296]=0;if((c|0)==1){break l}zb(d+48|0);z:{if(A){v[23296]=0;U(178,d+48|0,b|0,v[d+1328>>2]);b=v[23296];v[23296]=0;if((b|0)==1){break m}b=d+48|0;jc(d+136|0,b);break z}v[23296]=0;b=T(162,d+112|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break n}c=CD(d+48|0,b);jc(d+136|0,c);Ab(c)}Ab(b);Xb(d+48|0,0,64);c=1;A:{B:{C:{while(1){if((c|0)==32){break C}b=(B(c,34)+d|0)+198|0;f=b+32|0;Em(d,f);D:{E:{if(!w[v[d>>2]]){break E}e=w[b- -64|0];if(e>>>0>15){break B}b=w[b+65|0];if(b>>>0>64){break B}if(!Ht(f)){break B}j=b<<2;i=e<<4;f=0;b=1;F:{while(1){g=b&65535;e=x[p>>1];if(g>>>0>e>>>0){break F}v[23296]=0;U(474,d+16|0,v[d>>2],v[d+4>>2]);e=v[23296];v[23296]=0;if((e|0)==1){break D}e=jb-16|0;jb=e;k=d+16|0;ve(e+8|0,k);gR(e,((g<<5)+a|0)+946304|0);h=v[e+8>>2];r=v[e>>2];n=v[e+12>>2];o=v[e+4>>2];if((n|0)==(o|0)){h=(RS(h,n,r,o)|0)!=0}else{h=1}jb=e+16|0;yb(k);G:{H:{if(h){break H}D=dc(d+48|0,c),E=b,u[D>>1]=E;e=B(g,104)+a|0;g=e+484410|0;h=x[g>>1];if((h|0)==255){break G}f=b;if(w[e+484417|0]!=(i&255)){break H}if((h|0)==(j|0)){break G}}b=b+1|0;continue}break}t[e+484417|0]=i;u[g>>1]=j;break E}f=f&65535;if(!f){break E}if(!Sh(e)){break E}b=e+1|0;u[p>>1]=b;D=dc(d+48|0,c),E=b,u[D>>1]=E;b=B(x[p>>1],104)+y|0;hm(b);e=B(f,104)+y|0;g=go(b,e);u[b+30>>1]=j;t[b+37|0]=i;bS(g,e);f=(f<<5)+z|0;e=v[f+4>>2];b=(x[p>>1]<<5)+z|0;v[b>>2]=v[f>>2];v[b+4>>2]=e;e=v[f+28>>2];v[b+24>>2]=v[f+24>>2];v[b+28>>2]=e;e=v[f+20>>2];v[b+16>>2]=v[f+16>>2];v[b+20>>2]=e;e=v[f+12>>2];v[b+8>>2]=v[f+8>>2];v[b+12>>2]=e}c=c+1|0;continue}break}break v}i=0;v[d+40>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;e=64;j=65535;r=x[d+1320>>1];f=0;I:while(1){J:{if(f){break J}v[23296]=0;b=W(144,v[d+136>>2],v[d+144>>2],1)|0;c=v[23296];v[23296]=0;if((c|0)==1){break A}if(b){break J}b=j;break u}e=e+1|0;if(e>>>0>=64){v[23296]=0;j=Q(345,q|0,64)|0;b=v[23296];v[23296]=0;if((b|0)==1){break A}b=65535;if((j|0)==65535){break u}b=w[l|0];c=v[a+484360>>2];e=0;v[23296]=0;R(472,Zb(c,b)|0,j|0);b=v[23296];v[23296]=0;if((b|0)==1){break A}}b=0;c=$b(v[q>>2],j&65535);c=fd(v[c>>2],v[v[c+48>>2]+12>>2],e,0);while(1){if((b|0)==(r|0)){continue I}g=(d+16|0)+B(b,7)|0;h=w[g+6|0];K:{if(h){t[g+6|0]=h-1;h=w[g+4|0]|w[g+5|0]<<8;t[c+4|0]=h;t[c+5|0]=h>>>8;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[c|0]=g;t[c+1|0]=g>>>8;t[c+2|0]=g>>>16;t[c+3|0]=g>>>24;f=f-1|0;break K}v[23296]=0;h=W(144,v[d+136>>2],v[d+144>>2],1)|0;k=v[23296];v[23296]=0;if((k|0)==1){break v}if(!h){break K}if(v[d+144>>2]==v[d+1324>>2]){i=Zb(v[a+484360>>2],w[l|0]);_e(i,sB(v[i>>2],v[i+4>>2]));i=e}v[23296]=0;h=T(194,d+136|0)|0;k=v[23296];v[23296]=0;L:{if((k|0)!=1){h=h<<24>>24;if((h|0)>=0){break L}h=h&127;t[g+6|0]=h;k=w[g+4|0]|w[g+5|0]<<8;t[c+4|0]=k;t[c+5|0]=k>>>8;g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);t[c|0]=g;t[c+1|0]=g>>>8;t[c+2|0]=g>>>16;t[c+3|0]=g>>>24;f=f+h|0;break K}break v}if((h-1&255)>>>0<=35){t[c|0]=h+48}v[23296]=0;h=T(194,d+136|0)|0;k=v[23296];v[23296]=0;M:{N:{if((k|0)!=1){D=c,E=w[dc(d+48|0,h&31)|0],t[D+1|0]=E;if(!(h&128)){break N}t[c+3|0]=w[g+3|0];t[c+5|0]=w[g+5|0];break M}break v}v[23296]=0;R(247,d|0,d+136|0);h=v[23296];v[23296]=0;O:{if((h|0)!=1){h=w[d|0];if(h>>>0>19){break M}n=h<<1;o=w[n+26784|0];t[c+3|0]=o;k=w[kd(d)|0];t[c+5|0]=k;if((o|0)!=16|k>>>0<32){break O}t[c+3|0]=17;break M}break v}if(819137>>>h&1){break M}t[c+5|0]=w[n+26785|0]|k&15}h=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[g|0]=h;t[g+1|0]=h>>>8;t[g+2|0]=h>>>16;t[g+3|0]=h>>>24;h=w[c+4|0]|w[c+5|0]<<8;t[g+4|0]=h;t[g+5|0]=h>>>8}c=c+6|0;b=b+1|0;continue}}}m=0;break t}break v}Ai(s,0);v[23296]=0;b=Q(1,d+232|0,6428)|0;c=v[23296];v[23296]=0;P:{if((c|0)!=1){Hb(a+1298344|0,b);zb(b);v[23296]=0;b=Q(1,d+48|0,6730)|0;c=v[23296];v[23296]=0;if((c|0)==1){break P}Hb(a+1298356|0,b);zb(b);v[a+1298404>>2]=5;m=1;break b}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;Ab(d+136|0);break j}Q:{if(!i&e>>>0>62){break Q}b=b&65535;if((b|0)==65535){break Q}qe($b(v[q>>2],b),yh(Ke(Fe(d,14,i&255),e)))}c=32}Ab(d+136|0);if(c>>>0<32){break b}vh(d+160|0);c=0;continue}}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;zb(d+48|0);break j}c=P()|0;O()|0}ld(d+184|0)}ld(d+200|0)}_d(d+216|0)}S(c|0);L()}m=0}ld(d+184|0);ld(d+200|0);_d(d+216|0)}jb=d+1344|0;return m|0}function ufa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,M=0,N=0,Q=0,T=0,V=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ba=0,ca=0;d=jb-336|0;jb=d;a:{if(!$c(b,1080)){break a}if(!no(b,d+332|0)){break a}Ed(a,1);m=OR(d+312|0);if(!NR(d+332|0,m)){break a}h=x[m+10>>1];e=h;if(!e|e>>>0>127){break a}if(!c){g=1;break a}y=a+480188|0;u[y>>1]=h;s=w[m+14|0];J=w[m+13|0];f=w[m+12|0];D=1;if(!fe(d+332|0,26714)){D=fe(d+332|0,26719)}if(w[m+15|0]){Nb(a+1074312|0,5,1);h=x[a+480188>>1]}g=d+332|0;q=fe(g,16546);e=1;if(!fe(g,17310)){e=fe(d+332|0,13438)}z=(h&65535)==8&(J|0)!=0;$c(b,0);NA(b,a+1298308|0,20);u[a+480190>>1]=31;n=(f|0)!=0;p=a+480188|0;g=1;h=q;while(1)if((g|0)==32){b:{c:{d:{e:{f:{g:{K=v[m+4>>2];if(K>>>0>=E>>>0){f=d+176|0;JR(b,f);$c(b,x[m+8>>1]);g=w[d+177|0];e=128;i=a+484376|0;tq(Zb(v[a+484360>>2],w[i|0]),f|2,128);h=!g&h;k=h?k:0;f=w[d+176|0];h:{if(f>>>0>128){break h}e=f;if(e){break h}f=v[Zb(v[a+484360>>2],w[a+484376|0])>>2];g=128;while(1){e=g;if(e>>>0<2){e=1;break h}g=e-1|0;if(!x[dc(f,g)>>1]){continue}break}}r=IR(b,Zb(v[a+484360>>2],w[i|0]),e&65535,j,y,k,0);F=1;i:{if(!(h&x[a+480188>>1]==8)){F=(s|0)!=0;break i}v[m>>2]=11121}j:{if(!z){break j}f=Zb(v[a+484360>>2],w[a+484376|0]);ba=d,ca=Eb(v[f>>2]),v[ba+160>>2]=ca;h=Eb(v[f+4>>2]);while(1){f=v[d+160>>2];if(!Rb(f,h)){break j}u[f>>1]=x[f>>1]>>>1;Se(d+160|0);continue}}f=a+484376|0;_e(Zb(v[a+484360>>2],w[f|0]),w[d+177|0]);M=e-1|0;e=w[d+177|0];k:{if((M&65535)>>>0>=e>>>0){g=x[y>>1];if((e|0)!=120|(g|0)!=4){break k}}_e(Zb(v[a+484360>>2],w[f|0]),0);g=x[a+480188>>1]}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;v[a+480208>>2]=0;ba=a,ca=Yb(256/((g&65535)>>>0)|0,32,128),v[ba+480228>>2]=ca;xh(a,0);t[d+175|0]=0;s=1;g=0;N=1;if(!n){o=d+160|5;n=0;e=0;k=0;f=q;l:while(1){if(r>>>0>(k&65535)>>>0){i=0;g=0;while(1)if((g|0)==256){k=k+1|0;continue l}else{h=Th(d+160|0);ru(b,h);p=YA(w[h|0]);m:{n:{o:{p:{h=w[d+163|0];if((h-7&255)>>>0<3){f=0;break p}j=w[d+165|0];if(!((h|0)!=14|j>>>0<=1)){f=0;break o}if(!((h|0)==15&(j&255)>>>0>31)){f=p?f:0;if((h|0)!=13){break p}i=i+1|0;if((i&65535)>>>0<2){break m}}f=0;break m}if((h|0)==8){break n}if((h|0)!=14){break m}j=w[d+165|0]}if((j&240)!=128){break m}t[d+144|0]=j<<4;ba=d,ca=w[ef(d+175|0,d+144|0)|0],t[ba+175|0]=ca;break m}ba=d,ca=w[ef(d+175|0,o)|0],t[ba+175|0]=ca;h=t[d+165|0];if((h|0)>=0){n=1;break m}e=(h|0)!=-92&h>>>0>4294967183|e}s=p&s;g=g+1|0;continue}}break}g=0;g=(n^-1|e)&1?g:w[d+175|0]>47;N=f&1}$c(b,x[m+8>>1]);e=x[a+480188>>1];p=a+484344|0;G=r+z&65535;mg(p,G);Q=z?4:e;n=a+1074312|0;_=g^1;$=c&1;k=0;j=0;r=0;o=0;q:{r:{s:{while(1){if((k|0)==(G|0)){break r}t:{if(z){e=(k&65534)>>>1|0;f=k&1;if(!f){if(!bh(p,e,64)){break r}}h=f<<2;e=$b(v[p>>2],e);break t}if(!bh(p,k&65535,64)){break r}h=0;e=$b(v[p>>2],k)}i=0;H=fd(v[e>>2],v[v[e+48>>2]+12>>2],0,h);if(!$){r=0;o=0;break q}e=x[y>>1];t[d+80|0]=0;f=e;e=d+80|0;i=um(d+160|0,f,e);f=x[y>>1];v[23296]=0;t[d+80|0]=0;C=W(528,d+144|0,f|0,e|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){I=0;u:while(1){if((I|0)!=64){h=0;f=0;T=0;while(1){if((h|0)==(Q|0)){I=I+1|0;r=f&T|r;H=B(x[y>>1],6)+H|0;continue u}v[23296]=0;g=B(h,6)+H|0;R(529,b|0,g|0);e=v[23296];v[23296]=0;v:{w:{if((e|0)!=1){e=w[g+3|0];x:{y:{z:{if(!e){if(w[g+5|0]){break z}break y}if(!J){break z}A:{switch(e-14|0){case 0:t[g+3|0]=0;t[g+5|0]=0;break z;case 1:break A;default:break z}}if(w[g+5|0]<32){break z}t[g+5|0]=31}Of(g);e=1;B:{C:{D:{l=w[g+3|0];switch(l-14|0){case 2:break x;case 0:break C;case 3:break D;default:break B}}j=w[g+5|0]<100|j;T=1;break y}if(!N){break y}t[g+5|0]=0;break y}if(!((l|0)!=9|_)){e=w[g+5|0];if((e|0)==164){t[g+3|0]=20;t[g+5|0]=145;break y}ba=g,ca=xi(e<<1),t[ba+5|0]=ca;break y}if((l|0)!=19){break y}e=w[g+5|0];if(e>>>0>15){break y}l=e&1;e=!l;aa=!l;l=V&1;V=(l|0)==(e|0)?V:aa;o=((e|0)!=(l|0))+o|0}e=f}if(w[g|0]){break w}f=w[g+1|0];if(!f|z){break v}l=w[Lb(v[i>>2],h)|0];if(!l|(f|0)==(l|0)){break v}l=Lb(v[C>>2],h);f=w[l|0]+1|0;t[l|0]=f;if((f&255)>>>0<4){break v}v[23296]=0;W(251,n|0,85,1)|0;f=v[23296];v[23296]=0;if((f|0)!=1){break v}}h=P()|0;O()|0;fc(C);break s}ba=Lb(v[C>>2],h),ca=0,t[ba|0]=ca}f=w[g+1|0];if(f){ba=Lb(v[i>>2],h),ca=f,t[ba|0]=ca}h=h+1|0;f=e;continue}}break}fc(C);fc(i);k=k+1|0;continue}break}h=P()|0;O()|0}fc(i);break b}i=j}E:{F:{G:{if((s^-1|X)&1){break G}H:{if(fe(d+332|0,16546)){break H}if(fe(d+332|0,17315)){break H}if(!fe(d+332|0,13428)){break G}}v[a+480208>>2]=v[a+480208>>2]|2162688;e=Nb(Nb(Nb(n,85,1),91,1),92,1);I:{if(w[d+175|0]>47){break I}e=Nb(e,84,1);if(w[d+177|0]==127){break I}Nb(e,83,1)}if(!(s&1)){break E}break F}if(s&1){break F}if(q^1|w[d+177|0]!=127|(M&65535)>>>0>128){break E}v[m>>2]=8412;break E}if((o|0)>6|F){break E}v[a+480208>>2]=v[a+480208>>2]|8388608}if((q|F)==1){Nb(n,89,1)}if(D){Nb(n,84,1)}J:{if(!(c&2)){break J}$c(b,x[m+8>>1]+(B(G,Q)<<8)|0);f=(s&q^1|Y)&1;g=1;while(1){if((g|0)==32){break J}h=B(g,104)+a|0;c=h+484380|0;e=v[c>>2];if(e){j=2;if(!D){j=HR(b,13692)?10:0;e=v[c>>2]}j=_c(d+160|0,8,1,0,j);e=QA(j,e)+v[b+8>>2]|0;if(!f){ba=c,ca=v[Yc(c,h+484388|0)>>2],v[ba>>2]=ca}lg(j,c,b);$c(b,e)}g=g+1|0;continue}}K:{if((i&q^-1|r)&1){break K}b=GR(d+120|0,0);c=v[b+20>>2];v[d+40>>2]=v[b+16>>2];v[d+44>>2]=c;c=v[b+12>>2];v[d+32>>2]=v[b+8>>2];v[d+36>>2]=c;c=v[b+4>>2];v[d+24>>2]=v[b>>2];v[d+28>>2]=c;b=d+160|0;Kt(b,a,0,d+24|0);Z=A[v[d+160>>2]>>3];vi(b);if(!(Z>=480)){break K}c=Nb(n,5,1);b=FR(d+96|0,Z);e=v[b+20>>2];v[d+16>>2]=v[b+16>>2];v[d+20>>2]=e;e=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=e;e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=d+160|0;Kt(b,a,0,d);e=w[v[d+160>>2]+26|0];vi(b);if(e){Bf(c,5);break K}v[m>>2]=16898}b=d+332|0;e=b;f=kc(e);c=e;while(1){if((e|0)!=(f|0)){q=w[e|0];t[c|0]=q>>>0>32?q:32;c=c+1|0;e=e+1|0;continue}break}sg(d+80|0,16651);v[23296]=0;b=W(530,d+48|0,b|0,f|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break g}v[23296]=0;U(11,d- -64|0,1,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break f}v[23296]=0;U(133,d+160|0,d+80|0,d- -64|0);c=v[23296];v[23296]=0;if((c|0)==1){break e}c=d+160|0;Hb(a+1298344|0,c);zb(c);zb(d- -64|0);yb(b);ec(d+80|0);b=Vb(c,12176);Hb(a+1298356|0,b);zb(b);b=v[m>>2];if(b){wl(a+1298368|0,b)}v[a+1298404>>2]=13}g=E>>>0<=K>>>0;break a}h=P()|0;O()|0;break c}h=P()|0;O()|0;break d}h=P()|0;O()|0;zb(d- -64|0)}yb(b)}ec(d+80|0)}S(h|0);L()}else{i=B(g,104)+a|0;f=i+484380|0;r=hA(b,d+176|0,f,((g<<5)+a|0)+946304|0,x[p>>1]==4);f=v[f>>2];L:{if(e){t[i+484417|0]=0-(w[d+200|0]<<3);break L}n=f>>>0<65536&n}i=Mb(x[d+198>>1]);M:{if(i){X=!Mb(x[d+204>>1])|X;break M}Y=w[d+201|0]==64|Y}o=h&1;h=0;N:{if(!o){break N}k=(i<<1)+k|0;o=w[d+200|0];h=!o;if(o|!i){break N}h=w[d+201|0]==64}E=r+E|0;j=f+j|0;g=g+1|0;continue}}jb=d+336|0;return g|0}function n6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=C(0),g=C(0),h=C(0),i=0,j=C(0),k=C(0),l=0,m=0,n=0,o=C(0),p=0,q=0,r=0,s=0,u=0,x=C(0),y=C(0),A=0,B=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=C(0),Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=C(0),Z=0,_=0,$=C(0);a:{if(!w[a+5046|0]){break a}g=z[a+4268>>2];pK(a);if(g==z[a+4268>>2]){break a}xx(a)}b:{if(!w[a+5045|0]){break b}if(!Vh(a+44|0)){break b}i=v[a+44>>2];p=Fc(i,0);q=Fc(i,1);i=v[a+56>>2];l=Fc(i,0);m=Fc(i,1);c:{if(!(!w[a+5044|0]|(!d|w[a+4264|0]&2))){z[l>>2]=z[a+5036>>2];z[m>>2]=z[a+5040>>2];t[a+5044|0]=0;q=q+4|0;p=p+4|0;m=m+4|0;l=l+4|0;n=d-1|0;break c}n=d}r=n;s=a+4888|0;u=a+4864|0;U=a+4504|0;V=a+4960|0;W=a+4868|0;X=a+4892|0;D=a+4628|0;E=a+4604|0;Q=a+4916|0;F=a+4532|0;G=a+4508|0;H=a+4772|0;I=a+4748|0;R=a+4940|0;J=a+4676|0;K=a+4652|0;L=a+4724|0;M=a+4700|0;S=a+4844|0;N=a+4580|0;O=a+4556|0;T=a+4820|0;d:{while(1){if(!r){break d}g=z[p>>2];g=C(C(C(z[a+5008>>2]-g)*z[a+4276>>2])+g);z[a+5008>>2]=g;_=Lc(v[a+4864>>2],v[W>>2],v[a+4880>>2]),$=g,z[_>>2]=$;g=z[q>>2];g=C(C(C(z[a+5012>>2]-g)*z[a+4276>>2])+g);z[a+5012>>2]=g;_=Lc(v[a+4888>>2],v[X>>2],v[a+4904>>2]),$=g,z[_>>2]=$;g=C(C(C(C(C(Lh(u,v[a+4356>>2])*C(.6800000071525574))+C(Lh(u,v[a+4360>>2])*C(-.5)))-C(Lh(u,v[a+4364>>2])*C(.6200000047683716)))+C(Lh(u,v[a+4368>>2])*C(-.5)))-C(Lh(u,v[a+4372>>2])*C(.6200000047683716)));if(t[a+4264|0]&1){e=g;g=C(z[Lc(v[a+4816>>2],v[T>>2],v[a+4836>>2])>>2]+C(e*C(.6180340051651001)));_=Lc(v[a+4816>>2],v[T>>2],v[a+4832>>2]),$=C(e-C(g*C(.6180340051651001))),z[_>>2]=$}x=z[a+4280>>2];_=a,$=C(Lh(u,v[a+4352>>2])+z[a+5020>>2]),z[_+5020>>2]=$;e=C(Lh(s,v[a+4376>>2])+z[a+5024>>2]);z[a+5024>>2]=e;f=z[a+5020>>2];h=C(C(C(z[a+4980>>2]-z[Lc(v[a+4624>>2],v[D>>2],v[a+4644>>2])>>2])*z[a+4444>>2])+z[Lc(v[a+4624>>2],v[D>>2],v[a+4644>>2])>>2]);z[a+4980>>2]=h;P=C(h*z[a+4440>>2]);k=C(e*C(.7070000171661377));j=C(f*C(-.7070000171661377));f=C(k+j);h=z[a+4272>>2];e=C(P+C(f*h));_=Lc(v[a+4624>>2],v[D>>2],v[a+4640>>2]),$=C(f-C(h*e)),z[_>>2]=$;f=C(C(C(z[a+4976>>2]-z[Lc(v[a+4600>>2],v[E>>2],v[a+4620>>2])>>2])*z[a+4436>>2])+z[Lc(v[a+4600>>2],v[E>>2],v[a+4620>>2])>>2]);z[a+4976>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4432>>2])+C(e*h));_=Lc(v[a+4600>>2],v[E>>2],v[a+4616>>2]),$=C(e-C(h*f)),z[_>>2]=$;y=C(C(e*C(-.15000000596046448))+C(f*C(-.20000000298023224)));if(t[a+4264|0]&1){e=C(C(C(z[a+4972>>2]-z[Lc(v[a+4576>>2],v[N>>2],v[a+4596>>2])>>2])*z[a+4428>>2])+z[Lc(v[a+4576>>2],v[N>>2],v[a+4596>>2])>>2]);z[a+4972>>2]=e;h=z[a+4272>>2];e=C(C(e*z[a+4424>>2])+C(f*h));_=Lc(v[a+4576>>2],v[N>>2],v[a+4592>>2]),$=C(f-C(h*e)),z[_>>2]=$;f=C(C(C(z[a+4968>>2]-z[Lc(v[a+4552>>2],v[O>>2],v[a+4572>>2])>>2])*z[a+4420>>2])+z[Lc(v[a+4552>>2],v[O>>2],v[a+4572>>2])>>2]);z[a+4968>>2]=f;h=z[a+4272>>2];f=C(C(f*z[a+4416>>2])+C(e*h));_=Lc(v[a+4552>>2],v[O>>2],v[a+4568>>2]),$=C(e-C(h*f)),z[_>>2]=$;y=C(C(C(e*C(.3499999940395355))+y)+C(f*C(-.3799999952316284)))}_=Lc(v[a+4912>>2],v[Q>>2],v[a+4928>>2]),$=f,z[_>>2]=$;e=C(z[Lc(v[a+4912>>2],v[Q>>2],v[a+4932>>2])>>2]*z[a+4496>>2]);z[a+5028>>2]=C(C(z[a+5028>>2]-e)*z[a+4500>>2])+e;e=C(C(C(z[a+4964>>2]-z[Lc(v[a+4528>>2],v[F>>2],v[a+4548>>2])>>2])*z[a+4412>>2])+z[Lc(v[a+4528>>2],v[F>>2],v[a+4548>>2])>>2]);z[a+4964>>2]=e;f=z[a+5028>>2];o=z[a+4272>>2];h=C(C(f*o)+C(e*z[a+4408>>2]));_=Lc(v[a+4528>>2],v[F>>2],v[a+4544>>2]),$=C(f-C(o*h)),z[_>>2]=$;e=C(C(C(z[a+4960>>2]-z[Lc(v[a+4504>>2],v[G>>2],v[a+4524>>2])>>2])*z[a+4404>>2])+z[Lc(v[a+4504>>2],v[G>>2],v[a+4524>>2])>>2]);z[a+4960>>2]=e;f=C(e*z[a+4400>>2]);e=z[a+4272>>2];o=C(f+C(h*e));_=Lc(v[a+4504>>2],v[G>>2],v[a+4520>>2]),$=C(h-C(e*o)),z[_>>2]=$;z[a+5020>>2]=o;e=C(C(C(C(C(Lh(s,v[a+4380>>2])*C(.7070000171661377))+C(Lh(s,v[a+4384>>2])*C(-.6000000238418579)))-C(Lh(s,v[a+4388>>2])*C(.5)))+C(Lh(s,v[a+4392>>2])*C(-.6000000238418579)))-C(Lh(s,v[a+4396>>2])*C(.5)));if(t[a+4264|0]&1){f=e;e=C(z[Lc(v[a+4840>>2],v[S>>2],v[a+4860>>2])>>2]+C(e*C(.6180340051651001)));_=Lc(v[a+4840>>2],v[S>>2],v[a+4856>>2]),$=C(f-C(e*C(.6180340051651001))),z[_>>2]=$}Y=z[a+4280>>2];f=C(C(C(z[a+5004>>2]-z[Lc(v[a+4768>>2],v[H>>2],v[a+4788>>2])>>2])*z[a+4492>>2])+z[Lc(v[a+4768>>2],v[H>>2],v[a+4788>>2])>>2]);z[a+5004>>2]=f;P=C(f*z[a+4488>>2]);f=C(j-k);j=z[a+4272>>2];k=C(P+C(f*j));_=Lc(v[a+4768>>2],v[H>>2],v[a+4784>>2]),$=C(f-C(j*k)),z[_>>2]=$;f=C(C(C(z[a+5e3>>2]-z[Lc(v[a+4744>>2],v[I>>2],v[a+4764>>2])>>2])*z[a+4484>>2])+z[Lc(v[a+4744>>2],v[I>>2],v[a+4764>>2])>>2]);z[a+5e3>>2]=f;j=z[a+4272>>2];f=C(C(f*z[a+4480>>2])+C(k*j));_=Lc(v[a+4744>>2],v[I>>2],v[a+4760>>2]),$=C(k-C(j*f)),z[_>>2]=$;k=C(C(C(h*C(.3799999952316284))+C(k*C(-.15000000596046448)))+C(f*C(-.20000000298023224)));if(t[a+4264|0]&1){h=C(C(C(z[a+4996>>2]-z[Lc(v[a+4720>>2],v[L>>2],v[a+4740>>2])>>2])*z[a+4476>>2])+z[Lc(v[a+4720>>2],v[L>>2],v[a+4740>>2])>>2]);z[a+4996>>2]=h;j=z[a+4272>>2];h=C(C(h*z[a+4472>>2])+C(f*j));_=Lc(v[a+4720>>2],v[L>>2],v[a+4736>>2]),$=C(f-C(j*h)),z[_>>2]=$;f=C(C(C(z[a+4992>>2]-z[Lc(v[a+4696>>2],v[M>>2],v[a+4716>>2])>>2])*z[a+4468>>2])+z[Lc(v[a+4696>>2],v[M>>2],v[a+4716>>2])>>2]);z[a+4992>>2]=f;j=z[a+4272>>2];f=C(C(f*z[a+4464>>2])+C(h*j));_=Lc(v[a+4696>>2],v[M>>2],v[a+4712>>2]),$=C(h-C(j*f)),z[_>>2]=$;k=C(C(C(h*C(.3499999940395355))+k)+C(f*C(-.3799999952316284)))}Z=q+4|0;n=p+4|0;h=C(g*x);y=C(y-C(o*C(.3799999952316284)));o=C(e*Y);_=Lc(v[a+4936>>2],v[R>>2],v[a+4952>>2]),$=f,z[_>>2]=$;g=C(z[Lc(v[a+4936>>2],v[R>>2],v[a+4956>>2])>>2]*z[a+4496>>2]);z[a+5032>>2]=C(C(z[a+5032>>2]-g)*z[a+4500>>2])+g;g=C(C(C(z[a+4988>>2]-z[Lc(v[a+4672>>2],v[J>>2],v[a+4692>>2])>>2])*z[a+4460>>2])+z[Lc(v[a+4672>>2],v[J>>2],v[a+4692>>2])>>2]);z[a+4988>>2]=g;e=z[a+5032>>2];f=z[a+4272>>2];g=C(C(e*f)+C(g*z[a+4456>>2]));_=Lc(v[a+4672>>2],v[J>>2],v[a+4688>>2]),$=C(e-C(f*g)),z[_>>2]=$;f=z[a+4284>>2];e=C(C(C(z[a+4984>>2]-z[Lc(v[a+4648>>2],v[K>>2],v[a+4668>>2])>>2])*z[a+4452>>2])+z[Lc(v[a+4648>>2],v[K>>2],v[a+4668>>2])>>2]);z[a+4984>>2]=e;x=z[a+4272>>2];e=C(C(e*z[a+4448>>2])+C(g*x));_=Lc(v[a+4648>>2],v[K>>2],v[a+4664>>2]),$=C(g-C(x*e)),z[_>>2]=$;z[a+5024>>2]=e;e=C(-e);x=z[a+4288>>2];i=U;e:{f:{while(1){if((i|0)==(V|0)){g:{e=C(o+C(C(C(e*C(.3799999952316284))+k)*x));g=C(h+C(C(C(g*C(.3799999952316284))+y)*f));if(!(w[a+4264|0]&2)){break g}p=n;n=Z;break f}}else{A=v[i+16>>2];B=A-1|0;v[i+16>>2]=B;if((A|0)<=0){v[i+16>>2]=B+v[i+12>>2]}A=v[i+20>>2];B=A-1|0;v[i+20>>2]=B;if((A|0)<=0){v[i+20>>2]=B+v[i+12>>2]}i=i+24|0;continue}break}z[l>>2]=C(g+z[a+5036>>2])*C(.5);z[m>>2]=C(e+z[a+5040>>2])*C(.5);z[a+5040>>2]=e;z[a+5036>>2]=g;if((r|0)==1){break e}r=r-1|0;p=p+8|0;m=m+4|0;l=l+4|0;n=q+8|0}q=n;z[l>>2]=g;z[m>>2]=e;r=r-1|0;m=m+4|0;l=l+4|0;continue}break}t[a+5044|0]=1}n=a;a=v[a+56>>2];ji(n,b,c,Fc(a,0),Fc(a,1),d)}}function Ada(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=jb-288|0;jb=g;e=jb-128|0;jb=e;f=ie(g+104|0,c);v[23296]=0;n=T(162,f+20|0)|0;c=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{if((c|0)!=1){v[23296]=0;p=T(162,f+40|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break B}v[23296]=0;q=T(162,f+60|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break A}v[23296]=0;i=T(162,f+80|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break z}v[23296]=0;o=T(162,f+100|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break y}v[23296]=0;k=T(162,f+120|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break x}j=Qb(f+140|0);Ac(f);v[f+172>>2]=1873739776;u[f+176>>1]=0;v[23296]=0;d=Q(722,f|0,e+112|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break w}if(!d){break n}d=v[e+112>>2];if((d|0)!=1414744396&(d|0)!=1179011410){break n}c=v[e+120>>2];if((c|0)!=1163280727&(c|0)!=1702257015){break n}t[f+176|0]=(d|0)==1414744396;v[23296]=0;U(723,e+96|0,f|0,2);c=v[23296];v[23296]=0;if((c|0)==1){break v}h=v[e+96>>2];C:{if(wq(h,v[e+100>>2])>>>0<4){break C}c=Xx(h,1);d=v[c+4>>2];c=v[c>>2];yi(e+40|0,c,d);if(v[e+40>>2]!=1635017060){break C}yi(e- -64|0,c,d);if(!(t[e+68|0]&1)){break C}c=Xx(h,2);yi(e+24|0,v[c>>2],v[c+4>>2]);if(v[e+28>>2]){break C}c=Xx(h,3);yi(e+88|0,v[c>>2],v[c+4>>2]);if(v[e+88>>2]){break C}v[23296]=0;Q(143,f|0,12)|0;c=v[23296];v[23296]=0;if((c|0)==1){break u}v[23296]=0;U(723,e+40|0,f|0,1);c=v[23296];v[23296]=0;if((c|0)==1){break t}c=e+40|0;Ft(e+96|0,c);_d(c)}v[23296]=0;U(724,e- -64|0,e+96|0,544501094);c=v[23296];v[23296]=0;if((c|0)==1){break s}v[23296]=0;d=Q(725,e- -64|0,f+156|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break k}if(!d){break o}d=x[f+156>>1];if((d|0)!=1){break q}v[23296]=0;d=T(190,e- -64|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break r}break k}d=P()|0;O()|0;break b}d=P()|0;O()|0;break c}d=P()|0;O()|0;break d}d=P()|0;O()|0;break e}d=P()|0;O()|0;break f}d=P()|0;O()|0;break g}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}if((d|0)==4){v[23296]=0;h=T(185,e- -64|0)|0;c=v[23296];v[23296]=0;D:{if((c|0)!=1){v[23296]=0;d=T(185,e- -64|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break D}if((h|0)!=2|(d|0)!=1){break p}t[f+177|0]=1;break p}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=x[f+156>>1]}if((d&65535)!=65534){break p}v[23296]=0;d=Q(726,e- -64|0,e+40|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break l}if(!d){break o}c=v[e+60>>2];v[e+16>>2]=v[e+56>>2];v[e+20>>2]=c;c=v[e+52>>2];v[e+8>>2]=v[e+48>>2];v[e+12>>2]=c;c=e+24|0;v[c>>2]=w[e+8|0]|w[e+9|0]<<8|(w[e+10|0]<<16|w[e+11|0]<<24);u[c+4>>1]=w[e+12|0]|w[e+13|0]<<8;u[c+6>>1]=w[e+14|0]|w[e+15|0]<<8;r=c,s=Wz(w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24),w[e+20|0]|w[e+21|0]<<8|(w[e+22|0]<<16|w[e+23|0]<<24)),v[r+8>>2]=s;v[c+12>>2]=mb;u[f+172>>1]=v[c>>2]}v[23296]=0;U(724,e+40|0,e+96|0,1635017060);c=v[23296];v[23296]=0;E:{F:{G:{H:{I:{J:{if((c|0)!=1){c=e+40|0;m=cd(n,c);Ab(c);c=v[m>>2];v[23296]=0;d=T(166,c|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break k}if(!d){v[23296]=0;U(724,e+40|0,e+96|0,544039792);c=v[23296];v[23296]=0;if((c|0)==1){break J}c=e+40|0;cd(m,c);Ab(c)}v[23296]=0;U(724,e+40|0,e+96|0,1952670054);c=v[23296];v[23296]=0;if((c|0)==1){break I}v[23296]=0;d=T(145,e+40|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break H}v[f+152>>2]=d;Ab(e+40|0);if(v[f+152>>2]?x[f+156>>1]==17:0){break E}h=x[f+158>>1];d=NL(h,x[f+170>>1]);if(!d){break E}c=x[f+168>>1];if((c>>>0)/(h>>>0)>>>0<d<<1>>>0?c:0){break G}c=v[m>>2];v[23296]=0;d=T(148,c|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break k}c=NL(x[f+158>>1],x[f+170>>1]);break F}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0;Ab(e+40|0);break j}c=v[m>>2];v[23296]=0;d=T(148,c|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break k}c=x[f+168>>1]}v[f+152>>2]=(d>>>0)/((c&65535)>>>0)}v[23296]=0;d=Q(727,f|0,e+96|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break k}u[f+174>>1]=d;v[23296]=0;R(728,f|0,e+96|0);c=v[23296];v[23296]=0;if((c|0)==1){break k}v[23296]=0;U(724,e+40|0,e+96|0,1886221175);c=v[23296];v[23296]=0;if((c|0)==1){break m}c=e+40|0;cd(o,c);Ab(c)}Ab(e- -64|0);_d(e+96|0)}jb=e+128|0;break a}d=P()|0;O()|0;break j}d=P()|0;O()|0;break j}d=P()|0;O()|0}Ab(e- -64|0)}_d(e+96|0)}_d(j);Ab(k)}Ab(o)}Ab(i)}Ab(q)}Ab(p)}Ab(n)}Ab(f);S(d|0);L()}c=v[f+20>>2];v[23296]=0;d=T(665,c|0)|0;c=v[23296];v[23296]=0;K:{L:{if((c|0)!=1){M:{if(!d|(x[f+158>>1]-3&65535)>>>0<65534){break M}N:{O:{c=x[f+170>>1];P:{if(!c){if((Xj(f)|0)==85){break P}break M}if(c>>>0>31){break O}}if((Xj(f)|0)!=3){break N}break M}if(c>>>0>64){break M}}d=Xj(f);c=30080;while(1){Q:{R:{if((c|0)!=30104){if((d|0)!=v[c>>2]){break R}}else{c=30104}break Q}c=c+4|0;continue}break}if((c|0)==30104){break M}ft(a,b);v[23296]=0;d=Q(54,g+88|0,21473)|0;c=v[23296];v[23296]=0;S:{T:{U:{V:{W:{if((c|0)!=1){h=Ec(((b<<5)+a|0)+946304|0,d);yb(d);v[23296]=0;d=B(b,104)+a|0;i=d+484380|0;R(264,i|0,0);c=v[23296];v[23296]=0;if((c|0)==1){break W}v[i>>2]=v[f+152>>2];v[d+484404>>2]=v[f+160>>2];c=v[a+1298404>>2];v[23296]=0;X(666,f|0,i|0,c|0,h|0);c=v[23296];v[23296]=0;if((c|0)==1){break W}ie(g- -64|0,f+20|0);d=x[f+158>>1];j=_c(g+56|0,8,d>>>0>1?2:1,0,0);c=Xj(f);if((c|0)!=17|d>>>0>2){break U}yc(i,268435456);c=B(b,104)+a|0;b=c+484414|0;u[b>>1]=x[b>>1]&65470|((d|0)==2)<<6|1;if(Bg(i)){break V}break S}l=P()|0;O()|0;break K}l=P()|0;O()|0;break K}j=v[c+484400>>2];h=v[i>>2];k=ie(g+32|0,g- -64|0);d=x[f+158>>1];c=x[f+168>>1];v[23296]=0;b=v[k+12>>2];v[g+16>>2]=v[k+8>>2];v[g+20>>2]=b;v[g+24>>2]=v[k+16>>2];b=v[k+4>>2];v[g+8>>2]=v[k>>2];v[g+12>>2]=b;da(667,j|0,h|0,g+8|0,c|0,d|0);b=v[23296];v[23296]=0;if((b|0)==1){break L}mj(i,a);break T}if((c|0)==85){v[23296]=0;c=W(511,a|0,b|0,g- -64|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break L}if(c){break T}break S}X:{Y:{Z:{if(CP(x[f+156>>1])){break Z}_:{if(!Rd(w[f+177|0])){break _}if((Xj(f)|0)!=1|x[f+170>>1]!=32|x[f+168>>1]!=d<<2){break _}Fh(j,32);b=12;break Y}if((Xj(f)|0)!=1|x[f+170>>1]!=24|x[f+168>>1]!=d<<2){break Z}Fh(j,32);b=13;break Y}if((Xj(f)&65534)!=6){break X}Fh(j,16);b=(Xj(f)|0)==6?17:16}Sf(j,b);v[23296]=0;W(207,j|0,i|0,g- -64|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break T}break L}d=x[f+170>>1];c=(d-1>>>3|0)-1|0;b=c<<3;h=b&31;Fh(j,(c>>>0<7?(b&63)>>>0>=32?4196360>>>h|0:((1<<h)-1&4196360)<<32-h|136321040>>>h:8)&255);if(d>>>0<9){Sf(j,1)}if((Xj(f)|0)==3){Sf(j,3)}v[23296]=0;W(207,j|0,i|0,g- -64|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break L}}vz(i,v[a+480180>>2]);mj(i,a);l=1}Ab(g- -64|0)}BP(f);jb=g+288|0;return l|0}l=P()|0;O()|0;break K}l=P()|0;O()|0;Ab(g- -64|0)}BP(f);S(l|0);L()}function HI(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=jb-272|0;jb=h;a:{b:{if(g){Je(h+256|0,f,32);v[23296]=0;W(477,h+240|0,f|0,32)|0;k=v[23296];v[23296]=0;if((k|0)!=1){break b}f=P()|0;O()|0;break a}Kb(h+256|0);Kb(h+240|0)}c:{d:{e:{f:{g:{h:{i:{j:{if(es(c)){k=v[b+24>>2];i=v[k+484344>>2];if(oe(i,v[k+484348>>2],c&65535)){break j}}v[23296]=0;U(1033,a|0,h+256|0,h+240|0);a=v[23296];v[23296]=0;if((a|0)!=1){break i}f=P()|0;O()|0;break c}c=$b(i,c);if(!(!((e|0)<0|v[c+12>>2]<=(d|0)|(d|0)<0)&x[k+480188>>1]>e>>>0)){v[23296]=0;U(1033,a|0,h+256|0,h+240|0);a=v[23296];v[23296]=0;if((a|0)!=1){break i}f=P()|0;O()|0;break c}c=fd(v[c>>2],v[v[c+48>>2]+12>>2],d,e&65535);Nf(h+256|0);Nf(h+240|0);k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{d=w[c|0];if(!Uc(d)){if(!wp(d)){break A}}e=w[c+1|0];k=v[b+24>>2];v[23296]=0;X(1034,h+208|0,k|0,d|0,e|0);d=v[23296];v[23296]=0;e=1;if((d|0)==1){break y}v[23296]=0;R(962,h+224|0,h+208|0);d=v[23296];v[23296]=0;if((d|0)!=1){break z}f=P()|0;O()|0;break v}e=0;v[23296]=0;Q(54,h+224|0,16584)|0;d=v[23296];v[23296]=0;if((d|0)==1){break x}}v[23296]=0;k=Q(753,h+256|0,h+224|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break w}yb(h+224|0);if(e){zb(h+208|0)}e=9860;d=w[c|0];if(!Uc(d)){e=wp(d)?10170:16584}v[23296]=0;d=Q(54,h+224|0,e|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break u}v[23296]=0;e=Q(753,h+240|0,d|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break t}yb(d);if(f-6>>>0>4294967290){break l}v[23296]=0;d=Q(54,h+192|0,17644)|0;i=v[23296];v[23296]=0;if((i|0)==1){break s}v[23296]=0;i=Q(753,k|0,d|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break r}yb(d);v[23296]=0;d=Q(54,h+176|0,17644)|0;l=v[23296];v[23296]=0;if((l|0)==1){break q}v[23296]=0;l=Q(753,e|0,d|0)|0;j=v[23296];v[23296]=0;if((j|0)==1){break p}yb(d);d=c+1|0;B:{if(w[c+1|0]){v[23296]=0;R(495,h+160|0,d|0);j=v[23296];v[23296]=0;if((j|0)!=1){break B}break d}v[23296]=0;Q(54,h+160|0,16589)|0;j=v[23296];v[23296]=0;if((j|0)==1){break d}}v[23296]=0;j=Q(753,i|0,h+160|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break o}i=h+160|0;yb(i);d=w[d|0];v[23296]=0;d=Q(54,i|0,(d?10660:16589)|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break n}v[23296]=0;l=Q(753,l|0,d|0)|0;i=v[23296];v[23296]=0;if((i|0)!=1){break m}f=P()|0;O()|0;yb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(h+224|0);if(!e){break c}}zb(h+208|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(d);break c}f=P()|0;O()|0;yb(h+160|0);break c}f=P()|0;O()|0;break c}yb(d);if(f-9>>>0>4294967287){break l}C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{i=Sg(w[c|0]);O:{if(i){v[23296]=0;m=Q(54,h+128|0,17644)|0;d=v[23296];v[23296]=0;if((d|0)==1){break N}d=w[c+4|0];n=w[c+2|0];v[23296]=0;o=h,p=Tj(n,d)&255,v[o+96>>2]=p;R(494,h+112|0,h+96|0);d=v[23296];v[23296]=0;if((d|0)==1){break M}d=0;v[23296]=0;U(919,h+144|0,m|0,h+112|0);m=v[23296];v[23296]=0;if((m|0)!=1){break O}f=P()|0;O()|0;break G}d=w[c+2|0];if(d){d=FL(v[v[v[b+24>>2]+8>>2]+88>>2],d);v[23296]=0;d=W(477,h+128|0,1,d|0)|0;m=v[23296];v[23296]=0;if((m|0)==1){break E}v[23296]=0;R(495,h+112|0,c+4|0);m=v[23296];v[23296]=0;if((m|0)==1){break L}v[23296]=0;U(919,h+144|0,d|0,h+112|0);m=v[23296];v[23296]=0;d=1;if((m|0)!=1){break O}f=P()|0;O()|0;break J}d=0;v[23296]=0;Q(54,h+144|0,16588)|0;m=v[23296];v[23296]=0;if((m|0)==1){break e}}v[23296]=0;j=Q(753,j|0,h+144|0)|0;m=v[23296];v[23296]=0;if((m|0)==1){break K}yb(h+144|0);if(d){yb(h+112|0);yb(h+128|0)}if(i){yb(h+112|0);yb(h+128|0)}d=5449;if(!Sg(w[c|0])){d=w[c+2|0]?5445:16588}v[23296]=0;d=Q(54,h+144|0,d|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break D}v[23296]=0;i=Q(753,l|0,d|0)|0;l=v[23296];v[23296]=0;if((l|0)!=1){break C}f=P()|0;O()|0;yb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break F}f=P()|0;O()|0;break I}f=P()|0;O()|0;yb(h+144|0);if(!d){break H}}yb(h+112|0)}yb(h+128|0)}if(!i){break c}}yb(h+112|0)}yb(h+128|0);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}yb(d);if(f-13>>>0>4294967283){break l}v[23296]=0;d=Q(54,h+96|0,17644)|0;l=v[23296];v[23296]=0;P:{Q:{R:{S:{T:{U:{V:{W:{X:{Y:{Z:{if((l|0)!=1){v[23296]=0;l=Q(753,j|0,d|0)|0;j=v[23296];v[23296]=0;if((j|0)==1){break Z}yb(d);v[23296]=0;d=Q(54,h+80|0,17644)|0;j=v[23296];v[23296]=0;if((j|0)==1){break Y}v[23296]=0;i=Q(753,i|0,d|0)|0;j=v[23296];v[23296]=0;if((j|0)==1){break X}yb(d);_:{if(Sg(w[c|0])){d=w[c+5|0];j=w[c+3|0];b=0;v[23296]=0;o=h,p=Tj(j,d)&4095,v[o+16>>2]=p;R(1035,h- -64|0,h+16|0);d=v[23296];v[23296]=0;if((d|0)!=1){break _}f=P()|0;O()|0;break c}d=w[c+3|0];if(d){b=EL(v[v[v[b+24>>2]+8>>2]+84>>2],d);v[23296]=0;b=W(477,h+48|0,1,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break W}v[23296]=0;R(495,h+32|0,c+5|0);d=v[23296];v[23296]=0;if((d|0)==1){break V}v[23296]=0;U(919,h- -64|0,b|0,h+32|0);d=v[23296];v[23296]=0;b=1;if((d|0)!=1){break _}f=P()|0;O()|0;break S}b=0;v[23296]=0;Q(54,h- -64|0,16584)|0;d=v[23296];v[23296]=0;if((d|0)==1){break U}}v[23296]=0;Q(753,l|0,h- -64|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break T}yb(h- -64|0);if(b){yb(h+32|0);yb(h+48|0)}b=11024;if(!Sg(w[c|0])){b=w[c+3|0]?11024:16584}v[23296]=0;b=Q(54,h- -64|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break Q}v[23296]=0;Q(753,i|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break P}f=P()|0;O()|0;yb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(d);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break R}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(h- -64|0);if(!b){break c}}yb(h+32|0)}yb(h+48|0);break c}f=P()|0;O()|0;break c}yb(b);if(!f){break k}}$:{aa:{ba:{ca:{b=Fb(k);da:{if(b>>>0>f>>>0){v[23296]=0;X(118,h+16|0,k|0,0,f|0);b=v[23296];v[23296]=0;if((b|0)!=1){b=h+16|0;Bc(k,b);yb(b);break da}f=P()|0;O()|0;break c}if(!g){break da}v[23296]=0;b=W(477,h+16|0,f-b|0,32)|0;c=v[23296];v[23296]=0;if((c|0)==1){break ca}v[23296]=0;Q(753,k|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break ba}yb(b)}b=Fb(e);if(b>>>0<=f>>>0){break $}v[23296]=0;X(118,h|0,e|0,0,f|0);b=v[23296];v[23296]=0;if((b|0)==1){break aa}Bc(e,h);yb(h);break k}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(b);break c}f=P()|0;O()|0;break c}if(!g){break k}v[23296]=0;b=W(477,h|0,f-b|0,32)|0;c=v[23296];v[23296]=0;if((c|0)==1){break h}v[23296]=0;Q(753,e|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break g}yb(b)}v[23296]=0;U(1033,a|0,k|0,e|0);a=v[23296];v[23296]=0;if((a|0)==1){break f}}yb(h+240|0);yb(h+256|0);jb=h+272|0;return}f=P()|0;O()|0;break c}f=P()|0;O()|0;yb(b);break c}f=P()|0;O()|0;break c}f=P()|0;O()|0;break c}f=P()|0;O()|0}yb(h+240|0)}yb(h+256|0);S(f|0);L()}function Iha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;f=jb-1344|0;jb=f;Ac(b);d=jb-16|0;jb=d;k=f+768|0;kT(d+8|0,k);g=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);j=v[d+4>>2];if((j|0)==(g|0)){ac(b,v[d+12>>2])}jb=d+16|0;d=(g|0)==(j|0);if(!d){jT(k)}a:{if(!d){break a}if(!mT(f+768|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Vc(lT(x[f+802>>1],x[f+804>>1]),mb))){break a}if(!c){e=1;break a}q=Cc(f+760|0);b:{while(1){if((e|0)!=32){d=(e<<5)+a|0;g=d+480280|0;Te(g);k=(f+768|0)+(e<<4)|0;u[d+480284>>1]=((w[k+78|0]<<8&65280)>>>0)/255;l=f+496|0;ek(l,1,k- -64|0);j=f+112|0;Gc(j,l);wm(d+480289|0,j);yb(j);c:{d:{switch(w[k+79|0]){case 0:m=i+1|0;break c;case 1:v[g>>2]=1024;m=e+1|0;break c;case 2:break d;default:break b}}v[g>>2]=1024;d=f+112|0;tk(d,q,e);nm(d)}i=i+1|0;e=e+1|0;continue}break}Ed(a,33554432);u[a+480188>>1]=m&255;d=f+112|0;i=Vb(d,6734);Hb(a+1298344|0,i);zb(i);d=Vb(d,11e3);Hb(a+1298356|0,d);zb(d);v[a+1298404>>2]=5;e:{if(w[f+847|0]){break e}e=1;j=1;while(1){if((e|0)==16){while(1){if((j|0)==16){break e}d=((j<<5)+a|0)+480280|0;v[d>>2]=v[d>>2]&-1025;j=j+1|0;continue}}d=e<<4;e=e+1|0;if(w[(d+f|0)+847|0]==1){continue}break}}d=f+496|0;Ze(d,1,f+768|0);i=f+112|0;Gc(i,d);Bc(a+1298308|0,i);yb(i);v[a+480208>>2]=v[a+480208>>2]&-17|x[f+806>>1]<<4&16;v[a+480196>>2]=w[f+816|0];v[a+480204>>2]=B(w[f+817|0],1e4);v[a+480200>>2]=w[f+818|0]<<2;v[a+480228>>2]=w[f+819|0];i=x[f+804>>1];u[a+480190>>1]=0;u[a+480192>>1]=i;Su(b,d);Kq(Zb(v[a+484360>>2],w[a+484376|0]),d,x[f+800>>1],65535,255);r=c&1;if(r){mg(a+484344|0,x[f+802>>1])}o=a+484344|0;z=a+480188|0;f:{while(1){g:{if(x[f+802>>1]<=h>>>0){m=c&2;l=f+108|0;q=a+480192|0;i=1;c=0;h:while(1){if(x[q>>1]<=(c&65535)>>>0){e=32;break b}c=c+1|0;e=TB(a,c&65535,0);g=!e;d=jb-16|0;jb=d;k=f+112|0;ic(d+8|0,k,384);h=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);j=v[d+4>>2];if((j|0)==(h|0)){ac(b,v[d+12>>2])}jb=d+16|0;d=(h|0)==(j|0);if(!d){Xb(k,0,384)}if(!d|g){continue}k=i&65535;h=jb-32|0;jb=h;g=f+112|0;Ze(h,1,g);d=h+16|0;Gc(d,h);Ec(e+492|0,d);yb(d);i:{if(!(w[g+378|0]|w[g+379|0]<<8)){break i}j=e+236|0;d=0;while(1){v[h+16>>2]=120;v[h>>2]=116;if(y[Ib(h+16|0,h)>>2]<=d>>>0){break i}A=dc(j,d+12|0),C=k+w[(d+g|0)+32|0]|0,u[A>>1]=C;d=d+1|0;continue}}d=w[g+376|0]|w[g+377|0]<<8;t[e+33|0]=1;v[e>>2]=d;WA(g,e+48|0,0);WA(g,e+68|0,1);WA(g,e+88|0,2);d=w[e+100|0];if(d&1){t[e+100|0]=d|16}if(!(v[e>>2]|t[e+60|0]&1)){v[e>>2]=32767}jb=h+32|0;e=0;while(1){d=x[f+490>>1];if(d>>>0<=e>>>0){i=d+i|0;continue h}QT(b,f+48|0);j:{k:{if(Pb(l,15356,4)){break k}d=e+i|0;k=d&65535;if(k>>>0>3999){break k}u[a+480190>>1]=d;g=jb-32|0;jb=g;j=B(k,104)+a|0;d=j+484380|0;pd(d,0);Uh(g,1,f+48|0);h=g+16|0;Gc(h,g);ze(d+43|0,h);yb(h);o=w[f+64|0]|w[f+65|0]<<8|(w[f+66|0]<<16|w[f+67|0]<<24);v[d>>2]=o;p=w[f+68|0]|w[f+69|0]<<8|(w[f+70|0]<<16|w[f+71|0]<<24);v[d+4>>2]=p;n=w[f+72|0]|w[f+73|0]<<8|(w[f+74|0]<<16|w[f+75|0]<<24);v[d+8>>2]=n;v[d+24>>2]=w[f+76|0]|w[f+77|0]<<8|(w[f+78|0]<<16|w[f+79|0]<<24);u[d+30>>1]=w[f+80|0]<<2;u[d+28>>1]=w[f+81|0];h=w[f+96|0];if(h&1){u[d+34>>1]=x[d+34>>1]|2;h=w[f+96|0]}if(h&2){u[d+34>>1]=x[d+34>>1]|4;h=w[f+96|0]}if(h&4){v[d+8>>2]=n>>>1;v[d+4>>2]=p>>>1;v[d>>2]=o>>>1;u[d+34>>1]=x[d+34>>1]|1;h=w[f+96|0]}if(h&8){u[d+34>>1]=x[d+34>>1]|32}jb=g+32|0;h=jb-16|0;jb=h;av(h+8|0,j+484423|0);g=f+24|0;Rq(g,v[h+8>>2],v[h+12>>2]);jb=h+16|0;Ec(((k<<5)+a|0)+946304|0,g);yb(g);h=v[f+64>>2];if(!h){break k}Yd(f,b,h);h=jc(f+24|0,f);Ab(f);if(m){g=_c(f,u[j+484414>>1]&1?16:8,1,0,0);v[23296]=0;W(207,g|0,d|0,h|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break j}}Ab(h)}e=e+1|0;continue}break}break}a=P()|0;O()|0;Ab(h);break f}i=Fg(b);p=Fg(b);d=f+48|0;Yd(d,b,i-4|0);l=jc(f+112|0,d);Ab(d);l:{m:{if(!r){break m}v[23296]=0;d=W(214,o|0,h&65535,p|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break l}if(!d){break m}m=0;k=Th(f+24|0);while(1){if(m>>>0>=p>>>0){break m}v[23296]=0;g=T(194,l|0)|0;d=v[23296];v[23296]=0;n:{if((d|0)!=1){if(g){break n}m=m+1|0;continue}break g}e=k;n=g&31;if(n>>>0<x[z>>1]){d=$b(v[o>>2],h);e=fd(v[d>>2],v[v[d+48>>2]+12>>2],m,n)}if(g&32){v[23296]=0;R(247,f+48|0,l|0);d=v[23296];v[23296]=0;if((d|0)==1){break g}i=w[f+48|0];t[e|0]=i;A=e,C=w[kd(f+48|0)|0],t[A+1|0]=C;o:{p:{if((i|0)==160){d=255;break p}if((i|0)==255){d=0;break p}d=0;i=(B(i>>>4|0,12)+(i&15)|0)+13|0;if(iT(i)){break o}}i=d}t[e|0]=i}d=g&192;q:{if(!d){break q}if((d|0)==192){v[23296]=0;R(335,f+48|0,l|0);d=v[23296];v[23296]=0;if((d|0)!=1){d=f+48|0;g=kd(d);j=Ue(d);i=Ci(d);s=w[f+48|0];r:{s:{if((s|0)==12){t[f|0]=64;A=e,C=w[Wb(g,f)|0],t[A+4|0]=C;d=1;break s}d=w[j|0];t:{if((d|0)==12){t[f|0]=64;A=e,C=w[Wb(i,f)|0],t[A+4|0]=C;j=f+48|0;d=1;break t}if((s|0)==10){t[e+4|0]=(w[g|0]<<6>>>0)/255;d=2;break s}if((d|0)!=10){break r}t[e+4|0]=(w[i|0]<<6>>>0)/255;j=f+48|0;d=2}i=g}t[e+2|0]=d;d=w[j|0]}t[e+3|0]=d;t[e+5|0]=w[i|0];break q}break g}v[23296]=0;R(247,f+48|0,l|0);d=v[23296];v[23296]=0;if((d|0)==1){break g}t[e+3|0]=w[f+48|0];A=e,C=w[kd(f+48|0)|0],t[A+5|0]=C}if(w[e+3|0]){d=e+3|0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{i=w[e+3|0];switch(i-14|0){case 19:break A;case 17:break B;case 9:break C;case 8:break D;case 6:case 7:break E;case 1:break F;case 0:break G;default:break z}}d=w[e+5|0];if(!d){d=14;break w}if((d|0)==15){break y}if((d|0)==240){t[e+5|0]=239;break x}if(d>>>0>=16){t[e+5|0]=d|15;break x}t[e+5|0]=d|240;break x}t[e+5|0]=w[e+5|0]^128;break x}d=w[e+5|0];if(d>>>0>=16){t[e+5|0]=d>>>4|240;break x}t[e+5|0]=d|224;break x}t[e+5|0]=((w[e+5|0]^-1)&254)>>>1;break x}t[e+5|0]=w[e+5|0]&15|128;break x}A=e,C=xi(w[e+5|0]<<1),t[A+5|0]=C;break x}g=32;d=0;H:{I:{J:{K:{L:{M:{N:{j=w[e+5|0];switch(j>>>4|0){case 0:break x;case 3:break H;case 5:break I;case 14:break J;case 12:case 13:break K;case 11:break L;case 10:break M;case 8:break N;default:break w}}g=64;break H}g=176;break H}g=224;break H}if(j){break x}break w}O:{switch(j&15){case 0:t[e+5|0]=119;break x;case 1:t[e+5|0]=119;break x;case 2:t[e+5|0]=121;break x;case 3:break O;default:break x}}t[e+5|0]=123;break x}g=48}t[e+5|0]=j&15|g;break x}if(i>>>0<=35){break x}break v}t[e+5|0]=254}d=i}t[e+3|0]=w[d+26448|0];if(w[e+2|0]|(d|0)!=12){break u}t[e+2|0]=1;t[e+3|0]=0;t[e+4|0]=w[e+5|0];d=e+5|0}t[d|0]=0}}tk(f+48|0,q,n);if(!Cb(v[v[f+48>>2]>>2],v[f+52>>2])){continue}if(!CB(w[e+3|0],w[e+5|0])){continue}t[e+3|0]=0;continue}}Ab(l);h=h+1|0;continue}}break}a=P()|0;O()|0;Ab(l)}S(a|0);L()}e=e>>>0>31}jb=f+1344|0;return e|0}function Iea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;d=jb-304|0;jb=d;Ac(b);a:{b:{c:{d:{if(!Gt(b,d+208|0)){break d}if(!bR(d+208|0)){break d}if(!Ob(v[b>>2],v[b+8>>2],Vc(aR(d+208|0),mb))){break d}if(!c){g=1;break d}if(!$c(b,w[d+212|0])){break d}Ed(a,268435456);Dg(a);v[a+480208>>2]=4;Nb(a+1074312|0,114,1);f=d+88|0;i=Vb(f,15099);Hb(a+1298344|0,i);zb(i);i=Vb(f,10174);Hb(a+1298356|0,i);zb(i);v[a+1298404>>2]=5;i=d+16|0;df(i,d+208|6,48,3);Gc(f,i);Bc(a+1298308|0,f);yb(f);f=w[d+262|0];u[a+480188>>1]=f+1;v[a+480228>>2]=w[d+265|0];v[a+480204>>2]=B(w[d+266|0],1e4);v[a+480196>>2]=w[d+267|0];while(1){if((e|0)==(f|0)){e:{u[a+480190>>1]=w[d+300|0];f=x[d+302>>1];i=d+192|0;v[i>>2]=0;v[i+4>>2]=0;Cc(i+8|0);if(f){il(i,f);DA(i,f)}v[23296]=0;U(582,b|0,i|0,x[d+302>>1]);f=v[23296];v[23296]=0;if((f|0)==1){break b}z=Qb(d+176|0);r=Qb(d+160|0);v[23296]=0;W(355,b|0,z|0,w[d+301|0])|0;f=v[23296];v[23296]=0;if((f|0)==1){break c}v[23296]=0;W(355,b|0,r|0,w[d+300|0])|0;f=v[23296];v[23296]=0;if((f|0)==1){break c}p=c&2;s=d+126|0;n=d+88|6;f=0;f:{while(1){e=f;if(e>>>0>=w[d+300|0]){g=1;if(!(c&1)){break e}v[d+68>>2]=0;q=a+484376|0;Hc(Zb(v[a+484360>>2],w[q|0]));F=d,G=Eb(v[i>>2]),v[F+64>>2]=G;y=a+484344|0;C=Eb(v[i+4>>2]);D=a+484348|0;break f}v[23296]=0;f=e+1|0;h=B(f,104)+a|0;k=h+484380|0;R(264,k|0,0);g=v[23296];v[23296]=0;g:{if((g|0)!=1){g=Db(v[r>>2],e);g=w[g|0]|w[g+1|0]<<8|(w[g+2|0]<<16|w[g+3|0]<<24);if(!g){continue}v[23296]=0;g=Q(143,b|0,g|0)|0;j=v[23296];v[23296]=0;h:{if((j|0)==1){break h}if(!g){continue}v[23296]=0;g=Q(583,b|0,d+88|0)|0;j=v[23296];v[23296]=0;if((j|0)==1){break h}if(!g){continue}g=d+72|0;Ze(g,2,n);v[23296]=0;R(210,d+16|0,g|0);g=v[23296];v[23296]=0;if((g|0)==1){break c}g=d+16|0;Ec(((f<<5)+a|0)+946304|0,g);yb(g);j=d+72|0;ek(j,2,s);v[23296]=0;R(210,g|0,j|0);g=v[23296];v[23296]=0;if((g|0)==1){break c}g=d+16|0;ze(h+484423|0,g);yb(g);g=w[d+138|0];if(g>>>0<=15){u[h+484408>>1]=B(g,17);g=h+484414|0;u[g>>1]=x[g>>1]|32}t[d+16|0]=w[d+139|0];t[d+72|0]=64;F=h+484412|0,G=w[Wb(d+16|0,d+72|0)|0],u[F>>1]=G;v[h+484404>>2]=w[d+141|0]|w[d+142|0]<<8;m=h+484384|0;g=w[d+147|0]|w[d+148|0]<<8|(w[d+149|0]<<16|w[d+150|0]<<24);v[m>>2]=g;q=h+484388|0;j=w[d+151|0]|w[d+152|0]<<8|(w[d+153|0]<<16|w[d+154|0]<<24);v[q>>2]=j;y=w[d+155|0]|w[d+156|0]<<8|(w[d+157|0]<<16|w[d+158|0]<<24);v[k>>2]=y;l=w[d+140|0];if(l&1){g=g>>>1|0;v[m>>2]=g;j=j>>>1|0;v[q>>2]=j;v[k>>2]=y>>>1}i:{if(g>>>0>=j>>>0){break i}h=h+484414|0;g=x[h>>1];u[h>>1]=g|2;if(!(l&2)){break i}u[h>>1]=g|6}lk(k);if(!p){continue}e=Db(v[r>>2],e);e=w[e|0]|w[e+1|0]<<8|(w[e+2|0]<<16|w[e+3|0]<<24);v[23296]=0;Q(143,b|0,e+w[d+92|0]|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break g}}break c}break c}e=_c(d+16|0,t[d+140|0]&1?16:8,1,0,1);v[23296]=0;W(207,e|0,k|0,b|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){continue}break}break c}while(1){j:{k:{k=v[d+64>>2];if(!Rb(k,C)){b=v[d+68>>2];c=b&63;if(!c){break k}f=w[a+484376|0];e=v[a+484360>>2];v[23296]=0;b=b>>>6|0;f=Q(297,Zb(e,f)|0,b&65535)|0;e=v[23296];v[23296]=0;if((e|0)!=1){if(!f){break k}b=x[dc(v[Zb(v[a+484360>>2],w[a+484376|0])>>2],b&65535)>>1];f=v[a+484344>>2];v[23296]=0;R(584,$b(f,b)|0,c|0);b=v[23296];v[23296]=0;if((b|0)!=1){break k}}break c}c=w[k+3|0];if(w[k+2|0]>w[d+262|0]|c>>>0>=w[d+301|0]){break j}c=Db(v[z>>2],c);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[23296]=0;c=Q(143,b|0,c|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break c}if(!c){break j}v[23296]=0;R(585,b|0,d+88|0);c=v[23296];v[23296]=0;if((c|0)==1){break c}e=w[d+92|0];if(!e){break j}f=w[k|0]|w[k+1|0]<<8;t[d+16|0]=w[d+93|0];t[d+72|0]=w[d+262|0]-w[k+2|0];j=w[Wb(d+16|0,d+72|0)|0];v[d+60>>2]=e+f;F=d,G=v[Yc(d+68|0,d+60|0)>>2],v[F+68>>2]=G;v[d+40>>2]=0;v[d+44>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;c=f&63;p=f>>>6|0;s=0;while(1){if((e&255)>>>0<=s>>>0){break j}e=Zb(v[a+484360>>2],w[q|0]);h=c>>>0>63;p=h+p|0;f=p&65535;if(Nc(v[e>>2],v[e+4>>2])>>>0<=f>>>0){v[23296]=0;R(310,e|0,p+1&65535);e=v[23296];v[23296]=0;if((e|0)==1){break c}v[23296]=0;n=Q(345,y|0,64)|0;e=v[23296];v[23296]=0;if((e|0)==1){break c}e=Zb(v[a+484360>>2],w[q|0]);F=dc(v[e>>2],f),G=n,u[F>>1]=G}m=v[a+484344>>2];o=v[D>>2];n=x[dc(v[e>>2],f)>>1];if(!oe(m,o,n)){break j}f=0;e=$b(m,n);m=h?0:c;e=fd(v[e>>2],v[v[e+48>>2]+12>>2],m,w[k+2|0]);l:{while(1){if((f|0)==(j|0)){c=w[d+93|0];if(c>>>0<=j>>>0){break l}v[23296]=0;Q(176,b|0,B(c-j|0,5)|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break l}break c}v[23296]=0;R(586,d+72|0,b|0);c=v[23296];v[23296]=0;if((c|0)!=1){c=d+72|0;h=kd(c);E=Ue(c);l=Ci(c);o=kc(c);c=w[d+72|0];A=c-1&255;m:{if(A>>>0<=142){c=(B((c&240)>>>4|0,12)+(c&15)|0)+13|0;t[e|0]=c;t[(d+16|0)+f|0]=c;break m}t[e|0]=0}c=w[h|0];t[e+2|0]=1;t[e+1|0]=c;c=w[E|0];n:{if((c|0)!=255){t[e+4|0]=c;break n}t[e+2|0]=0}c=w[l|0];o:{if(c>>>0>22){break o}t[e+3|0]=w[c+26832|0];h=w[o|0];t[e+5|0]=h;c=e+5|0;p:{switch(w[l|0]-4|0){case 3:t[c|0]=h&3|64;break o;case 4:t[c|0]=h&3|48;break o;case 7:l=v[i>>2];if(wc(l,v[i+4>>2])>>>0<=h>>>0){break o}o=c;c=Db(l,h);c=w[c|0]|w[c+1|0]<<8;t[o|0]=c>>>6;h=$b(v[a+484344>>2],n);h=fd(v[h>>2],v[v[h+48>>2]+12>>2],m,x[a+480188>>1]-1&65535);t[h+5|0]=c&63;t[h+3|0]=14;break o;case 8:o=c;c=v[d+60>>2];t[o|0]=c>>>6;h=$b(v[a+484344>>2],n);h=fd(v[h>>2],v[v[h+48>>2]+12>>2],m,x[a+480188>>1]-1&65535);t[h+5|0]=c&63;t[h+3|0]=14;break o;case 10:t[c|0]=h&15|128;break o;case 12:t[d+15|0]=15;F=c,G=w[Wb(c,d+15|0)|0]|208,t[F|0]=G;break o;case 13:t[d+15|0]=15;F=c,G=w[Wb(c,d+15|0)|0]|192,t[F|0]=G;break o;case 14:t[d+15|0]=15;F=c,G=w[Wb(c,d+15|0)|0]|224,t[F|0]=G;break o;case 0:case 16:case 17:if(!(h&15)){break o}l=h&240;if(!l|(l|0)==240){break o}t[c|0]=h|15;break o;case 9:case 18:break p;default:break o}}if(A>>>0<143){break o}t[e|0]=w[(d+16|0)+f|0]}e=e+6|0;f=f+1|0;continue}break}break c}c=m+1|0;s=s+1|0;e=w[d+92|0];continue}}a=Zb(v[a+484360>>2],w[a+484376|0]);F=d,G=Eb(v[a>>2]),v[F+88>>2]=G;b=Eb(v[a+4>>2]);c=65535;while(1){a=v[d+88>>2];if(!Rb(a,b)){break e}if(x[a>>1]==65535){q:{if((c&65535)!=65535){break q}v[23296]=0;c=Q(345,y|0,64)|0;f=v[23296];v[23296]=0;if((f|0)!=1){break q}break c}u[a>>1]=c}Se(d+88|0);continue}}Ce(d- -64|0);continue}}}else{u[((e<<5)+a|0)+480284>>1]=B(w[(d+e|0)+268|0],17);e=e+1|0;continue}break}vc(r);vc(z);vc(i)}jb=d+304|0;return g|0}a=P()|0;O()|0;vc(r);vc(z);break a}a=P()|0;O()|0}vc(i);S(a|0);L()}function rN(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=C(0),r=0,s=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=C(0),R=C(0),S=0,T=0,U=0,V=C(0),W=0;m=jb-48|0;jb=m;t[m+40|0]=0;h=b+223848|0;j=m+40|0;Li(h,pi(e,mi(e,ao(e),j))+1|0);ke(j,v[h>>2],v[b+223852>>2]);h=jb-16|0;jb=h;t[h+15|0]=0;gc(m+32|0,e,pi(e,mi(e,ao(e),h+15|0)));jb=h+16|0;G=v[m+32>>2];H=v[m+36>>2];i=jb-16|0;jb=i;r=a+1074312|0;n=B(c,872)+b|0;I=n+1415|0;J=n+1304|0;K=n+1392|0;D=n+1368|0;E=n+1364|0;L=n+1336|0;M=n+1308|0;N=n+1300|0;O=n+1280|0;P=n+1402|0;p=n+1466|0;Q=C(w[p|0]);R=C(f>>>0);F=n+616|0;l=v[n+1272>>2];S=a+480188|0;k=1;o=255;while(1){if((s|0)!=(H|0)&y[j+4>>2]>g>>>0){e=w[Lb(G,s)|0];h=e-48|0;a:{b:{c:{if((h&255)>>>0<=9){break c}if((e-65&255)>>>0<=5){h=e-55|0;break c}d:{e:{f:{switch(e-97|0){case 2:g:{e=sl(a,b,c,3,0);if((e-1&255)>>>0>249){break g}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break g}e=Fy(e,47440,44540);if(!e){break g}h=nb[v[v[e>>2]+188>>2]](e,F,c)|0;e=(h|0)!=255;h=e?h:0;if(e|!l){break c}break d}if(l){break d}h=0;break c;case 21:Bb(i+8|0,r,28);h:{if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){Bb(i,r,1);e=0;if(!Cb(v[v[i>>2]>>2],v[i+4>>2])){break h}}e=u[K>>1]}h=B(v[D>>2],v[E>>2]);e=B(v[a+1074456>>2],e+v[J>>2]|0);e=Yb((Ic(Tia(Sia(h,h>>31,e,e>>31),mb,1048576,0),mb)|0)/2|0,1,127);break e;case 20:e=B(v[D>>2],v[E>>2]);h=e;A=e>>31;e=B(v[a+1074456>>2],v[L>>2]);e=Yb((Ic(Tia(Sia(h,A,e,e>>31),mb,67108864,0),mb)|0)/2|0,1,127);break e;case 23:v[i+8>>2]=v[M>>2]/2;v[i>>2]=127;e=v[td(i+8|0,i)>>2];break e;case 24:v[i+8>>2]=v[N>>2]/2;v[i>>2]=127;e=v[td(i+8|0,i)>>2];break e;case 0:e=0;if(!l){break e}h=x[l+28>>1];if(!h){break e}e=h-1>>>7&127;break e;case 1:e=0;if(!l){break e}h=x[l+28>>1];if(!h){break e}e=h-1&127;break e;case 14:e=v[O>>2]>>>8|0;break e;case 7:e=(x[S>>1]<=c>>>0?w[P|0]-1|0:c)&127;break e;case 12:e=w[n+704|0]>>>7|0;break e;case 15:e=0;if(!l){break e}h=w[l+30|0];if(!h){break e}e=h-1&127;break e;case 25:i:{if(!d|t[p|0]<0){break i}j:{if(g>>>0<3){break j}e=v[j>>2];if(w[Lb(e,g-3|0)|0]!=240){break j}if(w[Lb(e,g-2|0)|0]>239){break i}}q=Ap(b,Q,R);k:{if(q<C(4294967296)&q>=C(0)){e=~~q>>>0;break k}e=0}t[p|0]=e;o=128;break e}o=(o&255)==255?f:o;e=f;break e;case 18:l:{if(!g){h=0;break l}e=v[j>>2];h=g;while(1){h=h-1|0;A=Lb(e,h);if(!h){break l}if(w[A|0]!=240){continue}break}}if(g-h>>>0<5){break a}A=v[j>>2];if(w[Lb(A,h)|0]!=240){break a}h=h+5|0;e=0;while(1){if((g|0)!=(h|0)){e=w[Lb(A,h)|0]+e|0;h=h+1|0;continue}break};e=0-e&127;break e;case 13:break f;default:break a}}e=w[I|0];e=Uc(e)?e-1|0:0}h=((k^-1)&1)+g|0;T=Lb(v[j>>2],h),U=e,t[T|0]=U;g=h+1|0;k=1;break b}e=x[F+786>>1];h=(e?e-1|0:c)&15;e=w[l+31|0];if((e|0)!=17){h=nj(e)?e-1&15:0}}e=Lb(v[j>>2],g);m:{if(k){t[e|0]=h;break m}t[e|0]=w[e|0]<<4|h;g=g+1|0}k=(k^-1)&1}}s=s+1|0;continue}else{if(o<<24>>24>=0){t[p|0]=o}ic(i+8|0,v[j>>2],((k^-1)&1)+g|0);e=v[i+12>>2];v[j>>2]=v[i+8>>2];v[j+4>>2]=e;jb=i+16|0}break}p=v[m+44>>2];h=0;n:while(1){n=0;while(1){e=h;o:{p:{q:{r:{while(1){if(y[m+44>>2]<=e>>>0){break o}f=v[m+40>>2];k=Lb(f,e);g=t[k|0];if((g|0)==-16){g=e;if(p-g>>>0>=4){h=4;if((w[Lb(f,e+1|0)|0]&254)==240){break p}}s:{while(1){g=g+1|0;if(p>>>0<=g>>>0){break s}if(w[Lb(f,g)|0]!=247){continue}break}h=(g-e|0)+1|0;if(h){break p}}T=Lb(f,p),U=247,t[T|0]=U;p=p+1|0;h=p-e|0;break q}if((g|0)<0){break r}if(n&255){e=e-1|0;T=Lb(f,e),U=n,t[T|0]=U;continue}break}h=h+1|0;continue n}T=m,U=rP(g&255),v[T+16>>2]=U;v[m+28>>2]=p-e;h=v[Ib(m+16|0,m+28|0)>>2]}if(!h){break o}f=v[m+40>>2];k=Lb(f,e)}s=w[k|0];lq(m+16|0,f,v[m+44>>2],e,h);i=v[gc(m+8|0,v[m+16>>2],v[m+20>>2])>>2];k=jb-32|0;jb=k;f=v[m+12>>2];t:{if(!f){break t}j=Rd(w[b+223884|0]);u:{l=Lb(i,0);g=w[l|0]-250|0;if(g>>>0>5|!(1<<g&37)){break u}o=x[a+480188>>1];g=0;while(1){if((g|0)==(o|0)){break u}r=(B(g,872)+b|0)+1453|0;t[r|0]=127;t[r+1|0]=0;g=g+1|0;continue}}v:{if((f|0)!=4|w[l|0]!=240){break v}g=w[Lb(i,1)|0];if((g&254)!=240){break v}l=(B(c,872)+b|0)+616|0;o=Lb(i,2);i=w[Lb(i,3)|0];f=i<<24>>24;w:{x:{y:{z:{A:{B:{o=w[o|0];switch(o|0){case 3:break y;case 2:break z;case 1:break A;case 0:break B;default:break x}}if((g|0)==241|(f|0)<0){break x}g=B(c,872)+b|0;i=g+1453|0;if(d){f=Vg(Ap(b,C(w[i|0]),C((f&255)>>>0)))}t[i|0]=f;t[g+1412|0]=0;f=Gp(a,l,!(v[g+704>>2]&32768),256);if((f|0)<0|!(w[g+705|0]&2)){break t}g=v[a+1298300>>2];if(j|xd(g)^1){break t}Kp(g,c,f>>>2&255,1);break t}if((g|0)==241|(f|0)<0){break x}g=B(c,872)+b|0;i=g+1454|0;if(d){f=Vg(Ap(b,C(w[i|0]),C((f&255)>>>0)))}t[i|0]=f;t[g+1411|0]=0;Gp(a,l,!(v[g+704>>2]&32768),256);break t}if((g|0)==241){break w}if(f>>>0>31){break t}g=B(c,872)+b|0;t[g+1461|0]=(f&240)>>>4;Gp(a,l,!(v[g+704>>2]&32768),256);break t}if((g|0)==241){break w}g=(f|0)<0;f=sl(a,b,c,3,0)-1|0;if(g|(f&255)>>>0>249){break t}t[k+24|0]=f;g=f&255;f=v[(B(g,160)+a|0)+906300>>2];if(!f){break t}q=C(C(127-i|0)/C(127));if(j){j=0;i=jb-16|0;jb=i;T=i,U=ak(k+24|0),v[T>>2]=U;f=jb-16|0;jb=f;l=b+223860|0;o=Ey(l,f+12|0,w[k+24|0]);g=v[o>>2];if(!g){g=jb-16|0;jb=g;j=kc(l);r=th(f,xc(24),uh(g+8|0,j));j=v[r>>2];D=w[v[i>>2]];v[j+20>>2]=0;t[j+16|0]=D;T=kc(r),U=1,t[T+4|0]=U;jb=g+16|0;Zg(l,v[f+12>>2],o,v[f>>2]);g=de(f);cl(f);j=1}Yg(i+8|0,v[hc(f,g)>>2],j);jb=f+16|0;f=vd(v[i+8>>2]);jb=i+16|0;z[f+4>>2]=q;break t}if(!d){Vs(v[f+20>>2],q);break t}Vs(v[f+20>>2],Ap(b,z[(B(g,160)+a|0)+906444>>2],q));break t}if(o&128){break w}if((g|0)!=241){break t}}l=sl(a,b,c,3,0)-1|0;if((f|0)<0|(l&255)>>>0>249){break t}i=v[(B(l&255,160)+a|0)+906300>>2];if(!i){break t}g=(g|0)==241?o+128|0:o&127;q=C(C((f&255)>>>0)/C(127));if(j){T=GN(b+223872|0,bN(k+24|0,l,g)),V=q,z[T>>2]=V;break t}f=v[i>>2];if(!d){nb[v[f+44>>2]](i,g,q);break t}U=i,W=g,V=Ap(b,C(nb[v[f+48>>2]](i,g)),q),T=v[v[i>>2]+44>>2],nb[T](U|0,W|0,C(V));break t}if(j){break t}j=x[a+480188>>1];C:{if(j>>>0>c>>>0){g=c+1|0;break C}g=x[(B(c,872)+b|0)+1402>>1];if(!g){break t}}if(w[(B(c,872)+b|0)+707|0]&4|j>>>0<(g&65535)>>>0){break t}g=sl(a,b,c,3,0);if((g-1&255)>>>0>249){break t}g=v[(B(g,160)+a|0)+906140>>2];if(!g){break t}j=w[l|0];if((j|0)==240){Og(k+16|0,i,f);f=v[v[g>>2]+72>>2];i=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=i;nb[f|0](g,k)|0;break t}T=k,W=rP(j),v[T+24>>2]=W;v[k+12>>2]=f;f=k+24|0;j=v[Ib(f,k+12|0)>>2];v[k+24>>2]=0;qc(f,i,j);nb[v[v[g>>2]+68>>2]](g,v[k+24>>2])|0}jb=k+32|0;n=s>>>0<240?s:n;h=e+h|0;continue}break}break}jb=m+48|0}function l_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=jb-560|0;jb=l;v[l+548>>2]=k;v[l+552>>2]=b;a:{b:{c:{d:{if(Kj(a,l+552|0)){v[f>>2]=v[f>>2]|4;a=0;break d}v[l+96>>2]=1106;b=l+96|0;s=le(l+136|0,l+144|0,b);m=v[s>>2];v[l+132>>2]=m;v[l+128>>2]=m+400;y=Kb(b);o=Kb(l+80|0);q=Kb(l- -64|0);p=Kb(l+48|0);u=Kb(l+32|0);v[23296]=0;la(1115,c|0,d|0,l+120|0,l+116|0,l+112|0,y|0,o|0,q|0,p|0,l+28|0);b=v[23296];v[23296]=0;if((b|0)!=1){v[j>>2]=v[i>>2];z=e&512;A=z>>>9|0;k=v[l+28>>2];e=0;while(1){e:{f:{g:{h:{i:{j:{k:{l:{if((e|0)==4){break l}v[23296]=0;b=Q(1089,a|0,l+552|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}if(!b){break l}m:{n:{o:{p:{q:{switch(t[(l+120|0)+e|0]){case 1:if((e|0)==3){break e}b=v[a>>2];v[23296]=0;b=T(1091,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}v[23296]=0;b=W(1116,h|0,1,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}if(b){v[23296]=0;R(1117,l+16|0,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){v[23296]=0;R(48,u|0,v[l+16>>2]);b=v[23296];v[23296]=0;if((b|0)!=1){break p}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break i;case 4:break m;case 2:break n;case 3:break o;case 0:break q;default:break e}}if((e|0)==3){break e}}while(1){v[23296]=0;b=Q(1089,a|0,l+552|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break b}if(!b){break e}b=v[a>>2];v[23296]=0;b=T(1091,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break b}v[23296]=0;b=W(1116,h|0,1,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break b}if(!b){break e}v[23296]=0;R(1117,l+16|0,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){v[23296]=0;R(48,u|0,v[l+16>>2]);b=v[23296];v[23296]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}r:{if(!Fb(q)){break r}b=v[a>>2];v[23296]=0;b=T(1091,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}if((b|0)!=v[tc(q)>>2]){break r}v[23296]=0;T(1093,a|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break c}t[g|0]=0;r=Fb(q)>>>0>1?q:r;break e}s:{if(!Fb(p)){break s}b=v[a>>2];v[23296]=0;b=T(1091,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}if((b|0)!=v[tc(p)>>2]){break s}v[23296]=0;T(1093,a|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break c}t[g|0]=1;r=Fb(p)>>>0>1?p:r;break e}c=Fb(q);b=Fb(p);t:{if(c){if(!b){break t}v[f>>2]=v[f>>2]|4;a=0;break i}if(!b){break e}}B=g,C=!Fb(p),t[B|0]=C;break e}if(!(e>>>0<2|r|((e|0)==2&w[l+123|0]!=0|A))){r=0;break e}c=hc(l+16|0,Zd(o));u:{v:{if(!e|w[(e+l|0)+119|0]>1){break v}while(1){w:{b=zk(o);d=v[c>>2];if(!Rb(d,b)){break w}b=v[d>>2];v[23296]=0;b=W(1116,h|0,1,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break u}if(!b){break w}Ce(c);continue}break}b=Zd(o);b=Qt(v[c>>2],b);if(Fb(u)>>>0>=b>>>0){d=cm(zk(u),0-b|0);n=zk(u);x=Zd(o);b=jb-16|0;jb=b;v[b>>2]=x;v[b+8>>2]=d;while(1){x:{x=Rb(d,n);if(!x){break x}if(!uc(v[d>>2],v[v[b>>2]>>2])){break x}d=Ce(b+8|0);Ce(b);d=v[d>>2];continue}break}jb=b+16|0;if(x^1){break v}}B=c,C=v[hc(l+8|0,Zd(o))>>2],v[B>>2]=C}v[l+8>>2]=v[c>>2];y:{while(1){b=zk(o);if(!Rb(v[l+8>>2],b)){break y}v[23296]=0;b=Q(1089,a|0,l+552|0)|0;c=v[23296];v[23296]=0;z:{if((c|0)==1){break z}if(!b){break y}b=v[a>>2];v[23296]=0;b=T(1091,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break z}if((b|0)!=v[v[l+8>>2]>>2]){break y}v[23296]=0;T(1093,a|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break f}Ce(l+8|0);continue}break}break f}if(!z){break e}b=zk(o);if(!Rb(v[l+8>>2],b)){break e}v[f>>2]=v[f>>2]|4;a=0;break i}break f}b=0;n=v[l+112>>2];A:{while(1){B:{v[23296]=0;c=Q(1089,a|0,l+552|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break B}if(!c){break A}c=v[a>>2];v[23296]=0;c=T(1091,c|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break h}v[23296]=0;d=W(1116,h|0,64,c|0)|0;x=v[23296];v[23296]=0;if((x|0)==1){break h}C:{if(d){d=v[j>>2];if((d|0)==v[l+548>>2]){v[23296]=0;U(1118,i|0,j|0,l+548|0);d=v[23296];v[23296]=0;if((d|0)==1){break h}d=v[j>>2]}v[j>>2]=d+4;v[d>>2]=c;b=b+1|0;break C}if(!Fb(y)|!b|(c|0)!=(n|0)){break A}if(v[l+128>>2]==(m|0)){v[23296]=0;U(1112,s|0,l+132|0,l+128|0);c=v[23296];v[23296]=0;if((c|0)==1){break h}m=v[l+132>>2]}c=m+4|0;v[l+132>>2]=c;v[m>>2]=b;m=c;b=0}v[23296]=0;T(1093,a|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!b|v[s>>2]==(m|0)){break k}if(v[l+128>>2]==(m|0)){v[23296]=0;U(1112,s|0,l+132|0,l+128|0);c=v[23296];v[23296]=0;if((c|0)==1){break g}m=v[l+132>>2]}c=m+4|0;v[l+132>>2]=c;v[m>>2]=b;break j}v[l+28>>2]=k;D:{if(!r){break D}k=1;while(1){if(Fb(r)>>>0<=k>>>0){break D}v[23296]=0;b=Q(1090,a|0,l+552|0)|0;c=v[23296];v[23296]=0;E:{if((c|0)==1){break E}F:{if(!b){b=v[a>>2];v[23296]=0;b=T(1091,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break E}if((b|0)==v[ij(r,k)>>2]){break F}}v[f>>2]=v[f>>2]|4;a=0;break i}v[23296]=0;T(1093,a|0)|0;b=v[23296];v[23296]=0;k=k+1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;b=v[s>>2];if((b|0)==(m|0)){break i}a=0;v[l+16>>2]=0;rf(y,b,m,l+16|0);if(v[l+16>>2]){v[f>>2]=v[f>>2]|4;break i}a=1;break i}c=m}G:{if((k|0)<=0){break G}v[23296]=0;b=Q(1090,a|0,l+552|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break g}H:{if(!b){b=v[a>>2];v[23296]=0;b=T(1091,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break g}if((b|0)==v[l+116>>2]){break H}}v[l+28>>2]=k;v[f>>2]=v[f>>2]|4;a=0;break i}v[23296]=0;d=T(1093,a|0)|0;m=v[23296];v[23296]=0;b=k;if((m|0)==1){break g}while(1){if((b|0)<=0){k=0;break G}v[23296]=0;m=Q(1090,d|0,l+552|0)|0;n=v[23296];v[23296]=0;I:{if((n|0)==1){break I}J:{if(!m){m=v[d>>2];v[23296]=0;m=T(1091,m|0)|0;n=v[23296];v[23296]=0;if((n|0)==1){break I}v[23296]=0;m=W(1116,h|0,64,m|0)|0;n=v[23296];v[23296]=0;if((n|0)==1){break I}if(m){break J}}v[l+28>>2]=b;v[f>>2]=v[f>>2]|4;a=0;break i}if(v[j>>2]==v[l+548>>2]){v[23296]=0;U(1118,i|0,j|0,l+548|0);m=v[23296];v[23296]=0;if((m|0)==1){break I}}m=v[d>>2];v[23296]=0;m=T(1091,m|0)|0;n=v[23296];v[23296]=0;if((n|0)==1){break I}n=v[j>>2];v[j>>2]=n+4;v[n>>2]=m;v[23296]=0;T(1093,d|0)|0;m=v[23296];v[23296]=0;b=b-1|0;if((m|0)!=1){continue}}break}break f}if(v[j>>2]!=v[i>>2]){m=c;break e}v[l+28>>2]=k;v[f>>2]=v[f>>2]|4;a=0}Kc(u);Kc(p);Kc(q);Kc(o);yb(y);Qc(s);break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;v[l+28>>2]=k;break a}e=e+1|0;continue}}a=P()|0;O()|0;break a}jb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}Kc(u);Kc(p);Kc(q);Kc(o);yb(y);Qc(s);S(a|0);L()}function CV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=jb-224|0;jb=e;Ac(b);a:{b:{c:{d:{if(!uC(b,e+176|0)){break d}if(!xC(e+176|0)){break d}if(!c){n=1;break d}Ed(a,2048);Dg(a);d=jb-16|0;jb=d;f=e+8|0;h=Vb(d,3927);Sc(f,h);zb(h);jb=d+16|0;v[23296]=0;U(201,e+80|0,f|0,w[e+179|0]);d=v[23296];v[23296]=0;e:{f:{g:{h:{i:{j:{k:{if((d|0)!=1){d=e+80|0;Hb(a+1298344|0,d);zb(d);f=e+8|0;ec(f);h=Vb(d,11008);Hb(a+1298356|0,h);zb(h);v[a+1298404>>2]=5;h=a+480188|0;u[h>>1]=w[e+216|0];u[a+480190>>1]=w[e+212|0];Ze(f,2,e+176|4);Gc(d,f);Bc(a+1298308|0,d);yb(d);d=w[e+179|0];l:{if(d>>>0>=9){if(d>>>0>=11){f=(d|0)==11?16:32;d=0;while(1){if((d|0)==(f|0)){break l}h=Yu(b);m:{if((h|0)==100){v[((d<<5)+a|0)+480280>>2]=256;break m}v[e+80>>2]=(h<<1)+128;v[e+8>>2]=0;v[e+160>>2]=256;s=((d<<5)+a|0)+480284|0,y=v[wj(e+80|0,e+8|0,e+160|0)>>2],u[s>>1]=y}d=d+1|0;continue}}f=e+80|0;d=jb-16|0;jb=d;n:{if(!Ob(v[b>>2],v[b+8>>2],16)){jC(f);break n}Nu(d+8|0,f);qd(d,b,v[d+8>>2],v[d+12>>2])}jb=d+16|0;d=0;while(1){if((d|0)==16){break l}u[((d<<5)+a|0)+480284>>1]=t[(e+80|0)+d|0]&1?64:192;d=d+1|0;continue}}u[h>>1]=4;ng(b,1);xh(a,1)}o:{if(w[e+179|0]>=13){d=e+80|0;Ru(d,b);f=kd(d);d=w[e+80|0];if(d>>>0<=31){t[e+80|0]=125;d=125}v[a+480204>>2]=B(d,1e4);v[a+480196>>2]=w[f|0];break o}v[a+480196>>2]=6;v[a+480204>>2]=125e4}kg(Zb(v[a+484360>>2],w[a+484376|0]),w[e+213|0]);l=Qb(e+160|0);f=w[e+179|0];q=v[b+8>>2]+((f>>>0>13)<<1)|0;d=0;p:{if(f>>>0<14){break p}v[23296]=0;R(202,l|0,w[e+213|0]);f=v[23296];v[23296]=0;if((f|0)!=1){break p}d=P()|0;O()|0;break b}q:{r:{s:{while(1){t:{if(w[e+213|0]<=d>>>0){d=0;if(w[e+179|0]!=10){break s}m=v[b+8>>2];k=a+480190|0;d=1;while(1){j=x[k>>1];if(j>>>0<(d&65535)>>>0){break t}v[23296]=0;f=Q(203,b|0,e+80|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break r}if(f){f=0;u:{if(w[e+212|0]<(w[e+126|0]|w[e+127|0]<<8|(w[e+128|0]<<16|w[e+129|0]<<24))>>>0|w[e+80|0]>1){break u}h=w[e+130|0]|w[e+131|0]<<8|(w[e+132|0]<<16|w[e+133|0]<<24);if(h>>>0>1048576|w[e+136|0]>64|h>>>0<(w[e+137|0]|w[e+138|0]<<8|(w[e+139|0]<<16|w[e+140|0]<<24))>>>0){break u}f=h>>>0>=(w[e+141|0]|w[e+142|0]<<8|(w[e+143|0]<<16|w[e+144|0]<<24))>>>0}if(!f){break t}}d=d+1|0;continue}}s=dc(v[Zb(v[a+484360>>2],w[a+484376|0])>>2],d),y=d,u[s>>1]=y;if(w[e+179|0]>=14){v[23296]=0;f=T(182,b|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break q}s=dc(v[l>>2],d),y=f,u[s>>1]=y}f=x[a+480188>>1];v[23296]=0;Q(176,b|0,f<<1)|0;f=v[23296];v[23296]=0;if((f|0)==1){break q}d=d+1|0;continue}break}v[23296]=0;Q(143,b|0,m|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break c}d=j>>>0>=(d&65535)>>>0}j=a+480190|0;f=x[j>>1];v[23296]=0;v[e+80>>2]=0;m=W(204,e- -64|0,f|0,e+80|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break k}n=d?59:65;k=e+80|1;f=1;v:{while(1){h=f&65535;if(h>>>0>x[j>>1]){h=Qb(e+48|0);v[23296]=0;n=W(205,b|0,h|0,x[e+214>>1])|0;d=v[23296];v[23296]=0;w:{if((d|0)!=1){if(!n){break e}d=0;k=0;f=v[h>>2];if(!uc(f,v[h+4>>2])){f=Eb(f);g=Eb(v[h+4>>2]);k=jb-16|0;jb=k;x:{if(!Rb(f,g)){break x}v[k+8>>2]=f;while(1){j=v[Se(k+8|0)>>2];if(!Rb(j,g)){break x}f=rl(w[f|0]|w[f+1|0]<<8,w[j|0]|w[j+1|0]<<8)?j:f;continue}}jb=k+16|0;k=w[f|0]|w[f+1|0]<<8}v[23296]=0;j=Q(206,e+32|0,k|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break w}y:{while(1){if((d|0)==(k|0)){if(!(c&2)){break j}i=_c(e+80|0,8,1,0,1);o=a+480190|0;f=x[o>>1];g=1;z:{A:while(1){p=g&65535;if(p>>>0>(f&65535)>>>0){break j}d=v[b+8>>2];f=v[b>>2];v[23296]=0;d=W(144,f|0,d|0,1)|0;f=v[23296];v[23296]=0;if((f|0)==1){break z}if(!d){break j}r=v[b+8>>2];d=0;while(1){f=x[o>>1];if(f>>>0<=d>>>0){g=g+1|0;continue A}if((p|0)!=v[Db(v[m>>2],d)>>2]){d=d+1|0;continue}v[23296]=0;Q(143,b|0,r|0)|0;f=v[23296];v[23296]=0;if((f|0)!=1){v[23296]=0;d=d+1|0;W(207,i|0,(B(d,104)+a|0)+484380|0,b|0)|0;f=v[23296];v[23296]=0;if((f|0)!=1){continue}}break}break}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}v[23296]=0;f=T(182,b|0)|0;g=v[23296];v[23296]=0;B:{if((g|0)==1){break B}v[23296]=0;Q(176,b|0,1)|0;g=v[23296];v[23296]=0;if((g|0)==1){break B}if(f){v[23296]=0;U(178,e+8|0,b|0,B(f,3)+(w[e+179|0]==1?3:0)|0);f=v[23296];v[23296]=0;if((f|0)==1){break y}g=e+8|0;f=jc(e+80|0,g);cd(Cg(v[j>>2],d),f);Ab(f);Ab(g)}d=d+1|0;continue}break}d=P()|0;O()|0;break i}d=P()|0;O()|0;break i}d=P()|0;O()|0;break h}d=P()|0;O()|0;break h}C:{D:{if(w[e+179|0]<=9){v[23296]=0;R(208,b|0,e+80|0);g=v[23296];v[23296]=0;E:{F:{if((g|0)==1){break F}v[23296]=0;R(209,e+80|0,(B(h,104)+a|0)+484380|0);g=v[23296];v[23296]=0;if((g|0)==1){break F}g=e+48|0;Ze(g,2,k);v[23296]=0;R(210,e+8|0,g|0);g=v[23296];v[23296]=0;if((g|0)==1){break E}break D}d=P()|0;O()|0;break g}d=P()|0;O()|0;break g}v[23296]=0;U(211,b|0,e+80|0,n|0);g=v[23296];v[23296]=0;if((g|0)==1){break C}v[23296]=0;U(212,e+80|0,(B(h,104)+a|0)+484380|0,d|0);g=v[23296];v[23296]=0;if((g|0)==1){break C}g=e+48|0;Ze(g,2,k);v[23296]=0;R(210,e+8|0,g|0);g=v[23296];v[23296]=0;if((g|0)==1){break v}}g=e+8|0;Ec(((h<<5)+a|0)+946304|0,g);yb(g);s=Db(v[m>>2],h-1|0),y=x[e+126>>1]|x[e+128>>1]<<16,v[s>>2]=y;f=f+1|0;continue}break}d=P()|0;O()|0;break g}d=P()|0;O()|0;break g}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;ec(e+8|0);break a}d=P()|0;O()|0;break b}if(!(c&1)){break f}v[23296]=0;g=a+484344|0;R(213,g|0,w[e+213|0]);c=v[23296];v[23296]=0;G:{if((c|0)!=1){f=a+480188|0;a=0;while(1){H:{if(w[e+213|0]<=a>>>0){break f}d=64;c=v[l>>2];if(Nc(c,v[l+4>>2])>>>0>a>>>0){d=x[dc(c,a)>>1]}v[23296]=0;c=W(214,g|0,a&65535,d&65535)|0;d=v[23296];v[23296]=0;if((d|0)==1){break G}I:{if(c){c=x[f>>1];v[23296]=0;Q(143,b|0,B(((w[e+179|0]>13)<<1)+(c<<1)|0,a)+q|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break G}c=Qb(e+80|0);d=x[f>>1];v[23296]=0;i=W(205,b|0,c|0,d|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break I}d=0;J:{if(!i){break J}while(1){if(x[f>>1]<=d>>>0){break J}K:{i=dc(v[c>>2],d);i=w[i|0]|w[i+1|0]<<8;if(!i|i>>>0>x[e+214>>1]){break K}i=dc(v[h>>2],i-1|0);i=(w[i|0]|w[i+1|0]<<8)-1&65535;if(i>>>0>=k>>>0){break K}o=v[g>>2];p=v[j>>2];v[23296]=0;U(215,$b(o,a)|0,d&65535,Cg(p,i)|0);i=v[23296];v[23296]=0;if((i|0)!=1){break K}break H}d=d+1|0;continue}}ud(c)}a=a+1|0;continue}}break}d=P()|0;O()|0;ud(c);break i}d=P()|0;O()|0;break i}d=P()|0;O()|0}ld(j)}ud(h)}vc(m);break b}ld(j)}ud(h);vc(m);ud(l)}jb=e+224|0;return n|0}d=P()|0;O()|0}ud(l)}S(d|0);L()}function Dp(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0;g=jb-16|0;jb=g;i=x[a+480192>>1]>=c>>>0?v[((c<<2)+a|0)+900380>>2]:i;s=v[b+752>>2];k=w[b+802|0];a:{if(!k){Bb(g+8|0,a+1074312|0,11);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break a}}b:{c:{if(!i){break c}if(!Uc(k)){break c}d:{l=k-1|0;k=dc(i+236|0,l);if(x[k>>1]){break d}Bb(g+8|0,a+1074312|0,43);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break d}if(nj(w[i+31|0])){break d}v[b+656>>2]=i;break a}if(w[Lb(i+108|0,l)|0]>120){break a}k=x[k>>1];l=(k-1&65535)>>>0<3999?(B(k,104)+a|0)+484380|0:0;break b}l=(B(c,104)+a|0)+484380|0;if(!x[a+480192>>1]){break b}if(k>>>0>250){break a}Bb(g+8|0,a+1074312|0,43);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){if(i){l=0;if(nj(w[i+31|0])){break b}}t[b+803|0]=0;v[b+656>>2]=0;break a}l=0}k=v[b+104>>2];n=(k|0)!=0&(k|0)!=(l|0);j=v[b+656>>2];p=!i|v[a+480180>>2]!=16777216?p:v[i+44>>2]!=0;q=d^1;h=(j|0)!=(i|0);if((q|h|n)==1){u[b+774>>1]=0}r=!n;if(!(r|(h|!(d&p)))){break a}e:{if(!(d&n)){break e}k=a+1074312|0;Bb(g+8|0,k,32);if(!(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])|!(w[a+480208|0]&8))){l=v[b+8>>2]|v[b+12>>2]?v[b+104>>2]:l}m=v[a+480180>>2];f:{if(!(i?h|!(m&1048580):1)|(m|0)==268435456){break f}if((m|0)==1){if(qi(v[b+8>>2],v[b+12>>2])){break f}}Bb(g+8|0,k,79);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break e}if(!qi(v[b+8>>2],v[b+12>>2])){break e}}o=1}g:{if(!v[b+16>>2]|(!n|(h|!x[a+480192>>1]))){break g}Bb(g+8|0,a+1074312|0,87);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break g}o=Uc(w[b+788|0])^1|o}h:{i:{j:{k:{l:{if(qi(v[b+8>>2],v[b+12>>2])|!(v[a+480180>>2]&16777248)){break l}if(i){if(nj(w[i+31|0])){break l}}k=1;break k}if(!(h|n)){break j}k=(j|0)!=(i|0)}if(!d){break i}Bb(g+8|0,a+1074312|0,61);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break i}j=v[b+656>>2];if(!j){j=0;m=0;h=v[b+104>>2];if(!h){break i}break h}h=v[b+104>>2];m=0;break h}k=0}v[b+656>>2]=i;j=i;m=k;h=l}m:{n:{o:{if(!e){break o}p:{if(w[a+480180|0]&3){if(h){if(Ud(v[h>>2],v[h+20>>2])){break p}}if(!Sj(j)){break o}}if(!h){break n}}if(u[h+34>>1]<0){break o}v[b+688>>2]=x[h+30>>1]}i=(h|0)!=0;if(!(n&o)|!h){break m}Bb(g+8|0,a+1074312|0,85);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){u[b+772>>1]=t[h+37|0]}i=1;if(v[a+480180>>2]!=2){break m}if(!Ud(v[h>>2],v[h+20>>2])){break m}v[b+704>>2]=v[h+24>>2];break m}if(!(!j|!w[j+34|0])){k=v[b+688>>2];if(j){k=v[j+4>>2]<<2}v[b+688>>2]=k;i=0;break m}i=0;v[b+688>>2]=0}if(o){break a}t[b+803|0]=0;q:{if(!j){break q}Bb(g+8|0,a+1074312|0,29);if(!(z=1,A=(Cb(v[v[g+8>>2]>>2],v[g+12>>2])^-1)&i,C=w[j+34|0]|m,C?z:A)){break q}t[b+798|0]=w[j+16|0]}l=64;v[b+752>>2]=64;if(h){l=x[h+32>>1];v[b+752>>2]=l}if(j){v[b+752>>2]=B(v[j+4>>2],l)>>>6}r:{if(!(v[a+480180>>2]&1048580?e:1)){break r}Bb(g+8|0,a+1074312|0,48);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break r}mN(a,b,j,h)}s:{t:{u:{if(!f){break u}f=a+1074312|0;Bb(g+8|0,f,19);v:{w:{x:{y:{z:{A:{B:{C:{if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){if(!v[b+76>>2]){e=1;break B}if(!(!c|q)){e=(w[a+480208|0]&8)>>>3|0;if(e){break B}break C}e=0;if(c){break C}break B}c=v[a+480180>>2]&17301536;e=1;D:{if(!d|!c){break D}c=1;e=1;if(w[a+480208|0]&8){break D}e=1;if(!v[b+76>>2]){break D}e=0;if(!(w[b+89|0]&16)){break D}e=!v[b+696>>2]}if(!j|(!c|m)){break z}if(!e){break y}c=v[b+88>>2];e=c&6144;break A}if(d){break B}if(!(w[b+89|0]&24)){e=0;break B}e=(w[a+480208|0]&4)>>>2|0}if(!v[b+696>>2]|m){break z}if(!e){break y}c=v[b+88>>2];e=c&2048}v[b+88>>2]=c|2097152;if(!j){break v}if(e){break w}if(!(w[j+60|0]&8)){hj(b+724|0)}if(!(w[j+80|0]&8)){hj(b+732|0)}if(w[j+100|0]&8){break v}hj(b+740|0);break v}if(e){break x}}if(j){if(t[j+60|0]&1){break u}Bb(g+8|0,f,32);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){hj(b+724|0);break u}Vl(b);break u}c=0;if(!h){break t}break s}v[b+88>>2]=v[b+88>>2]|2097152;if(!j){break v}}Vl(b)}Bb(g+8|0,f,21);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break u}t[b+818|0]=0;v[b+756>>2]=0}c=0;if(h){break s}if(!j){break t}c=1;if(nj(w[j+31|0])){break s}}v[b+752>>2]=0;v[b+104>>2]=0;break a}E:{F:{G:{H:{I:{if(!(!d|(i^1|v[b+104>>2]!=(h|0)))){d=v[a+480180>>2];if(v[b+76>>2]?d&16777250:0){break a}if((d|0)!=4){break I}Bb(g+8|0,a+1074312|0,40);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])|w[b+789|0]){break I}d=v[b+88>>2];break H}v[b+88>>2]=v[b+88>>2]&-6145;e=a+1074312|0;Bb(g+8|0,e,18);J:{if(z=Cb(v[v[g+8>>2]>>2],v[g+12>>2]),A=1,C=v[a+480180>>2]&16777248,C?z:A){f=-640;if(!(v[b+104>>2]!=(h|0)|m)){break J}}f=-768}v[b+88>>2]=f&v[b+88>>2];K:{if(!j){break K}t[b+730|0]=w[j+60|0];t[b+738|0]=w[j+80|0];t[b+746|0]=w[j+100|0];L:{if((w[j+100|0]&17)!=17){break L}Bb(g+8|0,e,36);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])|w[b+837|0]){break L}t[b+837|0]=127}e=w[j+21|0];if(Uf(e)){z=b,A=Qq(e),t[z+837|0]=A}e=w[j+22|0];if(!Uf(e)){break K}z=b,A=Qq(e),t[z+838|0]=A}if(c){break G}if(!d){break E}break F}d=v[b+88>>2]&-6145}v[b+88>>2]=d&-640;if(!c){break F}}v[b+76>>2]=0;v[b+104>>2]=0;break a}if(v[b+76>>2]){break E}c=a+1074312|0;Bb(g+8|0,c,54);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){Bb(g,c,39);if(!Cb(v[v[g>>2]>>2],v[g+4>>2])){break E}}v[b+8>>2]=0;v[b+12>>2]=0}M:{if(w[b+788|0]!=255){break M}Bb(g+8|0,a+1074312|0,100);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])|(!(v[a+480208>>2]&4)|r)){break M}c=v[b+104>>2];if(c){v[b+88>>2]=v[b+88>>2]|x[c+34>>1]&1023}v[b+752>>2]=s;v[b+688>>2]=x[h+30>>1];if(!(w[h+34|0]&32)){break a}Mp(b,x[h+28>>1],a);break a}v[b+104>>2]=h;v[b+76>>2]=v[h>>2];v[b+80>>2]=v[h+4>>2];v[b+84>>2]=v[h+8>>2];e=a+1074312|0;Bb(g+8|0,e,83);if(!(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])|v[b+80>>2])){v[b+84>>2]=v[h>>2]}v[b+88>>2]=v[b+88>>2]|x[h+34>>1]&1023;Bb(g+8|0,e,21);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){t[b+818|0]=0;v[b+756>>2]=0}N:{O:{if(p){v[b+704>>2]=v[h+24>>2];t[b+851|0]=w[b+851|0]|64;c=0;break O}if(!(n|q)){d=v[a+480180>>2];if(d&5){break N}}v[b+704>>2]=v[h+24>>2];c=t[h+37|0]}u[b+772>>1]=c;d=v[a+480180>>2]}if(om(d)){c=t[h+36|0]}else{c=0}u[b+770>>1]=c;Bb(g+8|0,e,69);if(!(Cb(v[v[g+8>>2]>>2],v[g+12>>2])|v[a+480180>>2]==1)){v[b+708>>2]=0}v[b+852>>2]=0;i=v[b+88>>2];if(i&8){v[b+80>>2]=v[h+12>>2];v[b+84>>2]=v[h+16>>2];i=i>>>2&4|i|2;v[b+88>>2]=i}P:{if(!(i&2)){i=v[b+76>>2];break P}i=v[b+76>>2];c=v[b+84>>2];if(i>>>0<=c>>>0){break P}v[b+76>>2]=c;i=c}if(!(v[a+480180>>2]&16777248)|y[b+4>>2]<i>>>0){break a}v[b>>2]=0;v[b+4>>2]=0}jb=g+16|0}function Lha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;e=jb-272|0;jb=e;Ac(b);d=jb-16|0;jb=d;i=e+112|0;pT(d+8|0,i);g=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);h=v[d+4>>2];if((h|0)==(g|0)){ac(b,v[d+12>>2])}jb=d+16|0;d=(g|0)==(h|0);if(!d){oT(i)}a:{if(!d){break a}if(!qT(e+112|0)){break a}if(!c){f=1;break a}Ed(a,v[(x[e+228>>1]<<2)+26240>>2]);v[a+480208>>2]=v[a+480208>>2]|16777216;d=e+48|0;f=Vb(d,12961);Hb(a+1298344|0,f);zb(f);f=Vb(d,10205);Hb(a+1298356|0,f);zb(f);f=jb-16|0;jb=f;g=e+8|0;i=Vb(f,4350);Sc(g,i);zb(i);jb=f+16|0;v[23296]=0;X(217,d|0,g|0,w[e+191|0],e+188|0);d=v[23296];v[23296]=0;b:{if((d|0)!=1){d=e+48|0;Hb(a+1298368|0,d);zb(d);f=e+8|0;ec(f);wl(a+1298392|0,(x[e+228>>1]<<2)+26288|0);wl(a+1298380|0,v[(x[e+228>>1]<<2)+26336>>2]);v[a+1298404>>2]=5;Ze(f,2,e+112|4);Gc(d,f);Bc(a+1298308|0,d);yb(d);Ze(f,2,e+148|0);Gc(d,f);c:{if(gq(d,9642)){v[23296]=0;U(11,e+8|0,5,e+48|0);d=v[23296];v[23296]=0;if((d|0)==1){break c}d=e+8|0;Hb(a+1298320|0,d);zb(d)}yb(e+48|0);u[a+480188>>1]=32;d=0;d:{while(1){if((d|0)!=32){g=(d<<5)+a|0;i=g+480280|0;Te(i);f=w[(d+e|0)+193|0];e:{if(f>>>0<=15){v[e+48>>2]=f<<4|8;v[e+8>>2]=256;y=g+480284|0,z=v[td(e+48|0,e+8|0)>>2],u[y>>1]=z;break e}if((f|0)!=16){if((f|0)!=255){break e}u[a+480188>>1]=d;break d}u[g+480284>>1]=128;v[i>>2]=256}d=d+1|0;continue}break}d=x[a+480188>>1]}f=0;if(!(d&65535)){break a}v[e+48>>2]=w[e+225|0]<<2;v[e+8>>2]=256;y=a,z=v[Ib(e+48|0,e+8|0)>>2],v[y+480200>>2]=z;v[a+480196>>2]=w[e+226|0];v[a+480204>>2]=B(w[e+227|0],1e4);if($c(b,x[e+230>>1]|x[e+232>>1]<<16)){oo(Zb(v[a+484360>>2],w[a+484376|0]),b,w[e+234|0]+1|0,255,254)}if(!$c(b,v[e+240>>2])){break a}l=a+480190|0;d=w[e+248|0]+1|0;u[l>>1]=d;m=e+80|0;n=a+480180|0;i=1;while(1){f:{g:{j=i&65535;if(j>>>0>(d&65535)>>>0){break g}d=jb-16|0;jb=d;g=e+48|0;ic(d+8|0,g,62);f=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);h=v[d+4>>2];if((h|0)==(f|0)){ac(b,v[d+12>>2])}jb=d+16|0;d=(f|0)==(h|0);if(!d){Xb(g,0,62)}if(!d){break g}d=0;f=B(j,104)+a|0;k=f+484380|0;pd(k,0);h=e+32|0;Ze(h,2,e+48|0);g=e+8|0;Gc(g,h);Ec(((j<<5)+a|0)+946304|0,g);yb(g);ek(h,2,m);Gc(g,h);ze(f+484423|0,g);yb(g);g=x[e+106>>1];v[f+484404>>2]=g;if(!om(v[n>>2])){break f}while(1){if((d|0)==16){break f}if((g|0)==x[(d<<1)+26384>>1]){t[f+484417|0]=d<<4;break f}else{d=d+1|0;continue}}}h:{if(!(c&2)){break h}if(!$c(b,v[e+244>>2])){break h}d=1;f=a+480190|0;while(1){g=d&65535;if(g>>>0>x[f>>1]){break h}g=B(g,104)+a|0;lg(_c(e+48|0,u[g+484414>>1]&1?16:8,1,0,1),g+484380|0,b);d=d+1|0;continue}}n=a+484344|0;mg(n,w[e+239|0]+1|0);f=fq(a);d=jb-16|0;jb=d;v[d+12>>2]=0;Ps(d+12|0,f);k=v[d+12>>2];jb=d+16|0;$c(b,w[e+235|0]|w[e+236|0]<<8|(w[e+237|0]<<16|w[e+238|0]<<24));p=c&1;q=a+480188|0;r=a+480180|0;j=0;m=1;i:{j:{k:{while(1){if(w[e+239|0]<j>>>0){if(v[a+480180>>2]==1){break k}c=v[a+480208>>2]&-8454145;break j}l:{d=Fg(b);if(d>>>0>=3){c=e+8|0;Yd(c,b,d-2|0);h=jc(e+48|0,c);Ab(c);m:{if(!p){break m}c=v[h>>2];v[23296]=0;c=T(166,c|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break l}if(!c){break m}v[23296]=0;c=W(214,n|0,j&65535,64)|0;d=v[23296];v[23296]=0;if((d|0)==1){break l}l=0;if(!c){break m}while(1){if((l|0)==64){break m}c=$b(v[n>>2],j);s=Qf(v[c>>2],v[v[c+48>>2]+12>>2],l);n:{o:while(1){v[23296]=0;c=T(194,h|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break i}if(!c){break n}d=c&31;if(d>>>0>=x[q>>1]){break n}f=B(d,6)+s|0;if(c&32){v[23296]=0;R(247,e+8|0,h|0);d=v[23296];v[23296]=0;if((d|0)==1){break i}g=kd(e+8|0);d=w[e+8|0];if(d){d=(d&127)-1|0;t[e+8|0]=d;d=(B((d&240)>>>4|0,12)+(d&15)|0)+13|0;t[f|0]=d;m=YA(d)&m}t[f+1|0]=w[g|0]}if(!(c&64)){continue}t[f+2|0]=0;t[f+3|0]=0;g=f+5|0;while(1){c=v[h>>2];v[23296]=0;c=W(144,c|0,v[e+56>>2],2)|0;d=v[23296];v[23296]=0;if((d|0)==1){break i}if(!c){continue o}o=w[f+5|0];c=w[f+3|0];v[23296]=0;R(247,e+8|0,h|0);d=v[23296];v[23296]=0;if((d|0)!=1){i=w[kd(e+8|0)|0];t[g|0]=i;d=w[(w[e+8|0]&31)+26416|0];t[f+3|0]=d;p:{q:{r:{s:{t:{switch(d-2|0){case 0:case 1:if(i>>>0<224){break r}d=223;if(v[r>>2]!=1){break s}break r;case 11:t[e+32|0]=64;y=g,z=w[Wb(g,e+32|0)|0],t[y|0]=z;if(!nT(v[k+88>>2])){break r}t[f+2|0]=1;t[f+4|0]=w[g|0];t[f+3|0]=c;t[g|0]=o;d=c;break q;case 17:u:{switch(((i&240)>>>4|0)-8|0){case 0:t[f+3|0]=2;t[g|0]=i&15|224;break p;case 1:t[f+3|0]=3;t[g|0]=i&15|224;break p;default:break u}}if(eu(v[k+84>>2],19)){break r}Hu(f);break r;case 13:d=v[k+84>>2];if(eu(d,15)){break r}if(!eu(d,19)){break r}t[f+3|0]=19;t[g|0]=i&15|144;break p;case 18:d=145;if((i|0)==1){break s}if((i&240)==128){if(eu(v[k+84>>2],20)){break r}t[f+3|0]=19;break p}t[f+3|0]=0;break p;case 4:case 5:break t;default:break q}}d=i&240;if(!d){break r}}t[g|0]=d}d=w[f+3|0]}if((d&255)!=20){break p}d=w[g|0];if(w[f+2|0]|(d&240)!=128){break p}t[f+2|0]=2;t[f+4|0]=(((d&15)<<6|8)>>>0)/15;t[f+3|0]=c;t[g|0]=o}if(!(w[e+8|0]&32)){continue o}continue}break}break}break i}l=l+1|0;continue}}Ab(h)}j=j+1|0;continue}break}break i}c=v[a+480208>>2]&-8454145|(m&1?x[a+480188>>1]==4?8454144:0:0)}v[a+480208>>2]=c;f=1;if(!(w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24))){break a}if(!$c(b,w[e+249|0]|w[e+250|0]<<8|(w[e+251|0]<<16|w[e+252|0]<<24))){break a}jB(a+1298332|0,b,w[e+253|0]|w[e+254|0]<<8|(w[e+255|0]<<16|w[e+256|0]<<24),4);break a}d=P()|0;O()|0;Ab(h);break b}u[f+484412>>1]=64;g=w[e+93|0]|w[e+94|0]<<8|(w[e+95|0]<<16|w[e+96|0]<<24);v[k>>2]=g;d=w[e+105|0];if(d&2){h=f+484414|0;u[h>>1]=x[h>>1]|1;v[k>>2]=g>>>1}v[f+484384>>2]=w[e+97|0]|w[e+98|0]<<8|(w[e+99|0]<<16|w[e+100|0]<<24);v[f+484388>>2]=(w[e+101|0]|w[e+102|0]<<8|(w[e+103|0]<<16|w[e+104|0]<<24))-1;if(d&1){g=f+484414|0;u[g>>1]=x[g>>1]|2}v:{w:{if(!(d&4)){break w}g=w[e+108|0];if((g|0)==255){break w}t[e+8|0]=g;t[e+32|0]=64;y=f+484410|0,z=w[Wb(e+8|0,e+32|0)|0]<<2,u[y>>1]=z;break v}g=f+484414|0;u[g>>1]=x[g>>1]|32768}x:{if(d&8){d=f+484414|0;g=x[d>>1]|32;u[d>>1]=g;j=f+484408|0;f=w[e+109|0];if(f>>>0<=15){v[e+32>>2]=256;v[e+8>>2]=f<<4|8;h=v[td(e+8|0,e+32|0)>>2]}else{h=128}u[j>>1]=h;u[d>>1]=g&65279|((f|0)==16)<<8;break x}u[f+484408>>1]=128}i=i+1|0;d=x[l>>1];continue}}d=P()|0;O()|0;yb(e+48|0);break b}d=P()|0;O()|0;ec(e+8|0)}S(d|0);L()}jb=e+272|0;return f|0}function s_(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;l=jb-560|0;jb=l;v[l+548>>2]=k;v[l+552>>2]=b;a:{b:{c:{d:{if(Yi(a,l+552|0)){v[f>>2]=v[f>>2]|4;a=0;break d}v[l+104>>2]=1106;b=l+104|0;s=le(l+136|0,l+144|0,b);m=v[s>>2];v[l+132>>2]=m;v[l+128>>2]=m+400;x=Kb(b);o=Kb(l+88|0);q=Kb(l+72|0);p=Kb(l+56|0);u=Kb(l+40|0);v[23296]=0;la(1109,c|0,d|0,l+120|0,l+119|0,l+118|0,x|0,o|0,q|0,p|0,l+36|0);b=v[23296];v[23296]=0;if((b|0)!=1){v[j>>2]=v[i>>2];y=e&512;z=y>>>9|0;d=v[l+36>>2];k=h;h=0;while(1){e:{f:{g:{h:{i:{j:{k:{if((h|0)==4){break k}v[23296]=0;b=Q(1073,a|0,l+552|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}if(!b){break k}l:{m:{n:{o:{p:{switch(t[(l+120|0)+h|0]){case 1:if((h|0)==3){break e}b=v[a>>2];v[23296]=0;b=T(1075,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}if(lh(v[k+8>>2],1,b)){v[23296]=0;R(1110,l+24|0,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){v[23296]=0;R(46,u|0,t[l+24|0]);b=v[23296];v[23296]=0;if((b|0)!=1){break o}}a=P()|0;O()|0;break a}v[f>>2]=v[f>>2]|4;a=0;break h;case 4:break l;case 2:break m;case 3:break n;case 0:break p;default:break e}}if((h|0)==3){break e}}while(1){v[23296]=0;b=Q(1073,a|0,l+552|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break b}if(!b){break e}b=v[a>>2];v[23296]=0;b=T(1075,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break b}if(!lh(v[k+8>>2],1,b)){break e}v[23296]=0;R(1110,l+24|0,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){v[23296]=0;R(46,u|0,t[l+24|0]);b=v[23296];v[23296]=0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}q:{if(!Fb(q)){break q}b=v[a>>2];v[23296]=0;b=T(1075,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}if(w[Oc(q,0)|0]!=(b&255)){break q}v[23296]=0;T(1077,a|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break c}t[g|0]=0;r=Fb(q)>>>0>1?q:r;break e}r:{if(!Fb(p)){break r}b=v[a>>2];v[23296]=0;b=T(1075,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}if(w[Oc(p,0)|0]!=(b&255)){break r}v[23296]=0;T(1077,a|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break c}t[g|0]=1;r=Fb(p)>>>0>1?p:r;break e}c=Fb(q);b=Fb(p);s:{if(c){if(!b){break s}v[f>>2]=v[f>>2]|4;a=0;break h}if(!b){break e}}B=g,C=!Fb(p),t[B|0]=C;break e}if(!(h>>>0<2|r|((h|0)==2&w[l+123|0]!=0|z))){r=0;break e}B=l,C=Zd(o),v[B+16>>2]=C;c=Gf(l+24|0,l+16|0);t:{if(!h|w[(h+l|0)+119|0]>1){break t}while(1){u:{B=l,C=oh(o),v[B+16>>2]=C;if(!Nh(c,l+16|0)){break u}if(!lh(v[k+8>>2],1,t[v[c>>2]])){break u}Be(c);continue}break}B=l,C=Zd(o),v[B+16>>2]=C;b=dk(c,l+16|0);if(Fb(u)>>>0>=b>>>0){B=l,C=oh(u),v[B+16>>2]=C;e=Hi(l+16|0,0-b|0);n=oh(u);A=Zd(o);b=jb-32|0;jb=b;v[b+16>>2]=n;v[b+24>>2]=e;v[b+8>>2]=A;while(1){e=Nh(b+24|0,b+16|0);if(!(!e|w[v[b+24>>2]]!=w[v[b+8>>2]])){Be(b+24|0);Be(b+8|0);continue}break}jb=b+32|0;if(e^1){break t}}B=l,C=Zd(o),v[B+8>>2]=C;B=c,C=v[Gf(l+16|0,l+8|0)>>2],v[B>>2]=C}v[l+16>>2]=v[c>>2];v:{w:{while(1){B=l,C=oh(o),v[B+8>>2]=C;if(!Nh(l+16|0,l+8|0)){break v}v[23296]=0;b=Q(1073,a|0,l+552|0)|0;c=v[23296];v[23296]=0;x:{if((c|0)==1){break x}if(!b){break v}b=v[a>>2];v[23296]=0;b=T(1075,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break x}if(w[v[l+16>>2]]!=(b&255)){break v}v[23296]=0;T(1077,a|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break w}Be(l+16|0);continue}break}a=P()|0;O()|0;v[l+36>>2]=d;break a}a=P()|0;O()|0;v[l+36>>2]=d;break a}if(!y){break e}B=l,C=oh(o),v[B+8>>2]=C;if(!Nh(l+16|0,l+8|0)){break e}v[f>>2]=v[f>>2]|4;a=0;break h}b=0;n=w[l+118|0];y:{while(1){z:{v[23296]=0;c=Q(1073,a|0,l+552|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break z}if(!c){break y}c=v[a>>2];v[23296]=0;e=T(1075,c|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break g}A:{if(lh(v[k+8>>2],64,e)){c=v[j>>2];if((c|0)==v[l+548>>2]){v[23296]=0;U(1111,i|0,j|0,l+548|0);c=v[23296];v[23296]=0;if((c|0)==1){break g}c=v[j>>2]}v[j>>2]=c+1;t[c|0]=e;b=b+1|0;break A}if(!Fb(x)|!b|(n|0)!=(e&255)){break y}if(v[l+128>>2]==(m|0)){v[23296]=0;U(1112,s|0,l+132|0,l+128|0);c=v[23296];v[23296]=0;if((c|0)==1){break g}m=v[l+132>>2]}c=m+4|0;v[l+132>>2]=c;v[m>>2]=b;m=c;b=0}v[23296]=0;T(1077,a|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){continue}}break}a=P()|0;O()|0;break a}if(!b|v[s>>2]==(m|0)){break j}if(v[l+128>>2]==(m|0)){v[23296]=0;U(1112,s|0,l+132|0,l+128|0);c=v[23296];v[23296]=0;if((c|0)==1){break f}m=v[l+132>>2]}e=m+4|0;v[l+132>>2]=e;v[m>>2]=b;break i}v[l+36>>2]=d;B:{if(!r){break B}k=1;while(1){if(Fb(r)>>>0<=k>>>0){break B}v[23296]=0;b=Q(1074,a|0,l+552|0)|0;c=v[23296];v[23296]=0;C:{if((c|0)==1){break C}D:{if(!b){b=v[a>>2];v[23296]=0;b=T(1075,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break C}if(w[Yf(r,k)|0]==(b&255)){break D}}v[f>>2]=v[f>>2]|4;a=0;break h}v[23296]=0;T(1077,a|0)|0;b=v[23296];v[23296]=0;k=k+1|0;if((b|0)!=1){continue}}break}a=P()|0;O()|0;break a}a=1;b=v[s>>2];if((b|0)==(m|0)){break h}a=0;v[l+24>>2]=0;rf(x,b,m,l+24|0);if(v[l+24>>2]){v[f>>2]=v[f>>2]|4;break h}a=1;break h}e=m}E:{if((d|0)<=0){break E}v[23296]=0;b=Q(1074,a|0,l+552|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break f}F:{if(!b){b=v[a>>2];v[23296]=0;b=T(1075,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break f}if(w[l+119|0]==(b&255)){break F}}v[l+36>>2]=d;v[f>>2]=v[f>>2]|4;a=0;break h}v[23296]=0;c=T(1077,a|0)|0;m=v[23296];v[23296]=0;b=d;if((m|0)==1){break f}while(1){if((b|0)<=0){d=0;break E}v[23296]=0;m=Q(1074,c|0,l+552|0)|0;n=v[23296];v[23296]=0;G:{if((n|0)==1){break G}H:{if(!m){m=v[c>>2];v[23296]=0;m=T(1075,m|0)|0;n=v[23296];v[23296]=0;if((n|0)==1){break G}if(lh(v[k+8>>2],64,m)){break H}}v[l+36>>2]=b;v[f>>2]=v[f>>2]|4;a=0;break h}if(v[j>>2]==v[l+548>>2]){v[23296]=0;U(1111,i|0,j|0,l+548|0);m=v[23296];v[23296]=0;if((m|0)==1){break G}}m=v[c>>2];v[23296]=0;m=T(1075,m|0)|0;n=v[23296];v[23296]=0;if((n|0)==1){break G}n=v[j>>2];v[j>>2]=n+1;t[n|0]=m;v[23296]=0;T(1077,c|0)|0;m=v[23296];v[23296]=0;b=b-1|0;if((m|0)!=1){continue}}break}a=P()|0;O()|0;v[l+36>>2]=d;break a}if(v[j>>2]!=v[i>>2]){m=e;break e}v[l+36>>2]=d;v[f>>2]=v[f>>2]|4;a=0}yb(u);yb(p);yb(q);yb(o);yb(x);Qc(s);break d}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}h=h+1|0;continue}}a=P()|0;O()|0;break a}jb=l+560|0;return a|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}yb(u);yb(p);yb(q);yb(o);yb(x);Qc(s);S(a|0);L()}function O9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=jb+-64|0;jb=g;d=v[b>>2];v[23296]=0;e=T(166,d|0)|0;d=v[23296];v[23296]=0;a:{b:{c:{d:{if((d|0)==1){break d}e:{f:{if(e){h=Qb(g+48|0);v[23296]=0;f=(c|0)!=0;e=W(775,h|0,b|0,f|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break e}d=4;g:{h:{i:{j:{if(e){break j}v[23296]=0;e=W(776,h|0,b|0,f|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break e}d=5;if(e){break j}v[23296]=0;e=W(777,h|0,b|0,f|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break e}d=6;if(e){break j}e=0;v[23296]=0;f=W(778,h|0,b|0,f|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break e}d=3;if(!f){break i}}if(!c){d=1;e=0;break h}e=v[h>>2];if(!uc(e,v[h+4>>2])){gv(b,e+12|0)}e=d}d=31392;k:{while(1){f=d;if((f|0)!=31908){i=v[f+8>>2];j=(i>>1)+a|0;d=v[f+4>>2];d=i&1?v[v[j>>2]+d>>2]:d;v[23296]=0;i=W(d|0,j|0,b|0,c|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break c}d=f+12|0;if(!i){continue}break k}break}v[a+480180>>2]=0;v[a+480184>>2]=0}if(!c){d=(f|0)!=31908;e=0;break h}if(!(v[a+480184>>2]|!e)){v[a+480184>>2]=e}v[23296]=0;e=1;R(718,a+1298264|0,1);f=v[23296];v[23296]=0;d=1;if((f|0)==1){break g}}pM(h);if(e){break f}break a}break c}v[23296]=0;R(234,a|0,0);d=v[23296];v[23296]=0;if((d|0)==1){break d}v[23296]=0;R(718,a+1298264|0,1);d=v[23296];v[23296]=0;if((d|0)==1){break d}v[a+1074304>>2]=19923969}d=0;while(1){if((d|0)==127){d=1;while(1){e=d&65535;if(e>>>0>x[a+480190>>1]){e=0;j=a+480180|0;d=0;l:{while(1){f=d&65535;if(f>>>0>x[a+480192>>1]){m:{u[a+480192>>1]=e;d=a+480204|0;if(y[a+480204>>2]>=1e4){break m}v[d>>2]=125e4;break l}}else{f=v[((f<<2)+a|0)+900380>>2];if(f){i=v[j>>2];yc(f,65536);yc(f+4|0,64);yc(f+8|0,256);ug(f+28|0,16384);nf(f+30|0,128);nf(f+31|0,17);if(w[f+16|0]>=4){t[f+16|0]=0}if(w[f+17|0]>=5){t[f+17|0]=0}if(w[f+18|0]>=3){t[f+18|0]=0}nf(f+19|0,64);nf(f+20|0,100);k=224;e=t[f+26|0];n:{if((e|0)>=-32){k=32;if((e|0)<33){break n}}t[f+26|0]=k}nf(f+23|0,64);nf(f+24|0,64);xz(f+48|0,64);xz(f+68|0,64);xz(f+88|0,(i|0)==4096?255:64);i=f+108|0;k=0;while(1){o:{if((k|0)==128){if(!yo(w[f+14|0])){t[f+14|0]=5}if(w[f+34|0]>=251){t[f+34|0]=0}break o}e=Lb(i,k);if((w[e|0]-121&255)>>>0<=135){t[e|0]=k+1}k=k+1|0;continue}break}e=d}d=d+1|0;continue}break}yc(d,65535e4)}if(!v[a+480196>>2]){v[a+480196>>2]=6}e=a+480220|0;d=v[a+480216>>2];if(d>>>0>y[a+480220>>2]){v[e>>2]=d}d=a+480216|0;yc(d,65536);yc(e,65536);yc(a+480200|0,256);p:{e=a+480248|0;if(!uc(v[e>>2],v[a+480252>>2])){d=v[d>>2];v[23296]=0;R(779,e|0,d|0);d=v[23296];v[23296]=0;if((d|0)==1){break p}}v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];d=v[a+480220>>2];e=a+1074408|0;v[e>>2]=v[a+480216>>2];v[e+4>>2]=d;v[a+1074456>>2]=v[a+480200>>2];Ky(a+1074376|0);d=a+1074446|0;u[d>>1]=0;u[d+2>>1]=0;u[d+4>>1]=0;u[d+6>>1]=65535;v[a+1074392>>2]=-2;d=a+1074384|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074380>>2]=0;d=a+1074424|0;v[d>>2]=0;v[d+4>>2]=0;v[a+1074432>>2]=0;d=a+1074396|0;v[d>>2]=0;v[d+4>>2]=0;if(om(v[a+480180>>2])){v[23296]=0;Q(252,a+1074312|0,7)|0;d=v[23296];v[23296]=0;if((d|0)==1){break p}}u[a+480276>>1]=0;yp(a);n=g,o=Eb(v[a+484360>>2]),v[n+48>>2]=o;e=Eb(v[a+484364>>2]);while(1){f=v[g+48>>2];if(!Rb(f,e)){q:{r:{j=v[a+480180>>2];if(j){Ps(a+8|0,fq(a));if(v[a+1074308>>2]){v[23296]=0;Y(780,a|0);d=v[23296];v[23296]=0;if((d|0)==1){break p}}m=Qb(g+48|0);s:{if((c&12)!=12){break s}i=a+1298464|0;d=0;t:{u:{v:{w:{x:{y:{while(1){if((d|0)==250){break s}z:{e=B(d,160)+a|0;f=e+906316|0;A:{if(!(v[f>>2]|v[e+906320>>2])){break A}v[23296]=0;l=e+906300|0;R(781,l|0,a|0);c=v[23296];v[23296]=0;B:{if((c|0)!=1){h=v[l>>2];if(!h){break B}e=v[e+906448>>2];c=v[v[h>>2]+56>>2];v[23296]=0;R(c|0,h|0,e|0);c=v[23296];v[23296]=0;if((c|0)!=1){break A}}a=P()|0;O()|0;break q}k=Eb(v[m>>2]);e=Eb(v[m+4>>2]);h=jb-16|0;jb=h;v[h+8>>2]=k;while(1){C:{if(!Rb(k,e)){break C}c=v[k>>2];if((w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24))==(w[l+20|0]|w[l+21|0]<<8|(w[l+22|0]<<16|w[l+23|0]<<24))){c=(w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24))==(w[l+16|0]|w[l+17|0]<<8|(w[l+18|0]<<16|w[l+19|0]<<24))}else{c=0}if(c){break C}k=v[Ce(h+8|0)>>2];continue}break}jb=h+16|0;if(Rb(k,Eb(v[m+4>>2]))){break A}v[23296]=0;v[g+32>>2]=f;R(782,m|0,g+32|0);c=v[23296];v[23296]=0;if((c|0)==1){break z}v[23296]=0;e=Q(1,g+16|0,17520)|0;c=v[23296];v[23296]=0;if((c|0)==1){break y}v[23296]=0;R(783,g|0,l|0);c=v[23296];v[23296]=0;if((c|0)==1){break x}v[23296]=0;U(2,g+32|0,e|0,g|0);c=v[23296];v[23296]=0;if((c|0)==1){break w}c=v[i>>2];v[23296]=0;U(353,c|0,2,g+32|0);c=v[23296];v[23296]=0;if((c|0)==1){break v}zb(g+32|0);zb(g);zb(e)}d=d+1|0;continue}break}a=P()|0;O()|0;break q}a=P()|0;O()|0;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;break u}a=P()|0;O()|0;zb(g+32|0)}zb(g)}zb(e);break q}c=w[a+1074368|0];v[23296]=0;R(784,a|0,c|0);a=v[23296];v[23296]=0;if((a|0)==1){break r}vc(m)}d=(j|0)!=0;break a}a=P()|0;O()|0}vc(m);break b}v[23296]=0;Y(785,f|0);d=v[23296];v[23296]=0;if((d|0)!=1){if(Nc(v[f>>2],v[f+4>>2])>>>0<=x[f+28>>1]){_e(f,0)}sz(g+48|0);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}i=B(e,104)+a|0;j=i+484380|0;D:{if(Ud(v[j>>2],v[i+484400>>2])){mj(j,a);break D}f=i+484414|0;e=x[f>>1];if(e&16384){break D}v[j>>2]=0;v[j+4>>2]=0;v[j+16>>2]=0;v[j+8>>2]=0;v[j+12>>2]=0;u[f>>1]=e&65505}e=i+484412|0;if(x[e>>1]>=65){u[e>>1]=64}E:{F:{if(!(w[i+484415|0]&2)){break F}if(!Vj(v[a+1298300>>2])){break F}v[23296]=0;Y(786,a|0);e=v[23296];v[23296]=0;if((e|0)==1){break E}}d=d+1|0;continue}break}a=P()|0;O()|0;break b}f=(d<<5)+a|0;ug(f+480286|0,64);e=f+480284|0;if(x[e>>1]>=257){u[e>>1]=128}e=f+480288|0;if(w[e|0]>=251){t[e|0]=0}$n((B(d,872)+a|0)+1074992|0,a,d&65535,134217728);d=d+1|0;continue}}break c}a=P()|0;O()|0;break b}a=P()|0;O()|0;pM(h)}Ab(b);S(a|0);L()}Ab(b);jb=g- -64|0;return d|0}function D0(a,b,c,d,e,f){a=a|0;b=+b;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,k=0,l=0,m=0,n=0,p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,C=0,E=0,F=0;n=jb-560|0;jb=n;v[n+44>>2]=0;o(+b);g=j(1)|0;j(0)|0;a:{if((g|0)<0){x=1;A=5257;b=-b;o(+b);g=j(1)|0;j(0)|0;break a}if(e&2048){x=1;A=5260;break a}x=e&1;A=x?5263:5258;F=!x}b:{if((g&2146435072)==2146435072){d=x+3|0;sf(a,32,c,d,e&-65537);hf(a,A,x);f=f&32;hf(a,b!=b?f?9870:13636:f?10996:13998,3);sf(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c;break b}z=n+16|0;c:{d:{e:{b=CH(b,n+44|0);b=b+b;if(b!=0){g=v[n+44>>2];v[n+44>>2]=g-1;u=f|32;if((u|0)!=97){break e}break c}u=f|32;if((u|0)==97){break c}l=v[n+44>>2];m=(d|0)<0?6:d;break d}l=g-29|0;v[n+44>>2]=l;b=b*268435456;m=(d|0)<0?6:d}r=(n+48|0)+((l|0)<0?0:288)|0;h=r;while(1){if(b<4294967296&b>=0){d=~~b>>>0}else{d=0}v[h>>2]=d;h=h+4|0;b=(b-+(d>>>0))*1e9;if(b!=0){continue}break}f:{if((l|0)<=0){d=l;g=h;k=r;break f}k=r;d=l;while(1){d=(d|0)<29?d:29;g=h-4|0;g:{if(k>>>0>g>>>0){break g}i=0;while(1){q=v[g>>2];p=d&31;C=i;if((d&63)>>>0>=32){i=q<<p;q=0}else{i=(1<<p)-1&q>>>32-p;q=q<<p}p=C+q|0;i=i+E|0;i=p>>>0<q>>>0?i+1|0:i;i=Via(p,i,1e9,0);q=Sia(i,mb,-1e9,0)+p|0;v[g>>2]=q;g=g-4|0;if(k>>>0<=g>>>0){continue}break}if(!i){break g}k=k-4|0;v[k>>2]=i}while(1){g=h;if(k>>>0<g>>>0){h=g-4|0;if(!v[h>>2]){continue}}break}d=v[n+44>>2]-d|0;v[n+44>>2]=d;h=g;if((d|0)>0){continue}break}}if((d|0)<0){y=((m+25>>>0)/9|0)+1|0;p=(u|0)==102;while(1){d=0-d|0;i=(d|0)<9?d:9;h:{if(g>>>0<=k>>>0){h=v[k>>2];break h}q=1e9>>>i|0;E=-1<<i^-1;d=0;h=k;while(1){C=d;d=v[h>>2];v[h>>2]=C+(d>>>i|0);d=B(q,d&E);h=h+4|0;if(h>>>0<g>>>0){continue}break}h=v[k>>2];if(!d){break h}v[g>>2]=d;g=g+4|0}d=i+v[n+44>>2]|0;v[n+44>>2]=d;k=(!h<<2)+k|0;h=p?r:k;g=g-h>>2>(y|0)?h+(y<<2)|0:g;if((d|0)<0){continue}break}}d=0;i:{if(g>>>0<=k>>>0){break i}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break i}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=(m-((u|0)==102?0:d)|0)-((u|0)==103&(m|0)!=0)|0;if((h|0)<(B(g-r>>2,9)-9|0)){i=h+9216|0;p=(i|0)/9|0;l=((((l|0)<0?4:292)+n|0)+(p<<2)|0)-4048|0;h=10;i=i+B(p,-9)|0;if((i|0)<=7){while(1){h=B(h,10);i=i+1|0;if((i|0)!=8){continue}break}}p=v[l>>2];y=(p>>>0)/(h>>>0)|0;i=B(y,h);q=l+4|0;j:{if((i|0)==(p|0)&(q|0)==(g|0)){break j}p=p-i|0;k:{if(!(y&1)){b=9007199254740992;if(!(t[l-4|0]&1)|((h|0)!=1e9|k>>>0>=l>>>0)){break k}}b=9007199254740994}s=(g|0)==(q|0)?1:1.5;q=h>>>1|0;s=p>>>0<q>>>0?.5:(q|0)==(p|0)?s:1.5;if(!(w[A|0]!=45|F)){s=-s;b=-b}v[l>>2]=i;if(b+s==b){break j}d=h+i|0;v[l>>2]=d;if(d>>>0>=1e9){while(1){v[l>>2]=0;l=l-4|0;if(l>>>0<k>>>0){k=k-4|0;v[k>>2]=0}d=v[l>>2]+1|0;v[l>>2]=d;if(d>>>0>999999999){continue}break}}d=B(r-k>>2,9);h=10;i=v[k>>2];if(i>>>0<10){break j}while(1){d=d+1|0;h=B(h,10);if(i>>>0>=h>>>0){continue}break}}h=l+4|0;g=g>>>0>h>>>0?h:g}while(1){h=g;i=g>>>0<=k>>>0;if(!i){g=h-4|0;if(!v[g>>2]){continue}}break}l:{if((u|0)!=103){l=e&8;break l}g=m?m:1;l=(g|0)>(d|0)&(d|0)>-5;m=(l?d^-1:-1)+g|0;f=(l?-1:-2)+f|0;l=e&8;if(l){break l}g=-9;m:{if(i){break m}p=v[h-4>>2];if(!p){break m}i=10;g=0;if((p>>>0)%10|0){break m}while(1){l=g;g=g+1|0;i=B(i,10);if(!((p>>>0)%(i>>>0)|0)){continue}break}g=l^-1}i=B(h-r>>2,9);if((f&-33)==70){l=0;g=(g+i|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g;break l}l=0;g=((d+i|0)+g|0)-9|0;g=(g|0)>0?g:0;m=(g|0)>(m|0)?m:g}i=-1;u=l|m;if(((u?2147483645:2147483646)|0)<(m|0)){break b}p=(((u|0)!=0)+m|0)+1|0;q=f&-33;n:{if((q|0)==70){if((2147483647-p|0)<(d|0)){break b}g=(d|0)>0?d:0;break n}g=d>>31;g=sn((g^d)-g|0,0,z);if((z-g|0)<=1){while(1){g=g-1|0;t[g|0]=48;if((z-g|0)<2){continue}break}}y=g-2|0;t[y|0]=f;t[g-1|0]=(d|0)<0?45:43;g=z-y|0;if((g|0)>(2147483647-p|0)){break b}}d=g+p|0;if((d|0)>(x^2147483647)){break b}f=d+x|0;sf(a,32,c,f,e);hf(a,A,x);sf(a,48,c,f,e^65536);o:{p:{q:{if((q|0)==70){g=n+16|0;d=g|8;l=g|9;i=k>>>0>r>>>0?r:k;k=i;while(1){g=sn(v[k>>2],0,l);r:{if((i|0)!=(k|0)){if(n+16>>>0>=g>>>0){break r}while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break r}if((g|0)!=(l|0)){break r}t[n+24|0]=48;g=d}hf(a,g,l-g|0);k=k+4|0;if(r>>>0>=k>>>0){continue}break}if(u){hf(a,16590,1)}if((m|0)<=0|h>>>0<=k>>>0){break q}while(1){g=sn(v[k>>2],0,l);if(g>>>0>n+16>>>0){while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}}hf(a,g,(m|0)<9?m:9);g=m-9|0;k=k+4|0;if(h>>>0<=k>>>0){break p}d=(m|0)>9;m=g;if(d){continue}break}break p}s:{if((m|0)<0){break s}i=h>>>0>k>>>0?h:k+4|0;g=n+16|0;d=g|8;r=g|9;h=k;while(1){g=sn(v[h>>2],0,r);if((r|0)==(g|0)){t[n+24|0]=48;g=d}t:{if((h|0)!=(k|0)){if(n+16>>>0>=g>>>0){break t}while(1){g=g-1|0;t[g|0]=48;if(n+16>>>0<g>>>0){continue}break}break t}hf(a,g,1);g=g+1|0;if(!(l|m)){break t}hf(a,16590,1)}C=g;g=r-g|0;hf(a,C,(g|0)>(m|0)?m:g);m=m-g|0;h=h+4|0;if(i>>>0<=h>>>0){break s}if((m|0)>=0){continue}break}}sf(a,48,m+18|0,18,0);hf(a,y,z-y|0);break o}g=m}sf(a,48,g+9|0,9,0)}sf(a,32,c,f,e^8192);i=(c|0)<(f|0)?f:c;break b}m=(f<<26>>31&9)+A|0;u:{if(d>>>0>11){break u}g=12-d|0;s=16;while(1){s=s*16;g=g-1|0;if(g){continue}break}if(w[m|0]==45){b=-(s+(-b-s));break u}b=b+s-s}l=x|2;k=f&32;h=v[n+44>>2];g=h>>31;g=sn((g^h)-g|0,0,z);if((z|0)==(g|0)){t[n+15|0]=48;g=n+15|0}r=g-2|0;t[r|0]=f+15;t[g-1|0]=(h|0)<0?45:43;i=e&8;h=n+16|0;while(1){f=h;if(D(b)<2147483648){g=~~b}else{g=-2147483648}t[h|0]=k|w[g+75920|0];b=(b-+(g|0))*16;h=f+1|0;if(!(!(i|(d|0)>0)&b==0|(h-(n+16|0)|0)!=1)){t[f+1|0]=46;h=f+2|0}if(b!=0){continue}break}i=-1;p=z-r|0;f=p+l|0;if((2147483645-f|0)<(d|0)){break b}v:{w:{if(!d){break w}k=h-(n+16|0)|0;if((k-2|0)>=(d|0)){break w}g=d+2|0;break v}k=h-(n+16|0)|0;g=k}d=g+f|0;sf(a,32,c,d,e);hf(a,m,l);sf(a,48,c,d,e^65536);hf(a,n+16|0,k);sf(a,48,g-k|0,0,0);hf(a,r,p);sf(a,32,c,d,e^8192);i=(c|0)<(d|0)?d:c}jb=n+560|0;return i|0}function pea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-272|0;jb=e;Ac(b);d=jb-16|0;jb=d;f=e+120|0;OQ(d+8|0,f);g=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);h=v[d+4>>2];if((h|0)==(g|0)){ac(b,v[d+12>>2])}jb=d+16|0;d=(g|0)==(h|0);if(!d){NQ(f)}a:{b:{if(!d){break b}if(!PQ(e+120|0)){break b}if(!c){i=1;break b}Ed(a,4194304);d=e+32|0;g=Vb(d,16857);Hb(a+1298344|0,g);zb(g);g=Vb(d,10029);Hb(a+1298356|0,g);zb(g);v[a+1298404>>2]=5;n=a,o=Xd(x[e+198>>1],x[e+200>>1],127),u[n+480188>>1]=o;g=w[e+189|0];v[a+480228>>2]=(g|0)==255?48:g;v[a+480196>>2]=w[e+187|0];v[a+480204>>2]=B(w[e+188|0],1e4);g=e+96|0;df(g,e+120|4,59,3);Gc(d,g);Bc(a+1298308|0,d);yb(d);d=x[e+202>>1]|x[e+204>>1]<<16;c:{if(d>>>0<5){break c}if(!$c(b,d-4|0)){break c}if(!Ah(b,14098)){break c}oo(Zb(v[a+484360>>2],w[a+484376|0]),b,x[e+192>>1],65535,65535)}d:{d=x[e+206>>1]|x[e+208>>1]<<16;if(d>>>0<5){break d}if(!$c(b,d-4|0)){break d}if(!Ah(b,13631)){break d}d=0;while(1){if((d|0)==32){break d}g=(d<<5)+a|0;Te(g+480280|0);n=g+480284|0,o=((((Ee(b)^-1)&15)<<8|8)>>>0)/15|0,u[n>>1]=o;d=d+1|0;continue}}d=x[e+214>>1]|x[e+216>>1]<<16;e:{if(d>>>0<5){break e}if(!$c(b,d-4|0)){break e}if(!Ah(b,13955)){break e}d=e+32|0;Yd(d,b,x[e+196>>1]<<6);k=c&2;h=a+480190|0;g=jc(e+96|0,d);Ab(d);j=e+45|0;d=0;f:{while(1){if(x[e+196>>1]<=(d&65535)>>>0){break f}v[23296]=0;f=Q(612,g|0,e+32|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break a}if(!f){break f}f=w[e+77|0]|w[e+78|0]<<8;u[e+30>>1]=f;g:{h:{if((f-1&65535)>>>0>3998){break h}f=B(f,104)+a|0;i=f+484380|0;if(Ud(v[i>>2],v[f+484400>>2])){break h}n=h,o=x[We(h,e+30|0)>>1],u[n>>1]=o;v[23296]=0;R(613,e+32|0,i|0);f=v[23296];v[23296]=0;if((f|0)==1){break g}df(e,j,24,1);v[23296]=0;R(210,e+16|0,e|0);f=v[23296];v[23296]=0;if((f|0)==1){break a}f=e+16|0;Ec(((x[e+30>>1]<<5)+a|0)+946304|0,f);yb(f);if(!k){break h}v[23296]=0;Q(143,b|0,w[e+69|0]|w[e+70|0]<<8|(w[e+71|0]<<16|w[e+72|0]<<24))|0;f=v[23296];v[23296]=0;if((f|0)==1){break g}i=1;l=e+16|0;f=w[e+79|0];m=_c(l,f&4?16:8,1,0,0);i:{j:{if(f&8){break j}i=2;if(f&16){break j}if(f&127){break i}}Sf(m,i)}v[23296]=0;W(207,l|0,(B(x[e+30>>1],104)+a|0)+484380|0,b|0)|0;f=v[23296];v[23296]=0;if((f|0)!=1){break h}break a}d=d+1|0;continue}break}break a}Ab(g)}i=1;if(!(c&1)){break b}k:{c=x[e+210>>1]|x[e+212>>1]<<16;if(c>>>0<5){break k}if(!$c(b,c-4|0)){break k}if(!Ah(b,13481)){break k}k=a+484344|0;mg(k,x[e+194>>1]);f=0;while(1){if(x[e+194>>1]<=f>>>0){break k}if(!wA(b,e+16|0)){break k}l:{d=x[e+16>>1];if(d>>>0>3){c=e+96|0;Yd(c,b,(d+15&131056)-4|0);g=jc(e+32|0,c);Ab(c);v[23296]=0;c=W(214,k|0,f&65535,w[e+18|0])|0;d=v[23296];v[23296]=0;if((d|0)==1){break l}h=0;m:{if(!c){break m}while(1){n:{c=v[g>>2];v[23296]=0;d=W(144,c|0,v[e+40>>2],1)|0;c=v[23296];v[23296]=0;o:{if((c|0)!=1){c=w[e+18|0];if(!(d&c>>>0>(h&255)>>>0)){break n}v[23296]=0;d=T(194,g|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}if(d){break o}h=h+1|0;continue}break a}c=v[a+484344>>2];u[e+96>>1]=d&31;u[e>>1]=x[a+480188>>1]-1;c=$b(c,f);c=fd(v[c>>2],v[v[c+48>>2]+12>>2],h,x[Zc(e+96|0,e)>>1]);if(d&128){v[23296]=0;R(247,e+96|0,g|0);j=v[23296];v[23296]=0;if((j|0)==1){break a}t[c|0]=w[e+96|0]+36;n=c,o=w[kd(e+96|0)|0],t[n+1|0]=o}if(d&64){t[c+2|0]=1;v[23296]=0;j=T(194,g|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break a}t[e+96|0]=j;t[e|0]=64;n=c,o=w[Wb(e+96|0,e)|0],t[n+4|0]=o}if(!(d&32)){continue}v[23296]=0;R(247,e+96|0,g|0);d=v[23296];v[23296]=0;p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{H:{I:{J:{K:{L:{M:{N:{O:{P:{Q:{R:{S:{T:{U:{if((d|0)!=1){d=w[kd(e+96|0)|0];t[c+5|0]=d;switch(w[e+96|0]-1|0){case 71:break q;case 70:break r;case 69:break s;case 60:break t;case 59:break u;case 52:break v;case 51:break w;case 50:break x;case 49:break y;case 42:break z;case 41:break A;case 40:break B;case 39:break C;case 30:break D;case 29:break E;case 22:break F;case 21:break G;case 20:break H;case 19:break I;case 16:break J;case 15:break K;case 14:break L;case 13:break M;case 12:break N;case 11:break O;case 10:break P;case 9:break Q;case 3:break R;case 2:break S;case 1:break T;case 0:break U;default:break p}}break a}t[c+3|0]=11;t[c+5|0]=d<<4|15;continue}t[c+3|0]=11;t[c+5|0]=d<<4;continue}t[c+3|0]=11;t[c+5|0]=d|240;continue}t[c+3|0]=11;t[c+5|0]=d&15;continue}t[c+3|0]=2;t[c+5|0]=d|240;continue}t[c+3|0]=2;continue}t[c+3|0]=3;t[c+5|0]=d|240;continue}t[c+3|0]=3;continue}t[c+3|0]=4;continue}t[c+3|0]=20;t[c+5|0]=d|16;continue}t[c+3|0]=6;t[c+5|0]=d<<4;continue}t[c+3|0]=6;t[c+5|0]=d&15;continue}t[c+3|0]=5;continue}t[c+3|0]=20;t[c+5|0]=d|48;continue}t[c+3|0]=7;t[c+5|0]=d<<4;continue}t[c+3|0]=7;t[c+5|0]=d&15;continue}t[c+3|0]=8;continue}t[c+3|0]=20;t[c+5|0]=d|64;continue}t[c+3|0]=10;v[23296]=0;d=T(194,g|0)|0;j=v[23296];v[23296]=0;if((j|0)!=1){t[c+5|0]=d;v[23296]=0;Q(176,g|0,1)|0;c=v[23296];v[23296]=0;if((c|0)!=1){continue}}break a}t[c+3|0]=15;t[c+5|0]=d&15;continue}t[c+3|0]=20;t[c+5|0]=d|192;continue}t[c+3|0]=20;t[c+5|0]=d|208;continue}t[c+3|0]=12;continue}t[c+3|0]=14;continue}t[c+3|0]=20;t[c+5|0]=d|176;continue}t[c+3|0]=20;t[c+5|0]=d|224;continue}t[c+3|0]=16;continue}t[c+3|0]=17;continue}t[c+3|0]=1;continue}t[c+3|0]=20;t[c+5|0]=d&15|32;continue}t[c+3|0]=20;t[c+5|0]=d&15|128;continue}t[c+3|0]=0;continue}break}if((c|0)==64){break m}qe($b(v[k>>2],f),yh(Ke(Fe(e+96|0,14,0),c-1|0)))}Ab(g)}f=f+1|0;continue}break}break a}c=x[e+218>>1]|x[e+220>>1]<<16;if(!c){break b}$c(b,c);jB(a+1298332|0,b,Fg(b),4)}jb=e+272|0;return i|0}a=P()|0;O()|0;Ab(g);S(a|0);L()}function zda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=jb-208|0;jb=d;Ac(c);a:{if(!po(c,d+192|0)){break a}if(Pb(d+192|0,13662,4)){break a}f=d+200|0;if(Pb(f,14031,4)){if(Pb(f,14135,4)){break a}}e=jb-32|0;jb=e;i=d+176|0;g=Qb(i);b:{c:{d:{e:{f:{while(1){h=v[c+8>>2];j=v[c>>2];v[23296]=0;h=W(144,j|0,h|0,8)|0;j=v[23296];v[23296]=0;if((j|0)==1){break d}if(!h){break e}v[23296]=0;R(740,e|0,c|0);h=v[23296];v[23296]=0;if((h|0)!=1){v[23296]=0;R(741,g|0,e|0);h=v[23296];v[23296]=0;if((h|0)==1){break f}Md(e);continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;Md(e);break c}jb=e+32|0;break b}a=P()|0;O()|0}_d(g);S(a|0);L()}v[23296]=0;U(668,d+152|0,i|0,1129270605);c=v[23296];v[23296]=0;g:{h:{i:{j:{k:{l:{m:{if((c|0)!=1){v[23296]=0;c=Q(669,d+152|0,d+128|0)|0;e=v[23296];v[23296]=0;n:{o:{if((e|0)!=1){if(!c){break g}if(!cc(x[d+130>>1]|x[d+132>>1]<<16)){break g}if((Mb(x[d+128>>1])-3&65535)>>>0<65534){break g}if((Mb(x[d+134>>1])-65&65535)>>>0<65472){break g}v[d+124>>2]=1162760014;c=1;if(!Pb(f,14135,4)){v[23296]=0;c=Q(557,d+152|0,d+124|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break o}if(!c){break g}c=v[d+124>>2]!=1936684916}v[23296]=0;U(668,d+104|0,d+176|0,1397968452);e=v[23296];v[23296]=0;p:{q:{if((e|0)!=1){v[23296]=0;k=Q(670,d+104|0,d+96|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break p}if(k){break q}break h}c=P()|0;O()|0;break j}f=((Mb(x[d+134>>1])-1|0)/8|0)-1|0;g=f<<3;e=g&31;g=_c(d+88|0,(f>>>0<7?(g&63)>>>0>=32?4196360>>>e|0:((1<<e)-1&4196360)<<32-e|136321040>>>e:8)&255,(Mb(x[d+128>>1])|0)==2?2:1,c,0);c=v[d+124>>2];r:{if((c|0)!=544694642){s:{t:{if(!((c|0)==842222662|(c|0)==842230886|(c|0)==875973702)){if((c|0)==2002873461){break s}if((c|0)==1463897153){break t}if((c|0)==1463897173){break s}if((c|0)==2002873441){break t}if((c|0)!=875981926){break r}}Sf(g,3);break r}Sf(g,17);Fh(g,16);break r}Sf(g,16);Fh(g,16);break r}Sf(g,1)}c=v[d+96>>2];v[23296]=0;c=W(144,v[d+104>>2],v[d+112>>2],cc(c)|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break l}if(c){c=v[d+96>>2];v[23296]=0;Q(176,d+104|0,cc(c)|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break l}}ft(a,b);v[23296]=0;c=B(b,104)+a|0;i=c+484380|0;R(264,i|0,0);e=v[23296];v[23296]=0;u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{if((e|0)==1){break D}r=i,s=cc(x[d+130>>1]|x[d+132>>1]<<16),v[r>>2]=s;j=c+484404|0;c=w[d+138|0]|w[d+139|0]<<8|(w[d+140|0]<<16|w[d+141|0]<<24);f=c<<24|c<<8&16711680|(c>>>8&65280|c>>>24);h=30-w[d+137|0]|0;e=0;while(1){c=f;if(h&255){f=c>>>1|0;h=h-1|0;e=c;continue}break}v[j>>2]=c+(e&1);v[23296]=0;W(207,g|0,i|0,d+104|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break D}v[23296]=0;U(668,d- -64|0,d+176|0,1296126539);c=v[23296];v[23296]=0;if((c|0)==1){break C}v[23296]=0;c=T(166,v[d+64>>2])|0;e=v[23296];v[23296]=0;if((e|0)==1){break B}if(!c){break u}v[23296]=0;U(668,d+16|0,d+176|0,1229869908);c=v[23296];v[23296]=0;if((c|0)==1){break A}v[23296]=0;c=Q(671,d+16|0,d+40|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break z}Ab(d+16|0);if(!c){break u}v[23296]=0;f=T(258,d- -64|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break y}e=Qb(d+16|0);v[23296]=0;R(672,e|0,f|0);c=v[23296];v[23296]=0;if((c|0)==1){break w}c=0;while(1){if((c|0)==(f|0)){break x}v[23296]=0;g=Q(673,d- -64|0,d|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break w}if(!g){break x}v[23296]=0;R(674,e|0,d|0);g=v[23296];v[23296]=0;if((g|0)==1){break w}v[23296]=0;Q(176,d- -64|0,w[d+6|0]|1)|0;g=v[23296];v[23296]=0;if((g|0)==1){break w}c=c+1|0;continue}}c=P()|0;O()|0;break k}c=P()|0;O()|0;break k}c=P()|0;O()|0;break m}c=P()|0;O()|0;break m}c=P()|0;O()|0;Ab(d+16|0);break m}c=P()|0;O()|0;break m}c=Mb(x[d+48>>1]);if(c){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]&65511|((c|0)==2)<<4|8}c=Mb(x[d+54>>1]);if(c){f=(B(b,104)+a|0)+484414|0;u[f>>1]=x[f>>1]&65529|((c|0)==2?4:2)|2}r=d,s=Eb(v[e>>2]),v[r>>2]=s;c=B(b,104)+a|0;g=c+484388|0;h=c+484384|0;j=c+484396|0;l=c+484392|0;m=Eb(v[e+4>>2]);n=x[d+50>>1];o=x[d+52>>1];p=x[d+56>>1];q=x[d+58>>1];while(1){c=v[d>>2];if(!Rb(c,m)){break v}f=Mb(w[c|0]|w[c+1|0]<<8);if((f|0)==(Mb(n)|0)){r=l,s=cc(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Mb(w[c|0]|w[c+1|0]<<8)}if((Mb(o)|0)==(f|0)){r=j,s=cc(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Mb(w[c|0]|w[c+1|0]<<8)}if((Mb(p)|0)==(f|0)){r=h,s=cc(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s;f=Mb(w[c|0]|w[c+1|0]<<8)}if((f|0)==(Mb(q)|0)){r=g,s=cc(w[c+2|0]|w[c+3|0]<<8|(w[c+4|0]<<16|w[c+5|0]<<24)),v[r>>2]=s}v[d>>2]=v[d>>2]+7;continue}}c=P()|0;O()|0;VN(e);break m}lk(i);VN(e)}v[23296]=0;U(668,d+16|0,d+176|0,1312902469);c=v[23296];v[23296]=0;if((c|0)==1){break n}v[23296]=0;c=T(166,v[d+16>>2])|0;e=v[23296];v[23296]=0;E:{if((e|0)==1){break E}F:{if(c){v[23296]=0;c=T(148,v[d+16>>2])|0;e=v[23296];v[23296]=0;if((e|0)==1){break E}v[23296]=0;U(300,d+16|0,((b<<5)+a|0)+946304|0,c|0);b=v[23296];v[23296]=0;if((b|0)!=1){break F}break E}v[23296]=0;c=Q(54,d|0,21473)|0;e=v[23296];v[23296]=0;if((e|0)==1){break E}Ec(((b<<5)+a|0)+946304|0,c);yb(c)}vz(i,v[a+480180>>2]);mj(i,a);Ab(d+16|0);Ab(d- -64|0);break h}c=P()|0;O()|0;Ab(d+16|0);break m}c=P()|0;O()|0;break k}c=P()|0;O()|0;break j}c=P()|0;O()|0;break j}c=P()|0;O()|0;break m}c=P()|0;O()|0;break i}Ab(d- -64|0);break k}c=P()|0;O()|0}Ab(d+104|0)}Ab(d+152|0)}_d(d+176|0);S(c|0);L()}Ab(d+104|0)}Ab(d+152|0);_d(d+176|0)}jb=d+208|0;return k|0}function $da(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0,D=0;e=jb-224|0;jb=e;Ac(b);a:{if(!Jt(b,e+160|0)){break a}if(!oQ(e+160|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Vc(nQ(e+160|0),mb))){break a}if(!c){d=1;break a}Ed(a,256);f=e+144|0;tj(f,2,e+160|0);d=e+48|0;Gc(d,f);Bc(a+1298308|0,d);yb(d);f=x[e+210>>1];v[a+480260>>2]=64;v[a+480264>>2]=32767;u[a+480188>>1]=4;u[a+480190>>1]=f;Nb(a+1074312|0,107,1);f=w[e+203|0];f=f?f:96;k=Qz(f);v[a+480196>>2]=f>>>4;v[a+480204>>2]=k;t[e+48|0]=64;C=a,D=w[Wb(e+202|0,d)|0]<<2,v[C+480200>>2]=D;d=0;b:{c:{d:{e:{f:{g:{while(1){if((d|0)==4){h:{k=Qb(e+144|0);m=Qb(e+128|0);v[23296]=0;Q(143,b|0,x[e+192>>1]<<4)|0;d=v[23296];v[23296]=0;i:{if((d|0)==1){break i}v[23296]=0;W(205,b|0,k|0,x[e+208>>1])|0;d=v[23296];v[23296]=0;if((d|0)==1){break i}v[23296]=0;Q(143,b|0,x[e+194>>1]<<4)|0;d=v[23296];v[23296]=0;if((d|0)==1){break i}v[23296]=0;W(205,b|0,m|0,x[e+210>>1])|0;d=v[23296];v[23296]=0;if((d|0)==1){break i}v[23296]=0;Q(143,b|0,(x[e+196>>1]<<4)+32|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break i}d=a+484376|0;f=w[d|0];i=v[a+484360>>2];v[23296]=0;R(310,Zb(i,f)|0,x[e+212>>1]);f=v[23296];v[23296]=0;if((f|0)==1){break i}d=Zb(v[a+484360>>2],w[d|0]);C=e,D=Eb(v[d>>2]),v[C+48>>2]=D;d=Eb(v[d+4>>2]);j:{while(1){f=v[e+48>>2];if(!Rb(f,d)){d=0;if(!qQ(Zb(v[a+484360>>2],w[a+484376|0]))){break b}i=c&2;j=e+48|1;d=1;break j}v[23296]=0;i=T(194,b|0)|0;j=v[23296];v[23296]=0;k:{if((j|0)==1){break k}u[f>>1]=i;v[23296]=0;Q(176,b|0,4)|0;f=v[23296];v[23296]=0;if((f|0)==1){break k}Se(e+48|0);continue}break}d=P()|0;O()|0;break c}l:{m:{n:{o:{while(1){f=d&65535;if(f>>>0>x[e+210>>1]){break l}g=dc(v[m>>2],f-1|0);g=w[g|0]|w[g+1|0]<<8;v[23296]=0;g=Q(143,b|0,g<<4)|0;h=v[23296];v[23296]=0;p:{if((h|0)!=1){if(g){break p}d=0;break b}d=P()|0;O()|0;break c}v[23296]=0;Q(621,b|0,e+48|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break o}v[23296]=0;g=(B(f,104)+a|0)+484380|0;U(622,e+48|0,g|0,0);h=v[23296];v[23296]=0;if((h|0)==1){break o}h=e+16|0;ek(h,2,j);v[23296]=0;R(210,e+32|0,h|0);h=v[23296];v[23296]=0;if((h|0)==1){break n}h=((f<<5)+a|0)+946304|0;f=e+32|0;Ec(h,f);yb(f);q:{r:{if(!i|!v[e+64>>2]){break r}f=EQ(e+48|0);v[23296]=0;f=Q(143,b|0,f|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break m}if(!f){break r}f=e+32|0;DQ(f,w[e+78|0],w[e+79|0],1);v[23296]=0;W(207,f|0,g|0,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break q}}d=d+1|0;continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}t[e+15|0]=1;d=v[k>>2];s:{if(uc(d,v[k+4>>2])|x[e+188>>1]==26){break s}f=w[d|0]|w[d+1|0]<<8;d=0;v[23296]=0;f=Q(143,b|0,f<<4)|0;i=v[23296];v[23296]=0;if((i|0)==1){break h}if(!f){break b}v[23296]=0;d=T(182,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break h}if((d|0)!=x[e+188>>1]){break s}t[e+15|0]=0}n=c&1;if(n){v[23296]=0;R(213,a+484344|0,x[e+208>>1]);c=v[23296];v[23296]=0;if((c|0)==1){break h}}h=a+484344|0;c=e+48|0;p=c|5;q=c|3;r=c|4;s=c|2;y=c|1;z=a+480188|0;f=0;while(1){t:{if(!n|x[e+208>>1]<=f>>>0){break t}v[23296]=0;c=W(214,h|0,f&65535,64)|0;d=v[23296];v[23296]=0;if((d|0)==1){break g}if(!c){break t}c=dc(v[k>>2],f);c=w[c|0]|w[c+1|0]<<8;v[23296]=0;c=Q(143,b|0,c<<4)|0;d=v[23296];v[23296]=0;if((d|0)==1){break g}d=0;if(!c){break b}if(!w[e+15|0]){v[23296]=0;c=T(182,b|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break g}if(c>>>0>2112){break b}}u[e+16>>1]=65535;v[e+32>>2]=63;u:while(1){c=$b(v[h>>2],f);A=Qf(v[c>>2],v[v[c+48>>2]+12>>2],d);v:while(1){c=d;while(1){if(c>>>0<=63){v[23296]=0;i=T(194,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break f}if(!i){d=64;if(c>>>0>62){continue v}d=c+1|0;continue u}d=i&31;j=B(d,6)+A|0;l=Th(e+48|0);g=d>>>0<x[z>>1];o=g?j:l;if(i&32){v[23296]=0;R(247,e|0,b|0);d=v[23296];v[23296]=0;w:{x:{y:{if((d|0)!=1){l=kd(e);d=w[e|0];if(d>>>0>239){break y}d=CQ((B(d>>>4|0,12)+(d&15)|0)+37|0);break x}d=P()|0;O()|0;break c}z:{switch(d-254|0){case 0:break x;case 1:break z;default:break w}}d=0}t[o|0]=d}t[(g?j+1|0:y)|0]=w[l|0]}if(i&64){v[23296]=0;d=T(194,b|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break e}t[e|0]=d;t[(g?j+2|0:s)|0]=1;t[e+14|0]=64;C=g?j+4|0:r,D=w[Wb(e,e+14|0)|0],t[C|0]=D}if(!(i&128)){continue}v[23296]=0;R(247,e|0,b|0);d=v[23296];v[23296]=0;if((d|0)==1){break d}t[(g?j+3|0:q)|0]=w[e|0];C=g?j+5|0:p,D=w[kd(e)|0],t[C|0]=D;pQ(o,c,255,e+16|0,e+32|0);continue}break}break}break}c=x[e+16>>1];if((c|0)!=65535){qe($b(v[h>>2],f),qm(Ke(Fe(e+48|0,12,c&255),v[e+32>>2])))}f=f+1|0;continue}break}v[23296]=0;b=Q(1,e+48|0,6049)|0;c=v[23296];v[23296]=0;A:{B:{C:{if((c|0)!=1){Hb(a+1298344|0,b);zb(b);v[23296]=0;b=Q(1,e+32|0,5235)|0;c=v[23296];v[23296]=0;if((c|0)==1){break C}Hb(a+1298356|0,b);zb(b);v[a+1298404>>2]=5;v[23296]=0;R(624,e|0,4366);b=v[23296];v[23296]=0;if((b|0)==1){break B}v[23296]=0;U(291,e+16|0,e|0,e+15|0);b=v[23296];v[23296]=0;if((b|0)==1){break A}b=a+1298368|0;a=e+16|0;Hb(b,a);zb(a);ec(e);d=1;break b}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;ec(e);break c}d=P()|0;O()|0;break c}}else{f=(d<<5)+a|0;Te(f+480280|0);u[f+480284>>1]=d&1?64:192;d=d+1|0;continue}break}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0;break c}d=P()|0;O()|0}ud(m);ud(k);S(d|0);L()}ud(m);ud(k)}jb=e+224|0;return d|0}function AH(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,C=0,D=0,E=0,F=0;i=jb-80|0;jb=i;v[i+76>>2]=b;D=i+55|0;s=i+56|0;b=0;a:{b:{c:{d:{e:while(1){if((2147483647-o|0)<(b|0)){break d}o=b+o|0;f:{g:{h:{k=v[i+76>>2];b=k;h=w[b|0];if(h){while(1){i:{h=h&255;j:{if(!h){h=b;break j}if((h|0)!=37){break i}h=b;while(1){if(w[b+1|0]!=37){break j}j=b+2|0;v[i+76>>2]=j;h=h+1|0;l=w[b+2|0];b=j;if((l|0)==37){continue}break}}b=h-k|0;C=2147483647-o|0;if((b|0)>(C|0)){break d}if(a){hf(a,k,b)}if(b){continue e}r=-1;h=1;b=v[i+76>>2];j=t[b+1|0];if(!(!Mj(j)|w[b+2|0]!=36)){r=j-48|0;y=1;h=3}b=h+b|0;v[i+76>>2]=b;p=0;m=t[b|0];j=m-32|0;k:{if(j>>>0>31){h=b;break k}h=b;j=1<<j;if(!(j&75913)){break k}while(1){h=b+1|0;v[i+76>>2]=h;p=j|p;m=t[b+1|0];j=m-32|0;if(j>>>0>=32){break k}b=h;j=1<<j;if(j&75913){continue}break}}l:{if((m|0)==42){b=t[h+1|0];m:{if(!(!Mj(b)|w[h+2|0]!=36)){v[((b<<2)+e|0)-192>>2]=10;m=h+3|0;y=1;q=v[((t[h+1|0]<<3)+d|0)-384>>2];break m}if(y){break h}m=h+1|0;if(!a){v[i+76>>2]=m;y=0;q=0;break l}b=v[c>>2];v[c>>2]=b+4;y=0;q=v[b>>2]}v[i+76>>2]=m;if((q|0)>=0){break l}q=0-q|0;p=p|8192;break l}q=zH(i+76|0);if((q|0)<0){break d}m=v[i+76>>2]}b=0;l=-1;n:{if(w[m|0]!=46){j=m;h=0;break n}if(w[m+1|0]==42){h=t[m+2|0];o:{if(!(!Mj(h)|w[m+3|0]!=36)){v[((h<<2)+e|0)-192>>2]=10;j=m+4|0;l=v[((t[m+2|0]<<3)+d|0)-384>>2];break o}if(y){break h}j=m+2|0;l=0;if(!a){break o}h=v[c>>2];v[c>>2]=h+4;l=v[h>>2]}v[i+76>>2]=j;h=(l^-1)>>>31|0;break n}v[i+76>>2]=m+1;l=zH(i+76|0);j=v[i+76>>2];h=1}z=h;while(1){n=b;h=28;x=j;if(t[j|0]-123>>>0<4294967238){break c}j=x+1|0;v[i+76>>2]=j;b=w[(t[x|0]+B(n,58)|0)+75391|0];if(b-1>>>0<8){continue}break}p:{q:{if((b|0)!=27){if(!b){break c}if((r|0)>=0){v[(r<<2)+e>>2]=b;b=(r<<3)+d|0;h=v[b+4>>2];v[i+64>>2]=v[b>>2];v[i+68>>2]=h;break q}if(!a){break f}yH(i- -64|0,b,c,g);break p}if((r|0)>=0){break c}}b=0;if(!a){continue e}}m=p&-65537;j=p&8192?m:p;p=0;r=5247;h=s;r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{F:{G:{b=t[x|0];b=n?(b&15)==3?b&-33:b:b;switch(b-88|0){case 11:break r;case 9:case 13:case 14:case 15:break s;case 27:break x;case 12:case 17:break A;case 23:break B;case 0:case 32:break C;case 24:break D;case 22:break E;case 29:break F;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 10:case 16:case 18:case 19:case 20:case 21:case 25:case 26:case 28:case 30:case 31:break g;default:break G}}H:{switch(b-65|0){case 0:case 4:case 5:case 6:break s;case 2:break v;case 1:case 3:break g;default:break H}}if((b|0)==83){break w}break g}n=v[i+64>>2];k=v[i+68>>2];r=5247;break z}b=0;I:{switch(n&255){case 0:v[v[i+64>>2]>>2]=o;continue e;case 1:v[v[i+64>>2]>>2]=o;continue e;case 2:h=v[i+64>>2];v[h>>2]=o;v[h+4>>2]=o>>31;continue e;case 3:u[v[i+64>>2]>>1]=o;continue e;case 4:t[v[i+64>>2]]=o;continue e;case 6:v[v[i+64>>2]>>2]=o;continue e;case 7:break I;default:continue e}}h=v[i+64>>2];v[h>>2]=o;v[h+4>>2]=o>>31;continue e}l=l>>>0>8?l:8;j=j|8;b=120}m=s;E=b&32;n=v[i+64>>2];k=v[i+68>>2];if(n|k){while(1){m=m-1|0;t[m|0]=E|w[(n&15)+75920|0];F=!k&n>>>0>15|(k|0)!=0;x=k;k=k>>>4|0;n=(x&15)<<28|n>>>4;if(F){continue}break}}k=m;if(!(j&8)|!(v[i+64>>2]|v[i+68>>2])){break y}r=(b>>>4|0)+5247|0;p=2;break y}b=s;n=v[i+64>>2];k=v[i+68>>2];if(n|k){while(1){b=b-1|0;t[b|0]=n&7|48;x=!k&n>>>0>7|(k|0)!=0;m=k;k=m>>>3|0;n=(m&7)<<29|n>>>3;if(x){continue}break}}k=b;if(!(j&8)){break y}b=s-k|0;l=(b|0)<(l|0)?l:b+1|0;break y}b=v[i+68>>2];k=b;n=v[i+64>>2];if((b|0)<0){k=0-(k+((n|0)!=0)|0)|0;n=0-n|0;v[i+64>>2]=n;v[i+68>>2]=k;p=1;r=5247;break z}if(j&2048){p=1;r=5248;break z}p=j&1;r=p?5249:5247}k=sn(n,k,s)}if((l|0)<0?z:0){break d}j=z?j&-65537:j;m=v[i+64>>2];b=v[i+68>>2];if(!((m|b)!=0|l)){k=s;h=k;l=0;break g}b=!(b|m)+(s-k|0)|0;l=(b|0)<(l|0)?l:b;break g}b=v[i+64>>2];k=b?b:16891;b=k;h=l>>>0<2147483647?l:2147483647;j=Yt(b,0,h);b=j?j-b|0:h;h=b+k|0;if((l|0)>=0){j=m;l=b;break g}j=m;l=b;if(w[h|0]){break d}break g}if(l){h=v[i+64>>2];break u}b=0;sf(a,32,q,0,j);break t}v[i+12>>2]=0;v[i+8>>2]=v[i+64>>2];h=i+8|0;v[i+64>>2]=h;l=-1}b=0;J:{while(1){k=v[h>>2];if(!k){break J}k=xH(i+4|0,k);m=(k|0)<0;if(!(m|k>>>0>l-b>>>0)){h=h+4|0;b=b+k|0;if(l>>>0>b>>>0){continue}break J}break}if(m){break b}}h=61;if((b|0)<0){break c}sf(a,32,q,b,j);if(!b){b=0;break t}k=0;h=v[i+64>>2];while(1){l=v[h>>2];if(!l){break t}l=xH(i+4|0,l);k=l+k|0;if(k>>>0>b>>>0){break t}hf(a,i+4|0,l);h=h+4|0;if(b>>>0>k>>>0){continue}break}}sf(a,32,q,b,j^8192);b=(b|0)<(q|0)?q:b;continue e}if((l|0)<0?z:0){break d}h=61;b=nb[f|0](a,A[i+64>>3],q,l,j,b)|0;if((b|0)>=0){continue e}break c}t[i+55|0]=v[i+64>>2];l=1;k=D;j=m;break g}j=b+1|0;v[i+76>>2]=j;h=w[b+1|0];b=j;continue}}if(a){break a}if(!y){break f}b=1;while(1){a=v[(b<<2)+e>>2];if(a){yH((b<<3)+d|0,a,c,g);o=1;b=b+1|0;if((b|0)!=10){continue}break a}break}o=1;if(b>>>0>=10){break a}while(1){if(v[(b<<2)+e>>2]){break h}b=b+1|0;if((b|0)!=10){continue}break}break a}h=28;break c}m=h-k|0;n=(l|0)>(m|0)?l:m;if((n|0)>(2147483647-p|0)){break d}h=61;l=n+p|0;b=(l|0)<(q|0)?q:l;if((C|0)<(b|0)){break c}sf(a,32,b,l,j);hf(a,r,p);sf(a,48,b,l,j^65536);sf(a,48,n,m,0);hf(a,k,m);sf(a,32,b,l,j^8192);continue}break}o=0;break a}h=61}v[115772]=h}o=-1}jb=i+80|0;return o}function nha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=jb-224|0;jb=f;if(Ah(b,13677)){if(d){t[d|0]=1}k=a+480204|0;n=a+480216|0;o=a+480220|0;p=a+480224|0;l=a+1074368|0;s=a+480228|0;z=a+480232|0;q=a+480200|0;m=a+480268|0;A=a+1298320|0;C=a+480248|0;D=du(a+1074312|0);E=a+480180|0;F=a+484376|0;G=a+480190|0;a:{b:{c:{d:{e:{f:{g:{h:{while(1){if(!Ob(v[b>>2],v[b+8>>2],7)){break a}e=qg(b);g=Fg(b);if((e|0)==(w[21449]|w[21450]<<8|(w[21451]<<16|w[21452]<<24))){ng(b,6);break a}if(!(e&1616928864)|e&-2139062144){break a}if(!Ob(v[b>>2],v[b+8>>2],g)){break a}d=f+176|0;Yd(d,b,g);h=jc(f+200|0,d);Ab(d);i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{if((e|0)!=1127099950){if((e|0)==1129797166){break v}if((e|0)==1130917459){break o}if((e|0)==1145525806){break t}d=z;if((e|0)==1448301654){break s}if((e|0)==1196316499){break m}if((e|0)==1213486401){break p}if((e|0)==1280530262){break u}if((e|0)==1297303086){break l}if((e|0)==1347243310){break w}if((e|0)==1347244882){break q}if((e|0)!=1380340804){if((e|0)==1380986414){break r}d=n;if((e|0)==1380991534){break s}d=o;if((e|0)==1380994350){break s}if((e|0)==1397052739){break n}d=s;if((e|0)==1397768494){break s}if((e|0)==1414344238){break k}if((e|0)!=1146367534){break j}v[23296]=0;U(387,h|0,g|0,f+176|0);d=v[23296];v[23296]=0;if((d|0)==1){break i}v[k>>2]=B(v[f+176>>2],1e4)+(y[k>>2]%1e4|0);break j}v[23296]=0;U(387,h|0,g|0,f+176|0);d=v[23296];v[23296]=0;if((d|0)!=1){d=v[k>>2];v[k>>2]=d-((d>>>0)%1e4|0)+y[f+176>>2]%1e4;break j}e=P()|0;O()|0;break b}if(c){break j}v[23296]=0;u[f+176>>1]=0;U(388,h|0,g|0,f+176|0);d=v[23296];v[23296]=0;if((d|0)!=1){H=a,I=Xd(x[f+176>>1],x[a+480188>>1],127),u[H+480188>>1]=I;break j}e=P()|0;O()|0;break b}v[23296]=0;U(389,h|0,g|0,l|0);d=v[23296];v[23296]=0;if((d|0)!=1){break j}break c}v[23296]=0;v[f+176>>2]=0;U(387,h|0,g|0,f+176|0);d=v[23296];v[23296]=0;if((d|0)!=1){v[a+1074304>>2]=v[f+176>>2];break j}e=P()|0;O()|0;break b}v[23296]=0;v[f+176>>2]=0;U(387,h|0,g|0,f+176|0);d=v[23296];v[23296]=0;if((d|0)==1){break h}d=v[f+176>>2];if(!d){break j}v[a+1074308>>2]=d;break j}d=q}v[23296]=0;U(387,h|0,g|0,d|0);d=v[23296];v[23296]=0;if((d|0)==1){break c}break j}if(v[E>>2]==4){break j}v[23296]=0;U(388,h|0,g|0,f+176|0);d=v[23296];v[23296]=0;if((d|0)!=1){_e(Zb(v[a+484360>>2],w[F|0]),x[f+176>>1]);break j}e=P()|0;O()|0;break b}v[23296]=0;U(390,h|0,g|0,m|0);d=v[23296];v[23296]=0;if((d|0)==1){break c}if(yo(w[m|0])){break j}t[m|0]=5;break j}d=Kb(f+176|0);e=v[h>>2];v[23296]=0;e=T(148,e|0)|0;g=v[23296];v[23296]=0;x:{if((g|0)==1){break x}v[23296]=0;U(391,h|0,d|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break x}v[23296]=0;U(11,f+160|0,0,d|0);e=v[23296];v[23296]=0;if((e|0)==1){break x}e=f+160|0;Hb(A,e);zb(e);yb(d);break j}e=P()|0;O()|0;yb(d);break b}if(g&1|g>>>0>126){break j}d=64;u[f+176>>1]=(g>>>1|0)- -64;u[f+160>>1]=127;e=x[Zc(f+176|0,f+160|0)>>1];i=e>>>0>64?e:64;while(1){if((d|0)==(i|0)){break j}v[23296]=0;R(247,f+176|0,h|0);e=v[23296];v[23296]=0;if((e|0)==1){break g}e=w[f+176|0];y:{if((e|0)==255){break y}j=w[kd(f+176|0)|0];g=(d<<5)+a|0;r=g+480284|0;u[r>>1]=128;u[g+480286>>1]=j;g=g+480280|0;j=(e&128)<<3;v[g>>2]=j;e=e&127;if(e>>>0<65){u[r>>1]=e<<2;break y}if((e|0)!=100){break y}v[g>>2]=j|256}d=d+1|0;continue}}if(g>>>0<3){break j}v[23296]=0;d=T(182,h|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break f}if(!d|d>>>0>x[G>>1]){break j}d=(B(d,104)+a|0)+484448|0;g=bT(d);while(1){if((d|0)==(g|0)){break j}e=v[h>>2];v[23296]=0;i=W(144,e|0,v[f+208>>2],4)|0;e=v[23296];v[23296]=0;z:{if((e|0)!=1){e=268435456;if(!i){break z}v[23296]=0;e=T(145,h|0)|0;i=v[23296];v[23296]=0;if((i|0)!=1){break z}}e=P()|0;O()|0;break b}v[d>>2]=e;d=d+4|0;continue}}if(g>>>0<3){break j}v[23296]=0;R(392,f|0,h|0);d=v[23296];v[23296]=0;A:{B:{C:{D:{if((d|0)!=1){v[23296]=0;U(393,f+176|0,v[f>>2],v[f+4>>2]);d=v[23296];v[23296]=0;if((d|0)==1){break D}v[23296]=0;d=Q(78,f+16|0,f+176|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break C}yb(f+176|0);fc(f);e=v[h>>2];v[23296]=0;T(148,e|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break A}v[23296]=0;U(394,d|0,C|0,d|0);e=v[23296];v[23296]=0;if((e|0)==1){break A}jf(d);break j}e=P()|0;O()|0;break b}e=P()|0;O()|0;break B}e=P()|0;O()|0;yb(f+176|0)}fc(f);break b}e=P()|0;O()|0;jf(d);break b}e=0;g=du(D);E:while(1){d=v[h>>2];v[23296]=0;d=W(144,d|0,v[f+208>>2],1)|0;i=v[23296];v[23296]=0;if((i|0)==1){break d}if(!(d&e>>>0<117)){break j}v[23296]=0;i=T(194,h|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break e}d=0;while(1){if((d|0)==8){continue E}F:{if(!(i>>>d&1)|e>>>0>116){break F}v[23296]=0;W(251,g|0,e|0,1)|0;j=v[23296];v[23296]=0;if((j|0)!=1){break F}e=P()|0;O()|0;break b}e=e+1|0;d=d+1|0;continue}}}v[23296]=0;U(395,h|0,g|0,p|0);d=v[23296];v[23296]=0;if((d|0)==1){break c}}Ab(h);continue}break}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0}Ab(h);S(e|0);L()}b=v[a+8>>2];Fo(k,B(v[b+20>>2],1e4),B(v[b+24>>2],1e4));if(w[a+480224|0]>=3){t[p|0]=0}if(w[l|0]>=6){t[l|0]=0}yc(q,256);yc(n,65536);yc(o,65536)}jb=f+224|0}function dea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-352|0;jb=d;$c(b,60);h=15;a:{if(!Ah(b,13983)){$c(b,124);h=31;if(!Ah(b,15150)){break a}}Ed(a,536870912);u[a+480190>>1]=h;Ac(b);b:{while(1){if(x[a+480190>>1]>f>>>0){e=sm(b);v[(d+224|0)+(f<<2)>>2]=e;f=f+1|0;if(e>>>0<=131072){continue}break b}break}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480196>>2]=6;f=0;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;xh(a,1);ac(b,4);e=yq(b);if(e>>>0<178){break a}p=a,q=Ie(1776930/+(e>>>0)*1e4),v[p+480204>>2]=q;ac(b,14);h=0;k=1;c:while(1){n=k&65535;if(n>>>0<=x[a+480190>>1]){ER(b,d+56|0);e=v[((n<<2)+d|0)+220>>2];g=jb-16|0;jb=g;i=(B(n,104)+a|0)+484380|0;pd(i,1);v[i>>2]=e;t[i+37|0]=w[d+80|0]<<4;t[g+15|0]=w[d+81|0];t[g+14|0]=64;p=i,q=w[Wb(g+15|0,g+14|0)|0]<<2,u[p+30>>1]=q;d:{if(!e){break d}f=Mb(w[d+84|0]|w[d+85|0]<<8);l=Mb(w[d+82|0]|w[d+83|0]<<8);v[i+4>>2]=l;f=(f<<1)+l|0;v[i+8>>2]=f;if(e>>>0<=l>>>0){l=e-1|0;v[i+4>>2]=l}if(e>>>0<f>>>0){v[i+8>>2]=e;f=e}if(!(!(f>>>0<4|f>>>0<l>>>0)&f-l>>>0>3)){v[i+4>>2]=0;v[i+8>>2]=0;break d}if(f>>>0<=l>>>0){break d}u[i+34>>1]=x[i+34>>1]|2}jb=g+16|0;f=0;while(1)if((f|0)==22){if(h>>>0>127){break b}e=d+192|0;jl(e,3,d+56|0);f=d+208|0;Gc(f,e);Ec(((n<<5)+a|0)+946304|0,f);k=k+1|0;yb(f);continue c}else{e=(d+56|0)+f|0;if((w[e|0]-1&255)>>>0<=30){t[e|0]=32;h=h+1|0}f=f+1|0;continue}}break}i=1;e:{f:{g:{h=a+946336|0;f=Vb(d+56|0,13850);if(!xQ(h,f)){v[23296]=0;e=Q(54,d+208|0,13861)|0;i=v[23296];v[23296]=0;if((i|0)==1){break g}i=xQ(h,e);yb(e)}yb(f);f=0;e=d+56|0;h=DR(b,e);if(!h){cA(e)}if(!h){break a}e=w[d+56|0];if(!AQ(e)){break a}if(!c){break e}u[d+54>>1]=0;while(1)if((e|0)==(f|0)){f=a+484360|0;h=a+484376|0;g=Zb(v[f>>2],w[h|0]);k=w[d+57|0];_e(g,e>>>0>k>>>0?k:0);tq(Zb(v[f>>2],w[h|0]),d+56|2,w[d+56|0]);if(x[a+480190>>1]==31){ac(b,4)}v[d+48>>2]=0;v[d+44>>2]=0;v[d+40>>2]=0;t[d+39|0]=0;n=c&1;if(n){mg(a+484344|0,x[d+54>>1])}l=a+484344|0;k=0;while(1){h:{i:{j:{if(x[d+54>>1]<=k>>>0){if(!(c&2)){break j}f=1;while(1){h=x[a+480190>>1];c=f&65535;if(h>>>0<c>>>0){break i}c=(B(c,104)+a|0)+484380|0;if(v[c>>2]){lg(_c(d+192|0,8,1,0,0),c,b)}f=f+1|0;continue}}k:{if(n){h=0;if(bh(l,k&65535,64)){break k}}ac(b,1024);break h}l:while(1){if((h|0)==64){break h}f=0;e=$b(v[l>>2],k);o=fd(v[e>>2],v[v[e+48>>2]+12>>2],h,0);while(1)if((f|0)==4){h=h+1|0;continue l}else{g=d+192|0;zm(g,b);e=B(f,6)+o|0;m:{n:{o:{p:{if(w[Lb(g,0)|0]!=255){break p}t[(d+48|0)+f|0]=0;t[(d+40|0)+f|0]=0;g=Lb(d+192|0,1);j=w[g|0];if((j|0)==252&i){t[g|0]=254;break n}switch(j-252|0){case 1:break m;case 2:break n;case 0:break o;default:break p}}g=v[d+192>>2];v[d+32>>2]=g;v[d+12>>2]=g;gu(d+12|0,e);g=w[e|0];q:{if(!g){break q}t[(d+40|0)+f|0]=0;t[(d+48|0)+f|0]=g;if(g>>>0>48){break q}t[d+16|0]=8;p=d,q=w[ef(d+39|0,d+16|0)|0],t[p+39|0]=q}r:{s:{t:{u:{v:{w:{switch(w[e+3|0]){case 1:t[e+3|0]=1;break m;case 2:g=w[e+5|0];if(g&240){t[e+3|0]=3;t[e+5|0]=g>>>4;break m}g=g&15;if(g){t[e+3|0]=2;t[e+5|0]=g;break m}t[e+5|0]=0;break s;case 3:if(w[(d+40|0)+f|0]){break t}t[e+3|0]=19;t[e+5|0]=0;break m;case 4:if(w[(d+40|0)+f|0]){break t}t[e+3|0]=19;t[e+5|0]=1;break m;case 5:if(!w[e+1|0]){break t}t[e+3|0]=13;t[d+16|0]=63;t[d+31|0]=w[e+5|0]+(x[(B(w[e+1|0],104)+a|0)+484410>>1]>>>2|0);p=e,q=w[Wb(d+16|0,d+31|0)|0],t[p+5|0]=q;if(!w[(d+40|0)+f|0]){break v}t[e+2|0]=1;t[e+4|0]=w[e+5|0];t[e+5|0]=0;break s;case 6:g=w[e+1|0];if(!g){break t}t[e+3|0]=13;g=x[(B(g,104)+a|0)+484410>>1]>>>2|0;j=w[e+5|0];g=g>>>0<j>>>0?0:g-j|0;t[e+5|0]=g;if(!w[(d+40|0)+f|0]){break m}t[e+4|0]=g;t[e+2|0]=1;t[e+5|0]=0;break s;case 7:g=w[(d+48|0)+f|0];j=w[e+5|0];m=g-(j>>>4|0)|0;t[(d+44|0)+f|0]=m;t[e+3|0]=3;j=j&15;t[(d+40|0)+f|0]=j;p=e,q=wQ(j,m&255,g),t[p+5|0]=q;break m;case 8:j=w[(d+48|0)+f|0];g=w[e+5|0];m=j+(g>>>4|0)|0;t[(d+44|0)+f|0]=m;t[e+3|0]=2;g=g&15;t[(d+40|0)+f|0]=g;p=e,q=wQ(g,j,m&255),t[p+5|0]=q;break m;case 0:break u;case 9:break w;default:break s}}t[d+16|0]=8;p=d,q=w[ef(d+39|0,d+16|0)|0],t[p+39|0]=q;break s}if(!w[e+3|0]){break r}break m}if(!w[e+5|0]){break r}break s}t[e+5|0]=0}t[e+3|0]=0}j=w[(d+40|0)+f|0];if(!j){break m}m=(d+44|0)+f|0;g=w[m|0];if(g){t[(d+48|0)+f|0]=g;t[e|0]=g;t[e+5|0]=j;t[m|0]=0}t[e+3|0]=4;break m}t[e+3|0]=14;t[d+39|0]=9;break m}t[e+3|0]=13}f=f+1|0;continue}}}h=x[a+480190>>1]}x:{y:{z:{if((h&65535)==15){b=d+16|0;sg(b,4379);v[23296]=0;U(291,d+192|0,b|0,d+39|0);b=v[23296];v[23296]=0;if((b|0)==1){break x}b=d+192|0;Hb(a+1298344|0,b);zb(b);ec(d+16|0);break z}v[23296]=0;b=Q(1,d+192|0,12180)|0;c=v[23296];v[23296]=0;if((c|0)==1){break y}Hb(a+1298344|0,b);zb(b)}wl(a+1298356|0,x[a+480190>>1]==15?5243:14954);v[a+1298404>>2]=13;break e}h=P()|0;O()|0;break f}h=P()|0;O()|0;ec(d+16|0);break f}k=k+1|0;continue}}else{u[d+192>>1]=w[(d+f|0)+58|0]+1;p=d,q=x[We(d+54|0,d+192|0)>>1],u[p+54>>1]=q;f=f+1|0;continue}}h=P()|0;O()|0;yb(f)}S(h|0);L()}f=1;break a}f=0}jb=d+352|0;return f|0}function rfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;d=jb-1824|0;jb=d;Ac(b);e=jb-16|0;jb=e;i=d+1224|0;AR(e+8|0,i);h=v[e+12>>2];j=b;nc(e,v[b>>2],v[b+8>>2],v[e+8>>2],v[e+12>>2]);b=v[e+4>>2];if((b|0)==(h|0)){ac(j,v[e+12>>2])}jb=e+16|0;b=(b|0)==(h|0);if(!b){zR(i)}a:{if(!b){break a}if(!BR(d+1224|0)){break a}if(!gA(j,16,0)){break a}v[d+1216>>2]=v[d+1240>>2];b=v[d+1228>>2];v[d+1200>>2]=v[d+1224>>2];v[d+1204>>2]=b;b=d+1232|0;e=v[b+4>>2];v[d+1208>>2]=v[b>>2];v[d+1212>>2]=e;Ed(a,1);Nb(Nb(Bf(a+1074312|0,83),84,1),85,1);u[a+480188>>1]=4;v[d+1196>>2]=0;u[a+480190>>1]=15;$c(j,20);k=a+480188|0;f=1;i=1;while(1){b:{if((f|0)==16){b=d+1064|0;JR(j,b);e=a+484360|0;h=a+484376|0;tq(Zb(v[e>>2],w[h|0]),b|2,128);f=0;m=IR(j,Zb(v[e>>2],w[h|0]),w[d+1064|0],g,k,0,1);if(!(w[d+1064|0]?1:w[d+1065|0]|m>>>0>1)){break a}if(cf(j)+65536>>>0<(m<<10)+g>>>0){break a}if(c){break b}f=1;break a}e=B(f,104)+a|0;h=e+484380|0;b=((f<<5)+a|0)+946304|0;hA(j,d+24|0,h,b,1);m=v[h>>2];c:{if(!w[Lb(b,0)|0]){break c}d:{if(Pb(b,16592,3)){if(Pb(b,16596,3)){break d}}if(w[Lb(b,5)|0]==58){break c}}i=0}b=Mb(x[d+52>>1]);if(b>>>0>=2){l=b<<1;b=Mb(x[d+50>>1]);v[e+484388>>2]=l+b;v[e+484384>>2]=b;lk(h)}e:{if(Mb(x[d+46>>1])>>>0<=4999){if(Mb(x[d+50>>1])>>>0<1e4){break e}}v[d+1064>>2]=5;z=d,A=v[Ne(d+1196|0,d+1064|0)>>2],v[z+1196>>2]=A}g=g+m|0;f=f+1|0;continue}break}f=w[d+1065|0];if(!f){t[d+1065|0]=120;f=120}f:{if(!Pb(d+1200|0,14772,6)){t[d+1065|0]=120;v[a+480204>>2]=125e4;break f}v[a+480204>>2]=125e4;if((f|0)==120){break f}z=a,A=Ie(1773447.5/(+(240-f|0)*122)*1e4),v[z+480204>>2]=A;if(v[d+1196>>2]>=2){v[d+24>>2]=i?4:5;z=d,A=v[Ne(d+1196|0,d+24|0)>>2],v[z+1196>>2]=A;break f}v[d+24>>2]=i?1:2;z=d,A=v[Ne(d+1196|0,d+24|0)>>2],v[z+1196>>2]=A}v[a+480228>>2]=64;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480208>>2]=v[a+480208>>2]|2097152;g=d+1048|0;tj(g,3,d+1200|0);b=d+24|0;Gc(b,g);Bc(a+1298308|0,b);yb(b);xh(a,0);q=v[j+8>>2];r=a+484376|0;while(1){g:{h:{if(m>>>0>(p&65535)>>>0){b=Zb(v[a+484360>>2],w[r|0]);b=Rb(aA(Eb(v[b>>2]),Eb(v[b+4>>2]),p),Eb(v[b+4>>2]));yR(j,d+24|0);if(b){s=eA(d+24|0,0)+s|0;if(s>>>0>512){break h}}k=0;b=0;g=0;i:while(1){if((g|0)==64){break g}f=0;y=ed(d+24|0,g);while(1){e=b;if((f|0)==4){g=g+1|0;continue i}else{o=Db(y,f);l=w[Lb(o,2)|0]&15;h=w[Lb(o,3)|0];b=0;j:{if(!(e&255)){break j}if(Pb(o,26724,4)){break j}b=e+1|0;if((b&255)>>>0<33){break j}v[d+1196>>2]=6}k:{l:{m:{switch(l-1|0){case 0:case 1:e=v[d+1196>>2];if((e|0)==1&h>>>0>=32){break l}l=(l|0)!=1;if(!(l|!h|h>>>0>2)){v[d+1048>>2]=2;z=d,A=v[Ne(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break k}if(l|(h|0)!=55&(h|0)!=71){break k}if((e|0)<=2){break l}break k;case 10:v[d+1196>>2]=6;break k;case 11:case 12:case 13:v[d+1048>>2]=2;z=d,A=v[Ne(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;if((l|0)!=13){break k}k=((g|h)!=0)+k|0;b=1;break k;case 14:break m;default:break k}}v[d+1048>>2]=3;z=d,A=v[Ne(d+1196|0,d+1048|0)>>2],v[z+1196>>2]=A;break k}v[d+1196>>2]=i}f=f+1|0;continue}}}}if(!(v[d+1196>>2]!=6|m+32>>>0>=n>>>0)){v[d+1196>>2]=5}$c(j,q);o=c&1;if(o){mg(a+484344|0,m)}l=a+484344|0;n=0;while(1){if((m|0)==(n|0)){f=21473;b=v[d+1196>>2];if(b>>>0<7){f=v[(b<<2)+26736>>2]}b=d+24|0;g=Vb(b,8222);Hb(a+1298344|0,g);zb(g);b=Vb(b,10648);Hb(a+1298356|0,b);zb(b);wl(a+1298368|0,f);v[a+1298404>>2]=13;if(!(c&2)){break h}f=1;while(1){if((f|0)==16){break h}b=B(f,104)+a|0;c=b+484384|0;ac(j,v[c>>2]);g=v[c>>2];v[c>>2]=0;c=b+484380|0;v[c>>2]=v[c>>2]-g;b=b+484388|0;v[b>>2]=v[b>>2]-g;b=d+24|0;_c(b,8,1,1,0);lg(b,c,j);f=f+1|0;continue}}yR(j,d+24|0);n:{if(!o){break n}if(!bh(l,n&65535,64)){break n}i=0;v[d+1048>>2]=0;o:while(1){if((i|0)==64){break n}f=0;b=$b(v[l>>2],n);q=fd(v[b>>2],v[v[b+48>>2]+12>>2],i,0);r=ed(d+24|0,i);while(1)if((f|0)==4){i=i+1|0;continue o}else{b=Db(r,f);b=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[d+12>>2]=b;v[d+16>>2]=b;e=q+B(f,6)|0;gu(d+12|0,e);h=w[e+3|0];b=h;p:{q:{r:{g=w[e+5|0];if(g){b=14;if((h|0)!=14){break r}}t[(d+1048|0)+f|0]=0;if((b|g)&255){break q}break p}b=h;k=w[(d+1048|0)+f|0];if(!k){break q}s:{if(k>>>0>=16){t[e+2|0]=3;k=k>>>4|0;break s}t[e+2|0]=4}t[e+4|0]=k}t:{u:{v:{w:{x:{y:{switch((b&255)-12|0){case 1:b=v[d+1196>>2];if((b|0)==6){break u}h=10;t[e+3|0]=10;break v;case 0:g=g&127;break x;case 2:if(g>>>0<=1&v[d+1196>>2]>3){break t}h=10;t[e+3|0]=10;t[(d+1048|0)+f|0]=g;break w;case 3:break y;default:break w}}g=g&15}t[e+5|0]=g}b=v[d+1196>>2]}if((b|0)>1){break t}z:{A:{B:{switch(h|0){case 0:if(g>>>0>2){break A}break;case 2:break z;case 1:break A;default:break B}}t[e+3|0]=0;break p}t[e+3|0]=1;break p}b=g&15;if(b){t[e+3|0]=2;t[e+5|0]=b;break p}if(g>>>0<16){break p}t[e+3|0]=3;t[e+5|0]=g>>>4;break p}t[e+5|0]=0}Of(e)}f=f+1|0;continue}}}n=n+1|0;continue}}f=m>>>0<=(p&65535)>>>0;break a}if((k-1&255)>>>0<2){v[d+1196>>2]=6}p=p+1|0;n=(k&255)+n|0;continue}}jb=d+1824|0;return f|0}function cI(a,b,c,d,e,f){var g=0,h=C(0),i=0,j=0,k=C(0),l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=0,t=0,v=0,w=0,x=0,y=0,A=C(0),D=C(0),E=0,F=0,G=0,H=C(0),I=C(0),J=C(0),K=C(0),L=C(0),M=C(0),N=C(0),O=C(0),P=0,Q=0;F=(d|0)>0?d:0;while(1){if((s|0)!=(F|0)){G=B(s,2304)+b|0;v=0;q=(c|0)>0?c:0;n=jb-128|0;x=n+96|0;y=n- -64|0;E=n+32|0;while(1){if((q|0)!=(v|0)){o=G+(v<<2)|0;w=0;i=n;p=i;j=0;while(1){if((j|0)!=8){k=z[B(15-j|0,72)+o>>2];g=B(j,72)+o|0;h=z[g+1152>>2];l=C(k+h);m=z[g>>2];A=z[B(31-j|0,72)+o>>2];D=C(m+A);z[p>>2]=l+D;g=B(j,12);k=C(C(k-h)*z[g+70112>>2]);h=C(C(m-A)*z[g+70116>>2]);z[p+64>>2]=k+h;m=C(D-l);l=z[g+70120>>2];z[p+32>>2]=m*l;z[p+96>>2]=C(h-k)*l;p=p+4|0;j=j+1|0;continue}break}while(1){if((w|0)!=4){l=z[i+8>>2];m=z[i+20>>2];h=C(l+m);A=z[i+4>>2];D=z[i+24>>2];H=C(A+D);k=C(h+H);I=z[i+12>>2];J=z[i+16>>2];K=C(I+J);L=z[i>>2];M=z[i+28>>2];N=C(L+M);O=C(K+N);z[i>>2]=k+O;z[i+16>>2]=C(O-k)*C(.7071067690849304);k=C(N-K);h=C(C(k+C(H-h))*C(.7071067690849304));z[i+24>>2]=C(k-h)*C(1.3065630197525024);z[i+8>>2]=C(k+h)*C(.5411961078643799);k=C(L-M);h=C(l-m);l=C(A-D);m=C(C(h+l)*C(.7071067690849304));A=C(k+m);D=C(C(I-J)+h);h=C(l+k);l=C(D-C(h*C(.1989123672246933)));h=C(C(l*C(.3826834261417389))+h);z[i+28>>2]=C(A-h)*C(2.562915563583374);z[i+4>>2]=C(A+h)*C(.509795606136322);k=C(k-m);h=C(l-C(h*C(.1989123672246933)));z[i+20>>2]=C(k+h)*C(.8999761939048767);z[i+12>>2]=C(k-h)*C(.601344883441925);i=i+32|0;w=w+1|0;continue}break}i=0;while(1){if((i|0)!=7){p=i<<2;z[o>>2]=z[p+n>>2];k=z[p+x>>2];i=i+1|0;j=i<<2;h=z[j+x>>2];z[o+72>>2]=C(z[p+y>>2]+k)+h;z[o+144>>2]=z[p+E>>2]+z[j+E>>2];z[o+216>>2]=h+C(k+z[j+y>>2]);o=o+288|0;continue}break}z[o>>2]=z[n+28>>2];k=z[n+124>>2];z[o+72>>2]=z[n+92>>2]+k;h=z[n+60>>2];z[o+216>>2]=k;z[o+144>>2]=h;v=v+1|0;continue}break}s=s+1|0;continue}break}E=qc(f,a,3840);G=d<<5;s=0;while(1){if((c|0)>(s|0)){i=jb-32|0;jb=i;o=E+(s<<8)|0;v=(s<<2)+b|0;z[o+4080>>2]=z[v+1152>>2];f=d-1|0;w=v+B(f,2304)|0;z[o+4084>>2]=z[w+1152>>2];z[o+4088>>2]=z[v>>2];z[o+4092>>2]=z[w>>2];z[o+4336>>2]=z[v+1156>>2];z[o+4340>>2]=z[w+1156>>2];z[o+4344>>2]=z[v+4>>2];z[o+4348>>2]=z[w+4>>2];x=(B(s,G)<<1)+e|0;y=x+(f<<1)|0;cs(y,d,o+244|0);f=d<<6;cs(f+y|0,d,o+500|0);cs(x,d,o+240|0);cs(f+x|0,d,o+496|0);F=o+3840|0;p=14;n=70208;while(1){if((p|0)>=0){g=p<<4;j=g+F|0;f=B(31-p|0,72);z[j>>2]=z[f+v>>2];z[j+4>>2]=z[f+w>>2];f=f|4;z[j+8>>2]=z[f+v>>2];z[j+12>>2]=z[f+w>>2];f=B(p,72);q=f+76|0;z[j+256>>2]=z[q+v>>2];z[j+260>>2]=z[q+w>>2];f=f+72|0;z[j-248>>2]=z[f+v>>2];z[j-244>>2]=z[f+w>>2];q=p<<2;t=g+o|0;k=z[n+4>>2];h=z[n>>2];f=0;while(1){if((f|0)!=4){g=f<<2;l=z[g+j>>2];m=z[g+t>>2];z[g+(i+16|0)>>2]=C(l*h)-C(k*m);z[i+g>>2]=C(l*k)+C(h*m);f=f+1|0;continue}break}j=F+(q<<2)|0;q=j-3584|0;t=j-256|0;k=z[n+12>>2];h=z[n+8>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-3328|0;t=j-512|0;k=z[n+20>>2];h=z[n+16>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}q=j-3072|0;t=j-768|0;k=z[n+28>>2];h=z[n+24>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-2816|0;t=j-1024|0;k=z[n+36>>2];h=z[n+32>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}q=j-2560|0;t=j-1280|0;k=z[n+44>>2];h=z[n+40>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(m*k)-C(h*l))+z[g>>2];f=f+1|0;continue}break}q=j-2304|0;t=j-1536|0;k=z[n+52>>2];h=z[n+48>>2];f=0;while(1){if((f|0)!=4){g=f<<2;r=g+i|0;l=z[g+t>>2];m=z[g+q>>2];z[r>>2]=z[r>>2]+C(C(l*k)+C(h*m));g=g+(i+16|0)|0;z[g>>2]=C(C(l*h)-C(k*m))+z[g>>2];f=f+1|0;continue}break}g=j-2048|0;q=j-1792|0;k=z[n+60>>2];h=z[n+56>>2];f=0;while(1){if((f|0)!=4){j=f<<2;t=j+i|0;l=z[j+q>>2];m=z[g+j>>2];z[t>>2]=z[t>>2]+C(C(l*k)+C(h*m));j=j+(i+16|0)|0;z[j>>2]=C(C(m*k)-C(h*l))+z[j>>2];f=f+1|0;continue}break}f=B(15-p|0,d)<<1;P=f+y|0,Q=bj(z[i+20>>2]),u[P>>1]=Q;j=B(p+17|0,d)<<1;P=j+y|0,Q=bj(z[i+4>>2]),u[P>>1]=Q;P=f+x|0,Q=bj(z[i+16>>2]),u[P>>1]=Q;P=j+x|0,Q=bj(z[i>>2]),u[P>>1]=Q;f=B(47-p|0,d)<<1;P=f+y|0,Q=bj(z[i+28>>2]),u[P>>1]=Q;j=B(p+49|0,d)<<1;P=j+y|0,Q=bj(z[i+12>>2]),u[P>>1]=Q;P=f+x|0,Q=bj(z[i+24>>2]),u[P>>1]=Q;P=j+x|0,Q=bj(z[i+8>>2]),u[P>>1]=Q;p=p-1|0;n=n- -64|0;continue}break}jb=i+32|0;s=s+2|0;continue}break}b=c<<6;a:{if((d|0)==1){s=0;while(1){if(s>>>0>959){break a}z[(s<<2)+a>>2]=z[E+(b+s<<2)>>2];s=s+2|0;continue}}qc(a,E+(b<<2)|0,3840)}}function qda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0;i=jb-208|0;jb=i;Ac(b);a:{if(!$A(b,i+160|0)){break a}if(!HP(i+160|0)){break a}b:{if(!c){break b}if(!Ob(v[b>>2],v[b+8>>2],Vc(GP(w[i+207|0]),mb))){break a}Ed(a,128);e=i+144|0;Ze(e,2,i+175|0);d=i+72|0;Gc(d,e);Bc(a+1298308|0,d);yb(d);h=Vb(d,8371);Hb(a+1298344|0,h);zb(h);h=Vb(d,6017);Hb(a+1298356|0,h);zb(h);h=Vb(e,17359);v[23296]=0;U(675,d|0,h|0,v[(w[i+174|0]<<2)+26700>>2]);d=v[23296];v[23296]=0;c:{if((d|0)!=1){d=i+72|0;Hb(a+1298368|0,d);zb(d);zb(h);v[a+480208>>2]=12;v[a+1298404>>2]=5;rB(a+1298332|0,b,w[i+207|0]<<5,32,0);n=a+480190|0;e=Ee(b);u[n>>1]=e;h=1;while(1){m=h&65535;if(m>>>0>(e&65535)>>>0){oo(Zb(v[a+484360>>2],w[a+484376|0]),b,256,255,254);h=0;d=Ee(b);if(d>>>0>=127){break a}e=a+480188|0;u[e>>1]=d+1;d=Ee(b);while(1)if(x[e>>1]<=h>>>0){n=a+484344|0;q=d+1|0;mg(n,q);e=0;while(1){d:{f=e&65535;if(f>>>0>d>>>0){l=0;r=a+480188|0;e:while(1){s=l&65535;e=x[r>>1];if(s>>>0>=e>>>0){d=bo(i+8|0);t[d+16|0]=0;u[d+14>>1]=0;u[d+12>>1]=e;v[23296]=0;R(677,d|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){a=P()|0;O()|0;Le(d);S(a|0);L()}v[23296]=0;U(676,i+32|0,n|0,d|0);e=v[23296];v[23296]=0;h=1;if((e|0)==1){break d}Le(i+32|0);Le(d);if(!(c&2)){break a}c=a+480190|0;while(1){d=h&65535;if(d>>>0>x[c>>1]){break b}d=B(d,104)+a|0;lg(_c(i+72|0,u[d+484414>>1]&1?16:8,1,0,0),d+484380|0,b);h=h+1|0;continue}}m=0;f=Th(i+72|0);f:while(1){g:{if((m|0)!=(q|0)){if(Ob(v[b>>2],v[b+8>>2],5)){break g}}l=l+1|0;continue e}e=0;d=$b(v[n>>2],m);h=fd(v[d>>2],v[v[d+48>>2]+12>>2],0,s);while(1){h:{i:{if(e>>>0>63){break i}j=w[i+174|0];d=jb-16|0;jb=d;p=1;g=Ee(b);if((g|0)==252){p=Ee(b);g=Ee(b)}t[f|0]=(g-1&255)>>>0<60?g+36|0:0;g=d+8|0;zm(g,b);t[f+1|0]=w[d+8|0];k=w[kd(g)|0];t[d+7|0]=k&15;t[d+6|0]=k>>>4;y=d,z=w[Ue(g)|0],t[y+5|0]=z;y=d,z=w[Ci(g)|0],t[y+4|0]=z;EP(d+7|0,d+5|0,j);EP(d+6|0,d+4|0,j);j=w[d+7|0];k=(j|0)!=10;g=w[d+6|0];j:{if(!(k|(g|0)!=10)){j=w[d+5|0];g=w[d+4|0];t[f+3|0]=10;j=j|g<<8;t[f+5|0]=j>>>6;if(j>>>0<16384){break j}t[f+2|0]=15;t[f+4|0]=g>>>6;break j}k:{l:{m:{n:{if(!k){k=w[d+5|0];o=k<<2;y=d,z=Bm(o),t[y+5|0]=z;if(k>>>0<64){break n}if(Bi(g)>>>0>=Cz(10)>>>0){break n}t[f+5|0]=o;t[f+2|0]=15;t[f+3|0]=10;t[f+4|0]=k>>>6;break j}if((g|0)==10){g=w[d+4|0];k=g<<2;y=d,z=Bm(k),t[y+4|0]=z;if(g>>>0<64){break k}if(Bi(j)>>>0>=Cz(10)>>>0){break k}t[f+5|0]=k;t[f+2|0]=15;t[f+3|0]=10;t[f+4|0]=g>>>6;break j}if((g|0)!=(j|0)){break n}g=0;t[d+6|0]=0;break m}if((g|0)==13){break l}}if((j|0)==13|g){break k}}ah(d+7|0,d+6|0);ah(d+5|0,d+4|0)}g=d+6|0;j=d+4|0;k=d+7|0;o=d+5|0;Gu(g,j,k,o);uo(d,k,o,g,j);t[f+2|0]=w[d+7|0];t[f+4|0]=w[d+5|0];t[f+3|0]=w[d+6|0];t[f+5|0]=w[d+4|0]}jb=d+16|0;g=e+p|0;e=g>>>0>64?64-e|0:p;if(!e){break i}while(1){if(!e){break h}d=w[f|0]|w[f+1|0]<<8|(w[f+2|0]<<16|w[f+3|0]<<24);t[h|0]=d;t[h+1|0]=d>>>8;t[h+2|0]=d>>>16;t[h+3|0]=d>>>24;d=w[f+4|0]|w[f+5|0]<<8;t[h+4|0]=d;t[h+5|0]=d>>>8;e=e-1|0;h=B(x[r>>1],6)+h|0;continue}}m=m+1|0;continue f}e=g>>>0<64?g:64;continue}}}}e=e+1|0;h=0;if(bh(n,f,64)){continue}break a}break}e=P()|0;O()|0;Le(d);break c}else{f=(h<<5)+a|0;Te(f+480280|0);g=f+480284|0;o:{if(w[i+174|0]>=51){f=(Ee(b)<<4|8)&248;break o}f=h&1?192:64}u[g>>1]=f;h=h+1|0;continue}}else{p:{if(w[i+174|0]>=52){d=i+72|0;if(!UT(b,d)){tB(d)}break p}d=jb-32|0;jb=d;v[d+28>>2]=64;v[d+8>>2]=66;f=v[b>>2];g=v[b+8>>2];e=v[Ib(d+28|0,d+8|0)>>2];if(!Ob(f,g,e)){e=cf(b)}g=d+8|0;l=i+72|0;pu(g,l);f=gc(d+16|0,v[d+8>>2],e);nc(d,v[b>>2],v[b+8>>2],v[f>>2],v[f+4>>2]);pu(g,l);Xb(v[d+8>>2]+e|0,0,66-e|0);ac(b,v[d+28>>2]);jb=d+32|0;u[i+136>>1]=x[i+134>>1];u[i+134>>1]=8363}g=jb-32|0;jb=g;f=(B(m,104)+a|0)+484380|0;pd(f,0);kB(f);d=i+72|0;ek(g,2,d+32|0);e=g+16|0;Gc(e,g);ze(f+43|0,e);yb(e);e=w[d+56|0]|w[d+57|0]<<8|(w[d+58|0]<<16|w[d+59|0]<<24);l=w[d+52|0]|w[d+53|0]<<8|(w[d+54|0]<<16|w[d+55|0]<<24);q:{if(e>>>0<=l>>>0){break q}v[f>>2]=e-l;v[f+12>>2]=w[d+44|0]|w[d+45|0]<<8|(w[d+46|0]<<16|w[d+47|0]<<24);v[g+16>>2]=w[d+48|0]|w[d+49|0]<<8|(w[d+50|0]<<16|w[d+51|0]<<24);y=f,z=v[Ib(g+16|0,f)>>2],v[y+16>>2]=z;u[f+30>>1]=w[d+60|0];v[f+24>>2]=w[d+62|0]|w[d+63|0]<<8;e=w[d+64|0]|w[d+65|0]<<8;if(e){iq(f,+(e<<16>>16)/393216)}e=w[d+61|0];if(e&8){u[f+34>>1]=x[f+34>>1]|8;e=w[d+61|0]}if(e&16){u[f+34>>1]=x[f+34>>1]|16;e=w[d+61|0]}if(!(e&4)){break q}u[f+34>>1]=x[f+34>>1]|1;v[f+12>>2]=v[f+12>>2]>>>1;v[f+16>>2]=v[f+16>>2]>>>1}jb=g+32|0;e=i+56|0;Ze(e,2,d);d=i+144|0;Gc(d,e);Ec(((m<<5)+a|0)+946304|0,d);h=h+1|0;yb(d);e=x[n>>1];continue}}}e=P()|0;O()|0;zb(h)}S(e|0);L()}h=1}jb=i+208|0;return h|0}function WM(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;f=jb-16|0;jb=f;a:{if(!Uc(d&255)){break a}n=a+1074376|0;i=(n+B(b,872)|0)+616|0;b:{g=x[a+480192>>1];if(!(e?1:!(v[a+480180>>2]&17825824)|!g)){break b}if(Sj(v[i+656>>2])){break b}c=B(b,872)+a|0;d=c+1075068|0;if(!v[d>>2]){break a}c=v[c+1075080>>2];if(c&1024){break a}e=B(b,872)+a|0;g=e+1075012|0;e=e+1075016|0;if(!(v[g>>2]|v[e>>2])){break a}c:{if(!(c&512)){break c}c=v[a+1298300>>2];if(!xd(c)){break c}jj(c,b,0);break a}c=Cy(a,b);if((c|0)==65535){break a}k=B(c,872);c=a+1074992|0;a=k+c|0;Bp(a,i);t[a+831|0]=0;t[a+805|0]=0;u[a+786>>1]=b+1;v[a+88>>2]=v[a+88>>2]&-918529;fo(a+788|0);v[a+696>>2]=0;v[a+88>>2]=v[a+88>>2]|2101248;v[d>>2]=0;v[i>>2]=0;v[i+4>>2]=0;a=c+B(b,872)|0;v[a+92>>2]=0;v[a+96>>2]=0;v[g>>2]=0;v[e>>2]=0;break a}e=B(b,872)+a|0;m=v[e+1075096>>2];c=c>>>0>g>>>0?0:c;g=v[(c?((c<<2)+a|0)+900380|0:e+1075648|0)>>2];d:{if(!g){break d}l=d-1|0;c=x[dc(g+236|0,l)>>1];h=a+1074312|0;Bb(f+8|0,h,104);e:{if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){Bb(f,h,34);if(Cb(v[v[f>>2]>>2],v[f+4>>2])){break e}}d=w[Lb(g+108|0,l)|0]}if((c-1&65535)>>>0<=3998){m=(B(c,104)+a|0)+484380|0;break d}Bb(f+8|0,h,43);if(!Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break d}if(!nj(w[g+31|0])){break a}}if(w[e+1075081|0]&4){break a}p=b>>>0>256?b:256;l=a+1074312|0;q=b+1|0;r=a+480188|0;c=b;f:{while(1){if((c|0)==(p|0)){g:{e=0;c=0;if(!Sj(v[i+656>>2])){break f}c=0;if(!Uc(w[(B(b,872)+a|0)+1075789|0])){break f}d=sl(a,n,b,2,1);c=0;if((d-1&255)>>>0>249){break f}e=v[(B(d,160)+a|0)+906140>>2];if(e){break g}e=0;c=0;break f}}else{h:{if((b|0)!=(c|0)&x[r>>1]>c>>>0){break h}e=B(c,872)+a|0;if(x[e+1075778>>1]!=(q|0)&(b|0)!=(c|0)){break h}o=e+1075648|0;h=v[o>>2];if(!h){break h}j=e+1074992|0;i:{j:{k:{l:{m:{n:{o:{switch(w[h+17|0]-1|0){case 0:if(!d){break h}k=w[e+1075789|0]==(d|0)&(g|0)==(h|0);if(!g){break n}if(k){break k}break h;case 1:if(!m|v[e+1075096>>2]!=(m|0)){break h}if((g|0)==(h|0)){break i}Bb(f+8|0,l,104);if(!Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break i}break h;case 3:break m;case 2:break o;default:break h}}if(g){break l}k=(g|0)==(h|0)}if(k){break i}break h}if(!g){break h}k=w[g+34|0];if(!k){break h}if((k|0)==w[h+34|0]){break j}break h}if((g|0)!=(h|0)){break h}}if(!w[g+34|0]){break i}}if(!w[e+1075789|0]|w[h+18|0]>2){break i}Bb(f+8|0,l,34);Ul(a,c&65535,kP(j,Cb(v[v[f+8>>2]>>2],v[f+12>>2]))+255|0,0);t[e+1075792|0]=0}p:{q:{switch(w[v[o>>2]+18|0]){case 0:Qn(a,j);v[e+1075680>>2]=0;if(!(w[e+1075081|0]&2)){break p}h=v[a+1298300>>2];if(!xd(h)){break p}jj(h,c&65535,1);break p;case 1:Qn(a,j);if(!(w[e+1075081|0]&2)){break p}h=v[a+1298300>>2];if(!xd(h)){break p}Uj(h,c&65535);break p;case 2:break q;default:break p}}j=e+1075080|0;h=v[j>>2];v[j>>2]=h|4096;if(!(h&512)){break p}if(!xd(v[a+1298300>>2])){break p}Bb(f+8|0,l,105);if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break p}Uj(v[a+1298300>>2],c&65535)}if(v[e+1075680>>2]){break h}v[e+1075688>>2]=0;e=e+1075080|0;v[e>>2]=v[e>>2]|2101248}c=c+1|0;continue}break}Bb(f+8|0,l,34);c=(y=e,z=kP(i,Cb(v[v[f+8>>2]>>2],v[f+12>>2])),A=b,s=v[v[e>>2]+100>>2],nb[s](y|0,z|0,A|0)|0)}if(!(qi(v[i+8>>2],v[i+12>>2])?1:c)){break a}g=Cy(a,b);if((g|0)==65535){break a}h=B(g,872)+a|0;d=h+1075080|0;m=h+1074992|0;r:{if(!(w[h+1075081|0]&2)){break r}j=v[a+1298300>>2];if(!xd(j)){break r}jj(j,g,1)}m=Bp(m,i);v[d>>2]=v[d>>2]&-917505;t[h+1075823|0]=0;j=x[a+480188>>1];t[h+1075797|0]=0;u[h+1075778>>1]=b>>>0<j>>>0?b+1|0:0;s:{if(!(c&(e|0)!=0)){break s}c=w[(B(b,872)+a|0)+1075790|0];if(c>>>0>3|(c|0)==1){break s}Ul(a,b,255,0);t[(B(b,872)+a|0)+1075792|0]=0}t:{u:{switch(w[(B(b,872)+a|0)+1075790|0]){case 2:Qn(a,m);if(!(w[d+1|0]&2)){break t}c=v[a+1298300>>2];if(!xd(c)){break t}Uj(c,b);Bb(f+8|0,l,105);if(!Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break t}kz(v[a+1298300>>2],b,g);break t;case 0:v[(B(g,872)+a|0)+1075688>>2]=0;c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}c=v[a+1298300>>2];if(!xd(c)){break t}jj(c,b,1);break t;case 3:c=v[d>>2];v[d>>2]=c|4096;if(!(c&512)){break t}if(!xd(v[a+1298300>>2])){break t}Bb(f+8|0,l,105);c=v[a+1298300>>2];if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){kz(c,b,g);break t}Uj(c,b);break t;case 1:break u;default:break t}}if(!(w[d+1|0]&2)){break t}c=v[a+1298300>>2];if(!xd(c)){break t}kz(c,b,g)}if(!v[(B(g,872)+a|0)+1075680>>2]){v[(B(g,872)+a|0)+1075688>>2]=0;v[d>>2]=v[d>>2]|2101248}a=B(b,872)+a|0;v[a+1075068>>2]=0;v[i>>2]=0;v[i+4>>2]=0;a=a+1075084|0;v[a>>2]=0;v[a+4>>2]=0}jb=f+16|0}function Bda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-144|0;jb=d;Ac(c);a:{b:{c:{d:{if(!po(c,d+128|0)){break d}if(Pb(d+128|0,13662,4)){break d}k=d+136|0;e:{if(!Pb(k,13360,4)){break e}if(!Pb(k,13418,4)){break e}if(Pb(k,14093,4)){break d}}j=jb-32|0;jb=j;g=Qb(d+112|0);f:{g:{h:{i:{j:{while(1){f=v[c+8>>2];e=v[c>>2];v[23296]=0;f=W(144,e|0,f|0,8)|0;e=v[23296];v[23296]=0;if((e|0)==1){break h}if(!f){break i}v[23296]=0;R(744,j|0,c|0);e=v[23296];v[23296]=0;if((e|0)!=1){v[23296]=0;R(745,g|0,j|0);e=v[23296];v[23296]=0;if((e|0)==1){break j}Md(j);continue}break}a=P()|0;O()|0;break g}a=P()|0;O()|0;Md(j);break g}jb=j+32|0;break f}a=P()|0;O()|0}_d(g);S(a|0);L()}v[23296]=0;j=T(162,d+88|0)|0;c=v[23296];v[23296]=0;k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{if((c|0)!=1){l=_c(d+80|0,8,1,1,0);if(Pb(k,14093,4)){break t}v[23296]=0;U(662,d+56|0,d+112|0,1296581714);c=v[23296];v[23296]=0;if((c|0)==1){break q}v[23296]=0;U(662,d+32|0,d+112|0,1296318804);c=v[23296];v[23296]=0;if((c|0)==1){break c}c=d+32|0;f=cd(j,c);Ab(c);c=0;v[23296]=0;i=T(663,d+56|0)|0;e=v[23296];v[23296]=0;h=1;if((e|0)==1){break c}if(!i){break u}e=v[f>>2];v[23296]=0;i=T(166,e|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break c}if(!i){break u}v[23296]=0;m=T(266,d+56|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}v[23296]=0;g=T(258,d+56|0)|0;c=v[23296];v[23296]=0;w:{if((c|0)==1){break w}v[23296]=0;Q(176,d+56|0,2)|0;c=v[23296];v[23296]=0;if((c|0)==1){break w}v[23296]=0;c=T(266,d+56|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break v}}break c}h=P()|0;O()|0;break a}v[23296]=0;R(578,d+32|0,d+56|0);e=v[23296];v[23296]=0;if((e|0)==1){break c}e=Mb(x[d+32>>1]);if(!e){break u}c=(c>>>0)/(e>>>0)|0;e=d+32|0;f=kc(e);i=Ue(e);e=Mb(w[f|0]|w[f+1|0]<<8);if((e|0)!=(Mb(w[i|0]|w[i+1|0]<<8)+1|0)){break u}if((e|0)==2){Ao(l,2)}x:{if((g|0)!=16){if((g|0)!=8){break u}y:{switch(Mb(w[d+38|0]|w[d+39|0]<<8)|0){case 0:Sf(l,1);break x;case 2:Sf(l,17);break x;case 3:break y;default:break u}}Sf(l,16);break x}if(Mb(w[d+38|0]|w[d+39|0]<<8)){break u}Fh(l,16)}h=0}Ab(d+56|0);if(!h){break s}h=0;break k}v[23296]=0;U(662,d+56|0,d+112|0,1447576658);c=v[23296];v[23296]=0;z:{A:{if((c|0)!=1){v[23296]=0;U(662,d+32|0,d+112|0,1128808782);c=v[23296];v[23296]=0;if((c|0)==1){break A}v[23296]=0;U(662,d+8|0,d+112|0,1112491097);c=v[23296];v[23296]=0;if((c|0)==1){break m}c=d+8|0;g=cd(j,c);Ab(c);c=v[g>>2];v[23296]=0;f=T(166,c|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break z}c=0;e=0;B:{if(!f){break B}v[23296]=0;f=T(166,v[d+56>>2])|0;c=v[23296];v[23296]=0;if((c|0)==1){break z}c=0;e=0;if(!f){break B}v[23296]=0;f=Q(664,d+56|0,d+8|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break z}c=0;e=0;if(!f){break B}m=Pb(k,13360,4);v[23296]=0;k=T(266,d+32|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break m}if(m){p=l,q=v[_c(d,16,1,0,0)>>2],v[p>>2]=q}if((k|0)==6){Ao(l,3)}c=v[g>>2];v[23296]=0;n=v[d+24>>2];g=x[d+20>>1];o=v[d+12>>2];f=v[d+8>>2];e=T(148,c|0)|0;c=v[23296];v[23296]=0;i=1;if((c|0)==1){break m}c=e;e=B((k|0)==6?2:1,m?2:1);m=(c>>>0)/(e>>>0)|0;n=cc(n);c=Mb(g);o=(cc(o)>>>0)/(e>>>0)|0;e=(cc(f)>>>0)/(e>>>0)|0}Ab(d+32|0);Ab(d+56|0);if(i){break r}break k}h=P()|0;O()|0;break b}h=P()|0;O()|0;break l}break m}e=0}ft(a,b);v[23296]=0;f=B(b,104)+a|0;g=f+484380|0;R(264,g|0,0);i=v[23296];v[23296]=0;if((i|0)==1){break p}v[g>>2]=m;i=e+o|0;v[f+484388>>2]=i;v[f+484384>>2]=e;if(!(i>>>0<=e+4>>>0|i>>>0>m>>>0)){e=(B(b,104)+a|0)+484414|0;u[e>>1]=x[e>>1]|2}e=B(b,104)+a|0;v[e+484404>>2]=c?c:22050;c=n>>>8|0;u[e+484410>>1]=(n&16776960)>>>0>65536?256:c&65535?c:256;vz(g,v[a+480180>>2]);v[23296]=0;U(662,d+56|0,d+112|0,1312902469);c=v[23296];v[23296]=0;if((c|0)==1){break o}v[23296]=0;e=T(166,v[d+56>>2])|0;c=v[23296];v[23296]=0;if((c|0)==1){break n}C:{D:{if(e){v[23296]=0;e=T(148,v[d+56>>2])|0;c=v[23296];v[23296]=0;if((c|0)==1){break n}v[23296]=0;U(311,d+56|0,((b<<5)+a|0)+946304|0,e|0);b=v[23296];v[23296]=0;if((b|0)!=1){break D}break n}v[23296]=0;e=Q(54,d+32|0,21473)|0;c=v[23296];v[23296]=0;if((c|0)==1){break C}Ec(((b<<5)+a|0)+946304|0,e);yb(e)}v[23296]=0;W(207,l|0,g|0,j|0)|0;b=v[23296];v[23296]=0;h=1;if((b|0)==1){break n}mj(g,a);Ab(d+56|0);break k}break n}h=P()|0;O()|0;break b}h=P()|0;O()|0;break b}h=P()|0;O()|0;break b}h=P()|0;O()|0;Ab(d+56|0);break b}h=P()|0;O()|0;Ab(d+32|0)}Ab(d+56|0);break b}Ab(j);_d(d+112|0)}jb=d+144|0;return h|0}h=P()|0;O()|0;Ab(d+56|0)}Ab(j)}_d(d+112|0);S(h|0);L()}function Fd(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;k=jb-96|0;jb=k;t=h;u=i&65535;m=(e^i)&-2147483648;l=e&65535;p=l;A=l;K=i>>>16&32767;L=e>>>16&32767;a:{b:{if(K-32767>>>0>4294934529&L-32767>>>0>=4294934530){break b}l=e&2147483647;j=d;if(!(!d&(l|0)==2147418112?!(b|c):l>>>0<2147418112)){o=d;m=e|32768;break a}e=i&2147483647;if(!(!h&(e|0)==2147418112?!(f|g):e>>>0<2147418112)){o=h;m=i|32768;b=f;c=g;break a}if(!(b|j|(l^2147418112|c))){if(!(f|h|(e|g))){m=2147450880;b=0;c=0;break a}m=m|2147418112;b=0;c=0;break a}if(!(f|h|(e^2147418112|g))){d=b|j;e=c|l;b=0;c=0;if(!(d|e)){m=2147450880;break a}m=m|2147418112;break a}if(!(b|j|(c|l))){b=0;c=0;break a}if(!(f|h|(e|g))){b=0;c=0;break a}if((l|0)==65535|l>>>0<65535){j=b;h=!(d|p);i=h<<6;l=E(h?b:d)+32|0;b=E(h?c:p);b=i+((b|0)==32?l:b)|0;vf(k+80|0,j,c,d,p,b-15|0);s=16-b|0;d=v[k+88>>2];A=v[k+92>>2];c=v[k+84>>2];b=v[k+80>>2]}if(e>>>0>65535){break b}e=!(t|u);h=e<<6;i=E(e?f:t)+32|0;e=E(e?g:u);e=h+((e|0)==32?i:e)|0;vf(k- -64|0,f,g,t,u,e-15|0);s=(s-e|0)+16|0;t=v[k+72>>2];u=v[k+76>>2];f=v[k+64>>2];g=v[k+68>>2]}e=f;j=g<<15|e>>>17;h=e<<15;e=j;p=h&-32768;q=c;B=Sia(p,0,c,0);c=mb;x=c;C=e;i=0;j=Sia(e,0,b,i);e=j+B|0;h=mb+c|0;h=e>>>0<j>>>0?h+1|0:h;c=e;j=e;n=Sia(b,i,p,i);l=0+n|0;e=mb+e|0;e=l>>>0<n>>>0?e+1|0:e;y=l;n=l;l=e;D=(j|0)==(e|0)&r>>>0>n>>>0|e>>>0<j>>>0;r=d;M=Sia(p,i,d,0);H=mb;e=Sia(q,i,C,i);d=e+M|0;j=mb+H|0;n=d;d=d>>>0<e>>>0?j+1|0:j;e=t;j=u<<15|e>>>17;z=e<<15|g>>>17;g=j;j=Sia(z,0,b,i);e=j+n|0;f=mb+d|0;I=e;f=e>>>0<j>>>0?f+1|0:f;u=f;e=f;f=(h|0)==(x|0)&c>>>0<B>>>0|h>>>0<x>>>0;c=h+I|0;f=e+f|0;B=c;f=c>>>0<h>>>0?f+1|0:f;t=f;c=f;F=A|65536;A=w;N=Sia(p,i,F,w);J=mb;h=Sia(r,o,C,i);f=h+N|0;e=mb+J|0;O=f;e=f>>>0<h>>>0?e+1|0:e;w=e;G=g|-2147483648;x=0;g=Sia(G,x,b,i);b=g+f|0;f=mb+e|0;f=b>>>0<g>>>0?f+1|0:f;P=b;e=Sia(z,o,q,i);b=b+e|0;p=f;j=f+mb|0;Q=b;g=b>>>0<e>>>0?j+1|0:j;f=0;b=f+B|0;e=c+Q|0;e=b>>>0<f>>>0?e+1|0:e;R=b;c=b;b=b+D|0;D=e;f=b>>>0<c>>>0?e+1|0:e;c=f;s=((L+K|0)+s|0)-16383|0;j=Sia(G,x,q,i);h=mb;i=Sia(F,A,C,i);e=i+j|0;f=mb+h|0;f=e>>>0<i>>>0?f+1|0:f;i=(f|0)==(h|0)&e>>>0<j>>>0|f>>>0<h>>>0;h=e;q=i;i=Sia(z,o,r,o);e=i+e|0;j=mb+f|0;j=e>>>0<i>>>0?j+1|0:j;i=(f|0)==(j|0)&e>>>0<h>>>0|f>>>0>j>>>0;f=q+i|0;h=0;h=f>>>0<i>>>0?1:h;q=Sia(G,x,F,A);i=q+f|0;f=mb+h|0;f=i>>>0<q>>>0?f+1|0:f;q=e;h=j;C=i;e=(d|0)==(u|0)&n>>>0>I>>>0|d>>>0>u>>>0;d=e+((d|0)==(H|0)&n>>>0<M>>>0|d>>>0<H>>>0)|0;j=0;j=d>>>0<e>>>0?1:j;i=d;d=q+d|0;e=h+j|0;e=d>>>0<i>>>0?e+1|0:e;n=d;i=e;e=(e|0)==(h|0)&d>>>0<q>>>0|e>>>0<h>>>0;d=C+e|0;h=d>>>0<e>>>0?f+1|0:f;q=d;j=Sia(z,o,F,A);e=mb;r=Sia(G,x,r,o);d=r+j|0;f=mb+e|0;f=d>>>0<r>>>0?f+1|0:f;r=d;d=f;f=(e|0)==(f|0)&j>>>0>r>>>0|e>>>0>f>>>0;z=d+q|0;e=f+h|0;e=d>>>0>z>>>0?e+1|0:e;h=0;d=h+n|0;f=i+r|0;f=d>>>0<h>>>0?f+1|0:f;h=f;j=(i|0)==(f|0)&d>>>0<n>>>0|f>>>0<i>>>0;i=j+z|0;n=i;i=i>>>0<j>>>0?e+1|0:e;r=d;e=d;d=h;j=(p|0)==(w|0)&O>>>0>P>>>0|p>>>0<w>>>0;f=j+((w|0)==(J|0)&O>>>0<N>>>0|w>>>0<J>>>0)|0;h=0;j=f+((g|0)==(p|0)&P>>>0>Q>>>0|g>>>0<p>>>0)|0;f=g+e|0;e=d+j|0;e=f>>>0<g>>>0?e+1|0:e;g=f;h=(d|0)==(e|0)&f>>>0<r>>>0|d>>>0>e>>>0;d=h+n|0;f=i;f=d>>>0<h>>>0?f+1|0:f;h=e;n=d;i=(t|0)==(D|0)&B>>>0>R>>>0|t>>>0>D>>>0;d=i+((t|0)==(u|0)&B>>>0<I>>>0|t>>>0<u>>>0)|0;j=0;j=d>>>0<i>>>0?1:j;i=d;d=d+g|0;e=e+j|0;e=d>>>0<i>>>0?e+1|0:e;h=(e|0)==(h|0)&d>>>0<g>>>0|e>>>0<h>>>0;g=n+h|0;f=g>>>0<h>>>0?f+1|0:f;h=g;i=f;c:{if(f&65536){s=s+1|0;break c}w=l>>>31|0;f=i<<1|h>>>31;h=g<<1|e>>>31;i=f;f=e<<1|d>>>31;d=d<<1|c>>>31;e=f;g=y;f=l<<1|g>>>31;y=g<<1;l=f;f=c<<1|b>>>31;b=b<<1|w;c=f}if((s|0)>=32767){m=m|2147418112;b=0;c=0;break a}d:{if((s|0)<=0){f=1-s|0;if(f>>>0>=128){b=0;c=0;break a}g=s+127|0;vf(k+48|0,y,l,b,c,g);vf(k+32|0,d,e,h,i,g);fm(k+16|0,y,l,b,c,f);fm(k,d,e,h,i,f);y=v[k+32>>2]|v[k+16>>2]|(v[k+48>>2]|v[k+56>>2]|(v[k+52>>2]|v[k+60>>2]))!=0;l=v[k+36>>2]|v[k+20>>2];b=v[k+40>>2]|v[k+24>>2];c=v[k+44>>2]|v[k+28>>2];d=v[k>>2];e=v[k+4>>2];f=v[k+8>>2];g=v[k+12>>2];break d}f=h;g=i&65535|s<<16}o=f|o;m=g|m;if(!(!b&(c|0)==-2147483648?!(l|y):(c|0)>0|(c|0)>=0)){b=d+1|0;j=b?e:e+1|0;c=j;f=(e|0)==(j|0)&b>>>0<d>>>0|e>>>0>j>>>0;d=f+o|0;e=m;o=d;m=d>>>0<f>>>0?e+1|0:e;break a}if(b|y|(c^-2147483648|l)){b=d;c=e;break a}j=m;c=d&1;b=c+d|0;f=b>>>0<c>>>0?e+1|0:e;c=f;e=(e|0)==(f|0)&b>>>0<d>>>0|e>>>0>f>>>0;d=e+o|0;o=d;m=d>>>0<e>>>0?j+1|0:j}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=o;v[a+12>>2]=m;jb=k+96|0}function Oea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=jb-144|0;jb=g;Ac(b);a:{b:{c:{d:{e:{if(!eR(b,13979)){break e}k=Qb(g+128|0);j=Qb(g+112|0);v[23296]=0;v[g+104>>2]=0;v[g+108>>2]=0;R(234,a|0,32768);d=v[23296];v[23296]=0;if((d|0)==1){break b}v[23296]=0;d=Q(1,g+88|0,8087)|0;i=v[23296];v[23296]=0;if((i|0)==1){break c}Hb(a+1298344|0,d);zb(d);v[23296]=0;d=Q(1,g+72|0,6021)|0;i=v[23296];v[23296]=0;if((i|0)==1){break d}Hb(a+1298356|0,d);zb(d);v[a+1298404>>2]=13;m=a+484376|0;i=a+480280|0;while(1){d=v[b+8>>2];f=v[b>>2];v[23296]=0;d=W(144,f|0,d|0,8)|0;f=v[23296];v[23296]=0;f:{g:{h:{if((f|0)!=1){i:{j:{k:{l:{m:{n:{if(!d){break n}v[23296]=0;d=Q(577,b|0,g- -64|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break m}if(!d){break n}d=v[g+68>>2];v[23296]=0;U(178,g+16|0,b|0,cc(d)|0);d=v[23296];v[23296]=0;if((d|0)==1){break l}d=g+16|0;f=jc(g+40|0,d);Ab(d);d=v[f>>2];v[23296]=0;d=T(166,d|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break j}if(d){break k}Ab(f)}if(x[a+480188>>1]){break i}i=0;break g}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}o:{p:{q:{r:{s:{t:{u:{d=cc(v[g+64>>2]);if((d|0)!=1397769541){if((d|0)==1346458708){break t}if((d|0)==1346522948){break s}if((d|0)==1347175758){break u}if((d|0)!=1396788560){if((d|0)==1396854596){break r}if((d|0)==1397507406){break f}if((d|0)!=1129140036){break p}if(x[a+480188>>1]){break f}d=v[f>>2];v[23296]=0;d=T(148,d|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break j}if(d>>>0<8){break f}d=0;v[23296]=0;R(578,g+16|0,f|0);e=v[23296];v[23296]=0;if((e|0)==1){break j}while(1)if((d|0)==4){if(c){break f}i=1;break o}else{e=x[a+480188>>1];h=dc(g+16|0,d);v:{if(!Mb(w[h|0]|w[h+1|0]<<8)){h=(d&3)-1|0;break v}h=g+104|0;o=Lb(h,e),p=1,t[o|0]=p;o=Lb(h,x[a+480188>>1]+1|0),p=255,t[o|0]=p;Te(i+(x[a+480188>>1]<<5)|0);h=x[a+480188>>1];e=h+1|0;u[a+480188>>1]=e;l=i+(h<<5)|0;h=(d&3)-1|0;u[l+4>>1]=h>>>0<2?192:64}Te(i+((e&65535)<<5)|0);e=x[a+480188>>1];u[a+480188>>1]=e+1;u[(i+(e<<5)|0)+4>>1]=h>>>0<2?192:64;d=d+1|0;continue}}if(x[a+480190>>1]){break f}v[23296]=0;R(579,f|0,a|0);d=v[23296];v[23296]=0;if((d|0)!=1){break f}break j}d=v[f>>2];v[23296]=0;d=T(148,d|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break j}if(d>>>0<2){break f}v[23296]=0;d=T(258,f|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break j}o=a,p=Xd(d,1,255),v[o+480196>>2]=p;break f}d=v[f>>2];v[23296]=0;d=T(148,d|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break j}if(d>>>0<2){break f}v[23296]=0;n=T(258,f|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break f}break j}d=w[m|0];e=v[a+484360>>2];h=v[f>>2];v[23296]=0;h=T(148,h|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break j}v[23296]=0;da(326,Zb(e,d)|0,f|0,h|0,255,254);d=v[23296];v[23296]=0;if((d|0)==1){break j}break f}d=k;if(Df(v[d>>2],v[d+4>>2])>>>0>=256){break f}break q}if(Df(v[j>>2],v[j+4>>2])>>>0>3998){break f}d=v[f>>2];v[23296]=0;e=T(148,d|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break j}d=j;if(!e){break f}}v[23296]=0;R(580,d|0,f|0);d=v[23296];v[23296]=0;if((d|0)!=1){break f}break j}if(!(d&-2139062144)){break f}i=0}Ab(f);break g}a=P()|0;O()|0;Ab(f);break a}v[a+480200>>2]=256;v[a+480204>>2]=125e4;v[a+480260>>2]=452;v[a+480264>>2]=3424;v[a+480228>>2]=48;v[a+480232>>2]=48;b=w[a+484376|0];d=v[a+484360>>2];v[23296]=0;R(310,Zb(d,b)|0,n&65535);b=v[23296];v[23296]=0;if((b|0)==1){break b}w:{if(!(c&1)){break w}b=v[k+4>>2];i=v[k>>2];d=0;v[23296]=0;R(213,a+484344|0,Df(i,b)&65535);b=v[23296];v[23296]=0;if((b|0)==1){break b}while(1){f=v[k>>2];b=d&65535;if(Df(f,v[k+4>>2])>>>0<=b>>>0){break w}v[23296]=0;i=v[g+108>>2];e=v[g+104>>2];v[g+8>>2]=e;v[g+12>>2]=i;v[g>>2]=e;v[g+4>>2]=i;X(581,Cg(f,b)|0,b|0,a|0,g|0);b=v[23296];v[23296]=0;if((b|0)!=1){d=d+1|0;continue}break}a=P()|0;O()|0;break a}f=c&2;i=1;d=1;b=0;while(1){if(x[a+480190>>1]<=d>>>0){break g}if(!f|Df(v[j>>2],v[j+4>>2])>>>0<=b>>>0){break g}c=(B(d,104)+a|0)+484380|0;Bo(c);x:{if(v[c>>2]){e=v[Cg(v[j>>2],b)>>2];v[23296]=0;e=T(148,e|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break h}yc(c,e);e=_c(g+40|0,8,1,1,0);h=v[j>>2];v[23296]=0;W(207,e|0,c|0,Cg(h,b)|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break x}b=b+1|0}d=d+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}ld(j);ld(k);break e}Ab(f);continue}}jb=g+144|0;return i|0}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}ld(j);ld(k);S(a|0);L()}function pV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-112|0;jb=f;Ac(b);a:{if(!Hq(b,11632)){break a}if(!Lu(b,f+96|0)){break a}if(!hC(w[f+97|0])){break a}if(!Ob(v[b>>2],v[b+8>>2],Vc(gC(f+96|0),mb))){break a}if(!ac(b,w[f+105|0]|w[f+106|0]<<8)){break a}b:{if(!c){break b}Ed(a,4096);v[a+480208>>2]=12;u[a+480188>>1]=(w[f+98|0]&31)+1;e=a+480190|0;u[e>>1]=w[f+99|0];xh(a,1);d=f+24|0;i=Vb(d,8394);Hb(a+1298344|0,i);zb(i);i=Vb(d,7011);Hb(a+1298356|0,i);zb(i);i=jb-16|0;jb=i;g=Vb(i,4208);Sc(f,g);zb(g);jb=i+16|0;v[23296]=0;X(217,d|0,f|0,w[f+97|0],f+96|0);d=v[23296];v[23296]=0;c:{if((d|0)!=1){d=f+24|0;Hb(a+1298368|0,d);zb(d);ec(f);v[a+1298404>>2]=5;d=w[f+99|0];i=f+80|0;v[i>>2]=0;v[i+4>>2]=0;Zj(i+8|0,0);if(d){Pq(i,d);RC(i,d,0)}d=1;d:{while(1){g=d&65535;if(g>>>0>x[e>>1]){v[23296]=0;Q(218,b|0,a+1298308|0)|0;g=v[23296];v[23296]=0;d=1;e:{if((g|0)==1){break e}g=a+480190|0;while(1){e=d&65535;if(e>>>0>x[g>>1]){d=0;g=a+480188|0;f:{while(1){if(x[g>>1]<=d>>>0){d=0;v[23296]=0;g=a+484344|0;R(213,g|0,x[f+100>>1]);e=v[23296];v[23296]=0;if((e|0)==1){break e}break f}e=(d<<5)+a|0;Te(e+480280|0);v[23296]=0;R(219,b|0,e+480289|0);e=v[23296];v[23296]=0;if((e|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}g:{h:{i:{j:{while(1){if(x[f+100>>1]<=d>>>0){v[23296]=0;e=T(182,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break h}if(!e){break i}d=v[b+8>>2];g=v[b>>2];v[23296]=0;d=W(144,g|0,d|0,e|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break h}if(d){break j}break i}v[23296]=0;e=Q(220,b|0,f+24|0)|0;h=v[23296];v[23296]=0;k:{if((h|0)==1){break k}v[23296]=0;h=W(214,g|0,d&65535,64)|0;j=v[23296];v[23296]=0;if((j|0)==1){break k}if((e&h)==1){e=v[g>>2];v[23296]=0;R(221,$b(e,d)|0,f+24|0);e=v[23296];v[23296]=0;if((e|0)==1){break k}}d=d+1|0;continue}break}b=P()|0;O()|0;break d}g=Qb(f+24|0);v[23296]=0;U(222,b|0,g|0,e|0);d=v[23296];v[23296]=0;l:{if((d|0)!=1){d=Kb(f);v[23296]=0;R(45,d|0,e|0);e=v[23296];v[23296]=0;m:{if((e|0)==1){break m}k=f,l=Eb(v[g>>2]),v[k+48>>2]=l;h=Eb(v[g+4>>2]);while(1){n:{e=v[f+48>>2];if(!Rb(e,h)){v[23296]=0;X(223,f+48|0,5,6,d|0);e=v[23296];v[23296]=0;if((e|0)==1){break n}h=f+48|0;e=Bc(d,h);yb(h);h=Jc(e);j=Fb(e);v[23296]=0;da(224,a+1298332|0,h|0,j|0,76,0);h=v[23296];v[23296]=0;if((h|0)==1){break m}yb(e);fc(g);break i}o:{e=w[e|0];if(e&128){k=f,l=oh(d),v[k+64>>2]=l;j=v[Gf(f+72|0,f- -64|0)>>2];v[23296]=0;X(225,d|0,j|0,e&127,32);e=v[23296];v[23296]=0;if((e|0)!=1){break o}break m}v[23296]=0;R(46,d|0,e<<24>>24);e=v[23296];v[23296]=0;if((e|0)!=1){break o}break m}Be(f+48|0);continue}break}}b=P()|0;O()|0;yb(d);break l}b=P()|0;O()|0}fc(g);break d}d=w[a+484376|0];g=v[a+484360>>2];v[23296]=0;U(226,Zb(g,d)|0,b|0,x[f+102>>1]);d=v[23296];v[23296]=0;if((d|0)==1){break h}e=c&1;h=a+484348|0;d=0;while(1){p:{q:{if(x[f+100>>1]>d>>>0){g=v[b+8>>2];j=v[b>>2];v[23296]=0;g=W(144,j|0,g|0,4)|0;j=v[23296];v[23296]=0;if((j|0)==1){break p}if(g){break q}}if(!(c&2)){break g}g=a+480190|0;d=1;while(1){c=d&65535;if(c>>>0>x[g>>1]){break g}e=B(c,104)+a|0;h=x[e+484414>>1];Bb(f+24|0,v[i>>2],c-1|0);c=_c(f,h&1?16:8,1,0,Cb(v[v[f+24>>2]>>2],v[f+28>>2])?6:0);v[23296]=0;W(207,c|0,e+484380|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}v[23296]=0;g=T(145,b|0)|0;j=v[23296];v[23296]=0;r:{s:{if((j|0)!=1){v[23296]=0;U(178,f|0,b|0,g|0);g=v[23296];v[23296]=0;if((g|0)==1){break s}g=jc(f+24|0,f);Ab(f);if(!e){break r}j=v[a+484344>>2];if(!oe(j,v[h>>2],d&65535)){break r}v[23296]=0;U(227,$b(j,d)|0,0,g|0);j=v[23296];v[23296]=0;if((j|0)!=1){break r}b=P()|0;O()|0;Ab(g);break d}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}Ab(g);d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}Le(i);break b}v[23296]=0;Q(228,b|0,((e<<5)+a|0)+946304|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){d=d+1|0;continue}break}b=P()|0;O()|0;break d}b=P()|0;O()|0;break d}v[23296]=0;R(229,b|0,f+24|0);h=v[23296];v[23296]=0;t:{if((h|0)==1){break t}v[23296]=0;R(230,f+24|0,(B(g,104)+a|0)+484380|0);h=v[23296];v[23296]=0;if((h|0)==1){break t}h=w[f+40|0];Bb(f,v[i>>2],g-1|0);xg(f,(h&3)!=0);d=d+1|0;continue}break}b=P()|0;O()|0}Le(i);break c}b=P()|0;O()|0;ec(f)}S(b|0);L()}d=1}jb=f+112|0;return d|0}function H8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0;e=jb-320|0;jb=e;d=-1;a:{b:{c:{if(!Hk(v[(v[v[b>>2]-12>>2]+b|0)+16>>2])){b=Dl(e+216|0,b);v[23296]=0;d=Q(396,e+200|0,13810)|0;f=v[23296];v[23296]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((f|0)!=1){v[23296]=0;v[e+184>>2]=83886084;v[e+188>>2]=0;U(397,b|0,d|0,e+184|0);f=v[23296];v[23296]=0;if((f|0)==1){break A}Tb(d);t[e+199|0]=0;v[23296]=0;d=Q(396,e+184|0,14588)|0;f=v[23296];v[23296]=0;if((f|0)==1){break z}v[23296]=0;U(398,b|0,e+199|0,d|0);f=v[23296];v[23296]=0;if((f|0)==1){break y}Tb(d);v[23296]=0;f=w[e+199|0];d=Q(396,e+168|0,15625)|0;g=v[23296];v[23296]=0;if((g|0)==1){break x}v[23296]=0;f=f?0:c;X(833,b|0,a+40|0,d|0,f|0);c=v[23296];v[23296]=0;if((c|0)==1){break w}Tb(d);u[e+166>>1]=65535;v[23296]=0;c=Q(396,e+152|0,15234)|0;d=v[23296];v[23296]=0;if((d|0)==1){break v}v[23296]=0;W(426,b|0,e+166|0,c|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break u}Tb(c);u[e+150>>1]=0;v[23296]=0;c=Q(396,e+136|0,15133)|0;d=v[23296];v[23296]=0;if((d|0)==1){break t}v[23296]=0;W(426,b|0,e+150|0,c|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break s}Tb(c);u[a>>1]=x[e+150>>1];v[23296]=0;c=Q(396,e+120|0,14885)|0;d=v[23296];v[23296]=0;if((d|0)==1){break r}v[23296]=0;X(834,b|0,a+52|0,c|0,f|0);d=v[23296];v[23296]=0;if((d|0)==1){break q}Tb(c);v[23296]=0;c=Q(396,e+104|0,14828)|0;d=v[23296];v[23296]=0;if((d|0)==1){break p}v[23296]=0;U(825,b|0,a+36|0,c|0);d=v[23296];v[23296]=0;if((d|0)==1){break o}Tb(c);v[23296]=0;c=Q(396,e+88|0,15241)|0;d=v[23296];v[23296]=0;if((d|0)==1){break n}v[23296]=0;h=a+4|0;U(835,b|0,h|0,c|0);d=v[23296];v[23296]=0;if((d|0)==1){break m}Tb(c);v[23296]=0;c=Q(396,e+72|0,15135)|0;d=v[23296];v[23296]=0;if((d|0)==1){break l}v[23296]=0;f=a+28|0;U(836,b|0,f|0,c|0);d=v[23296];v[23296]=0;if((d|0)==1){break k}Tb(c);v[23296]=0;c=Q(396,e+56|0,14999)|0;d=v[23296];v[23296]=0;if((d|0)==1){break j}v[23296]=0;U(836,b|0,a+30|0,c|0);d=v[23296];v[23296]=0;if((d|0)==1){break i}Tb(c);v[23296]=0;c=Q(396,e+40|0,14857)|0;d=v[23296];v[23296]=0;if((d|0)==1){break h}v[23296]=0;U(837,b|0,a+32|0,c|0);d=v[23296];v[23296]=0;if((d|0)==1){break g}Tb(c);u[e+38>>1]=0;v[23296]=0;c=Q(396,e+24|0,14807)|0;d=v[23296];v[23296]=0;if((d|0)==1){break c}v[23296]=0;W(426,b|0,e+38|0,c|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break f}Tb(c);i=nL(z[a+32>>2]);z[a+32>>2]=i;d=-1;if(!Rl(i)){break d}k=e,l=Eb(v[a+4>>2]),v[k+16>>2]=l;c=Eb(v[a+8>>2]);while(1){g=v[e+16>>2];if(!Rb(g,c)){break e}if(!Rl(z[g>>2])){break d}Ce(e+16|0);continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(c);break a}a=P()|0;O()|0;Tb(c);break a}if(w[b+3|0]&64){break d}c=x[f>>1];if((c+300&65535)>>>0>600){break d}g=x[a>>1];if(g>>>0>3|(g|0)==2){break d}j=u[a+30>>1];if((j|0)<0){break d}k=e,l=wi(v[a+36>>2]),v[k+16>>2]=l;v[e+8>>2]=0;k=a,l=v[wj(e+16|0,e+8|0,43824)>>2],v[k+36>>2]=l;if(wc(v[a+4>>2],v[a+8>>2])>>>0>32767){break d}B:{C:{switch(g-1|0){case 2:f=u[e+38>>1];if((f|0)<=0){break d}u[e+6>>1]=j;z[e+16>>2]=z[a+32>>2];v[23296]=0;u[e+8>>1]=c;u[e+10>>1]=(c+f|0)-1;a=fa(838,a|0,e+6|0,e+16|0,e+8|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;O()|0;break a;case 0:g=u[e+38>>1];if((g|0)<=0){break d}z[e+16>>2]=z[a+32>>2];v[23296]=0;u[e+8>>1]=c;u[e+10>>1]=(c+g|0)-1;a=ja(839,a|0,h|0,e+16|0,e+8|0,f|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(a){break B}break d}a=P()|0;O()|0;break a;default:break C}}v[23296]=0;Y(840,a|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}}d=1}_g(b)}jb=e+320|0;return d|0}a=P()|0;O()|0;break a}a=P()|0;O()|0}_g(b);S(a|0);L()}function Oha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;e=jb-352|0;jb=e;Ac(b);f=jb-16|0;jb=f;sT(f+8|0,e+128|0);h=v[f+12>>2];nc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);i=v[f+4>>2];if((i|0)==(h|0)){ac(b,v[f+12>>2])}jb=f+16|0;a:{b:{c:{d:{e:{f:{g:{if((h|0)!=(i|0)){break g}if(!uT(e+128|0)){break g}if(!Ob(v[b>>2],v[b+8>>2],Vc(tT(w[e+344|0],w[e+345|0]),mb))){break g}if(!c){d=1;break g}Ed(a,2);Dg(a);v[a+480188>>2]=524296;s=a,z=Ie(455e3),v[s+480204>>2]=z;Nb(a+1074312|0,110,1);v[a+480208>>2]=v[a+480208>>2]|16777216;f=e+96|0;Ze(f,2,e+159|0);d=e+112|0;Gc(d,f);Bc(a+1298308|0,d);yb(d);d=0;h:{i:{while(1){if((d|0)==8){j:{d=Zb(v[a+484360>>2],w[a+484376|0]);o=w[e+344|0];n=o+1|0;oo(d,b,n,65535,65535);f=Qb(e+112|0);v[23296]=0;U(222,b|0,f|0,n|0);d=v[23296];v[23296]=0;if((d|0)==1){break j}s=e,z=Eb(v[f>>2]),v[s+96>>2]=z;d=Eb(v[f+4>>2]);while(1){h=v[e+96>>2];p=Rb(h,d);if(p){if((w[h|0]-9&255)>>>0<248){break h}Be(e+96|0);continue}break}s=a,z=w[Lb(v[f>>2],0)|0],v[s+480196>>2]=z;d=w[e+343|0];i=w[e+345|0];h=Qb(e+96|0);v[23296]=0;m=i+1|0;U(222,b|0,h|0,m|0);i=v[23296];v[23296]=0;k:{if((i|0)==1){break k}v[23296]=0;i=a+484344|0;R(213,i|0,m|0);g=v[23296];v[23296]=0;if((g|0)==1){break k}q=d+1|0;if(!(c&1)){break i}c=0;while(1){if((c|0)==(m|0)){break i}d=w[Lb(v[h>>2],c)|0];v[23296]=0;d=W(214,i|0,d|0,q|0)|0;g=v[23296];v[23296]=0;l:{if((g|0)!=1){if(!d){break i}j=0;k=$b(v[i>>2],w[Lb(v[h>>2],c)|0]);m:while(1){r=j&65535;if(r>>>0>7){break l}j=j+1|0;d=0;while(1){if(y[k+12>>2]<=d>>>0){continue m}v[23296]=0;g=T(194,b|0)|0;l=v[23296];v[23296]=0;n:{o:{if((l|0)!=1){if(!(g&128)){break o}d=(g&127)+d|0;break n}d=P()|0;O()|0;break b}l=fd(v[k>>2],v[v[k+48>>2]+12>>2],d,r);if((g|0)==1){t[l|0]=254;break n}if((g-1&255)>>>0>96){break n}t[l+1|0]=j;t[l|0]=g+12}d=d+1|0;continue}}}d=P()|0;O()|0;break b}c=c+1|0;continue}}d=P()|0;O()|0;break b}}else{i=e+112|0;f=(e+128|0)+B(d,19)|0;_A(i,f+63|0);h=e+96|0;Gc(h,i);wm(((d<<5)+a|0)+480289|0,h);yb(h);d=d+1|0;g=B(d,104)+a|0;j=g+484380|0;pd(j,2);t[e+107|0]=0;h=w[f+78|0]|w[f+79|0]<<8|(w[f+80|0]<<16|w[f+81|0]<<24);t[e+103|0]=h;t[e+104|0]=h>>>8;t[e+105|0]=h>>>16;t[e+106|0]=h>>>24;h=w[f+75|0]|w[f+76|0]<<8|(w[f+77|0]<<16|w[f+78|0]<<24);f=w[f+71|0]|w[f+72|0]<<8|(w[f+73|0]<<16|w[f+74|0]<<24);v[e+8>>2]=v[e+104>>2];v[e+96>>2]=f;v[e+100>>2]=h;f=v[e+100>>2];v[e>>2]=v[e+96>>2];v[e+4>>2]=f;hl(j,1,e);v[g+484404>>2]=8215;f=e+80|0;Gc(f,i);Ec(((d<<5)+a|0)+946304|0,f);yb(f);continue}break}d=P()|0;O()|0;break a}j=o+1|0;c=a+484376|0;d=0;p:{q:{while(1){if((d|0)==(j|0)){v[23296]=0;b=Q(1,e+80|0,8518)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break p}d=P()|0;O()|0;break b}b=w[c|0];g=v[a+484360>>2];v[23296]=0;k=d&65535;b=Q(297,Zb(g,b)|0,k|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){r:{s:{if(b){b=Zb(v[a+484360>>2],w[c|0]);break s}v[23296]=0;g=Q(345,i|0,q|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break q}if((g|0)==65535){break r}b=Zb(v[a+484360>>2],w[c|0]);s=dc(v[b>>2],d),z=g,u[s>>1]=z}b=ZA(Eb(v[$b(v[i>>2],x[dc(v[b>>2],d)>>1])+4>>2]),1);g=w[b+5|0];l=w[Lb(v[f>>2],(d+1>>>0)%(n>>>0)|0)|0];if((g|0)==(l|0)){break r}t:{if(w[b+3|0]!=16){break t}g=w[c|0];m=v[a+484360>>2];v[23296]=0;g=Q(346,Zb(m,g)|0,k|0)|0;k=v[23296];v[23296]=0;if((k|0)==1){break c}if((g|0)==65535){break t}b=ZA(Eb(v[$b(v[i>>2],g)+4>>2]),1)}t[b+5|0]=l;t[b+3|0]=16}d=d+1|0;continue}break}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}Hb(a+1298344|0,b);zb(b);v[23296]=0;b=Q(1,e- -64|0,6010)|0;c=v[23296];v[23296]=0;if((c|0)==1){break f}Hb(a+1298356|0,b);zb(b);b=e+16|0;tj(b,2,e+139|0);v[23296]=0;R(210,e+32|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break e}v[23296]=0;U(11,e+48|0,5,e+32|0);b=v[23296];v[23296]=0;if((b|0)==1){break d}b=e+48|0;Hb(a+1298368|0,b);zb(b);yb(e+32|0);v[a+1298404>>2]=5;fc(h)}fc(f);d=p^1}jb=e+352|0;return d|0}d=P()|0;O()|0;break b}d=P()|0;O()|0;break b}d=P()|0;O()|0;yb(e+32|0);break b}d=P()|0;O()|0}fc(h)}fc(f);S(d|0);L()}function ux(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;l=jb-48|0;jb=l;v[l+44>>2]=0;if(i?1:d|g|h){j=g?l+44|0:0;a:{if(!j){break a}k=v[j>>2];if(!k){break a}Jb(k);v[j>>2]=0}v[23296]=0;Z(93);k=v[23296];v[23296]=0;b:{c:{if((k|0)==1){m=Xa(91780,48896,48952,61592,91968,92072,92020,91912,91900,92216,92184,92152,92140,92364,0)|0;d:{e:{n=O()|0;if((n|0)==(ea(91780)|0)){k=_(m|0)|0;v[23296]=0;R(1e3,j|0,k|0);j=v[23296];v[23296]=0;k=277;if((j|0)==1){break e}break b}if((ea(48896)|0)==(n|0)){k=_(m|0)|0;v[23296]=0;R(1e3,j|0,k|0);j=v[23296];v[23296]=0;k=358;if((j|0)!=1){break b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break c}break d}if((ea(48952)|0)==(n|0)){k=_(m|0)|0;v[23296]=0;R(1e3,j|0,k|0);j=v[23296];v[23296]=0;k=359;if((j|0)!=1){break b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break c}break d}if((ea(61592)|0)==(n|0)){k=_(m|0)|0;v[23296]=0;R(1e3,j|0,k|0);j=v[23296];v[23296]=0;k=357;if((j|0)!=1){break b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break c}break d}if((ea(91968)|0)==(n|0)){k=_(m|0)|0;v[23296]=0;R(1e3,j|0,k|0);j=v[23296];v[23296]=0;k=300;if((j|0)!=1){break b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break c}break d}if((ea(92072)|0)==(n|0)){k=_(m|0)|0;v[23296]=0;R(1e3,j|0,k|0);j=v[23296];v[23296]=0;k=299;if((j|0)!=1){break b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break c}break d}if((ea(92020)|0)==(n|0)){k=_(m|0)|0;v[23296]=0;R(1e3,j|0,k|0);j=v[23296];v[23296]=0;k=298;if((j|0)!=1){break b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break c}break d}if((ea(91912)|0)==(n|0)){k=_(m|0)|0;v[23296]=0;R(1e3,j|0,k|0);j=v[23296];v[23296]=0;k=297;if((j|0)!=1){break b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break c}break d}if((ea(91900)|0)==(n|0)){k=_(m|0)|0;v[23296]=0;R(1e3,j|0,k|0);j=v[23296];v[23296]=0;k=296;if((j|0)!=1){break b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break c}break d}if((ea(92216)|0)==(n|0)){k=_(m|0)|0;v[23296]=0;R(1e3,j|0,k|0);j=v[23296];v[23296]=0;k=289;if((j|0)!=1){break b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break c}break d}if((ea(92184)|0)==(n|0)){k=_(m|0)|0;v[23296]=0;R(1e3,j|0,k|0);j=v[23296];v[23296]=0;k=288;if((j|0)!=1){break b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break c}break d}if((ea(92152)|0)==(n|0)){k=_(m|0)|0;v[23296]=0;R(1e3,j|0,k|0);j=v[23296];v[23296]=0;k=287;if((j|0)!=1){break b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break c}break d}if((ea(92140)|0)==(n|0)){k=_(m|0)|0;v[23296]=0;R(1e3,j|0,k|0);j=v[23296];v[23296]=0;k=286;if((j|0)!=1){break b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break c}break d}o=ea(92364)|0;k=257;m=_(m|0)|0;if((n|0)!=(o|0)){break b}v[23296]=0;R(1e3,j|0,m|0);j=v[23296];v[23296]=0;k=267;if((j|0)!=1){break b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)==1){break d}break c}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break c}}V(0)|0;O()|0;Ub()}L()}S(a|0);L()}$()}m=!g;if(d){j=nb[d|0](k,e)|0}else{j=3}if(!(m|!(j&2))){v[g+16>>2]=k;m=g;g=v[l+44>>2];p=m,q=Xf(g?g:21473),v[p+20>>2]=q}if(h){v[h>>2]=k}if(i){g=v[l+44>>2];p=i,q=Xf(g?g:21473),v[p>>2]=q}g=v[l+44>>2];if(g){Jb(g);v[l+44>>2]=0}f:{if(!(j&1)){break f}v[23296]=0;R(998,l+32|0,a|0);g=v[23296];v[23296]=0;g:{h:{if((g|0)!=1){i:{if(f){g=v[f+24>>2];v[23296]=0;R(999,g|0,l+32|0);g=v[23296];v[23296]=0;if((g|0)!=1){break i}break h}g=Jc(l+32|0);if(b){v[23296]=0;R(b|0,g|0,c|0);g=v[23296];v[23296]=0;if((g|0)==1){break h}break i}Bs(g,l)}yb(l+32|0);break f}g=V(0)|0;O()|0;break g}g=V(0)|0;O()|0;yb(l+32|0)}_(g|0)|0;v[l+28>>2]=f;v[l+24>>2]=e;v[l+20>>2]=d;v[l+16>>2]=c;v[l+12>>2]=b;v[l+8>>2]=a?a:21473;v[l+4>>2]=250;v[l>>2]=9076;YJ(17689,l);As(92720);$()}jb=l+48|0}function DH(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0,C=0;i=jb-560|0;jb=i;g=c;c=(c-3|0)/24|0;s=(c|0)>0?c:0;k=g+B(s,-24)|0;o=v[(e<<2)+72608>>2];j=d-1|0;if((o+j|0)>=0){g=d+o|0;c=s-j|0;while(1){A[(i+320|0)+(h<<3)>>3]=(c|0)<0?0:+v[(c<<2)+72624>>2];c=c+1|0;h=h+1|0;if((g|0)!=(h|0)){continue}break}}q=k-24|0;g=0;t=(o|0)>0?o:0;h=(d|0)<=0;while(1){a:{if(h){f=0;break a}n=g+j|0;c=0;f=0;while(1){f=A[(c<<3)+a>>3]*A[(i+320|0)+(n-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;c=(g|0)==(t|0);g=g+1|0;if(!c){continue}break}z=47-k|0;u=48-k|0;C=k-25|0;g=o;b:{while(1){f=A[(g<<3)+i>>3];c=0;h=g;l=(g|0)<=0;if(!l){while(1){n=(i+480|0)+(c<<2)|0;m=f*5.960464477539063e-8;c:{if(D(m)<2147483648){j=~~m;break c}j=-2147483648}m=+(j|0);f=m*-16777216+f;d:{if(D(f)<2147483648){j=~~f;break d}j=-2147483648}v[n>>2]=j;h=h-1|0;f=A[(h<<3)+i>>3]+m;c=c+1|0;if((g|0)!=(c|0)){continue}break}}f=Dj(f,q);f=f+H(f*.125)*-8;e:{if(D(f)<2147483648){n=~~f;break e}n=-2147483648}f=f-+(n|0);f:{g:{h:{w=(q|0)<=0;i:{if(!w){h=(g<<2)+i|0;j=v[h+476>>2];c=j>>u;r=h;h=j-(c<<u)|0;v[r+476>>2]=h;n=c+n|0;j=h>>z;break i}if(q){break h}j=v[((g<<2)+i|0)+476>>2]>>23}if((j|0)<=0){break f}break g}j=2;if(f>=.5){break g}j=0;break f}c=0;h=0;if(!l){while(1){r=(i+480|0)+(c<<2)|0;x=v[r>>2];l=16777215;j:{k:{if(h){break k}l=16777216;if(x){break k}h=0;break j}v[r>>2]=l-x;h=1}c=c+1|0;if((g|0)!=(c|0)){continue}break}}l:{if(w){break l}c=8388607;m:{switch(C|0){case 1:c=4194303;break;case 0:break m;default:break l}}l=(g<<2)+i|0;v[l+476>>2]=v[l+476>>2]&c}n=n+1|0;if((j|0)!=2){break f}f=1-f;j=2;if(!h){break f}f=f-Dj(1,q)}if(f==0){c=1;l=0;h=g;n:{if((g|0)<=(o|0)){break n}while(1){h=h-1|0;l=v[(i+480|0)+(h<<2)>>2]|l;if((h|0)>(o|0)){continue}break}if(!l){break n}k=q;while(1){k=k-24|0;g=g-1|0;if(!v[(i+480|0)+(g<<2)>>2]){continue}break}break b}while(1){h=c;c=c+1|0;if(!v[(i+480|0)+(o-h<<2)>>2]){continue}break}h=g+h|0;while(1){j=d+g|0;g=g+1|0;A[(i+320|0)+(j<<3)>>3]=v[(s+g<<2)+72624>>2];c=0;f=0;if((d|0)>0){while(1){f=A[(c<<3)+a>>3]*A[(i+320|0)+(j-c<<3)>>3]+f;c=c+1|0;if((d|0)!=(c|0)){continue}break}}A[(g<<3)+i>>3]=f;if((g|0)<(h|0)){continue}break}g=h;continue}break}f=Dj(f,24-k|0);o:{if(f>=16777216){d=(i+480|0)+(g<<2)|0;m=f*5.960464477539063e-8;p:{if(D(m)<2147483648){c=~~m;break p}c=-2147483648}f=+(c|0)*-16777216+f;q:{if(D(f)<2147483648){a=~~f;break q}a=-2147483648}v[d>>2]=a;g=g+1|0;break o}if(D(f)<2147483648){c=~~f}else{c=-2147483648}k=q}v[(i+480|0)+(g<<2)>>2]=c}f=Dj(1,k);if((g|0)>=0){d=g;while(1){a=d;A[(a<<3)+i>>3]=f*+v[(i+480|0)+(a<<2)>>2];d=a-1|0;f=f*5.960464477539063e-8;if(a){continue}break}a=0;h=g;while(1){d=a>>>0>t>>>0?t:a;c=0;f=0;while(1){f=A[(c<<3)+75392>>3]*A[(c+h<<3)+i>>3]+f;k=(c|0)!=(d|0);c=c+1|0;if(k){continue}break}A[(i+160|0)+(g-h<<3)>>3]=f;h=h-1|0;c=(a|0)!=(g|0);a=a+1|0;if(c){continue}break}}r:{s:{t:{switch(e|0){case 3:u:{if((g|0)<=0){break u}d=(i+160|0)+(g<<3)|0;f=A[d>>3];c=g;while(1){m=f;e=i+160|0;a=c-1|0;h=e+(a<<3)|0;y=A[h>>3];f=y+f;A[e+(c<<3)>>3]=m+(y-f);A[h>>3]=f;e=c>>>0>1;c=a;if(e){continue}break}if((g|0)<2){break u}f=A[d>>3];c=g;while(1){m=f;d=i+160|0;a=c-1|0;e=d+(a<<3)|0;p=A[e>>3];f=p+f;A[d+(c<<3)>>3]=m+(p-f);A[e>>3]=f;d=c>>>0>2;c=a;if(d){continue}break}p=0;while(1){p=p+A[(i+160|0)+(g<<3)>>3];a=(g|0)>2;g=g-1|0;if(a){continue}break}}f=A[i+160>>3];if(j){break s}A[b>>3]=f;f=A[i+168>>3];A[b+16>>3]=p;A[b+8>>3]=f;break r;case 0:f=0;if((g|0)>=0){while(1){a=g;g=g-1|0;f=f+A[(i+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;break r;case 1:case 2:break t;default:break r}}f=0;if((g|0)>=0){d=g;while(1){a=d;d=a-1|0;f=f+A[(i+160|0)+(a<<3)>>3];if(a){continue}break}}A[b>>3]=j?-f:f;f=A[i+160>>3]-f;c=1;if((g|0)>0){while(1){f=f+A[(i+160|0)+(c<<3)>>3];a=(c|0)!=(g|0);c=c+1|0;if(a){continue}break}}A[b+8>>3]=j?-f:f;break r}A[b>>3]=-f;f=A[i+168>>3];A[b+16>>3]=-p;A[b+8>>3]=-f}jb=i+560|0;return n&7}function w_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;h=jb+-64|0;jb=h;v[h+56>>2]=b;v[e>>2]=0;bd(h,d);v[23296]=0;b=T(1084,h|0)|0;i=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((i|0)!=1){_b(h);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;_b(h);S(a|0);L()}YF(a,f+24|0,h+56|0,c,e,b);break b}XF(a,f+16|0,h+56|0,c,e,b);break b}b=nb[v[v[a+8>>2]+12>>2]](a+8|0)|0;g=a;i=v[h+56>>2];a=tc(b);j=h,k=Ij(g,i,c,d,e,f,a,a+(Fb(b)<<2)|0),v[j+56>>2]=k;break b}a=Qi(h+56|0,c,e,b,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}b=v[20475];v[h+24>>2]=v[20474];v[h+28>>2]=b;b=v[20473];v[h+16>>2]=v[20472];v[h+20>>2]=b;b=v[20471];v[h+8>>2]=v[20470];v[h+12>>2]=b;b=v[20469];v[h>>2]=v[20468];v[h+4>>2]=b;j=h,k=Ij(a,v[h+56>>2],c,d,e,f,h,h+32|0),v[j+56>>2]=k;break b}b=v[20483];v[h+24>>2]=v[20482];v[h+28>>2]=b;b=v[20481];v[h+16>>2]=v[20480];v[h+20>>2]=b;b=v[20479];v[h+8>>2]=v[20478];v[h+12>>2]=b;b=v[20477];v[h>>2]=v[20476];v[h+4>>2]=b;j=h,k=Ij(a,v[h+56>>2],c,d,e,f,h,h+32|0),v[j+56>>2]=k;break b}a=Qi(h+56|0,c,e,b,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Qi(h+56|0,c,e,b,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Qi(h+56|0,c,e,b,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Qi(h+56|0,c,e,b,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Qi(h+56|0,c,e,b,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+56|0;d=jb-16|0;jb=d;v[d+8>>2]=c;while(1){H:{if(!Qr(a,d+8|0)){break H}if(!Ck(b,1,Dk(v[a>>2]))){break H}on(a);continue}break}if(Kj(a,d+8|0)){v[e>>2]=v[e>>2]|2}jb=d+16|0;break b}d=h+56|0;a=nb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Fb(a)|0)==(0-Fb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}c=Dr(d,c,a,a+24|0,b,e,0);b=v[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}b=qc(h,81936,44);j=b,k=Ij(a,v[b+56>>2],c,d,e,f,b,b+44|0),v[j+56>>2]=k;break b}v[h+16>>2]=v[20500];b=v[20499];v[h+8>>2]=v[20498];v[h+12>>2]=b;b=v[20497];v[h>>2]=v[20496];v[h+4>>2]=b;j=h,k=Ij(a,v[h+56>>2],c,d,e,f,h,h+20|0),v[j+56>>2]=k;break b}a=Qi(h+56|0,c,e,b,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}b=v[20511];v[h+24>>2]=v[20510];v[h+28>>2]=b;b=v[20509];v[h+16>>2]=v[20508];v[h+20>>2]=b;b=v[20507];v[h+8>>2]=v[20506];v[h+12>>2]=b;b=v[20505];v[h>>2]=v[20504];v[h+4>>2]=b;j=h,k=Ij(a,v[h+56>>2],c,d,e,f,h,h+32|0),v[j+56>>2]=k;break b}a=Qi(h+56|0,c,e,b,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=nb[v[v[a>>2]+20>>2]](a,v[h+56>>2],c,d,e,f)|0;break a}b=nb[v[v[a+8>>2]+24>>2]](a+8|0)|0;g=a;i=v[h+56>>2];a=tc(b);j=h,k=Ij(g,i,c,d,e,f,a,a+(Fb(b)<<2)|0),v[j+56>>2]=k;break b}WF(f+20|0,h+56|0,c,e,b);break b}a=Qi(h+56|0,c,e,b,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=jb-16|0;jb=a;v[a+8>>2]=c;c=6;d=h+56|0;L:{M:{if(Kj(d,a+8|0)){break M}c=4;if((dn(b,Dk(v[d>>2]))|0)!=37){break M}c=2;if(!Kj(on(d),a+8|0)){break L}}v[e>>2]=v[e>>2]|c}jb=a+16|0}a=v[h+56>>2]}jb=h- -64|0;return a|0}function II(a,b,c,d,e,f){var g=0,h=0,i=0,j=0,k=0,l=0;g=jb-48|0;jb=g;a:{b:{if(es(c)){j=v[b+484344>>2];if(oe(j,v[b+484348>>2],c&65535)){break b}}c=a;a=Kb(g+32|0);b=Kb(g+16|0);fi(c,a,b);yb(b);yb(a);break a}c=$b(j,c);if(!(v[c+12>>2]>(d|0)&(d|0)>=0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);fi(c,a,b);yb(b);yb(a);break a}if(!(x[b+480188>>1]>e>>>0&(e|0)>=0)){c=a;a=Kb(g+32|0);b=Kb(g+16|0);fi(c,a,b);yb(b);yb(a);break a}if(f>>>0>=6){c=a;a=Kb(g+32|0);b=Kb(g+16|0);fi(c,a,b);yb(b);yb(a);break a}c=fd(v[c>>2],v[v[c+48>>2]+12>>2],d,e&65535);c:{d:{e:{f:{switch(f|0){case 0:g:{h:{i:{j:{k:{d=w[c|0];if(!Uc(d)){if(!wp(d)){break k}}e=g+16|0;dM(e,b,d,w[c+1|0]);v[23296]=0;R(962,g+32|0,e|0);b=v[23296];v[23296]=0;d=1;if((b|0)!=1){break j}c=P()|0;O()|0;break g}d=0;v[23296]=0;Q(54,g+32|0,16584)|0;b=v[23296];v[23296]=0;if((b|0)==1){break i}}b=9860;c=w[c|0];if(!Uc(c)){b=wp(c)?10170:16584}v[23296]=0;b=Q(54,g|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break h}c=a;a=g+32|0;fi(c,a,b);yb(b);yb(a);if(!d){break a}zb(g+16|0);break a}c=P()|0;O()|0;break d}c=P()|0;O()|0;yb(g+32|0);if(!d){break d}}zb(g+16|0);break d;case 1:b=c+1|0;l:{if(w[c+1|0]){Nt(g+32|0,b);break l}Vb(g+32|0,16589)}b=w[b|0];v[23296]=0;b=Q(54,g+16|0,(b?10660:16589)|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break e}c=a;a=g+32|0;fi(c,a,b);yb(b);yb(a);break a;case 2:m:{if(Sg(w[c|0])){Vb(g+32|0,17644);break m}d=w[c+2|0];if(d){Je(g+32|0,1,FL(v[v[b+8>>2]+88>>2],d));break m}Vb(g+32|0,17644)}b=17644;if(!Sg(w[c|0])){b=w[c+2|0]?5466:17644}v[23296]=0;b=Q(54,g+16|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){c=a;a=g+32|0;fi(c,a,b);yb(b);yb(a);break a}c=P()|0;O()|0;yb(g+32|0);break d;case 4:n:{if(Sg(w[c|0])){k=g,l=Tj(w[c+2|0],w[c+4|0])&255,v[k>>2]=l;oA(g+32|0,g);break n}if(w[c+2|0]){Nt(g+32|0,c+4|0);break n}Vb(g+32|0,16589)}b=5450;if(!Sg(w[c|0])){b=w[c+2|0]?5450:16589}v[23296]=0;b=Q(54,g+16|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){c=a;a=g+32|0;fi(c,a,b);yb(b);yb(a);break a}c=P()|0;O()|0;yb(g+32|0);break d;case 3:o:{if(Sg(w[c|0])){k=g,l=(Tj(w[c+3|0],w[c+5|0])&3840)!=0,t[k|0]=l;d=jb-32|0;jb=d;t[d+24|0]=44;v[d+16>>2]=-1;v[d+20>>2]=0;v[d+8>>2]=1058;v[d+12>>2]=1;j=g+32|0;b=jb+-64|0;jb=b;h=v[d+8>>2]&2?16:10;f=jb-32|0;jb=f;e=Je(f+16|0,1,0);p:{q:{r:{while(1){i=tc(e);lx(f+8|0,i,Fb(e)+i|0,w[g|0],h);if(!v[f+12>>2]){break r}i=Hf(Fb(e));v[23296]=0;R(58,e|0,i|0);i=v[23296];v[23296]=0;if((i|0)!=1){continue}break}break q}h=v[f+8>>2];i=tc(e);v[23296]=0;R(59,e|0,h-i|0);h=v[23296];v[23296]=0;s:{if((h|0)!=1){v[23296]=0;R(60,b|0,e|0);h=v[23296];v[23296]=0;if((h|0)!=1){break s}break q}break q}yb(e);jb=f+32|0;break p}a=P()|0;O()|0;yb(e);S(a|0);L()}e=b+16|0;ms(e,b,v[d+8>>2]);f=v[d+12>>2];h=v[d+8>>2];v[23296]=0;X(73,b+32|0,e|0,h|0,f|0);e=v[23296];v[23296]=0;t:{u:{v:{w:{x:{if((e|0)!=1){e=w[d+24|0];f=v[d+20>>2];v[23296]=0;X(74,b+48|0,b+32|0,f|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break x}v[23296]=0;R(57,j|0,b+48|0);e=v[23296];v[23296]=0;if((e|0)==1){break w}yb(b+48|0);yb(b+32|0);yb(b+16|0);yb(b);jb=b- -64|0;break t}a=P()|0;O()|0;break u}a=P()|0;O()|0;break v}a=P()|0;O()|0;yb(b+48|0)}yb(b+32|0)}yb(b+16|0);yb(b);S(a|0);L()}jb=d+32|0;break o}d=w[c+3|0];if(d){Je(g+32|0,1,EL(v[v[b+8>>2]+84>>2],d));break o}Vb(g+32|0,16590)}b=12165;if(!Sg(w[c|0])){b=w[c+3|0]?12165:16590}v[23296]=0;b=Q(54,g+16|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){c=a;a=g+32|0;fi(c,a,b);yb(b);yb(a);break a}c=P()|0;O()|0;yb(g+32|0);break d;case 5:break f;default:break c}}y:{if(Sg(w[c|0])){k=g,l=Tj(w[c+3|0],w[c+5|0])&255,v[k>>2]=l;oA(g+32|0,g);break y}if(w[c+3|0]){Nt(g+32|0,c+5|0);break y}Vb(g+32|0,16589)}b=11025;if(!Sg(w[c|0])){b=w[c+3|0]?11025:16589}v[23296]=0;b=Q(54,g+16|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){c=a;a=g+32|0;fi(c,a,b);yb(b);yb(a);break a}c=P()|0;O()|0;yb(g+32|0);break d}c=P()|0;O()|0;yb(g+32|0)}S(c|0);L()}c=a;a=Kb(g+32|0);b=Kb(g+16|0);fi(c,a,b);yb(b);yb(a)}jb=g+48|0}function dM(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;k=jb-16|0;jb=k;a:{b:{c:{if(!Uc(c)|!d|v[b+480180>>2]!=16777216|x[b+480192>>1]<d>>>0){break c}d=v[((d<<2)+b|0)+900380>>2];if(!d){break c}e=v[d+44>>2];if(!e){break c}u[k+14>>1]=c-61;c=jb+-64|0;jb=c;d:{e:{d=u[e+28>>1];h=k+14|0;b=u[h>>1];if((d|0)<=(b|0)){if((b|0)<=(wc(v[e+4>>2],v[e+8>>2])+d<<16)-65536>>16){break e}}Kb(a);break d}f:{d=x[e+30>>1];if(!d){b=e+52|0;d=Rx(b,h);if(!Ag(d,yf(b))){break f}Sm(a,vd(d)+4|0);break d}b=In(b,d<<16>>16);u[c+62>>1]=b;d=Kb(a);g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{a=e+52|0;f=Rx(a,c+62|0);t:{if(Ag(f,yf(a))){v[23296]=0;R(123,d|0,vd(f)+4|0);a=v[23296];v[23296]=0;if((a|0)==1){break t}a=u[e+30>>1];b=u[h>>1];v[23296]=0;l=c,m=Qx(b,a)+5|0,v[l+32>>2]=m;R(120,c+48|0,c+32|0);a=v[23296];v[23296]=0;u:{if((a|0)!=1){v[23296]=0;Q(87,d|0,c+48|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break u}zb(c+48|0);break d}a=P()|0;O()|0;break g}a=P()|0;O()|0;zb(c+48|0);break g}if(u[e+30>>1]>26){break q}v[23296]=0;b=W(477,c+32|0,1,(b<<24)+1090519040>>24)|0;a=v[23296];v[23296]=0;if((a|0)==1){break s}v[23296]=0;U(11,c+48|0,0,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break r}a=c+48|0;f=Hb(d,a);zb(a);yb(b);v[23296]=0;Q(121,f|0,14489)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break p}}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(b);break g}v[23296]=0;a=b<<16>>16;v[c+28>>2]=(a|0)%16;R(793,c+32|0,c+28|0);f=v[23296];v[23296]=0;if((f|0)==1){break o}v[23296]=0;v[c+12>>2]=((a|0)/16<<16>>16)%16;R(793,c+16|0,c+12|0);a=v[23296];v[23296]=0;if((a|0)==1){break n}v[23296]=0;U(2,c+48|0,c+32|0,c+16|0);a=v[23296];v[23296]=0;if((a|0)==1){break m}a=c+48|0;f=Hb(d,a);zb(a);zb(c+16|0);zb(c+32|0);if(b<<16>>16<256){break p}v[23296]=0;U(8,c|0,0,f|0);a=v[23296];v[23296]=0;if((a|0)==1){break k}b=c+32|0;g=Zd(c);j=oh(c);i=Zd(c);a=jb-32|0;jb=a;v[a+16>>2]=j;v[a+24>>2]=g;v[a+8>>2]=i;while(1){if(Nh(a+24|0,a+16|0)){g=a+24|0;j=xp(t[v[g>>2]]);i=a+8|0;t[v[i>>2]]=j;Be(g);Be(i);continue}break}jb=a+32|0;Sc(b,c);v[23296]=0;U(11,c+48|0,0,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break j}a=c+48|0;Hb(f,a);zb(a);yb(c+32|0);yb(c)}a=u[e+30>>1];b=u[h>>1];v[23296]=0;l=c,m=Qx(b,a)+5|0,v[l+16>>2]=m;R(120,c+48|0,c+16|0);a=v[23296];v[23296]=0;if((a|0)==1){break i}v[23296]=0;Q(87,d|0,c+48|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break h}zb(c+48|0);break d}a=P()|0;O()|0;break g}a=P()|0;O()|0;break l}a=P()|0;O()|0;zb(c+16|0)}zb(c+32|0);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(c+32|0);yb(c);break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;zb(c+48|0)}break a}d=jb-16|0;jb=d;f=jb-32|0;jb=f;e=Je(f+16|0,1,0);v:{w:{x:{while(1){j=f+8|0;b=tc(e);i=Fb(e)+b|0;g=u[h>>1];if(!((b|0)==(i|0)|(g|0)>=0)){t[b|0]=45;g=0-(g&65535)&65535;b=b+1|0}px(j,b,i,g&65535);if(!v[f+12>>2]){break x}b=Hf(Fb(e));v[23296]=0;R(58,e|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){continue}break}break w}b=v[f+8>>2];h=tc(e);v[23296]=0;R(59,e|0,b-h|0);b=v[23296];v[23296]=0;y:{if((b|0)!=1){v[23296]=0;R(71,d|0,e|0);b=v[23296];v[23296]=0;if((b|0)!=1){break y}break w}break w}yb(e);jb=f+32|0;break v}a=P()|0;O()|0;yb(e);S(a|0);L()}v[23296]=0;R(70,a|0,d|0);a=v[23296];v[23296]=0;z:{if((a|0)!=1){zb(d);jb=d+16|0;break z}a=P()|0;O()|0;break a}}jb=c- -64|0;break b}e=v[b>>2];b=jb-32|0;jb=b;A:{if(wp(c)){v[b+16>>2]=v[7984];d=v[7983];v[b+8>>2]=v[7982];v[b+12>>2]=d;d=v[7981];v[b>>2]=v[7980];v[b+4>>2]=d;Vb(a,(b+(c<<2)|0)-1004|0);break A}if(Uc(c)){d=Kb(b);v[23296]=0;c=c-1|0;f=(c|0)/12|0;c=Q(794,d|0,e+(B(f,-12)+c<<16>>16<<2)|0)|0;e=v[23296];v[23296]=0;B:{if((e|0)==1){break B}v[23296]=0;c=Q(795,c|0,(f<<24)+805306368>>24)|0;e=v[23296];v[23296]=0;if((e|0)==1){break B}v[23296]=0;Q(3,a|0,c|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break B}zb(c);break A}a=P()|0;O()|0;break a}if(!c){Vb(a,16584);break A}Vb(a,14460)}jb=b+32|0}jb=k+16|0;return}zb(d);S(a|0);L()}function B8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=0;d=jb-128|0;jb=d;g=-1;a:{b:{c:{d:{e:{f:{if(!Kg(v[v[b>>2]-12>>2]+b|0)){break f}e=d+112|0;ae(e,b);f=v[e+8>>2];i=v[e+12>>2];e=d+104|0;ul(e);b=Bk(b,e,8);if(Pb(e,16560,8)){a=jh(d+88|0,f,i);c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;Gj(b,d+8|0);break f}u[d+86>>1]=0;Kf(b,d+86|0);l=u[d+86>>1];if((l-4&65535)>>>0<65534){break f}e=d+78|0;ul(e);b=Bk(b,e,8);if(Pb(e,14140,8)){break f}u[d+76>>1]=0;Kf(b,d+76|0);i=u[d+76>>1];if((i-5&65535)>>>0<65534){break f}g:{h:{i:{if(i>>>0<=3){e=Kb(d+112|0);v[23296]=0;f=W(430,b|0,e|0,65535)|0;k=v[23296];v[23296]=0;if((k|0)==1){break b}if(!f){break h}v[23296]=0;U(11,d- -64|0,c|0,e|0);f=v[23296];v[23296]=0;if((f|0)!=1){break i}break b}e=Kb(d+112|0);v[23296]=0;f=Q(432,b|0,e|0)|0;k=v[23296];v[23296]=0;if((k|0)==1){break c}if(!f){break g}v[23296]=0;U(11,d- -64|0,c|0,e|0);f=v[23296];v[23296]=0;if((f|0)==1){break c}}f=d- -64|0;Hb(a+40|0,f);zb(f);yb(e);u[d+62>>1]=0;Kf(b,d+62|0);u[d+60>>1]=0;Kf(b,d+60|0);u[a>>1]=x[d+60>>1];u[d+58>>1]=0;j:{if((i|0)<=3){v[d+112>>2]=0;bk(b,d+112|0);e=v[d+112>>2];if(e>>>0>65535){break f}f=ou(e);u[d+58>>1]=f;break j}Kf(b,d+58|0);f=x[d+58>>1]}k=a+52|0;n=f&65535;i=(i|0)>3;f=0;k:{l:{m:{while(1){if((f&65535)>>>0>=n>>>0){break l}e=Kb(d+112|0);v[23296]=0;u[d+40>>1]=0;R(844,b|0,d+40|0);h=v[23296];v[23296]=0;if((h|0)==1){break e}n:{if(!i){v[23296]=0;h=W(430,b|0,e|0,65535)|0;j=v[23296];v[23296]=0;if((j|0)==1){break e}if(h){break n}yb(e);break f}v[23296]=0;h=Q(432,b|0,e|0)|0;j=v[23296];v[23296]=0;if((j|0)==1){break e}if(!h){break k}}v[23296]=0;U(11,d- -64|0,c|0,e|0);h=v[23296];v[23296]=0;if((h|0)!=1){v[23296]=0;h=Q(841,k|0,d+40|0)|0;j=v[23296];v[23296]=0;if((j|0)==1){break m}j=h;h=d- -64|0;Hb(j,h);zb(h);yb(e);f=f+1|0;continue}break}g=P()|0;O()|0;break d}g=P()|0;O()|0;zb(d- -64|0);break d}c=d- -64|0;ul(c);b=Bk(b,c,8);if(Pb(c,14084,8)){break f}c=x[a>>1];if(c>>>0>3|(c|0)==2){break f}c=a+4|0;o:{if((l|0)<=2){if(lL(b,c)){break o}break f}if(!kL(b,c)){break f}}o=d,p=Eb(v[a+4>>2]),v[o+112>>2]=p;c=Eb(v[a+8>>2]);while(1){e=v[d+112>>2];if(Rb(e,c)){if(!Rl(z[e>>2])){break f}Ce(d+112|0);continue}break}c=a+16|0;p:{if((l|0)<=2){if(lL(b,c)){break p}break f}if(!kL(b,c)){break f}}o=d,p=Eb(v[a+16>>2]),v[o+112>>2]=p;c=Eb(v[a+20>>2]);while(1){e=v[d+112>>2];if(Rb(e,c)){if(!Rl(z[e>>2])){break f}Ce(d+112|0);continue}break}o=a,p=wc(v[a+16>>2],v[a+20>>2]),v[o+36>>2]=p;u[d+56>>1]=0;Kf(b,d+56|0);c=x[d+56>>1];u[a+28>>1]=c;if((c-201&65535)>>>0<65135){break f}u[d+54>>1]=0;Kf(b,d+54|0);c=u[d+54>>1];u[a+30>>1]=c;if((c|0)<0){break f}v[d+48>>2]=0;qp(b,d+48|0);m=nL(z[d+48>>2]);z[a+32>>2]=m;if(!Rl(m)){break f}c=d+40|0;ul(c);Bk(b,c,8);if(Pb(c,16551,8)){break f}b=wc(v[a+4>>2],v[a+8>>2]);if(b>>>0>32767){break f}c=u[a+30>>1];e=x[a>>1];if(!(e?!(z[a+32>>2]<=C(0))&(c|0)>0:1)){break f}q:{switch(e-1|0){case 0:case 2:if(b>>>0<c>>>0){break f}break;default:break q}}b=0;c=v[a+36>>2];if(c){b=c-1|0;v[a+36>>2]=b}o=d,p=wi(b),v[o+112>>2]=p;v[d+32>>2]=0;o=a,p=v[wj(d+112|0,d+32|0,43824)>>2],v[o+36>>2]=p;rp(a);g=1;if(x[a>>1]!=3){break f}c=u[a+30>>1];if((c-u[a+28>>1]|0)>(tL(wc(v[a+4>>2],v[a+8>>2]))|0)){break f}g=a+32|0;e=Qb(d+112|0);b=0;while(1){r:{if(c<<16>>16<=(b|0)){b=x[a+28>>1];u[d+32>>1]=b;o=d,p=(wc(v[a+4>>2],v[a+8>>2])+b|0)-1|0,u[o+34>>1]=p;v[23296]=0;u[d+30>>1]=0;ja(839,a|0,e|0,g|0,d+32|0,d+30|0)|0;a=v[23296];v[23296]=0;g=1;if((a|0)==1){break r}vc(e);break f}c=u[a+28>>1];f=v[a+4>>2];v[23296]=0;R(845,e|0,Db(f,b-c|0)|0);c=v[23296];v[23296]=0;if((c|0)!=1){b=b+1|0;c=x[a+30>>1];continue}}break}g=P()|0;O()|0;vc(e);break a}yb(e);break f}yb(e);break f}yb(e)}jb=d+128|0;return g|0}g=P()|0;O()|0}yb(e);break a}g=P()|0;O()|0;yb(e);break a}g=P()|0;O()|0;yb(e)}S(g|0);L()}function mea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0,C=0;d=jb-752|0;jb=d;Ac(b);e=jb-16|0;jb=e;g=d+144|0;JQ(e+8|0,g);f=v[e+12>>2];nc(e,v[b>>2],v[b+8>>2],v[e+8>>2],v[e+12>>2]);i=v[e+4>>2];if((i|0)==(f|0)){ac(b,v[e+12>>2])}jb=e+16|0;e=(f|0)==(i|0);if(!e){IQ(g)}a:{if(!e){break a}if(!LQ(d+144|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Vc(KQ(x[d+178>>1]),mb))){break a}if(!c){o=1;break a}Ed(a,262144);f=d+104|0;el(f,2,d+144|0);e=d+24|0;Gc(e,f);Bc(a+1298308|0,e);yb(e);g=Vb(e,8235);Hb(a+1298344|0,g);zb(g);e=Vb(e,10017);Hb(a+1298356|0,e);zb(e);e=jb-16|0;jb=e;h=f;f=Vb(e,4154);Sc(h,f);zb(f);jb=e+16|0;t[d+8|0]=w[d+174|0];v[23296]=0;t[d+127|0]=w[d+173|0];R(614,d+128|0,d+127|0);e=v[23296];v[23296]=0;b:{c:{d:{if((e|0)!=1){v[23296]=0;X(238,d+24|0,d+104|0,d+8|0,d+128|0);e=v[23296];v[23296]=0;if((e|0)!=1){e=d+24|0;Hb(a+1298368|0,e);zb(e);zb(d+128|0);f=d+104|0;ec(f);v[a+480208>>2]=12;v[a+1298404>>2]=5;g=a+480188|0;u[g>>1]=x[d+182>>1];u[d+24>>1]=x[d+178>>1];u[d+104>>1]=3999;A=a,C=x[Zc(e,f)>>1],u[A+480190>>1]=C;yT(Zb(v[a+484360>>2],w[a+484376|0]),d+240|0,x[d+176>>1]);e=0;while(1)if(x[g>>1]<=e>>>0){e=d+24|0;Yd(e,b,B(x[d+178>>1],80));g=c&2;k=jc(d+104|0,e);Ab(e);i=d+72|0;e=0;e:{f:{while(1){if(x[a+480190>>1]<=e>>>0){o=1;if(c&1){break f}break b}v[23296]=0;R(615,k|0,d+24|0);f=v[23296];v[23296]=0;if((f|0)==1){break e}f=d+8|0;el(f,2,i);v[23296]=0;R(210,d+128|0,f|0);f=v[23296];v[23296]=0;if((f|0)==1){break e}e=e+1|0;f=d+128|0;Ec(((e<<5)+a|0)+946304|0,f);yb(f);v[23296]=0;h=f;f=(B(e,104)+a|0)+484380|0;U(616,h|0,d+24|0,f|0);h=v[23296];v[23296]=0;g:{if((h|0)==1){break g}if(!g|!v[f>>2]){continue}v[23296]=0;h=Q(143,b|0,x[d+42>>1]|x[d+44>>1]<<16)|0;j=v[23296];v[23296]=0;if((j|0)==1){break g}if(!h){continue}v[23296]=0;W(207,d+128|0,f|0,b|0)|0;f=v[23296];v[23296]=0;if((f|0)!=1){continue}}break}break e}v[23296]=0;l=a+484344|0;R(213,l|0,x[d+180>>1]);c=v[23296];v[23296]=0;if((c|0)==1){break e}c=d+24|0;q=c|4;r=c|2;s=c|5;y=c|3;z=c|1;p=a+480188|0;e=0;while(1){if(x[d+180>>1]<=e>>>0){break b}v[23296]=0;a=W(214,l|0,e&65535,64)|0;c=v[23296];v[23296]=0;if((c|0)==1){break e}h:{if(!a){break h}a=(e<<1)+d|0;a=w[a+496|0]|w[a+497|0]<<8;if(!a){break h}v[23296]=0;a=Q(143,b|0,a<<4)|0;c=v[23296];v[23296]=0;if((c|0)==1){break e}if(!a){break h}m=0;a=$b(v[l>>2],e);c=fd(v[a>>2],v[v[a+48>>2]+12>>2],0,0);while(1){if(m>>>0>63){break h}a=v[b+8>>2];f=v[b>>2];v[23296]=0;a=W(144,f|0,a|0,1)|0;f=v[23296];v[23296]=0;i:{if((f|0)!=1){if(!a){break h}v[23296]=0;f=T(194,b|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break e}if(f){break i}m=m+1|0;c=B(x[p>>1],6)+c|0;continue}break e}u[d+28>>1]=0;v[d+24>>2]=0;a=f&31;g=B(a,6)+c|0;h=Th(d+24|0);i=a>>>0<x[p>>1];n=i?g:h;j:{if(!(f&32)){break j}v[23296]=0;R(247,d+128|0,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break e}a=w[d+128|0];t[n|0]=a;A=i?g+1|0:z,C=w[kd(d+128|0)|0],t[A|0]=C;k:{if(a){if((a|0)==254){break k}if(a>>>0<121){break j}}a=0}t[n|0]=a}l:{if(!(f&64)){break l}v[23296]=0;R(247,d+128|0,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break e}h=i?g+3|0:y;a=w[d+128|0];t[h|0]=a;j=i?g+5|0:s;A=j,C=w[kd(d+128|0)|0],t[A|0]=C;m:{if(a>>>0>=16){if(a>>>0<=23){a=w[a+26839|0];t[h|0]=a;break m}t[h|0]=0;break l}Of(n);a=w[h|0]}if((a|0)!=23){if((a|0)!=9){break l}t[h|0]=20;t[d+8|0]=w[j|0]>>>3;t[d+127|0]=1;A=j,C=w[ef(d+8|0,d+127|0)|0]-1&15|128,t[A|0]=C;break l}t[d+8|0]=64;A=j,C=w[Wb(j,d+8|0)|0]<<1,t[A|0]=C}if(!(f&128)){continue}t[(i?g+2|0:r)|0]=1;v[23296]=0;a=T(194,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break e}t[(i?g+4|0:q)|0]=a;continue}}e=e+1|0;continue}}e=P()|0;O()|0;Ab(k);break c}else{f=(e<<5)+a|0;Te(f+480280|0);u[f+480284>>1]=(w[(d+e|0)+208|0]<<4|4)&244;e=e+1|0;continue}}e=P()|0;O()|0;zb(d+128|0);break d}e=P()|0;O()|0}ec(d+104|0)}S(e|0);L()}Ab(k)}jb=d+752|0;return o|0}function UU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-3056|0;jb=e;Ac(b);f=jb-16|0;jb=f;h=e+1096|0;MB(f+8|0,h);i=v[f+12>>2];j=b;nc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);b=v[f+4>>2];if((b|0)==(i|0)){ac(j,v[f+12>>2])}jb=f+16|0;b=(b|0)==(i|0);if(!b){LB(h)}a:{if(!b){break a}if(!NB(e+1096|0)){break a}b:{if(!c){break b}if(!Ob(v[j>>2],v[j+8>>2],Vc(1024,0))){break a}JB(j,e+576|0);JB(j,e- -64|0);while(1){if((g|0)!=128){b=g<<2;f=v[b+(e+576|0)>>2];if(f>>>0>16777215){break a}b=v[b+(e- -64|0)>>2];if(b-4097>>>0<4294963202){break a}g=g+1|0;if(hr(v[j>>2],(b+f|0)+2978|0)){continue}break a}break}Ed(a,2);Dg(a);b=e+40|0;d=Vb(b,13687);Hb(a+1298344|0,d);zb(d);d=Vb(b,14605);Hb(a+1298356|0,d);zb(d);b=Vb(b,15257);Hb(a+1298368|0,b);zb(b);v[a+1298404>>2]=5;b=w[e+1096|0];v[a+480204>>2]=143e4;v[a+480196>>2]=b;_e(Zb(v[a+484360>>2],w[a+484376|0]),w[e+1097|0]);v[a+480188>>2]=4194317;Nb(a+1074312|0,95,1);v[a+480208>>2]=v[a+480208>>2]|16777216;d=0;g=0;while(1){if((g|0)==4){c:{while(1){d:{if((d|0)==32){g=0;break d}b=d+1|0;g=B(b,104)+a|0;i=g+484380|0;pd(i,2);h=e+16|0;Uh(h,1,(B(d,13)+e|0)+1098|0);f=e+40|0;Gc(f,h);Ec(((b<<5)+a|0)+946304|0,f);yb(f);d=(e+1096|0)+(d<<4)|0;f=w[d+422|0]|w[d+423|0]<<8|(w[d+424|0]<<16|w[d+425|0]<<24);v[i>>2]=f;h=f;f=w[d+430|0]|w[d+431|0]<<8|(w[d+432|0]<<16|w[d+433|0]<<24);if(h>>>0>=f>>>0){d=w[d+426|0]|w[d+427|0]<<8|(w[d+428|0]<<16|w[d+429|0]<<24);u[g+484414>>1]=2;v[g+484388>>2]=f;v[g+484384>>2]=d}v[g+484404>>2]=8287;d=b;continue}break}while(1){if((g|0)!=32){d=g+33|0;f=(B(d,104)+a|0)+484380|0;pd(f,2);i=e+16|0;Uh(i,1,(B(g,13)+e|0)+2026|0);b=e+40|0;Gc(b,i);Ec(((d<<5)+a|0)+946304|0,b);yb(b);v[e+48>>2]=0;v[e+40>>2]=0;v[e+44>>2]=0;d=(e+1096|0)+B(g,11)|0;o=Lb(b,0),p=w[d+1347|0],t[o|0]=p;o=Lb(b,1),p=w[d+1352|0],t[o|0]=p;o=Lb(b,2),p=w[d+1348|0],t[o|0]=p;o=Lb(b,3),p=w[d+1353|0],t[o|0]=p;o=Lb(b,4),p=w[d+1349|0],t[o|0]=p;o=Lb(b,5),p=w[d+1354|0],t[o|0]=p;o=Lb(b,6),p=w[d+1350|0],t[o|0]=p;o=Lb(b,7),p=w[d+1355|0],t[o|0]=p;o=Lb(b,8),p=w[d+1351|0],t[o|0]=p;o=Lb(b,9),p=w[d+1356|0],t[o|0]=p;o=Lb(b,10),p=w[d+1346|0],t[o|0]=p;v[e+8>>2]=v[e+48>>2];b=v[e+44>>2];v[e>>2]=v[e+40>>2];v[e+4>>2]=b;hl(f,1,e);g=g+1|0;continue}break}Kq(Zb(v[a+484360>>2],w[a+484376|0]),e+2794|0,256,255,65535);l=a+484344|0;mg(l,128);m=c&1;f=0;while(1){e:{f:{if((f|0)!=128){b=f<<2;$c(j,v[b+(e+576|0)>>2]+2978|0);d=e+16|0;Yd(d,j,v[b+(e- -64|0)>>2]);b=jc(e+40|0,d);Ab(d);if(!m){break e}v[23296]=0;d=W(214,l|0,f&65535,64)|0;g=v[23296];v[23296]=0;if((g|0)==1){break c}if(!d){break e}g=0;i=$b(v[l>>2],f);while(1){if(g>>>0>63){break e}g:{while(1){h:{d=v[b>>2];v[23296]=0;d=W(144,d|0,v[e+48>>2],1)|0;h=v[23296];v[23296]=0;if((h|0)==1){break h}if(!d){break e}v[23296]=0;d=T(194,b|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break c}if(d>>>0>12){break g}h=fd(v[i>>2],v[v[i+48>>2]+12>>2],g,d);v[23296]=0;R(247,e+16|0,b|0);k=v[23296];v[23296]=0;if((k|0)==1){break c}k=w[e+16|0];d=d>>>0>3;t[h|0]=((k&15)+(d?13:37)|0)+B(k>>>4&7,12);k=kd(e+16|0);t[h+1|0]=((w[k|0]>>>4|0)+(d?33:1)|0)+(w[e+16|0]>>>3&16);IB(h,w[k|0],d);continue}break}break c}h=d-32|0;if((h&255)>>>0<=12){h=fd(v[i>>2],v[v[i+48>>2]+12>>2],g,h&65535);v[23296]=0;k=T(194,b|0)|0;n=v[23296];v[23296]=0;if((n|0)==1){break c}IB(h,k,d>>>0>35);continue}if((d|0)!=64){if((d|0)!=96){break f}if(!g){break e}o=fd(v[i>>2],v[v[i+48>>2]+12>>2],g-1|0,0),p=14,t[o+3|0]=p;break e}v[23296]=0;d=T(194,b|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break c}g=d+g|0;continue}}d=1;if(!(c&2)){break a}while(1){if((d|0)==33){break b}lg(_c(e+40|0,8,1,0,1),(B(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}Ab(b);d=0;break a}Ab(b);f=f+1|0;continue}}}else{u[((g<<5)+a|0)+480284>>1]=g&1?192:64;g=g+1|0;continue}break}a=P()|0;O()|0;Ab(b);S(a|0);L()}d=1}jb=e+3056|0;return d|0}function mfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=jb-224|0;jb=d;Ac(b);a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if(!po(b,d+208|0)){break l}if(!wR(d+208|0)){break l}g=Bh(d+184|0);h=Kb(d+168|0);ku(d+104|0);v[23296]=0;f=Q(546,b|0,d+96|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break h}m:{if(!f){break m}m=d,n=cc(cc(v[d+100>>2])-4|0),v[m+100>>2]=n;while(1){f=cc(cc(v[d+100>>2])-8|0);v[d+100>>2]=f;n:{if(c){break n}if((cc(v[d+96>>2])|0)!=1347699796){break n}j=1;break m}v[23296]=0;U(178,d+72|0,b|0,cc(f)|0);f=v[23296];v[23296]=0;if((f|0)==1){break d}e=d+72|0;f=jc(d+8|0,e);Ab(e);e=v[f>>2];v[23296]=0;i=T(166,e|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break b}o:{if(!i){break o}p:{e=cc(v[d+96>>2]);if((e|0)!=1129139796){if((e|0)!=1229866575){if((e|0)==1347699796){break p}if((e|0)!=1447383635){break o}v[23296]=0;Q(176,f|0,4)|0;e=v[23296];v[23296]=0;if((e|0)==1){break b}v[23296]=0;e=T(547,f|0)|0;k=v[23296];v[23296]=0;if((k|0)==1){break b}if(!e){break o}e=cc(v[d+100>>2]);if(e>>>0<7){break o}v[23296]=0;U(548,f|0,h|0,e-6|0);e=v[23296];v[23296]=0;if((e|0)==1){break b}break o}v[23296]=0;l=Q(549,f|0,d+104|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break o}break b}gv(g,f);break o}v[23296]=0;j=W(550,a|0,f|0,c|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break b}}Ab(f);if(i){v[23296]=0;f=Q(546,b|0,d+96|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break i}if(f){continue}}break}if(gh(v[h+4>>2],w[h+11|0])){v[23296]=0;b=Q(1,d+72|0,14724)|0;c=v[23296];v[23296]=0;if((c|0)==1){break g}Hb(h,b);zb(b)}q:{if(!(j&l&1)){break q}b=x[d+146>>1];v[23296]=0;b=Mb(b)&256;W(251,a+1074312|0,5,!b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break f}c=Mb(x[d+142>>1]);if(c){u[d+8>>1]=64;u[d+56>>1]=c;m=a,n=x[Zc(d+8|0,d+56|0)>>1],v[m+480228>>2]=n}c=!b;b=Mb(x[d+144>>1]);if(!(c|!b)){v[a+480204>>2]=B(b,1e4)}if(w[d+104|0]){b=d+56|0;Ze(b,2,d+104|0);v[23296]=0;R(210,d+8|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break e}b=d+8|0;Bc(a+1298308|0,b);yb(b)}c=x[d+150>>1];if(!Tp(c,1,12)){break q}f=x[d+148>>1];if(!Tp(f,1,31)){break q}e=x[d+154>>1];if(!Tp(e,0,23)){break q}i=x[d+156>>1];if(!Tp(i,0,59)){break q}k=x[d+158>>1];if(!Tp(k,0,59)){break q}b=sq(d+8|0);m=b,n=Mb(x[d+152>>1]),v[m+20>>2]=n;m=b,n=Mb(c)-1|0,v[m+16>>2]=n;m=b,n=Mb(f),v[m+12>>2]=n;m=b,n=Mb(e),v[m+8>>2]=n;m=b,n=Mb(i),v[m+4>>2]=n;m=b,n=Mb(k),v[m>>2]=n;v[23296]=0;R(381,a+1298408|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break q}a=P()|0;O()|0;break a}if(j&1){b=v[g>>2];v[23296]=0;b=T(166,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break h}if(b){b=Kb(d+8|0);v[23296]=0;U(255,g|0,b|0,32);c=v[23296];v[23296]=0;if((c|0)==1){break c}if(gq(b,13580)){v[23296]=0;U(11,d+56|0,13,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break c}c=d+56|0;Hb(a+1298320|0,c);zb(c)}c=v[g+8>>2];f=v[g>>2];v[23296]=0;c=Q(551,f|0,c|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break c}if(!c){v[23296]=0;c=T(190,g|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break c}v[23296]=0;da(299,a+1298332|0,g|0,c|0,40,0);c=v[23296];v[23296]=0;if((c|0)==1){break c}}yb(b)}v[23296]=0;b=Q(1,d+56|0,17347)|0;c=v[23296];v[23296]=0;if((c|0)==1){break k}v[23296]=0;U(424,d+8|0,b|0,h|0);c=v[23296];v[23296]=0;if((c|0)==1){break j}c=d+8|0;Hb(a+1298368|0,c);zb(c);zb(b)}v[a+480208>>2]=v[a+480208>>2]|2097152;v[23296]=0;a=W(251,a+1074312|0,84,1)|0;b=v[23296];v[23296]=0;if((b|0)==1){break h}v[23296]=0;a=W(251,a|0,83,1)|0;b=v[23296];v[23296]=0;if((b|0)==1){break h}v[23296]=0;Q(252,a|0,85)|0;a=v[23296];v[23296]=0;if((a|0)==1){break h}}zb(h);Ab(g)}jb=d+224|0;return j&1}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(b);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(b);break a}a=P()|0;O()|0;Ab(f)}zb(h);Ab(g);S(a|0);L()}function Wea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=jb-256|0;jb=e;Ac(b);a:{if(!kU(b,e+184|0)){break a}if(!mR(e+184|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Vc(lR(e+184|0),mb))){break a}b:{if(!c){break b}Ed(a,16);f=e+24|0;tj(f,2,e+184|4);d=e+48|0;Gc(d,f);Bc(a+1298308|0,d);yb(d);l=a+480190|0;u[l>>1]=w[e+214|0];u[a+480188>>1]=w[e+217|0];g=Vb(d,8283);Hb(a+1298344|0,g);zb(g);g=Vb(d,10021);Hb(a+1298356|0,g);zb(g);sg(f,4172);g=w[e+187|0];v[e>>2]=g>>>4;v[23296]=0;v[e+180>>2]=g&15;X(288,d|0,f|0,e|0,e+180|0);d=v[23296];v[23296]=0;c:{d:{e:{if((d|0)!=1){d=e+48|0;Hb(a+1298368|0,d);zb(d);ec(e+24|0);v[a+1298404>>2]=5;g=1;while(1){j=g&65535;if(j>>>0>x[l>>1]){g=0;d=a+480188|0;while(1)if(x[d>>1]<=g>>>0){f=e+48|0;d=jb-16|0;jb=d;h=b;f:{if(!Ob(v[b>>2],v[b+8>>2],128)){b=0;while(1){if((b|0)!=128){vg(b+f|0);b=b+1|0;continue}break}break f}GS(d+8|0,f);qd(d,h,v[d+8>>2],v[d+12>>2])}jb=d+16|0;Uu(Zb(v[a+484360>>2],w[a+484376|0]),f,w[e+211|0]+1|0);b=w[e+216|0];Yd(e,h,B(x[e+208>>1],192));i=jc(e+24|0,e);Ab(e);n=c&1;if(n){v[23296]=0;R(213,a+484344|0,w[e+210|0]+1|0);d=v[23296];v[23296]=0;if((d|0)==1){break d}}o=b?b:64;p=a+484344|0;q=a+480188|0;while(1){if(w[e+210|0]<m>>>0){b=x[e+212>>1];if(b){v[23296]=0;da(299,a+1298332|0,h|0,b|0,39,1);b=v[23296];v[23296]=0;if((b|0)==1){break d}}if(!(c&2)){break e}g=1;b=a+480190|0;while(1){c=g&65535;if(c>>>0>x[b>>1]){break e}c=B(c,104)+a|0;d=_c(e,u[c+484414>>1]&1?16:8,1,0,1);v[23296]=0;W(207,d|0,c+484380|0,h|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){g=g+1|0;continue}break}break d}g:{h:{if(n){v[23296]=0;b=W(214,p|0,m&65535,o|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break d}k=0;if(b){break h}}v[23296]=0;Q(176,h|0,64)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break g}break d}while(1){d=k&65535;if(d>>>0>31){break g}v[23296]=0;b=T(182,h|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break d}i:{if(!b|b>>>0>x[e+208>>1]|d>>>0>=x[q>>1]){break i}v[23296]=0;Q(143,i|0,B(b,192)-192|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break d}l=0;b=$b(v[p>>2],m);g=fd(v[b>>2],v[v[b+48>>2]+12>>2],0,d);while(1){if((l|0)==(o|0)){break i}v[23296]=0;R(484,e|0,i|0);b=v[23296];v[23296]=0;if((b|0)!=1){j=kd(e);d=Ue(e);b=w[e|0];if(b>>>0>=4){t[g|0]=(b>>>2|0)+37;b=w[e|0]}t[g+1|0]=b<<4&48|w[j|0]>>>4;b=w[d|0];d=0;f=0;j:{k:{l:{m:{n:{o:{j=w[j|0]&15;switch(j-8|0){case 0:break l;case 6:break n;case 2:break o;default:break m}}b=(b&240?-16:15)&b;j=10;break k}j=14;r=(b+16&240)>>>4|0;if(r>>>0>8){break k}if(1<<r&435){break l}break k}d=j;f=b}j=d;b=f;if(!((d|b)&255)){break j}}t[g+5|0]=b;t[g+3|0]=j;Of(g)}l=l+1|0;g=B(x[q>>1],6)+g|0;continue}break}break d}k=k+1|0;continue}}m=m+1|0;continue}}else{f=(g<<5)+a|0;Te(f+480280|0);u[f+480284>>1]=(w[(e+g|0)+218|0]<<4|8)&248;g=g+1|0;continue}}else{f=e+48|0;yC(b,f);h=jb-16|0;jb=h;d=(B(j,104)+a|0)+484380|0;pd(d,0);u[h+14>>1]=w[f+35|0]<<2;u[h+12>>1]=256;s=d,y=x[Zc(h+14|0,h+12|0)>>1],u[s+30>>1]=y;i=w[f+22|0]|w[f+23|0]<<8|(w[f+24|0]<<16|w[f+25|0]<<24);p:{if(i>>>0<3){break p}v[d>>2]=i;v[d+4>>2]=w[f+26|0]|w[f+27|0]<<8|(w[f+28|0]<<16|w[f+29|0]<<24);v[h+8>>2]=w[f+30|0]|w[f+31|0]<<8|(w[f+32|0]<<16|w[f+33|0]<<24);v[h+4>>2]=1;s=d,y=v[Yc(h+8|0,h+4|0)>>2]-1|0,v[s+8>>2]=y;yc(d+8|0,i);k=v[d+8>>2];i=v[d+4>>2];q:{if(k>>>0<=i+4>>>0){v[d+4>>2]=0;v[d+8>>2]=0;k=0;i=0;break q}u[d+34>>1]=x[d+34>>1]|2;k=k>>>1|0;i=i>>>1|0}t[d+37|0]=w[f+34|0];s=d,y=Ju(0,t[f+34|0]<<4),v[s+24>>2]=y;if(!(t[f+36|0]&1)){break p}v[d+8>>2]=k;v[d+4>>2]=i;u[d+34>>1]=x[d+34>>1]|1;v[d>>2]=v[d>>2]>>>1}jb=h+16|0;jl(e,2,f);d=e+24|0;Gc(d,e);Ec(((j<<5)+a|0)+946304|0,d);g=g+1|0;yb(d);continue}}}g=P()|0;O()|0;ec(e+24|0);break c}v[a+480260>>2]=64;v[a+480264>>2]=32767;Ab(i);break b}g=P()|0;O()|0;Ab(i)}S(g|0);L()}g=1}jb=e+256|0;return g|0}function C_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;h=jb-32|0;jb=h;v[h+24>>2]=b;v[e>>2]=0;b=h+8|0;bd(b,d);v[23296]=0;b=T(18,b|0)|0;i=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{if((i|0)!=1){_b(h+8|0);switch(g-65|0){case 54:break j;case 19:break k;case 18:break l;case 17:break m;case 49:break n;case 47:break o;case 45:case 51:break p;case 12:break q;case 44:break r;case 41:break s;case 8:break t;case 7:break u;case 5:break v;case 3:break w;case 35:case 36:break x;case 34:break y;case 1:case 33:case 39:break z;case 0:case 32:break A;case 2:case 4:case 6:case 9:case 10:case 11:case 13:case 14:case 15:case 16:case 20:case 21:case 22:case 25:case 26:case 27:case 28:case 29:case 30:case 31:case 37:case 38:case 40:case 42:case 43:case 46:case 48:case 50:case 52:case 53:break d;case 24:break f;case 56:break g;case 23:break h;case 55:break i;default:break e}}a=P()|0;O()|0;_b(h+8|0);S(a|0);L()}$F(a,f+24|0,h+24|0,c,e,b);break b}_F(a,f+16|0,h+24|0,c,e,b);break b}b=nb[v[v[a+8>>2]+12>>2]](a+8|0)|0;g=a;i=v[h+24>>2];a=Jc(b);j=h,k=Jj(g,i,c,d,e,f,a,Fb(b)+a|0),v[j+24>>2]=k;break b}a=Ri(h+24|0,c,e,b,2);b=v[e>>2];B:{if(!(b&4|a-1>>>0>30)){v[f+12>>2]=a;break B}v[e>>2]=b|4}break b}v[h+8>>2]=623865125;v[h+12>>2]=2032480100;j=h,k=Jj(a,v[h+24>>2],c,d,e,f,h+8|0,h+16|0),v[j+24>>2]=k;break b}v[h+8>>2]=623728933;v[h+12>>2]=1680158061;j=h,k=Jj(a,v[h+24>>2],c,d,e,f,h+8|0,h+16|0),v[j+24>>2]=k;break b}a=Ri(h+24|0,c,e,b,2);b=v[e>>2];C:{if(!(b&4|(a|0)>23)){v[f+8>>2]=a;break C}v[e>>2]=b|4}break b}a=Ri(h+24|0,c,e,b,2);b=v[e>>2];D:{if(!(b&4|a-1>>>0>11)){v[f+8>>2]=a;break D}v[e>>2]=b|4}break b}a=Ri(h+24|0,c,e,b,3);b=v[e>>2];E:{if(!(b&4|(a|0)>365)){v[f+28>>2]=a;break E}v[e>>2]=b|4}break b}a=Ri(h+24|0,c,e,b,2);b=v[e>>2];F:{if(!(b&4|(a|0)>12)){v[f+16>>2]=a-1;break F}v[e>>2]=b|4}break b}a=Ri(h+24|0,c,e,b,2);b=v[e>>2];G:{if(!(b&4|(a|0)>59)){v[f+4>>2]=a;break G}v[e>>2]=b|4}break b}a=h+24|0;d=jb-16|0;jb=d;v[d+8>>2]=c;while(1){H:{if(!ep(a,d+8|0)){break H}c=Ek(v[a>>2]);if(!lh(v[b+8>>2],1,c)){break H}Hl(a);continue}break}if(Yi(a,d+8|0)){v[e>>2]=v[e>>2]|2}jb=d+16|0;break b}d=h+24|0;a=nb[v[v[a+8>>2]+8>>2]](a+8|0)|0;I:{if((Fb(a)|0)==(0-Fb(a+12|0)|0)){v[e>>2]=v[e>>2]|4;break I}c=Gr(d,c,a,a+24|0,b,e,0);b=v[f+8>>2];if(!((c|0)!=(a|0)|(b|0)!=12)){v[f+8>>2]=0;break I}if(!((c-a|0)!=12|(b|0)>11)){v[f+8>>2]=b+12}}break b}b=w[81848]|w[81849]<<8|(w[81850]<<16|w[81851]<<24);t[h+15|0]=b;t[h+16|0]=b>>>8;t[h+17|0]=b>>>16;t[h+18|0]=b>>>24;b=w[81845]|w[81846]<<8|(w[81847]<<16|w[81848]<<24);v[h+8>>2]=w[81841]|w[81842]<<8|(w[81843]<<16|w[81844]<<24);v[h+12>>2]=b;j=h,k=Jj(a,v[h+24>>2],c,d,e,f,h+8|0,h+19|0),v[j+24>>2]=k;break b}t[h+12|0]=w[81856];v[h+8>>2]=w[81852]|w[81853]<<8|(w[81854]<<16|w[81855]<<24);j=h,k=Jj(a,v[h+24>>2],c,d,e,f,h+8|0,h+13|0),v[j+24>>2]=k;break b}a=Ri(h+24|0,c,e,b,2);b=v[e>>2];J:{if(!(b&4|(a|0)>60)){v[f>>2]=a;break J}v[e>>2]=b|4}break b}v[h+8>>2]=624576549;v[h+12>>2]=1394948685;j=h,k=Jj(a,v[h+24>>2],c,d,e,f,h+8|0,h+16|0),v[j+24>>2]=k;break b}a=Ri(h+24|0,c,e,b,1);b=v[e>>2];K:{if(!(b&4|(a|0)>6)){v[f+24>>2]=a;break K}v[e>>2]=b|4}break b}a=nb[v[v[a>>2]+20>>2]](a,v[h+24>>2],c,d,e,f)|0;break a}b=nb[v[v[a+8>>2]+24>>2]](a+8|0)|0;g=a;i=v[h+24>>2];a=Jc(b);j=h,k=Jj(g,i,c,d,e,f,a,Fb(b)+a|0),v[j+24>>2]=k;break b}ZF(f+20|0,h+24|0,c,e,b);break b}a=Ri(h+24|0,c,e,b,4);if(!(w[e|0]&4)){v[f+20>>2]=a-1900}break b}if((g|0)==37){break c}}v[e>>2]=v[e>>2]|4;break b}a=jb-16|0;jb=a;v[a+8>>2]=c;c=6;d=h+24|0;L:{M:{if(Yi(d,a+8|0)){break M}c=4;if((en(b,Ek(v[d>>2]))|0)!=37){break M}c=2;if(!Yi(Hl(d),a+8|0)){break L}}v[e>>2]=v[e>>2]|c}jb=a+16|0}a=v[h+24>>2]}jb=h+32|0;return a|0}function Nj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=1;o(+b);f=j(1)|0;d=j(0)|0;a:{b:{m=f&2147483647;g=d;c:{if(!(m|d)){break c}o(+a);d=j(1)|0;t=j(0)|0;if(!t&(d|0)==1072693248){break c}q=d&2147483647;if(!(!(q>>>0>2146435072|(q|0)==2146435072&(t|0)!=0|m>>>0>2146435072)&(!g|(m|0)!=2146435072))){return a+b}d:{e:{f:{r=0;g:{if((d|0)>0|(d|0)>=0){break g}r=2;if(m>>>0>1128267775){break g}r=0;if(m>>>0<1072693248){break g}h=m>>>20|0;if(m>>>0<1094713344){break f}e=1075-h|0;h=g>>>e|0;r=0;if((g|0)!=h<<e){break g}r=2-(h&1)|0}e=r;if(!g){break e}break d}if(g){break d}g=1043-h|0;h=m>>>g|0;e=0;if((m|0)!=h<<g){break e}e=2-(h&1)|0}if((m|0)==2146435072){if(!(q-1072693248|t)){break c}if(q>>>0>=1072693248){return(f|0)>0|(f|0)>=0?b:0}return(f|0)>0|(f|0)>=0?0:-b}if((m|0)==1072693248){if((f|0)>0|(f|0)>=0){return a}return 1/a}if((f|0)==1073741824){return a*a}if((f|0)!=1071644672|(d|0)<0){break d}return K(a)}c=D(a);h:{if(t){break h}i:{if((d|0)<0){if((d|0)==-2147483648|(d|0)==-1074790400){break i}if((d|0)!=-1048576){break h}break i}if(!d|(d|0)==2146435072){break i}if((d|0)!=1072693248){break h}}k=(f|0)<0?1/c:c;if((d|0)>0|(d|0)>=0){break c}if(!(q-1072693248|e)){a=k-k;return a/a}return(e|0)==1?-k:k}j:{if((d|0)>0|(d|0)>=0){break j}k:{switch(e|0){case 0:a=a-a;return a/a;case 1:break k;default:break j}}k=-1}l:{if(m>>>0>=1105199105){if(m>>>0>=1139802113){if(q>>>0<=1072693247){return(f|0)<0?N:0}return(f|0)>0?N:0}if(q>>>0<=1072693246){return(f|0)<0?k*1e300*1e300:k*1e-300*1e-300}if(q>>>0>=1072693249){return(f|0)>0?k*1e300*1e300:k*1e-300*1e-300}a=c+-1;c=a*1.9259629911266175e-8+a*a*(.5-a*(a*-.25+.3333333333333333))*-1.4426950408889634;i=c;c=a*1.4426950216293335;o(+(i+c));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();c=i-(a-c);break l}a=c*9007199254740992;g=q>>>0<1048576;c=g?a:c;o(+a);e=j(1)|0;j(0)|0;h=g?e:q;d=h&1048575;e=d|1072693248;h=(h>>20)+(g?-1076:-1023)|0;g=0;m:{if(d>>>0<235663){break m}if(d>>>0<767610){g=1;break m}e=d|1071644672;h=h+1|0}d=g<<3;w=A[d+3536>>3];o(+c);j(1)|0;q=0;l(0,j(0)|q);l(1,e|0);p=+n();s=A[d+3520>>3];i=p-s;u=1/(s+p);c=i*u;o(+c);m=j(1)|0;j(0)|0;l(0,0);l(1,m|0);a=+n();x=a;l(0,q|0);l(1,((g<<18)+(e>>>1|0)|0)+537395200|0);v=a*a;y=i;i=+n();p=u*(y-a*i-a*(p-(i-s)));i=p*(c+a);a=c*c;s=i+a*a*(a*(a*(a*(a*(a*.20697501780033842+.23066074577556175)+.272728123808534)+.33333332981837743)+.4285714285785502)+.5999999999999946);o(+(v+3+s));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();i=x*a;c=p*a+c*(s-(a+-3-v));o(+(i+c));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();c=w+(a*-7.028461650952758e-9+(c-(a-i))*.9617966939259756);i=c;p=A[d+3552>>3];c=a*.9617967009544373;s=+(h|0);o(+(p+(i+c)+s));e=j(1)|0;j(0)|0;l(0,0);l(1,e|0);a=+n();c=i-(a-s-p-c)}l(0,0);l(1,f|0);p=+n();c=(b-p)*a+c*b;b=a*p;a=c+b;o(+a);d=j(1)|0;e=j(0)|0;n:{f=d;if((d|0)>=1083179008){if(e|f-1083179008){break b}if(!(c+8008566259537294e-32>a-b)){break n}break b}if((f&2147482624)>>>0<1083231232){break n}if(e|f+1064252416){break a}if(!(c<=a-b)){break n}break a}g=0;h=f&2147483647;if(h>>>0>=1071644673){e=f+(1048576>>>(h>>>20|0)-1022|0)|0;f=e>>>20&2047;g=(e&1048575|1048576)>>>1043-f|0;g=(d|0)<0?0-g|0:g;l(0,0);l(1,e&-1048576>>f-1023);b=b-+n();o(+(c+b));d=j(1)|0;j(0)|0}l(0,0);l(1,d|0);a=+n();p=a*.6931471824645996;c=(c-(a-b))*.6931471805599453+a*-1.904654299957768e-9;a=p+c;b=a*a;b=a-b*(b*(b*(b*(b*4.1381367970572385e-8+-16533902205465252e-22)+6613756321437934e-20)+-.0027777777777015593)+.16666666666666602);i=a*b/(b+-2);b=a;a=c-(a-p);a=b-(i-(b*a+a))+1;o(+a);e=j(1)|0;d=j(0)|0;e=(g<<20)+e|0;o:{if((e|0)<=1048575){a=Dj(a,g);break o}l(0,d|0);l(1,e|0);a=+n()}k=k*a}return k}return k*1e300*1e300}return k*1e-300*1e-300}function Hha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=jb-736|0;jb=h;a:{b:{if(d>>>0<=511){a=jb-16|0;jb=a;e=h+56|0;ic(a+8|0,e,554);d=v[a+12>>2];nc(a,v[b>>2],v[b+8>>2],v[a+8>>2],v[a+12>>2]);f=v[a+4>>2];if((f|0)==(d|0)){ac(b,v[a+12>>2])}jb=a+16|0;a=(d|0)==(f|0);if(!a){Xb(e,0,554)}if(!a){break b}d=jb-32|0;jb=d;c:{a=h+56|0;if(Pb(a,13840,4)){break c}Sq(d,a+32|0);b=d+16|0;Gc(b,d);Ec(c+492|0,b);yb(b);Uh(d,1,a+4|0);Gc(b,d);Ec(c+524|0,b);yb(b);b=w[a+24|0]|w[a+25|0]<<8;v[c+4>>2]=64;v[c+8>>2]=128;v[c>>2]=b<<6;t[c+16|0]=w[a+26|0];t[c+17|0]=w[a+27|0];f=c+108|0;g=c+236|0;b=0;while(1)if((b|0)==120){b=w[c+60|0]&-2|t[a+17|0]&1;t[c+60|0]=b;b=b&-3|w[a+17|0]&2;t[c+60|0]=b;t[c+60|0]=b&251|w[a+17|0]&4;g=c+61|0;t[g|0]=w[a+18|0];i=c+62|0;t[i|0]=w[a+19|0];j=c+63|0;t[j|0]=w[a+20|0];k=c- -64|0;t[k|0]=w[a+21|0];f=c+48|0;dh(f,25);e=v[c+48>>2];b=0;while(1){d:{if((b|0)!=25){l=Db(e,b);m=b<<1;n=w[(a+m|0)+504|0];u[l>>1]=n;if((n|0)!=255){break d}dh(f,b);e=v[f>>2]}b=ef(g,i);a=re(e,v[c+52>>2]);if(a>>>0<=w[b|0]){t[c+60|0]=w[c+60|0]&253}if(a>>>0>w[ef(j,k)|0]){break c}t[c+60|0]=w[c+60|0]&251;break c}t[l+2|0]=w[(a+(m|1)|0)+504|0];b=b+1|0;continue}}else{i=a+(b<<1)|0;e=w[i- -64|0];o=dc(g,b),p=w[i+65|0],u[o>>1]=p;o=Lb(f,b),p=(e>>>0<120?e:b)+1|0,t[o|0]=p;b=b+1|0;continue}}jb=d+32|0;break b}i=v[b+8>>2];d=jb-32|0;jb=d;v[d+28>>2]=674;v[d+8>>2]=674;e=v[b>>2];g=v[b+8>>2];f=v[Ib(d+28|0,d+8|0)>>2];if(!Ob(e,g,f)){f=cf(b)}j=d+8|0;e=h+56|0;hT(j,e);g=gc(d+16|0,v[d+8>>2],f);nc(d,v[b>>2],v[b+8>>2],v[g>>2],v[g+4>>2]);hT(j,e);Xb(v[d+8>>2]+f|0,0,674-f|0);ac(b,v[d+28>>2]);jb=d+32|0;f=v[a+480180>>2];a=0;d=jb-32|0;jb=d;if(!Pb(e,13840,4)){Sq(d,e+32|0);a=d+16|0;Gc(a,d);Ec(c+492|0,a);yb(a);Uh(d,1,e+4|0);Gc(a,d);Ec(c+524|0,a);yb(a);v[c>>2]=(w[e+20|0]|w[e+21|0]<<8)<<5;v[c+4>>2]=w[e+24|0]>>>1;yc(c+4|0,64);g=w[e+25|0]&127;v[c+8>>2]=g>>>0>64?128:g<<2;t[c+15|0]=w[c+15|0]&254|((w[e+25|0]^-1)&128)>>>7;t[d+16|0]=w[e+26|0];t[d|0]=100;o=c,p=w[Wb(a,d)|0],t[o+20|0]=p;t[d+16|0]=w[e+27|0];t[d|0]=64;o=c,p=w[Wb(a,d)|0],t[o+19|0]=p;t[c+16|0]=w[e+17|0];t[c+17|0]=w[e+18|0];t[c+18|0]=w[e+19|0];t[c+26|0]=w[e+22|0];t[c+27|0]=w[e+23|0];a=w[e+58|0];Dm(c,a&127,a>>>7|0);a=w[e+59|0];Cm(c,a&127,a>>>7|0);e:{f:{g:{h:{i:{j:{a=w[e+28|0]|w[e+29|0]<<8;switch(a-529|0){case 1:case 2:break h;case 0:case 3:break i;default:break j}}if((a|0)==544){break i}if((a|0)!=514){break h}}a=w[e+61|0];if((a|0)==255){break g}if(a>>>0<=128){t[c+30|0]=a}a=w[e+62|0]|w[e+63|0]<<8;if(a>>>0<129){break f}break e}a=t[e+61|0];if((a|0)<0){break g}t[c+30|0]=a+1}a=w[e+62|0];a=a<<24>>24>=0?a+1|0:0;g=t[e+63|0];if((g|0)<0){break f}a=((g&255)<<7)+a|0}u[c+28>>1]=a}a=t[e+60|0];t[c+31|0]=a;if((a|0)<0){t[c+31|0]=0;t[c+34|0]=a^128}a=0;f=f&16777216?240:25;dv(e+304|0,c+48|0,0,f);dv(e+386|0,c+68|0,32,f);dv(e+468|0,c+88|0,32,f);t[c+100|0]=w[c+100|0]&239|w[e+468|0]>>>3&16;g=c+108|0;j=c+236|0;while(1){if((a|0)!=120){k=e+(a<<1)|0;f=w[k- -64|0];o=dc(j,a),p=w[k+65|0],u[o>>1]=p;o=Lb(g,a),p=(f>>>0<120?f:a)+1|0,t[o|0]=p;a=a+1|0;continue}break}a=554}jb=d+32|0;d=0;k:{if(!a){break k}d=e+550|0;l:{if(Pb(d,13365,4)){if(Pb(d,13672,4)){break l}}d=c+236|0;a=0;while(1){if((a|0)!=120){f=dc(d,a);u[f>>1]=x[f>>1]|w[(a+e|0)+554|0]<<8;a=a+1|0;continue}break}a=674}d=a}$c(b,d+i|0);if(!Ah(b,13845)){break b}d=h+8|0;Yd(d,b,qg(b));a=jc(h+32|0,d);Ab(d);b=v[a>>2];v[23296]=0;T(148,b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break a}v[23296]=0;b=Q(348,a|0,13595)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}if(b){v[23296]=0;b=T(194,a|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}t[c+34|0]=b>>>0>250?0:b}Ab(a)}jb=h+736|0;return}b=P()|0;O()|0;Ab(a);S(b|0);L()}function fK(){var a=0,b=0,c=0,d=0,e=0,f=0;if(w[467136]){return v[116783]}b=Od(468776);v[b>>2]=82056;c=b+8|0;v[c>>2]=0;v[c+4>>2]=0;e=Cc(c+8|0),f=0,t[e+128|0]=f;if(ih(1073741823)>>>0<=29){Wc();L()}a=BF(gw(c),30);v[c>>2]=a;v[c+4>>2]=a;e=Gb(c),f=a+120|0,v[e>>2]=f;FF(c,30);v[23296]=0;d=Q(54,b+152|0,14138)|0;a=v[23296];v[23296]=0;a:{b:{c:{if((a|0)!=1){Hc(c);Od(468448);v[117112]=84644;v[23296]=0;Y(1125,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468456);v[117114]=84676;v[23296]=0;Y(1126,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}a=Od(468464);t[a+12|0]=0;v[a+8>>2]=0;v[a>>2]=82076;v[a+8>>2]=82128;v[23296]=0;Y(1127,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468480);v[117120]=83592;v[23296]=0;Y(1128,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468488);v[117122]=83740;v[23296]=0;Y(1129,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}v[23296]=0;Z(1130);a=v[23296];v[23296]=0;if((a|0)==1){break c}v[23296]=0;Y(1131,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468512);v[117128]=83888;v[23296]=0;Y(1132,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468520);v[117130]=84120;v[23296]=0;Y(1133,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468528);v[117132]=84004;v[23296]=0;Y(1134,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468536);v[117134]=84236;v[23296]=0;Y(1135,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}a=Od(468544);u[a+8>>1]=11310;v[a>>2]=83208;Kb(a+12|0);v[23296]=0;Y(1136,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}a=Od(468568);v[a+8>>2]=46;v[a+12>>2]=44;v[a>>2]=83248;Kb(a+16|0);v[23296]=0;Y(1137,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468600);v[117150]=84708;v[23296]=0;Y(1138,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468608);v[117152]=84952;v[23296]=0;Y(1139,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468616);v[117154]=85164;v[23296]=0;Y(1140,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468624);v[117156]=85396;v[23296]=0;Y(1141,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468632);v[117158]=86380;v[23296]=0;Y(1142,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468640);v[117160]=86528;v[23296]=0;Y(1143,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468648);v[117162]=86644;v[23296]=0;Y(1144,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468656);v[117164]=86760;v[23296]=0;Y(1145,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468664);v[117166]=86876;v[23296]=0;Y(1146,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468672);v[117168]=87040;v[23296]=0;Y(1147,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468680);v[117170]=87204;v[23296]=0;Y(1148,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468688);v[117172]=87368;v[23296]=0;Y(1149,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468696);v[117176]=88624;v[117176]=85644;v[117174]=85596;v[23296]=0;Y(1150,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468712);v[117180]=88660;v[117180]=85908;v[117178]=85860;v[23296]=0;Y(1151,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}v[23296]=0;Z(1152);a=v[23296];v[23296]=0;if((a|0)==1){break c}v[23296]=0;Y(1153,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}v[23296]=0;Z(1154);a=v[23296];v[23296]=0;if((a|0)==1){break c}v[23296]=0;Y(1155,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468760);v[117190]=87532;v[23296]=0;Y(1156,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Od(468768);v[117192]=87652;v[23296]=0;Y(1157,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break c}break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;yb(d)}GF(c);S(b|0);L()}v[116782]=468776;t[467136]=1;v[116783]=467128;return 467128}function QM(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=jb-16|0;jb=f;g=a+1074376|0;h=B(b,872);e=(g+h|0)+616|0;d=c&15;a:{b:{switch((c&240)-16>>>4|0){case 0:a=(a+h|0)+1075080|0;v[a>>2]=v[a>>2]&-1048577|((d|0)!=0)<<20;break a;case 1:if(!(w[a+480209|0]&16)){break a}if(oj(v[e+656>>2])){a=B(b,872)+a|0;u[a+1075764>>1]=d-8;a=a+1075843|0;t[a|0]=w[a|0]|64;break a}if(v[a+480180>>2]!=64){b=B(b,872)+a|0;u[b+1075764>>1]=d<<28>>24;c=x[(d<<1)+33280>>1];v[b+1075696>>2]=c;e=b+1075692|0;if(!v[e>>2]){break a}k=e,l=Rg(a,w[b+1075789|0],d<<28>>24,c),v[k>>2]=l;break a}a=B(b,872)+a|0;b=v[a+1075096>>2];if(!b){break a}v[a+1075696>>2]=v[b+24>>2]+B(d,80);break a;case 2:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075814|0]=c&3;break a}Bb(f+8|0,a+1074312|0,21);if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075814|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075814|0]=c&7;break a;case 3:if(v[a+480180>>2]==2){t[(B(b,872)+a|0)+1075817|0]=c&3;break a}Bb(f+8|0,a+1074312|0,21);if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){t[(B(b,872)+a|0)+1075817|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075817|0]=c&7;break a;case 4:Bb(f+8|0,a+1074312|0,21);if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){a=B(b,872)+a|0;t[a+1075813|0]=0;t[a+1075820|0]=d>>>0<4?d:0;break a}t[(B(b,872)+a|0)+1075820|0]=c&7;break a;case 5:if(v[a+1074392>>2]|!(w[a+480209|0]&16)){break a}a=a+1074400|0;v[a>>2]=v[a>>2]+d;break a;case 6:if(!(w[a+480209|0]&16)){break a}if(d>>>0<=2){d=x[a+480188>>1];h=d>>>0>256?d:256;i=b+1|0;j=(c&15)-1|0;while(1){if((d|0)==(h|0)){break a}c=B(d,872)+a|0;c:{if(x[c+1075778>>1]!=(i|0)){break c}d:{e:{switch(j|0){case 0:Qn(a,c+1074992|0);if(!(w[c+1075081|0]&2)){break d}e=v[a+1298300>>2];if(!xd(e)){break d}Uj(e,d&65535);break d;case 1:g=c+1075080|0;e=v[g>>2];v[g>>2]=e|4096;if(!(e&512)){break d}e=v[a+1298300>>2];if(!xd(e)){break d}Uj(e,d&65535);break d;default:break e}}v[c+1075688>>2]=0;g=c+1075080|0;e=v[g>>2];v[g>>2]=e|4096;if(!(e&512)){break d}e=v[a+1298300>>2];if(!xd(e)){break d}jj(e,d&65535,1)}e=v[c+1075648>>2];if(!e){break c}g=w[e+34|0];if(!g){break c}g=v[(B(g,160)+a|0)+906140>>2];if(!g){break c}nb[v[v[g>>2]+92>>2]](g,e,w[c+1075789|0]+255|0,0,b)}d=d+1|0;continue}}gP(e,d,v[a+480180>>2]);break a;case 7:if(!(w[a+480209|0]&16)){break a}Wl(a,e,d,4);break a;case 8:b=e;c=v[a+480208>>2];f:{if(!(c&4096)){break f}g:{switch(d&15){case 0:v[b+88>>2]=v[b+88>>2]&-257;break f;case 1:v[b+692>>2]=128;v[b+88>>2]=v[b+88>>2]|256;break f;case 8:v[b+88>>2]=v[b+88>>2]&-25165825|16777216;break f;case 9:v[b+88>>2]=v[b+88>>2]&-25165825|8388608;break f;case 10:v[a+480208>>2]=c&-16385;break f;case 11:v[a+480208>>2]=c|16384;break f;case 12:v[a+480208>>2]=c&-8193;break f;case 13:v[a+480208>>2]=c|8192;break f;case 14:v[b+88>>2]=v[b+88>>2]&-129;break f;case 15:break g;default:break f}}h:{if(v[b>>2]|v[b+4>>2]){break h}a=v[b+76>>2];if(!a){break h}if(!(k=Uc(w[b+788|0]),l=1,m=w[b+88|0]&2,m?k:l)){break h}v[b>>2]=-1;v[b+4>>2]=a-1}v[b+88>>2]=v[b+88>>2]|128}break a;case 9:if(!(w[a+480209|0]&16)){break a}c=B(b,872)+a|0;t[c+1075828|0]=d;Bb(f+8|0,a+1074312|0,35);if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break a}if(!Uc(w[c+1075780|0])){break a}b=v[(B(b,872)+a|0)+1075068>>2];a=d<<16;if(b>>>0<=a>>>0){break a}v[e+4>>2]=a;break a;case 10:if(!(w[a+480209|0]&16)){break a}My(a,g,e,d);break a;case 11:i:{if(d){break i}d=1;c=v[a+480180>>2];if(c&16777248){break i}d=0;if((c|0)==2){break a}}Bb(f+8|0,a+1074312|0,30);By(a,b,d,Cb(v[v[f+8>>2]>>2],v[f+12>>2])|v[a+480180>>2]==2);break a;case 14:break b;default:break a}}if(v[a+480180>>2]==2){break a}t[(B(b,872)+a|0)+1075836|0]=d}jb=f+16|0}function RJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=jb-192|0;jb=g;v[g+188>>2]=c;v[g+184>>2]=b;a:{if(!c){break a}h=w[Kk(b,c)|0];if((h|0)==33){f=1}else{if((h|0)!=63){break a}f=0}Tk(g+8|0,b,c,c-1|0);b=v[g+12>>2];v[g+184>>2]=v[g+8>>2];v[g+188>>2]=b}b=g+8|0;Qd(b);c=v[g+8>>2];Qd(g+160|0);h=Jk(c,v[g+164>>2],g+184|0);Qd(b);b=v[g+188>>2];c=v[g+184>>2];b:{c:{d:{e:{if((h|0)==v[g+12>>2]){a=rc(g+176|0,21473);if(Mc(c,b,v[a>>2],v[a+4>>2])){a=ba(8)|0;v[23296]=0;b=Eh(g+160|0,d,e);c=v[23296];v[23296]=0;f:{g:{h:{if((c|0)!=1){v[23296]=0;U(915,g+8|0,17452,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break h}f=0;c=sc(a,g+8|0);v[23296]=0;U(107,c|0,61592,904);c=v[23296];v[23296]=0;if((c|0)!=1){break b}c=P()|0;O()|0;yb(g+8|0);break g}c=P()|0;O()|0;break f}c=P()|0;f=1;O()|0}yb(b);if(!f){break c}}ca(a|0);break c}if(!f){break e}a=ba(8)|0;v[23296]=0;b=Eh(g+128|0,v[g+184>>2],v[g+188>>2]);c=v[23296];v[23296]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((c|0)!=1){v[23296]=0;U(915,g+144|0,17488,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break q}v[23296]=0;R(917,g+160|0,g+144|0);c=v[23296];v[23296]=0;f=1;if((c|0)==1){break p}v[23296]=0;d=Eh(g+112|0,d,e);c=v[23296];v[23296]=0;if((c|0)==1){break o}v[23296]=0;U(919,g+8|0,g+160|0,d|0);c=v[23296];v[23296]=0;if((c|0)==1){break n}c=sc(a,g+8|0);v[23296]=0;U(107,c|0,61592,904);c=v[23296];v[23296]=0;if((c|0)!=1){break b}c=P()|0;O()|0;yb(g+8|0);f=0;break m}c=P()|0;O()|0;break i}c=P()|0;f=1;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;O()|0;break l}c=P()|0;O()|0}yb(d)}yb(g+160|0)}yb(g+144|0)}yb(b);if(!f){break c}}ca(a|0);break c}f=rc(g+104|0,21473);if(Mc(c,b,v[f>>2],v[f+4>>2])){a=ba(8)|0;v[23296]=0;b=Eh(g+160|0,d,e);c=v[23296];v[23296]=0;r:{s:{t:{if((c|0)!=1){v[23296]=0;U(915,g+8|0,17452,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break t}f=0;c=sc(a,g+8|0);v[23296]=0;U(107,c|0,61592,904);c=v[23296];v[23296]=0;if((c|0)!=1){break b}c=P()|0;O()|0;yb(g+8|0);break s}c=P()|0;O()|0;break r}c=P()|0;f=1;O()|0}yb(b);if(!f){break c}}ca(a|0);break c}f=rc(g+96|0,12211);if(Mc(c,b,v[f>>2],v[f+4>>2])){b=d;c=e;f=rc(g+88|0,5562);if(Mc(b,c,v[f>>2],v[f+4>>2])){v[a+52>>2]=0;break e}f=rc(g+80|0,11143);if(Mc(b,c,v[f>>2],v[f+4>>2])){v[a+52>>2]=1;break e}f=b;b=rc(g+72|0,9108);if(Mc(f,c,v[b>>2],v[b+4>>2])){v[a+52>>2]=2;break e}a=ba(8)|0;v[23296]=0;b=Eh(g+160|0,d,e);c=v[23296];v[23296]=0;u:{v:{w:{if((c|0)!=1){v[23296]=0;U(915,g+8|0,14466,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break w}f=0;c=sc(a,g+8|0);v[23296]=0;U(107,c|0,61592,904);c=v[23296];v[23296]=0;if((c|0)!=1){break b}c=P()|0;O()|0;yb(g+8|0);break v}c=P()|0;O()|0;break u}c=P()|0;f=1;O()|0}yb(b);if(!f){break c}}ca(a|0);break c}f=b;b=rc(g- -64|0,11380);if(!Mc(c,f,v[b>>2],v[b+4>>2])){break e}b=0;x:{c=d;d=e;e=rc(g+56|0,15415);if(Mc(c,d,v[e>>2],v[e+4>>2])){break x}b=1;e=rc(g+48|0,15420);if(Mc(c,d,v[e>>2],v[e+4>>2])){break x}b=2;e=rc(g+40|0,12485);if(Mc(c,d,v[e>>2],v[e+4>>2])){break x}b=3;e=c;c=rc(g+32|0,9172);if(Mc(e,d,v[c>>2],v[c+4>>2])){break x}a=ba(8)|0;v[23296]=0;b=Q(54,g+8|0,11416)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}v[a+56>>2]=b;a=v[a+24>>2];if(!v[a+24668>>2]){break e}c=a+24664|0;d=v[c+4>>2];v[g+24>>2]=v[c>>2];v[g+28>>2]=d;c=a+24656|0;d=v[c+4>>2];v[g+16>>2]=v[c>>2];v[g+20>>2]=d;c=v[a+24652>>2];v[g+8>>2]=v[a+24648>>2];v[g+12>>2]=c;i=g,j=vJ(b),v[i+28>>2]=j;if(!qx(g+8|0,a+24648|0)){break e}jy(a,g+8|0)}jb=g+192|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function bda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-192|0;jb=f;a:{b:{if(Ob(v[c>>2],v[c+8>>2],8)){ac(c,4);while(1){if(Wt(v[c>>2],v[c+8>>2])){break b}m=jb-288|0;jb=m;e=zO(m);i=jb-384|0;jb=i;j=qc(e,zO(i+96|0),282);e=0;c:{d:{e:{f:{g:{if(Ah(c,13486)){ng(c,4);h=ie(i+72|0,c);v[23296]=0;k=Q(712,h|0,j|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break g}h:{if(!k){break h}k=v[h+8>>2];g=v[h>>2];l=w[j+26|0];v[23296]=0;k=W(144,g|0,k|0,l|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break g}if(!k){break h}k=0;i:{while(1){if(w[j+26|0]<=e>>>0){g=v[h+8>>2];l=v[h>>2];e=0;v[23296]=0;k=k&65535;g=W(144,l|0,g|0,k|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break e}if(!g){break h}v[23296]=0;Q(176,h|0,k|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break e}ng(h,AO(j));e=Cc(i- -64|0);g=i+96|0;gz(g);v[23296]=0;R(713,h|0,g|0);g=v[23296];v[23296]=0;if((g|0)!=1){u[i+118>>1]=0;u[i+120>>1]=0;e=hz(e,i+96|0,i+123|0);g=w[j+26|0];v[23296]=0;Q(176,h|0,g|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){break i}}e=P()|0;O()|0;break d}v[23296]=0;g=T(186,h|0)|0;l=v[23296];v[23296]=0;if((l|0)!=1){t[(e+j|0)+27|0]=g;e=e+1|0;k=g+k|0;continue}break}e=P()|0;O()|0;break d}l=e;e=j+27|0;l=hz(l,e,e+w[j+26|0]|0);v[23296]=0;U(178,i+16|0,h|0,k|0);e=v[23296];v[23296]=0;if((e|0)==1){break f}g=i+16|0;k=jc(i+40|0,g);Ab(g);e=0;v[23296]=0;R(512,g|0,k|0);g=v[23296];v[23296]=0;if((g|0)==1){e=P()|0;O()|0;Ab(k);break d}g=i+16|0;bC(i+8|0,g);n=l;l=v[i+8>>2];l=hz(n,l,Lb(l,v[i+12>>2]));Pc(g);Ab(k);if(v[l>>2]!=(w[j+22|0]|w[j+23|0]<<8|(w[j+24|0]<<16|w[j+25|0]<<24))){break h}e=AO(j);v[23296]=0;Q(176,c|0,e|0)|0;j=v[23296];v[23296]=0;e=1;if((j|0)==1){break e}}Ab(h)}jb=i+384|0;break c}e=P()|0;O()|0;break d}e=P()|0;O()|0;break d}e=P()|0;O()|0}Ab(h);S(e|0);L()}jb=m+288|0;if(e){continue}break}}Ac(c);lg(b,a,c);a=1;break a}t[d|0]=1;Ac(c);e=qg(c);d=f+144|0;Yd(d,c,cf(c));i=jc(f+168|0,d);Ab(d);b=x[a+34>>1]&-66|w[b|0]>15|(w[b+1|0]!=1)<<6;u[a+34>>1]=b;v[a>>2]=e>>>(b&1)>>>(b>>>6&1);v[f+140>>2]=0;v[f+136>>2]=0;v[23296]=0;R(512,d|0,i|0);b=v[23296];v[23296]=0;j:{k:{l:{m:{if((b|0)!=1){c=ye(f+144|0);e=v[f+144>>2];j=nA(c,wi(e),f+140|0,f+136|0);v[23296]=0;b=v[f+140>>2];Q(176,i|0,b|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){if(!j){break j}Bg(a);d=b+c|0;b=e-b|0;e=v[f+136>>2];c=0;while(1){n:{if(e){if(!b|(e|0)!=1){break k}e=v[a>>2];if(e>>>0>c>>>0){break n}break k}e=v[a>>2];if(e>>>0<=c>>>0){break k}}if(!Ud(e,v[a+20>>2])){break k}v[f+132>>2]=0;v[f+128>>2]=0;k=$R(j,d,wi(b),f+132|0,f+124|0,f+128|0);v[23296]=0;Q(176,i|0,k|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break m}Wh(f+128|0,wi(v[a>>2]-c|0));e=v[f+128>>2];o:{if((e|0)<=0){break o}h=v[f+132>>2];l=x[a+34>>1];if((Gd(l)|0)!=(h|0)){break o}m=B(c,h);g=v[a+20>>2];if(l&1){h=Wg(f+112|0,g+(m<<1)|0,h,e);m=Wg(f+96|0,v[f+124>>2],v[f+132>>2],e);v[23296]=0;v[f+56>>2]=v[h+8>>2];g=v[h+4>>2];v[f+48>>2]=v[h>>2];v[f+52>>2]=g;v[f+40>>2]=v[m+8>>2];h=v[m+4>>2];v[f+32>>2]=v[m>>2];v[f+36>>2]=h;R(513,f+48|0,f+32|0);h=v[23296];v[23296]=0;if((h|0)!=1){break o}break m}h=Wg(f+80|0,g+m|0,h,e);m=Wg(f- -64|0,v[f+124>>2],v[f+132>>2],e);v[23296]=0;v[f+24>>2]=v[h+8>>2];g=v[h+4>>2];v[f+16>>2]=v[h>>2];v[f+20>>2]=g;v[f+8>>2]=v[m+8>>2];h=v[m+4>>2];v[f>>2]=v[m>>2];v[f+4>>2]=h;R(514,f+16|0,f|0);h=v[23296];v[23296]=0;if((h|0)==1){break m}}b=b-k|0;d=d+k|0;c=c+e|0;e=_R(j);continue}}break m}c=P()|0;O()|0;break l}c=P()|0;O()|0;Pc(f+144|0)}Ab(i);S(c|0);L()}ZR(j)}Pc(f+144|0);Ab(i);a=(j|0)!=0}jb=f+192|0;return a|0}function Qha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;e=jb-976|0;jb=e;Ac(b);d=jb-16|0;jb=d;h=e+872|0;BT(d+8|0,h);f=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);g=v[d+4>>2];if((g|0)==(f|0)){ac(b,v[d+12>>2])}jb=d+16|0;d=(f|0)==(g|0);if(!d){AT(h)}a:{if(!d){break a}if(!DT(e+872|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Vc(CT(w[e+919|0]|w[e+920|0]<<8),mb))){break a}if(!c){l=1;break a}Ed(a,512);v[a+480228>>2]=32;u[a+480188>>1]=16;v[a+480196>>2]=w[e+947|0];v[a+480208>>2]=16;v[a+480200>>2]=256;v[a+480204>>2]=8e5;Nb(a+1074312|0,7,1);d=e+96|0;f=Vb(d,8142);Hb(a+1298344|0,f);zb(f);f=Vb(d,8814);Hb(a+1298356|0,f);zb(f);v[a+1298404>>2]=5;f=e+16|0;zT(f,e+872|4);Gc(d,f);Bc(a+1298308|0,d);yb(d);d=0;while(1){if((d|0)==16){b:{d=x[e+968>>1];if(d){rB(a+1298332|0,b,d,132,0)}d=jb-16|0;jb=d;h=e+96|0;ic(d+8|0,h,771);f=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);g=v[d+4>>2];if((g|0)==(f|0)){ac(b,v[d+12>>2])}jb=d+16|0;l=(f|0)==(g|0);if(!l){Xb(h,0,771)}if(!l){break a}d=a+484360|0;f=a+484376|0;yT(Zb(v[d>>2],w[f|0]),e+96|0,w[e+353|0]);_e(Zb(v[d>>2],w[f|0]),w[e+354|0]);$c(b,w[e+919|0]|w[e+920|0]<<8);o=a+484344|0;p=c&1;h=0;while(1){c:{if((h|0)==256){if(!(c&2)){break a}BB(b,e- -64|0);d=0;while(1){if((d|0)==64){break a}if(!(w[e- -64+(d>>>3)|0]>>>(d&7)&1)){d=d+1|0;continue}if(!$A(b,e+16|0)){break a}d=d+1|0;u[a+480190>>1]=d;Ze(e,1,e+16|0);h=e+72|0;Gc(h,e);Ec(((x[a+480190>>1]<<5)+a|0)+946304|0,h);yb(h);c=(B(d,104)+a|0)+484380|0;pd(c,0);i=w[e+48|0]|w[e+49|0]<<8|(w[e+50|0]<<16|w[e+51|0]<<24);v[c>>2]=i;f=w[e+54|0]|w[e+55|0]<<8|(w[e+56|0]<<16|w[e+57|0]<<24);v[c+4>>2]=f;g=w[e+58|0]|w[e+59|0]<<8|(w[e+60|0]<<16|w[e+61|0]<<24);v[c+24>>2]=16726;v[c+8>>2]=g;u[c+30>>1]=w[e+53|0]<<4;if(t[e+62|0]&1){g=g>>>1|0;v[c+8>>2]=g;f=f>>>1|0;v[c+4>>2]=f;v[c>>2]=i>>>1}if(!(!(w[e+63|0]&8)|f>>>0>=g>>>0)){u[c+34>>1]=x[c+34>>1]|2}_c(h,t[e+62|0]&1?16:8,1,0,0);lg(h,c,b);continue}}d:{d=(h<<1)+e|0;g=w[d+355|0]|w[d+356|0]<<8;if(g){f=e+72|0;Yd(f,b,g);i=jc(e+16|0,f);Ab(f);n=((w[d+355|0]|w[d+356|0]<<8)-2|0)/64|0;e:{if(!p){break e}v[23296]=0;d=W(214,o|0,h&65535,n|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break d}if(!d){break e}v[23296]=0;d=T(194,i|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break b}v[23296]=0;Q(176,i|0,1)|0;f=v[23296];v[23296]=0;if((f|0)==1){break b}q=d?d>>>0<n-2>>>0?d+1|0:-1:-1;f=0;f:while(1){g:{d=$b(v[o>>2],h);if((f|0)==(n|0)){break g}m=0;r=Qf(v[d>>2],v[v[d+48>>2]+12>>2],f);while(1){if((m|0)==16){f=f+1|0;continue f}v[23296]=0;R(335,e+72|0,i|0);d=v[23296];v[23296]=0;if((d|0)==1){break c}d=B(m,6)+r|0;j=e+72|0;g=Ue(j);j=Ci(j);k=w[e+72|0];if((k-1&255)>>>0<=71){t[d|0]=k+36;s=d,y=w[kd(e+72|0)|0]+1|0,t[s+1|0]=y}if((w[g|0]-1&255)>>>0<=15){t[d+2|0]=1;t[d+4|0]=((w[g|0]<<6)+-64>>>0)/15}k=w[j|0];g=k&15;t[d+5|0]=g;h:{i:{switch((w[j|0]>>>4|0)-1|0){case 0:case 1:t[d+5|0]=k|240;break h;case 2:t[d+5|0]=g<<2;break h;case 3:t[d+5|0]=(6/(g+1>>>0)|0)+1;break h;case 5:case 6:t[d+5|0]=g<<3;break h;case 9:t[d+4|0]=(g<<2)+4;t[d+2|0]=1;break h;case 10:t[d+5|0]=g|128;break h;case 11:break i;default:break h}}t[d+5|0]=(6/(g+1>>>0)|0)+1|13}t[d+3|0]=w[(w[j|0]>>>4|0)+26224|0];m=m+1|0;continue}}break}qe(d,yh(Ke(Fe(e+72|0,14,0),q)))}Ab(i)}h=h+1|0;continue}}break}}}else{f=(d<<5)+a|0;h=f+480280|0;Te(h);g=h;h=(e+872|0)+d|0;v[g>>2]=!w[h+50|0]<<10;u[f+480284>>1]=(w[h+76|0]<<4|8)&248;d=d+1|0;continue}break}a=P()|0;O()|0;Ab(i);S(a|0);L()}jb=e+976|0;return l|0}function HV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-576|0;jb=e;Ac(b);d=jb-16|0;jb=d;f=e+72|0;HC(d+8|0,f);g=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);j=v[d+4>>2];if((j|0)==(g|0)){ac(b,v[d+12>>2])}jb=d+16|0;d=(g|0)==(j|0);if(!d){GC(f)}a:{if(!d){break a}if(!JC(e+72|0)){break a}b:{if(!c){break b}if(!Ob(v[b>>2],v[b+8>>2],Vc(IC(w[e+182|0],w[e+183|0]),mb))){break a}Ed(a,64);v[a+480204>>2]=78e4;v[a+480260>>2]=112;v[a+480264>>2]=13696;v[a+480196>>2]=4;u[a+480188>>1]=8;Nb(a+1074312|0,7,1);d=e+40|0;g=Vb(d,14502);Hb(a+1298344|0,g);zb(g);d=Vb(d,14535);Hb(a+1298356|0,d);zb(d);wl(a+1298368|0,Pb(e+72|0,11012,2)?14530:14502);v[a+1298404>>2]=5;f=w[e+182|0];u[a+480190>>1]=f;g=1;while(1){j=g&65535;if(j>>>0<=f>>>0){f=jb-16|0;jb=f;d=e+40|0;ic(f+8|0,d,25);l=v[f+12>>2];nc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);i=v[f+4>>2];if((i|0)==(l|0)){ac(b,v[f+12>>2])}jb=f+16|0;if((i|0)!=(l|0)){t[d|0]=0;t[d+1|0]=0;t[d+2|0]=0;t[d+3|0]=0;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;t[d+24|0]=0;t[d+16|0]=0;t[d+17|0]=0;t[d+18|0]=0;t[d+19|0]=0;t[d+20|0]=0;t[d+21|0]=0;t[d+22|0]=0;t[d+23|0]=0;t[d+8|0]=0;t[d+9|0]=0;t[d+10|0]=0;t[d+11|0]=0;t[d+12|0]=0;t[d+13|0]=0;t[d+14|0]=0;t[d+15|0]=0}if((w[e+53|0]|w[e+54|0]<<8|(w[e+55|0]<<16|w[e+56|0]<<24))>>>0>67108863){break a}f=(B(j,104)+a|0)+484380|0;pd(f,0);v[f+24>>2]=8363;l=e+40|0;d=l;i=w[d+13|0]|w[d+14|0]<<8|(w[d+15|0]<<16|w[d+16|0]<<24);v[f>>2]=i;k=w[d+17|0]|w[d+18|0]<<8|(w[d+19|0]<<16|w[d+20|0]<<24);v[f+4>>2]=k;d=w[d+21|0]|w[d+22|0]<<8|(w[d+23|0]<<16|w[d+24|0]<<24);d=d>>>0>i>>>0?k?d:0:d;v[f+8>>2]=d;if(d){u[f+34>>1]=2;lk(f)}f=e+8|0;Uh(f,2,l);d=e+24|0;Gc(d,f);Ec(((j<<5)+a|0)+946304|0,d);g=g+1|0;yb(d);f=x[a+480190>>1];continue}break}g=e+24|0;h=e+72|2;Rf(g,3,h,36);d=e+40|0;Gc(d,g);Bc(a+1298308|0,d);yb(d);g=0;FC(a+1298332|0,h,108,36,0);d=a+484360|0;h=a+484376|0;Uu(Zb(v[d>>2],w[h|0]),e+185|0,128);d=Zb(v[d>>2],w[h|0]);h=w[e+184|0];if(x[dc(v[d>>2],h)>>1]<w[e+183|0]){_e(d,h)}while(1)if((g|0)==8){j=a+484344|0;mg(j,w[e+183|0]);n=c&1;f=0;while(1){if(w[e+183|0]<=f>>>0){h=1;if(!(c&2)){break a}c=_c(e+40|0,8,1,0,1);g=1;while(1){d=g&65535;if(d>>>0>x[a+480190>>1]){break b}lg(c,(B(d,104)+a|0)+484380|0,b);g=g+1|0;continue}}c:{d:{if(n){if(bh(j,f&65535,64)){break d}}ac(b,1536);break c}v[e+24>>2]=-1;v[e+28>>2]=-1;l=0;e:while(1){if((l|0)==64){d=(e+72|0)+f|0;g=w[d+369|0];if(g>>>0<63){qe($b(v[j>>2],f),yh(Ke(Fe(e+40|0,14,0),g)))}qe($b(v[j>>2],f),yh(Fe(e+40|0,16,w[d+241|0])));break c}g=0;d=$b(v[j>>2],f);h=Qf(v[d>>2],v[v[d+48>>2]+12>>2],l);while(1){if((g|0)==8){l=l+1|0;continue e}d=e+40|0;Mq(d,b);i=kd(d);k=Ue(d);i=w[i|0];d=w[e+40|0];if(d>>>0<=253){t[h|0]=(d>>>2|0)+37;t[h+1|0]=(d<<4&48|i>>>4)+1;t[(e+24|0)+g|0]=255;d=w[e+40|0]}if((d&255)!=255){t[h+2|0]=1;t[h+4|0]=(((i&15)<<6|8)>>>0)/15}d=w[k|0];if((d|0)!=255){t[(e+24|0)+g|0]=d}i=(e+24|0)+g|0;f:{g:{if(d&15?0:(d|0)!=48){break g}k=w[i|0];if((k|0)==255){break f}m=k<<24>>24;d=m&15;t[h+5|0]=d;h:{if((m|0)<0){break h}k=k>>>4|0;t[h+3|0]=w[k+26008|0];i:{switch(k-3|0){case 0:t[h+5|0]=d|32;break g;case 1:t[h+5|0]=d|m<<4;break f;case 2:break g;case 3:break i;default:break f}}j:{switch(d|0){case 0:t[h+5|0]=79;break f;case 1:break j;default:break h}}t[h+5|0]=244;break f}t[h+3|0]=0;break f}t[i|0]=255}h=h+6|0;g=g+1|0;continue}}}f=f+1|0;continue}}else{d=(g<<5)+a|0;Te(d+480280|0);u[d+480284>>1]=g&1?208:48;g=g+1|0;continue}}h=1}jb=e+576|0;return h|0}function q5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=jb-96|0;jb=f;a:{if(De(b)){break a}e=w[yJ(b)|0];if((e|0)==33){d=1}else{if((e|0)!=63){break a}d=0}e=f+80|0;Cv(e,b,0,Fb(b)-1|0);Bc(b,e);yb(e)}g=f+80|0;Qd(g);e=v[f+80>>2];Qd(f- -64|0);e=xJ(e,v[f+68>>2],b);Qd(g);b:{c:{d:{e:{if((e|0)==v[f+84>>2]){if(ne(b,21473)){a=ba(8)|0;v[23296]=0;U(906,f+80|0,17452,c|0);b=v[23296];v[23296]=0;if((b|0)==1){break d}a=sc(a,f+80|0);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}b=P()|0;O()|0;yb(f+80|0);break c}if(!d){break e}a=ba(8)|0;v[23296]=0;U(906,f+48|0,17488,b|0);b=v[23296];v[23296]=0;f:{g:{h:{i:{j:{if((b|0)!=1){v[23296]=0;R(917,f- -64|0,f+48|0);b=v[23296];v[23296]=0;if((b|0)==1){break j}v[23296]=0;U(479,f+80|0,f- -64|0,c|0);b=v[23296];v[23296]=0;d=1;if((b|0)==1){break i}b=sc(a,f+80|0);v[23296]=0;U(107,b|0,61592,904);b=v[23296];v[23296]=0;if((b|0)!=1){break b}b=P()|0;O()|0;yb(f+80|0);d=0;break h}b=P()|0;O()|0;break f}b=P()|0;d=1;O()|0;break g}b=P()|0;O()|0}yb(f- -64|0)}yb(f+48|0);if(!d){break c}}ca(a|0);break c}k:{switch(v[e+4>>2]){case 0:ve(f+40|0,b);b=jb-192|0;jb=b;e=b+16|0;gi(e,c);v[23296]=0;R(77,b+32|0,e|0);c=v[23296];v[23296]=0;l:{m:{n:{o:{p:{if((c|0)!=1){v[23296]=0;c=Q(78,b+48|0,b+32|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break p}yb(b+32|0);yb(b+16|0);e=v[v[c>>2]-12>>2];v[23296]=0;g=ga(61)|0;h=v[23296];v[23296]=0;if((h|0)==1){break n}v[23296]=0;U(62,b+8|0,c+e|0,g|0);e=v[23296];v[23296]=0;if((e|0)==1){break n}_b(b+8|0);v[23296]=0;e=Q(1015,c|0,b+32|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break n}c=Hk(v[(e+v[v[e>>2]-12>>2]|0)+16>>2]);g=w[b+32|0];jf(e);jb=b+192|0;b=(c^-1)&(g|0)!=0;break l}a=P()|0;O()|0;break o}a=P()|0;O()|0;yb(b+32|0)}yb(b+16|0);break m}a=P()|0;O()|0;jf(c)}S(a|0);L()}UJ(a,v[f+40>>2],v[f+44>>2],b,d);break e;case 1:ve(f+32|0,b);b=jb-192|0;jb=b;e=b+16|0;gi(e,c);v[23296]=0;R(77,b+32|0,e|0);c=v[23296];v[23296]=0;q:{r:{s:{t:{u:{if((c|0)!=1){v[23296]=0;c=Q(78,b+48|0,b+32|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break u}yb(b+32|0);yb(b+16|0);e=v[v[c>>2]-12>>2];v[23296]=0;g=ga(61)|0;h=v[23296];v[23296]=0;if((h|0)==1){break s}v[23296]=0;U(62,b+8|0,c+e|0,g|0);e=v[23296];v[23296]=0;if((e|0)==1){break s}_b(b+8|0);v[23296]=0;e=Q(84,c|0,b+32|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break s}c=Hk(v[(e+v[v[e>>2]-12>>2]|0)+16>>2]);g=v[b+32>>2];h=v[b+36>>2];jf(e);jb=b+192|0;b=c?0:g;c=c?0:h;break q}a=P()|0;O()|0;break t}a=P()|0;O()|0;yb(b+32|0)}yb(b+16|0);break r}a=P()|0;O()|0;jf(c)}S(a|0);L()}SJ(a,v[f+32>>2],v[f+36>>2],b,c,d);break e;case 2:ve(f+24|0,b);b=jb-192|0;jb=b;e=b+16|0;gi(e,c);v[23296]=0;R(77,b+32|0,e|0);c=v[23296];v[23296]=0;v:{w:{x:{y:{z:{if((c|0)!=1){v[23296]=0;c=Q(78,b+48|0,b+32|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break z}yb(b+32|0);yb(b+16|0);e=v[v[c>>2]-12>>2];v[23296]=0;g=ga(61)|0;h=v[23296];v[23296]=0;if((h|0)==1){break x}v[23296]=0;U(62,b+8|0,c+e|0,g|0);e=v[23296];v[23296]=0;if((e|0)==1){break x}_b(b+8|0);v[23296]=0;e=Q(85,c|0,b+32|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break x}c=Hk(v[(e+v[v[e>>2]-12>>2]|0)+16>>2]);i=A[b+32>>3];jf(e);jb=b+192|0;i=c?0:i;break v}a=P()|0;O()|0;break y}a=P()|0;O()|0;yb(b+32|0)}yb(b+16|0);break w}a=P()|0;O()|0;jf(c)}S(a|0);L()}TJ(a,v[f+24>>2],v[f+28>>2],i,d);break e;case 3:break k;default:break e}}ve(f+16|0,b);ve(f+8|0,c);RJ(a,v[f+16>>2],v[f+20>>2],v[f+8>>2],v[f+12>>2],d)}jb=f+96|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function Xn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0,z=0,A=0;f=jb-96|0;jb=f;q=dz(v[a+24>>2],w[a+32|0]);s=lj(q);c=s;e=v[a>>2];d=wd(e,v[a+4>>2]);a:{if(c>>>0>d>>>0){i=jb-32|0;jb=i;c=c-d|0;d=v[Gb(a)>>2];e=v[a+4>>2];b:{if(c>>>0<=(d-e|0)/12>>>0){e=jb-16|0;jb=e;c=At(e,a,c);d=v[c+4>>2];h=v[c+8>>2];while(1){if((d|0)==(h|0)){lc(c);jb=e+16|0}else{_N(d);d=d+12|0;v[c+4>>2]=d;continue}break}break b}d=Gb(a);d=ok(i+8|0,Tm(a,wd(v[a>>2],e)+c|0),wd(v[a>>2],v[a+4>>2]),d);h=jb-16|0;jb=h;e=cQ(h,d+8|0,c);c=v[e>>2];while(1){if(v[e+4>>2]!=(c|0)){_N(c);c=v[e>>2]+12|0;v[e>>2]=c;continue}break}Id(e);jb=h+16|0;h=v[a>>2];c=v[a+4>>2];e=d+4|0;while(1){if((c|0)!=(h|0)){c=c-12|0;Sz(v[e>>2]-12|0,c);v[e>>2]=v[e>>2]-12;continue}break}oc(a,e);oc(a+4|0,d+8|0);oc(Gb(a),zc(d));v[d>>2]=v[d+4>>2];c=v[d+4>>2];while(1){e=v[d+8>>2];if((e|0)!=(c|0)){e=e-12|0;v[d+8>>2]=e;Le(e);continue}break}c=v[d>>2];if(c){Ro(d);Jb(c)}}jb=i+32|0;break a}if(d>>>0>c>>>0){eO(a,e+B(c,12)|0)}}if(b){c=a+12|0;Hp(c,Wd(c));z=Gb(c),A=0,v[z>>2]=A;d=c;c=kc(c);v[d>>2]=c;v[c>>2]=0;v[a+28>>2]=0}i=Qb(f+80|0);c=v[a+24>>2];c=ht(v[c+484344>>2],v[c+484348>>2]);v[23296]=0;h=W(555,f- -64|0,c|0,30060)|0;c=v[23296];v[23296]=0;c:{if((c|0)!=1){e=a+12|0;d:{while(1){if((k|0)==(s|0)){ud(h);fc(i);jb=f+96|0;return}c=v[a+24>>2];m=x[dc(v[q>>2],k)>>1];d=jO(c,m);v[f+60>>2]=d;c=Hd(v[a>>2],k);e:{f:{if(b){v[23296]=0;t[f+40|0]=0;U(719,c|0,d|0,f+40|0);d=v[23296];v[23296]=0;if((d|0)!=1){break f}d=P()|0;O()|0;break d}v[23296]=0;R(677,c|0,d|0);d=v[23296];v[23296]=0;if((d|0)==1){break e}}v[23296]=0;d=Q(297,q|0,k&65535)|0;g=v[23296];v[23296]=0;if((g|0)==1){break e}g:{if(!d){break g}v[f+40>>2]=b?0:v[c+4>>2];r=v[Ib(f+40|0,f+60|0)>>2];o=yf(e);c=x[dc(v[h>>2],m)>>1];if((c|0)!=65535){d=hO(e,x[$l(f+40|0,c,r)>>1],v[f+44>>2]);h:{if(Ag(d,yf(e))){c=hO(e,x[$l(f+40|0,x[dc(v[h>>2],m)>>1],v[f+60>>2])>>1],v[f+44>>2]);break h}c=yf(e)}v[f+56>>2]=d;while(1){i:{if(!Ag(d,c)){break g}g=Qb(f+40|0);d=Qm(vd(d)+8|0);v[23296]=0;R(720,g|0,d|0);d=v[23296];v[23296]=0;if((d|0)!=1){d=Zj(f+24|0,o);j=$l(f+16|0,k,v[vd(v[f+56>>2])+4>>2]);d=v[d>>2];v[23296]=0;d=fa(721,e|0,d|0,j|0,g|0)|0;j=v[23296];v[23296]=0;if((j|0)==1){break i}v[f+32>>2]=d;o=v[Xg(f+32|0)>>2];je(g);d=v[Xg(f+56|0)>>2];continue}}break}d=P()|0;O()|0;je(g);break d}p=$b(v[v[a+24>>2]+484344>>2],m);c=Eg(v[v[p+48>>2]+12>>2]);v[23296]=0;t[f+40|0]=0;U(701,i|0,c|0,f+40|0);c=v[23296];v[23296]=0;if((c|0)!=1){n=v[f+60>>2];j:while(1){k:{if((n|0)==(r|0)){if(r){break g}z=dc(v[h>>2],m),A=k,u[z>>1]=A;break g}g=1;j=0;c=v[v[p+48>>2]+12>>2];n=n-1|0;d=Qf(v[p>>2],c,n);while(1){if(g>>>0<16&Eg(c)>>>0>j>>>0){y=Lb(v[i>>2],j);c=w[y|0];l:{m:{n:{switch(w[d+3|0]-19|0){case 1:l=w[d+5|0];if((l&240)==176){break m}break l;case 0:break n;default:break l}}l=w[d+5|0];if((l&240)!=96){break l}}t[y|0]=l&15;l=w[Lb(v[i>>2],j)|0];c=l?l:c}c=c&255;g=B(c?c+1|0:1,g);d=d+6|0;j=j+1|0;c=v[v[p+48>>2]+12>>2];continue}else{o:{if(g>>>0<=1){continue j}c=Qb(f+40|0);v[23296]=0;R(720,c|0,g|0);d=v[23296];v[23296]=0;if((d|0)==1){break o}d=Zj(f+8|0,o);g=$l(f+16|0,k,n);d=v[d>>2];v[23296]=0;o=fa(721,e|0,d|0,g|0,c|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break k}je(c);continue j}}break}}break}d=P()|0;O()|0;je(c);break d}d=P()|0;O()|0;break d}k=k+1|0;continue}break}d=P()|0;O()|0}ud(h);break c}d=P()|0;O()|0}fc(i);S(d|0);L()}function qia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,y=0;d=jb-336|0;jb=d;Ac(b);a:{if(!po(b,d+320|0)){break a}if(!ST(d+320|0)){break a}if(!Pb(d+320|0,14007,4)){ac(b,4)}if(!Zh(b,d+312|0)){break a}if(Pb(d+312|0,13983,4)){break a}if(!c){n=1;break a}QB(b,d+120|0,v[d+316>>2]);if(x[d+156>>1]>128|x[d+162>>1]>16|(x[d+160>>1]>256|x[d+154>>1]>128)){break a}Ed(a,8192);i=d+32|0;e=Vb(i,6500);Hb(a+1298344|0,e);zb(e);e=Vb(i,10033);Hb(a+1298356|0,e);zb(e);v[a+1298404>>2]=5;e=d+96|0;el(e,2,d+120|0);Gc(i,e);Bc(a+1298308|0,i);yb(i);u[d+32>>1]=x[d+162>>1];u[d+96>>1]=1;g=x[We(i,e)>>1];u[a+480188>>1]=g;v[a+480196>>2]=w[d+166|0];v[a+480204>>2]=B(w[d+167|0],1e4);t[d+32|0]=w[d+164|0];t[d+96|0]=64;e=w[Wb(i,e)|0];v[a+480200>>2]=e<<2;if(!e){v[a+480200>>2]=256}e=w[d+165|0];b:{if((e|0)==128){v[d+32>>2]=256/(g>>>0);v[d+96>>2]=128;l=v[Ib(d+32|0,d+96|0)>>2];break b}l=e&127}v[a+480228>>2]=l;while(1){if((f|0)==16){g=a+484376|0;Uu(Zb(v[a+484360>>2],w[g|0]),d+184|0,x[d+156>>1]);e=x[d+154>>1];if(e>>>0<x[d+156>>1]){_e(Zb(v[a+484360>>2],w[g|0]),e)}q=c&2;o=a+484344|0;n=1;r=c&1;l=d+68|0;m=a+480190|0;i=a+480188|0;while(1){if(!Zh(b,d+312|0)){break a}c=d+32|0;Yd(c,b,v[d+316>>2]);h=jc(d+96|0,c);Ab(c);c:{d:{if(!(Pb(d+312|0,13428,4)|!r)){v[23296]=0;g=p&65535;e=W(214,o|0,g|0,64)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}if(!e){break c}v[23296]=0;Q(176,h|0,2)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}wh(d+32|0);j=0;e:{while(1){c=v[h>>2];v[23296]=0;e=W(144,c|0,v[d+104>>2],1)|0;c=v[23296];v[23296]=0;f:{if((c|0)!=1){if(!(e&j>>>0<64)){break e}v[23296]=0;k=T(194,h|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}if(k){break f}j=j+1|0;continue}break d}f=d+32|0;e=k&15;if(e>>>0<x[i>>1]){c=$b(v[o>>2],g);f=fd(v[c>>2],v[v[c+48>>2]+12>>2],j,e)}g:{if(!(k&128)){break g}v[23296]=0;e=T(194,h|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}if(!e){break g}t[f|0]=e>>>0<109?e+12|0:e}if(k&64){v[23296]=0;e=T(194,h|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}t[f+1|0]=e}if(k&32){t[f+2|0]=1;v[23296]=0;e=T(194,h|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}t[d+16|0]=e;t[d|0]=64;s=f,y=w[Wb(d+16|0,d)|0],t[s+4|0]=y}if(!(k&16)){continue}v[23296]=0;R(247,d+16|0,h|0);c=v[23296];v[23296]=0;if((c|0)!=1){e=kd(d+16|0);h:{i:{j:{k:{l:{c=w[d+16|0];switch(c-17|0){case 2:break k;case 0:case 1:break l;default:break j}}c=c&15;break i}t[d+16|0]=33;t[e|0]=145;c=w[d+16|0];break h}if(c>>>0<17){break h}c=(c&240)==32?9:-1}t[d+16|0]=c}t[f+3|0]=c;t[f+5|0]=w[e|0];Of(f);continue}break}break d}p=p+1|0;break c}if(Pb(d+312|0,13433,4)){break c}c=x[m>>1];if(!Sh(c)){break c}e=c+1|0;u[m>>1]=e;v[23296]=0;R(305,h|0,d+32|0);c=v[23296];v[23296]=0;m:{if((c|0)==1){break m}v[23296]=0;e=(B(e&65535,104)+a|0)+484380|0;R(306,d+32|0,e|0);c=v[23296];v[23296]=0;if((c|0)==1){break m}el(d,2,l);v[23296]=0;R(210,d+16|0,d|0);c=v[23296];v[23296]=0;if((c|0)==1){break m}c=d+16|0;Ec(((x[m>>1]<<5)+a|0)+946304|0,c);yb(c);if(!q){break c}j=w[d+45|0]|w[d+46|0]<<8;f=2;c=d+16|0;g=_c(c,8,1,0,1);n:{if(!(j&64)){f=0;if(!(j&2)){break n}}Sf(g,f)}if(j&4){Fh(g,16)}v[23296]=0;W(207,c|0,e|0,h|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break c}}}a=P()|0;O()|0;Ab(h);S(a|0);L()}Ab(h);continue}}g=(f<<5)+a|0;Te(g+480280|0);e=w[(d+f|0)+168|0];if(e>>>0<=128){u[g+480284>>1]=e<<1}f=f+1|0;continue}}jb=d+336|0;return n|0}function bea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=jb-192|0;jb=e;Ac(b);a:{if(!$A(b,e+144|0)){break a}if(!uQ(e+144|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Vc(sQ(w[e+175|0],w[e+177|0]),mb))){break a}b:{if(!c){break b}Ed(a,256);g=e+32|0;tj(g,2,e+144|0);d=e- -64|0;Gc(d,g);Bc(a+1298308|0,d);yb(d);f=Vb(d,15118);Hb(a+1298344|0,f);zb(f);d=Vb(d,10012);Hb(a+1298356|0,d);zb(d);sg(g,4232);v[23296]=0;R(237,e+128|0,e+175|0);d=v[23296];v[23296]=0;c:{d:{if((d|0)!=1){v[23296]=0;X(623,e- -64|0,e+32|0,e+174|0,e+128|0);d=v[23296];v[23296]=0;if((d|0)!=1){d=e- -64|0;Hb(a+1298368|0,d);zb(d);zb(e+128|0);ec(e+32|0);v[a+1298404>>2]=5;d=Nb(a+1074312|0,107,1);v[a+480260>>2]=64;v[a+480264>>2]=32767;v[a+480188>>2]=2031620;Nb(d,107,1);f=w[e+176|0];d=w[e+175|0];if(d>>>0<=20){g=((f&255)>>>0)/10|0;f=g<<4|B(g,-10)+f}g=(f&255?f:96)&255;f=Qz(g);v[a+480196>>2]=g>>>4;v[a+480204>>2]=f;f=0;if(d>>>0>=11){t[e+64|0]=64;o=a,p=w[Wb(e+178|0,e- -64|0)|0]<<2,v[o+480200>>2]=p}while(1)if((f|0)==4){f=1;while(1){if((f|0)!=32){It(b,e+32|0);d=w[e+44|0];if(d?(d|0)!=46:0){break c}h=jb-32|0;jb=h;d=(B(f,104)+a|0)+484380|0;pd(d,0);k=e+32|0;g=k;ek(h,2,g);i=h+16|0;Gc(i,h);ze(d+43|0,i);yb(i);v[d+24>>2]=w[g+24|0]|w[g+25|0]<<8;t[h+16|0]=w[g+22|0];t[h|0]=64;o=d,p=w[Wb(i,h)|0]<<2,u[o+30>>1]=p;i=w[g+16|0]|w[g+17|0]<<8;v[d>>2]=i;j=w[g+18|0]|w[g+19|0]<<8;v[d+4>>2]=j;g=w[g+20|0]|w[g+21|0]<<8;v[d+8>>2]=g;e:{if(i>>>0<=1){v[d>>2]=0;break e}if((g|0)==65535|i>>>0<=j>>>0|g>>>0<=j>>>0){break e}u[d+34>>1]=2;o=d,p=v[Ib(d+8|0,d)>>2],v[o+8>>2]=p}jb=h+32|0;g=e+16|0;ek(g,2,k);d=e+128|0;Gc(d,g);Ec(((f<<5)+a|0)+946304|0,d);yb(d);u[((f<<1)+e|0)+62>>1]=x[e+46>>1];f=f+1|0;continue}break}d=a+484360|0;g=a+484376|0;oo(Zb(v[d>>2],w[g|0]),b,w[e+175|0]?128:64,65535,65535);f=0;if(!qQ(Zb(v[d>>2],w[g|0]))){break a}m=c&1;if(m){mg(a+484344|0,w[e+177|0])}i=a+484344|0;while(1){if(w[e+177|0]<=l>>>0){f=1;if(!(c&2)){break a}c=_c(e+32|0,8,1,0,0);while(1){if((f|0)==32){break b}d=B(f,104)+a|0;g=d+484380|0;f:{if(!v[g>>2]|!x[d+484410>>1]){break f}d=x[((f<<1)+e|0)+62>>1];if(d>>>0<4){break f}if(!$c(b,d<<4)){break f}lg(c,g,b)}f=f+1|0;continue}}f=0;g:{h:{if(m){if(bh(i,l&65535,64)){break h}}while(1){if((f|0)==256){break g}if((Ee(b)+2&255)>>>0<=252){ac(b,3)}f=f+1|0;continue}}o=e,p=Eb(v[$b(v[i>>2],l)>>2]),v[o+128>>2]=p;u[e+14>>1]=65535;v[e+16>>2]=63;h=0;i:while(1){f=0;if((h|0)==64){d=x[e+14>>1];if((d|0)==65535){break g}qe($b(v[i>>2],l),qm(Ke(Fe(e+32|0,12,d&255),v[e+16>>2])));break g}while(1){j:{k:{l:{if((f&65535)>>>0<=3){d=0;j=0;k=0;n=0;m:{n:{o:{p:{g=Ee(b);switch(g-251|0){case 1:break j;case 0:break n;case 2:break p;default:break o}}t[v[e+128>>2]]=254;break j}d=e+32|0;Mq(d,b);j=w[Lb(d,0)|0];k=w[Lb(d,1)|0];n=w[Lb(d,2)|0];d=254;if((g|0)==254){break m}if(g>>>0>=96){break l}d=g}d=(B(d>>>4|0,12)+(d&15)|0)+37|0}g=d;d=v[e+128>>2];t[d|0]=g;break k}h=h+1|0;continue i}d=v[e+128>>2]}t[d+1|0]=(j&248)>>>3;g=k>>>1&120|j&7;if(g>>>0<=64){t[d+4|0]=g;t[d+2|0]=1}t[d+5|0]=n;t[d+3|0]=k&15;pQ(d,h,w[e+175|0],e+14|0,e+16|0)}f=f+1|0;$z(e+128|0);continue}}}l=l+1|0;continue}}else{d=(f<<5)+a|0;Te(d+480280|0);u[d+480284>>1]=f&1?64:192;f=f+1|0;continue}}f=P()|0;O()|0;zb(e+128|0);break d}f=P()|0;O()|0}ec(e+32|0);S(f|0);L()}f=0;break a}f=1}jb=e+192|0;return f|0}function zy(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,z=0,A=0,C=0,D=0,E=0;f=jb-16|0;jb=f;k=B(b,872)+a|0;m=k+1075800|0;i=w[m|0];l=a+1074312|0;Bb(f+8|0,l,23);h=c&15;a:{b:{c:{if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){if(!(v[a+1074392>>2]|!w[(B(b,872)+a|0)+1075780|0])){t[m|0]=h;break c}e=w[m|0];if(e){g=e-1|0;t[m|0]=g;e=0;if(g&255){break c}}t[m|0]=h;e=1;break c}Bb(f+8|0,l,52);d:{e:{g=c&256;if(!(!g|!Cb(v[v[f+8>>2]>>2],v[f+12>>2]))){g=v[a+480208>>2]&4096;if(!g){break e}e=B(b,872)+a|0;if(w[e+1075781|0]){i=iT(w[e+1075780|0])?1:i}if(w[(B(b,872)+a|0)+1075784|0]?w[e+1075782|0]==1:0){break b}e=0;if(h>>>0>i>>>0){break c}if(!g){break d}if(Uc(w[(B(b,872)+a|0)+1075780|0])){break c}break d}j=v[a+480180>>2];if(j&16777250){e=!(i?(i>>>0)%((h?h:1)>>>0)|0:1);i=i+1|0;break c}f:{if((j|0)!=16){if((j|0)!=1){break f}g=y[a+1074392>>2]%y[a+1074416>>2]|0;if(!g){if(Uc(w[(B(b,872)+a|0)+1075780|0])){break a}}e=h?!((g>>>0)%(h>>>0)|0):e;break c}e=v[a+1074392>>2]==(h|0)&(h|0)!=0;break c}g:{if(!g){break g}e=B(b,872)+a|0;if(w[e+1075782|0]!=1){break g}h=(w[e+1075785|0]>15)+h|0}h:{if(v[a+480208>>2]&4096?g:1){h=h?h:1;e=0;e=!v[a+1074416>>2]|g?e:!(y[a+1074392>>2]%(h>>>0)|0);i=i+1|0;break h}e=0;i=j&1048580?0:i}if(!(!(w[(B(b,872)+a|0)+1075780|0]|!g?v[a+1074392>>2]:1)|(i&255)>>>0<h>>>0)){e=1}Bb(f+8|0,l,52);if(!Cb(v[v[f+8>>2]>>2],v[f+12>>2])|c){break c}e=!v[a+1074392>>2];break c}if(h>>>0>i>>>0){break c}}i=0;e=1}h=k+1074992|0;n=(B(b,872)+a|0)+1075068|0;i:{if(v[n>>2]){break i}Bb(f+8|0,l,38);if(!Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break i}if(!Sj(v[h+656>>2])){break a}}Bb(f+8|0,l,106);if(C=0,D=Cb(v[v[f+8>>2]>>2],v[f+12>>2]),E=v[(B(b,872)+a|0)+1075688>>2],E?C:D){break a}if(e){j=B(b,872)+a|0;q=j+1075680|0;g=v[q>>2];v[f+4>>2]=g;e=c>>>4&15;j:{if(!e){e=v[j+1075080>>2];break j}Bb(f+8|0,l,52);k:{if(C=Cb(v[v[f+8>>2]>>2],v[f+12>>2]),D=0,E=w[(B(b,872)+a|0)+1075782|0]==1,E?C:D){break k}if(!(16191>>>e&1)){v[f+4>>2]=(B(g,t[e+33696|0])|0)/16;break k}v[f+4>>2]=g+(t[e+33712|0]<<2)}he(f+4|0,0,256);g=(B(b,872)+a|0)+1075080|0;e=v[g>>2]|2097152;v[g>>2]=e}k=B(b,872)+a|0;r=k+1075692|0;s=v[r>>2];g=w[k+1075794|0];j=0;if(e&512){Bb(f+8|0,l,108);j=Cb(v[v[f+8>>2]>>2],v[f+12>>2])}if(!((j^-1)&v[a+480180>>2]==2|(!v[n>>2]|(g-1&255)>>>0>119))){WM(a,b,0,g,1)}k=k+1075080|0;l:{if(!(v[a+480180>>2]&1048580)){break l}u=(c|0)<256;if((c|0)>255){break l}e=w[(B(b,872)+a|0)+1075781|0];if(!e){break l}u=1;Dp(a,h,e,0,0,1)}o=B(b,872)+a|0;p=o+1075652|0;z=v[p>>2];A=v[k>>2];v[p>>2]=0;Bb(f+8|0,l,23);e=1;m:{if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break m}e=0;if(v[a+480180>>2]!=2){break m}e=(j^1)&v[n>>2]!=0}bt(a,h,g,e,u,0,b);if(!w[o+1075781|0]){v[p>>2]=z}if(!(!(A&4096)|v[a+480180>>2]!=4)){v[k>>2]=v[k>>2]|4096}j=o+1075780|0;v[q>>2]=v[f+4>>2];if(x[a+480192>>1]){t[j|0]=g;UM(a,b)}g=v[a+480180>>2];if(!(!(g&16777248)|(w[j|0]|!s))){v[r>>2]=s}if(e){v[h>>2]=0;v[h+4>>2]=0}e=g&16777250;n:{if(d-11>>>0<4294967286){break n}g=v[(B(b,872)+a|0)+1075096>>2];if(!g){break n}o:{if((d|0)==1){b=v[(B(b,872)+a|0)+1075656>>2];break o}j=(B(b,872)+a|0)+1075656|0;b=v[Db(g+68|0,d-2|0)>>2];v[j>>2]=b}Vn(a,h,b)}i=e?i:0}a=f+8|0;Bb(a,l,52);b=v[v[f+8>>2]>>2];d=v[f+12>>2];Bb(a,l,23);if(Cb(v[v[f+8>>2]>>2],v[f+12>>2])){break a}i=(Cb(b,d)&c>>>8)+i|0}t[m|0]=i}jb=f+16|0}function Aaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-112|0;jb=e;g=a+140|0;sj(e+88|0,g,1296125513);v[23296]=0;f=T(166,v[e+88>>2])|0;h=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{if((h|0)!=1){if(f){f=Kb(e+32|0);v[23296]=0;h=T(148,v[e+88>>2])|0;i=v[23296];v[23296]=0;if((i|0)==1){break p}v[23296]=0;U(729,e+88|0,f|0,h|0);h=v[23296];v[23296]=0;if((h|0)==1){break p}h=x[a+174>>1];v[23296]=0;U(730,e+72|0,h|0,f|0);h=v[23296];v[23296]=0;if((h|0)==1){break o}v[23296]=0;U(8,e+8|0,c|0,e+72|0);c=v[23296];v[23296]=0;if((c|0)==1){break n}c=e+8|0;Ec(d,c);yb(c);zb(e+72|0);yb(f)}if(w[a+176|0]){v[23296]=0;R(731,e+32|0,d|0);c=v[23296];v[23296]=0;if((c|0)==1){break e}c=e+32|0;ze(b+43|0,c);yb(c)}v[23296]=0;U(724,e+32|0,g|0,1413894985);c=v[23296];v[23296]=0;if((c|0)==1){break l}v[23296]=0;f=T(732,e+32|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break k}g=e+32|0;Ab(g);c=a+40|0;Ac(c);v[23296]=0;g=Q(733,c|0,g|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break j}if(g){q:{if(y[e+60>>2]<2){break q}v[23296]=0;g=Q(734,c|0,e+8|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break i}if(!g){break q}ML(e+8|0,b+12|0,b+16|0,v[b>>2],b+34|0,8,16,f)}v[23296]=0;c=Q(734,c|0,e+8|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break i}if(c){ML(e+8|0,b+4|0,b+8|0,v[b>>2],b+34|0,2,4,f)}c=v[e+44>>2];t[b+42|0]=c&128?0:c+1|0;lk(b)}r:{if(w[b+42|0]){break r}c=v[a+60>>2];v[23296]=0;c=Q(602,c|0,7)|0;f=v[23296];v[23296]=0;if((f|0)==1){break j}if(!c){break r}c=a+60|0;Ac(c);v[23296]=0;c=Q(735,c|0,e+8|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break d}if(!c){break r}c=t[e+8|0];t[b+42|0]=(c|0)<0?0:c+1|0}c=v[a+120>>2];v[23296]=0;c=T(166,c|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break j}if(!c){break f}v[23296]=0;h=a+120|0;c=T(145,h|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break c}v[e+72>>2]=c;yc(e+72|0,9);f=b+68|0;g=v[e+72>>2];c=0;while(1){if((c|0)==(g|0)){break g}v[23296]=0;R(736,h|0,e+8|0);i=v[23296];v[23296]=0;if((i|0)==1){break h}j=Db(f,c),k=v[e+12>>2],v[j>>2]=k;c=c+1|0;continue}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break m}a=P()|0;O()|0;break m}a=P()|0;O()|0;zb(e+72|0)}yb(f);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(e+32|0);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Pz(f+(g<<2)|0,bT(f),42680)}c=a+80|0;Ac(c);v[23296]=0;f=Q(737,c|0,e+8|0)|0;g=v[23296];v[23296]=0;s:{if((g|0)==1){break s}if(!f){break b}if(w[e+8|0]&32){u[b+34>>1]=x[b+34>>1]|32}u[e+72>>1]=x[e+12>>1];u[e+6>>1]=256;j=b,k=x[Zc(e+72|0,e+6|0)>>1],u[j+28>>1]=k;u[e+72>>1]=x[e+14>>1];u[e+6>>1]=256;j=b,k=x[Zc(e+72|0,e+6|0)>>1],u[j+30>>1]=k;u[e+72>>1]=x[e+16>>1];u[e+6>>1]=64;j=b,k=x[Zc(e+72|0,e+6|0)>>1],u[j+32>>1]=k;t[b+38|0]=w[e+20|0];t[b+39|0]=w[e+21|0];t[b+40|0]=w[e+22|0];t[b+41|0]=w[e+23|0];f=v[a+88>>2];a=v[a+80>>2];v[23296]=0;a=W(144,a|0,f|0,32)|0;f=v[23296];v[23296]=0;if((f|0)==1){break s}if(!a){break b}v[23296]=0;R(738,c|0,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break s}v[23296]=0;a=T(190,c|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break s}v[23296]=0;U(739,c|0,b+43|0,a|0);a=v[23296];v[23296]=0;if((a|0)!=1){break b}}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}Ab(e+88|0);jb=e+112|0;return}Ab(e+88|0);S(a|0);L()}function pK(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=0,i=0,j=0,k=0,l=C(0),m=C(0),n=0,o=C(0),p=0,q=C(0),r=C(0),s=C(0),u=0,w=C(0);j=jb-16|0;jb=j;b=a+4208|0;i=Wj(C(z[Db(b,12)>>2]*C(3)));v[a+4264>>2]=i;d=C(v[v[a+16>>2]+24620>>2]>>>((i>>>1^-1)&1)>>>0);z[a+4268>>2]=d;u=a,w=C(C(z[Db(b,9)>>2]*C(100))*C(.0061803399585187435)),z[u+4272>>2]=w;u=j,w=me(C(10),C(C(oK(a)+C(C(z[Db(b,5)>>2]*C(11e3))+C(-1e4)))/C(2e3))),z[u+12>>2]=w;v[j+8>>2]=1065353216;u=a,w=C(z[Ol(j+12|0,j+8|0)>>2]*C(.7609999775886536)),z[u+4280>>2]=w;c=me(C(10),C(C(C(C(z[Db(b,1)>>2]*C(1e4))+C(-1e4))/C(100))/C(10)));if(c!=C(1)){d=pp(C(C(nK(a)*C(6.2831854820251465))/d));f=C(c+c);e=C(c*c);c=Ty(C(C(C(C(d*f)+C(-2))+C(K(C(C(C(C(d*C(C(d*e)*C(4)))+C(c*C(8)))-C(e*C(4)))-C(C(d*c)*C(8))))))/C(f+C(-2))),C(0),C(1))}else{c=C(0)}z[a+4276>>2]=c;i=jb-16|0;jb=i;c=z[a+4268>>2];b=a+4208|0;d=C(z[Db(b,6)>>2]*C(.30000001192092896));u=i,w=C(z[Db(b,8)>>2]*C(.10000000149011612)),z[u+12>>2]=w;v[i+8>>2]=1000593162;f=z[Gx(i+12|0,i+8|0)>>2];e=C(c*C(C(d+f)+C(.007000000216066837)));a:{if(C(D(e))<C(2147483648)){b=~~e;break a}b=-2147483648}v[a+4352>>2]=b;b=1;while(1){if((b|0)==12){u=i,w=C(C(C(C(z[Db(a+4208|0,10)>>2]*C(100))/C(100))+C(.10000000149011612))*C(.9090999960899353)),z[u+12>>2]=w;v[i+8>>2]=1065353216;d=z[Ol(i+12|0,i+8|0)>>2];f=C(c*C(C(d*C(75))/C(1e3)));d=C(c*C(C(d*C(67))/C(1e3)));b=0;while(1){if((b|0)==6){h=a+4348|0;d=C(c*C(.0035299998708069324));b:{if(C(D(d))<C(2147483648)){b=~~d;break b}b=-2147483648}v[h>>2]=b;h=a+4344|0;d=C(c*C(.0032500000670552254));c:{if(C(D(d))<C(2147483648)){b=~~d;break c}b=-2147483648}v[h>>2]=b;h=a+4340|0;c=C(c*C(.009999999776482582));d:{if(C(D(c))<C(2147483648)){b=~~c;break d}b=-2147483648}v[h>>2]=b}else{h=(b<<2)+a|0;p=h+4316|0;n=b+n|0;e=me(C(.9300000071525574),C(n|0));g=C(f*e);e:{if(C(D(g))<C(2147483648)){k=~~g;break e}k=-2147483648}v[p>>2]=k;k=h+4292|0;e=C(d*e);f:{if(C(D(e))<C(2147483648)){h=~~e;break f}h=-2147483648}v[k>>2]=h;b=b+1|0;continue}break}b=0;while(1){if((b|0)!=15){sK((B(b,24)+a|0)+4504|0,v[((b<<2)+a|0)+4292>>2]);b=b+1|0;continue}break}jb=i+16|0}else{k=((B(b&1,24)+a|0)+(b<<1&-4)|0)+4352|0;e=C(c*C(C(f*z[(b<<2)+46896>>2])+d));g:{if(C(D(e))<C(2147483648)){h=~~e;break g}h=-2147483648}v[k>>2]=h;b=b+1|0;continue}break}b=jb-16|0;jb=b;d=nh(a,5);e=nh(a,11);c=C(d*nh(a,4));d=C(C(c*C(.03999999910593033))+C(C(d*C(.02250000089406967))+C(0)));f=C(e*nh(a,10));e=C(C(f*C(.03999999910593033))+C(C(e*C(.02250000089406967))+C(0)));if(t[a+4264|0]&1){g=nh(a,3);l=nh(a,9);g=C(c*g);c=C(g*nh(a,2));d=C(C(c*C(.1444000005722046))+C(C(g*C(.12250000238418579))+d));g=C(f*l);f=C(g*nh(a,8));e=C(C(f*C(.1444000005722046))+C(C(g*C(.12250000238418579))+e))}nh(a,12);g=z[a+4496>>2];l=nh(a,1);m=nh(a,7);q=nh(a,0);r=nh(a,6);u=b,w=me(C(10),C(C(oK(a)+C(C(z[Db(a+4208|0,7)>>2]*C(12e3))+C(-1e4)))/C(2e3))),z[u+12>>2]=w;v[b+8>>2]=1065353216;o=z[Ol(b+12|0,b+8|0)>>2];s=c;c=C(g*g);g=C(l*C(s*c));l=C(q*g);c=C(m*C(f*c));f=C(r*c);m=C(C(C(l+f)*C(-.5))+C(1));z[a+4284>>2]=o*C(K(C(m/C(C(l*C(.1444000005722046))+C(C(c*C(.1444000005722046))+d)))));z[a+4288>>2]=o*C(K(C(m/C(C(f*C(.1444000005722046))+C(C(g*C(.1444000005722046))+e)))));jb=b+16|0;t[a+5046|0]=0;jb=j+16|0}function DM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,x=0,y=0;if(b){h=a+327720|0;c=jb-400|0;jb=c;xO(c+384|0,8);v[23296]=0;qa(714,c+368|0,9);i=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{if((i|0)!=1){v[23296]=0;i=Q(715,c+352|0,14)|0;e=v[23296];v[23296]=0;if((e|0)==1){break l}v[23296]=0;R(716,c+384|0,i|0);e=v[23296];v[23296]=0;if((e|0)==1){break k}v[23296]=0;R(716,c+368|0,i|0);e=v[23296];v[23296]=0;if((e|0)==1){break k}wO(c+280|0,4900);wO(c+208|0,32e3);pO(c+136|0,8377175819504598e-21,16754351639009197e-21,8377175819504598e-21,-1.991112714669597,.9911462233728751);v[23296]=0;e=Q(717,c+104|0,c+384|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break j}kt(c+120|0,c+280|0,e);je(e);v[23296]=0;e=Q(717,c+72|0,c+368|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break i}kt(c+88|0,c+208|0,e);je(e);v[23296]=0;e=Q(717,c+40|0,c+120|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break h}kt(c+56|0,c+136|0,e);je(e);v[23296]=0;e=Q(717,c+8|0,c+88|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break g}g=c+24|0;kt(g,c+136|0,e);je(e);e=c+120|0;Jp(e);l=c+56|0;Jp(l);m=c+88|0;Jp(m);Jp(g);p=c+368|0;Jp(p);Ip(v[c+120>>2],v[c+124>>2],Yn(h,0));Ip(v[c+56>>2],v[c+60>>2],Yn(h,1));Ip(v[c+88>>2],v[c+92>>2],Yn(h,2));Ip(v[c+24>>2],v[c+28>>2],Yn(h,3));Ip(v[c+368>>2],v[c+372>>2],Yn(h,4));je(g);je(l);je(m);je(e);dl(i);je(p);je(c+384|0);jb=c+400|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;je(c+56|0)}je(c+88|0)}je(c+120|0)}dl(i)}je(c+368|0)}je(c+384|0);S(a|0);L()}_x(a+131112|0,9.6377,.97);_x(a+196648|0,8.5,.5);_x(a+262184|0,2.7625,.425)}c=a+368680|0;if(!(t=0,x=PL(c,a),y=b,y?t:x)){e=a+24|0;r=A[a+8>>3];g=w[a+16|0];h=jb+-64|0;jb=h;m:while(1){if((n|0)!=8193){s=+(n-4096|0)*.0001220703125;b=0;o=0;while(1)if((b|0)==8){j=1/o;l=n<<3;b=0;while(1)if((b|0)==8){n=n+1|0;continue m}else{m=e+(b+l<<1)|0;d=H(A[h+(b<<3)>>3]*32768*j+.5);d=d<-32768?-32768:F(d,32768);n:{if(D(d)<2147483648){i=~~d;break n}i=-2147483648}u[m>>1]=i;b=b+1|0;continue}}else{j=r;f=1;d=+(b|0)-s;q=d+-3.5;if(!(D(q)<1e-8)){o:{p:{switch(g|0){case 0:f=Qe(d*.8975979010256552)*-.5+.5;break o;case 1:f=Qe(d*.8975979010256552)*-.46+.54;break o;case 2:f=Qe(d*1.7951958020513104)*.08+(Qe(d*.8975979010256552)*-.5+.42);break o;case 3:f=Qe(d*1.7951958020513104)*.05677+(Qe(d*.8975979010256552)*-.49364+.44959);break o;case 4:f=Qe(d*1.7951958020513104)*.07922+(Qe(d*.8975979010256552)*-.49755+.42323);break o;case 5:f=Qe(d*1.7951958020513104);k=Qe(d*.8975979010256552);f=Qe(d*2.6927937030769655)*-.01168+(f*.14128+(k*-.48829+.35875));break o;case 6:f=Qe(d*1.7951958020513104);k=Qe(d*.8975979010256552);f=Qe(d*2.6927937030769655)*-.00183+(f*.09392+(k*-.49703+.40217));break o;case 7:break p;default:break o}}f=Qe(d*1.7951958020513104);k=Qe(d*.8975979010256552);f=Qe(d*2.6927937030769655)*-.00122+(f*.09831+(k*-.49804+.40243))}d=q*3.141592653589793;j=ti(d*j)/d}j=f*j;A[h+(b<<3)>>3]=j;o=o+j;b=b+1|0;continue}}break}jb=h- -64|0;b=v[a+20>>2];v[c+16>>2]=v[a+16>>2];v[c+20>>2]=b;b=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=b;b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b}}function Tga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;f=jb-224|0;jb=f;ae(f+208|0,b);g=jb-48|0;jb=g;v[g+44>>2]=0;bk(b,g+44|0);a:{b:{c:{if(v[g+44>>2]!=(Am(13947)|0)){break c}v[g+40>>2]=0;e=jb-32|0;jb=e;v[e+24>>2]=0;Hv(e+8|0,e+24|0);ln(e+16|0,b,v[e+8>>2],v[e+12>>2]);v[g+40>>2]=v[e+24>>2];jb=e+32|0;e=-1;i=v[g+40>>2];if(i-3>>>0<4294967294){break c}d:{e:{f:{if(i>>>0<=1){i=Kb(g+24|0);v[23296]=0;h=W(430,b|0,i|0,256)|0;j=v[23296];v[23296]=0;if((j|0)==1){break b}if(!h){break e}v[23296]=0;U(11,g+8|0,d|0,i|0);h=v[23296];v[23296]=0;if((h|0)!=1){break f}break b}i=Kb(g+24|0);v[23296]=0;h=Q(432,b|0,i|0)|0;j=v[23296];v[23296]=0;if((j|0)==1){break b}if(!h){break d}v[23296]=0;U(11,g+8|0,d|0,i|0);h=v[23296];v[23296]=0;if((h|0)==1){break b}}h=g+8|0;Hb(c,h);zb(h);yb(i);Kf(b,h);i=0;v[g+24>>2]=0;bk(b,g+24|0);h=v[g+24>>2];if(h>>>0>50){break c}g:{while(1){if((h|0)==(i|0)){break g}i=i+1|0;if(jL(a,b,d)){continue}break}break c}v[g+24>>2]=0;bk(b,g+24|0);e=v[g+24>>2]==(Am(13993)|0)?1:-1;break c}yb(i);break c}yb(i)}jb=g+48|0;break a}a=P()|0;O()|0;yb(i);S(a|0);L()}h:{if(e){break h}Wm(v[v[b>>2]-12>>2]+b|0,0);e=v[f+220>>2];v[f+8>>2]=v[f+216>>2];v[f+12>>2]=e;e=v[f+212>>2];v[f>>2]=v[f+208>>2];v[f+4>>2]=e;b=Dl(f+104|0,Gj(b,f));v[23296]=0;e=Q(396,f+88|0,14132)|0;g=v[23296];v[23296]=0;i:{if((g|0)!=1){v[23296]=0;v[f+72>>2]=3;v[f+76>>2]=0;U(397,b|0,e|0,f+72|0);g=v[23296];v[23296]=0;if((g|0)!=1){Tb(e);t[f+87|0]=0;v[23296]=0;e=Q(396,f+72|0,14588)|0;g=v[23296];v[23296]=0;if((g|0)!=1){v[23296]=0;U(398,b|0,f+87|0,e|0);g=v[23296];v[23296]=0;if((g|0)!=1){Tb(e);v[23296]=0;g=w[f+87|0];e=T(411,b|0)|0;i=v[23296];v[23296]=0;if((i|0)!=1){v[23296]=0;i=T(412,b|0)|0;h=v[23296];v[23296]=0;if((h|0)!=1){g=g?0:d;v[f+64>>2]=e;j:{k:{l:{m:{while(1){if(!Rb(e,i)){a=v[b>>2];_g(b);e=a&1073741824?-1:1;break h}v[23296]=0;d=Q(396,f+48|0,15625)|0;e=v[23296];v[23296]=0;if((e|0)==1){break l}e=v[b+36>>2];h=v[b+32>>2];v[23296]=0;e=fa(413,h|0,e|0,v[f+64>>2],d|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break k}Tb(d);n:{o:{if(!e){v[23296]=0;X(414,b|0,f- -64|0,c|0,g|0);d=v[23296];v[23296]=0;if((d|0)!=1){break o}break j}v[23296]=0;d=Q(396,f+32|0,15234)|0;e=v[23296];v[23296]=0;p:{q:{if((e|0)!=1){e=v[b+36>>2];h=v[b+32>>2];v[23296]=0;e=fa(413,h|0,e|0,v[f+64>>2],d|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break q}Tb(d);if(e){break p}v[23296]=0;U(415,b|0,f- -64|0,f+62|0);d=v[23296];v[23296]=0;if((d|0)==1){break j}break o}a=P()|0;O()|0;break i}a=P()|0;O()|0;Tb(d);break i}v[23296]=0;d=Q(396,f+16|0,15133)|0;e=v[23296];v[23296]=0;if((e|0)==1){break n}e=v[b+36>>2];h=v[b+32>>2];v[23296]=0;e=fa(413,h|0,e|0,v[f+64>>2],d|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break m}Tb(d);if(e){break o}v[23296]=0;X(416,b|0,f- -64|0,a|0,g|0);d=v[23296];v[23296]=0;if((d|0)==1){break j}}eo(f- -64|0);e=v[f+64>>2];continue}break}a=P()|0;O()|0;break i}a=P()|0;O()|0;Tb(d);break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;Tb(d);break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;Tb(e);break i}a=P()|0;O()|0;break i}a=P()|0;O()|0;Tb(e);break i}a=P()|0;O()|0}_g(b);S(a|0);L()}jb=f+224|0;return e|0}function eha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-400|0;jb=e;g=jb-32|0;jb=g;d=g+8|0;LA(d,b);Fu(g,d);v[23296]=0;U(410,e+240|0,v[g>>2],v[g+4>>2]);b=v[23296];v[23296]=0;a:{if((b|0)!=1){Pc(g+8|0);jb=g+32|0;break a}a=P()|0;O()|0;Pc(g+8|0);S(a|0);L()}v[23296]=0;U(393,e+136|0,v[e+240>>2],v[e+244>>2]);b=v[23296];v[23296]=0;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{if((b|0)!=1){v[23296]=0;g=Q(78,e+256|0,e+136|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break z}yb(e+136|0);fc(e+240|0);if(c>>>0<2189){break g}b=Dl(e+136|0,g);v[23296]=0;c=Q(396,e+120|0,10016)|0;d=v[23296];v[23296]=0;if((d|0)==1){break x}v[23296]=0;v[e+104>>2]=19923969;v[e+108>>2]=0;U(397,b|0,c|0,e+104|0);d=v[23296];v[23296]=0;if((d|0)==1){break w}Tb(c);t[e+119|0]=0;v[23296]=0;c=Q(396,e+104|0,10906)|0;d=v[23296];v[23296]=0;if((d|0)==1){break i}v[23296]=0;U(398,b|0,e+119|0,c|0);d=v[23296];v[23296]=0;if((d|0)==1){break v}Tb(c);c=0;c=w[e+119|0]?c:v[a+1298404>>2];f=v[a+4>>2];v[23296]=0;d=Q(396,e+88|0,15625)|0;h=v[23296];v[23296]=0;if((h|0)==1){break u}v[23296]=0;X(399,b|0,f|0,d|0,c|0);f=v[23296];v[23296]=0;if((f|0)==1){break t}Tb(d);v[23296]=0;d=Q(396,e+72|0,15234)|0;f=v[23296];v[23296]=0;if((f|0)==1){break s}v[23296]=0;X(400,b|0,a|0,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break r}Tb(d);v[23296]=0;c=Q(396,e+56|0,15133)|0;d=v[23296];v[23296]=0;if((d|0)==1){break q}v[23296]=0;d=a+484360|0;U(401,b|0,d|0,c|0);f=v[23296];v[23296]=0;if((f|0)==1){break p}Tb(c);v[23296]=0;c=Q(396,e+40|0,26486)|0;f=v[23296];v[23296]=0;if((f|0)==1){break o}v[23296]=0;U(402,b|0,a+484344|0,c|0);f=v[23296];v[23296]=0;if((f|0)==1){break n}Tb(c);f=v[a+1298404>>2];v[23296]=0;c=Q(396,e+24|0,26492)|0;h=v[23296];v[23296]=0;if((h|0)==1){break m}v[23296]=0;X(403,b|0,d|0,c|0,f|0);d=v[23296];v[23296]=0;if((d|0)==1){break l}Tb(c);if(w[b+3|0]&64){v[23296]=0;c=Q(1,e+8|0,16104)|0;d=v[23296];v[23296]=0;if((d|0)==1){break k}a=v[a+1298464>>2];v[23296]=0;U(353,a|0,1,c|0);a=v[23296];v[23296]=0;if((a|0)==1){break j}zb(c)}_g(b);break f}a=P()|0;O()|0;break y}a=P()|0;O()|0;yb(e+136|0)}fc(e+240|0);break b}a=P()|0;O()|0;break h}a=P()|0;O()|0;Tb(c);break h}a=P()|0;O()|0;Tb(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Tb(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Tb(d);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Tb(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Tb(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;Tb(c);break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;zb(c);break h}a=P()|0;O()|0}_g(b);break c}b=Kb(e+136|0);d=v[a+1298404>>2];f=v[a+4>>2];v[23296]=0;d=fa(404,f|0,g|0,b|0,d|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break e}A:{if((d|0)!=1){v[23296]=0;c=Q(1,e+120|0,16410)|0;d=v[23296];v[23296]=0;B:{if((d|0)!=1){a=v[a+1298464>>2];v[23296]=0;U(353,a|0,1,c|0);a=v[23296];v[23296]=0;if((a|0)==1){break B}zb(c);break A}a=P()|0;O()|0;break d}a=P()|0;O()|0;zb(c);break d}d=v[a+1298404>>2];v[23296]=0;X(405,g|0,a|0,d|0,c>>>0<2188|0);a=v[23296];v[23296]=0;if((a|0)==1){break e}}zb(b)}jf(g);jb=e+400|0;return}a=P()|0;O()|0}zb(b)}jf(g)}S(a|0);L()}function Jb(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!a){break a}d=a-8|0;b=v[a-4>>2];a=b&-8;f=d+a|0;b:{if(b&1){break b}if(!(b&3)){break a}b=v[d>>2];d=d-b|0;if(d>>>0<y[115808]){break a}a=a+b|0;if(v[115809]!=(d|0)){if(b>>>0<=255){e=v[d+8>>2];b=b>>>3|0;c=v[d+12>>2];if((c|0)==(e|0)){i=463216,j=v[115804]&Wia(-2,b),v[i>>2]=j;break b}v[e+12>>2]=c;v[c+8>>2]=e;break b}h=v[d+24>>2];b=v[d+12>>2];c:{if((d|0)!=(b|0)){c=v[d+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break c}d:{e=d+20|0;c=v[e>>2];if(c){break d}e=d+16|0;c=v[e>>2];if(c){break d}b=0;break c}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break b}e=v[d+28>>2];c=(e<<2)+463520|0;e:{if(v[c>>2]==(d|0)){v[c>>2]=b;if(b){break e}i=463220,j=v[115805]&Wia(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(d|0)?16:20)>>2]=b;if(!b){break b}}v[b+24>>2]=h;c=v[d+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[d+20>>2];if(!c){break b}v[b+20>>2]=c;v[c+24>>2]=b;break b}b=v[f+4>>2];if((b&3)!=3){break b}v[115806]=a;v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a;return}if(d>>>0>=f>>>0){break a}b=v[f+4>>2];if(!(b&1)){break a}f:{if(!(b&2)){if(v[115810]==(f|0)){v[115810]=d;a=v[115807]+a|0;v[115807]=a;v[d+4>>2]=a|1;if(v[115809]!=(d|0)){break a}v[115806]=0;v[115809]=0;return}if(v[115809]==(f|0)){v[115809]=d;a=v[115806]+a|0;v[115806]=a;v[d+4>>2]=a|1;v[a+d>>2]=a;return}a=(b&-8)+a|0;g:{if(b>>>0<=255){e=v[f+8>>2];b=b>>>3|0;c=v[f+12>>2];if((c|0)==(e|0)){i=463216,j=v[115804]&Wia(-2,b),v[i>>2]=j;break g}v[e+12>>2]=c;v[c+8>>2]=e;break g}h=v[f+24>>2];b=v[f+12>>2];h:{if((f|0)!=(b|0)){c=v[f+8>>2];v[c+12>>2]=b;v[b+8>>2]=c;break h}i:{e=f+20|0;c=v[e>>2];if(c){break i}e=f+16|0;c=v[e>>2];if(c){break i}b=0;break h}while(1){g=e;b=c;e=b+20|0;c=v[e>>2];if(c){continue}e=b+16|0;c=v[b+16>>2];if(c){continue}break}v[g>>2]=0}if(!h){break g}e=v[f+28>>2];c=(e<<2)+463520|0;j:{if(v[c>>2]==(f|0)){v[c>>2]=b;if(b){break j}i=463220,j=v[115805]&Wia(-2,e),v[i>>2]=j;break g}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=b;if(!b){break g}}v[b+24>>2]=h;c=v[f+16>>2];if(c){v[b+16>>2]=c;v[c+24>>2]=b}c=v[f+20>>2];if(!c){break g}v[b+20>>2]=c;v[c+24>>2]=b}v[d+4>>2]=a|1;v[a+d>>2]=a;if(v[115809]!=(d|0)){break f}v[115806]=a;return}v[f+4>>2]=b&-2;v[d+4>>2]=a|1;v[a+d>>2]=a}if(a>>>0<=255){b=(a&-8)+463256|0;c=v[115804];a=1<<(a>>>3);k:{if(!(c&a)){v[115804]=a|c;a=b;break k}a=v[b+8>>2]}v[b+8>>2]=d;v[a+12>>2]=d;v[d+12>>2]=b;v[d+8>>2]=a;return}e=31;if(a>>>0<=16777215){b=a>>>8|0;g=b+1048320>>>16&8;b=b<<g;e=b+520192>>>16&4;b=b<<e;c=b+245760>>>16&2;b=(b<<c>>>15|0)-(c|(e|g))|0;e=(b<<1|a>>>b+21&1)+28|0}v[d+28>>2]=e;v[d+16>>2]=0;v[d+20>>2]=0;g=(e<<2)+463520|0;l:{m:{c=v[115805];b=1<<e;n:{if(!(c&b)){v[115805]=b|c;v[g>>2]=d;v[d+24>>2]=g;break n}e=a<<((e|0)==31?0:25-(e>>>1|0)|0);b=v[g>>2];while(1){c=b;if((v[b+4>>2]&-8)==(a|0)){break m}b=e>>>29|0;e=e<<1;g=c+(b&4)|0;b=v[g+16>>2];if(b){continue}break}v[g+16>>2]=d;v[d+24>>2]=c}v[d+12>>2]=d;v[d+8>>2]=d;break l}a=v[c+8>>2];v[a+12>>2]=d;v[c+8>>2]=d;v[d+24>>2]=0;v[d+12>>2]=c;v[d+8>>2]=a}a=v[115812]-1|0;v[115812]=a?a:-1}}function yg(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=jb-112|0;jb=j;k=i&2147483647;l=e&2147483647;m=l;a:{b:{p=!(b|c);if(!(d|l?l-2147418112>>>0<2147549184:p)){n=k-2147418112|0;if(!h&(n|0)==-2147418112?f|g:(n|0)==-2147418112&(h|0)!=0|n>>>0>2147549184){break b}}if(!(!d&(m|0)==2147418112?p:m>>>0<2147418112)){h=d;i=e|32768;f=b;g=c;break a}if(!(!h&(k|0)==2147418112?!(f|g):k>>>0<2147418112)){i=i|32768;break a}if(!(b|d|(m^2147418112|c))){m=d;d=!(b^f|d^h|(c^g|e^i^-2147483648));h=d?0:m;i=d?2147450880:e;f=d?0:b;g=d?0:c;break a}if(!(f|h|(k^2147418112|g))){break a}if(!(b|d|(c|m))){if(f|h|(g|k)){break a}f=b&f;g=c&g;h=d&h;i=e&i;break a}if(f|h|(g|k)){break b}f=b;g=c;h=d;i=e;break a}l=(k|0)==(m|0);k=l&(d|0)==(h|0)?(c|0)==(g|0)&b>>>0<f>>>0|c>>>0<g>>>0:l&d>>>0<h>>>0|k>>>0>m>>>0;o=k?f:b;l=k?g:c;m=k?i:e;r=m;q=k?h:d;n=m&65535;e=k?e:i;s=e;h=k?d:h;m=e>>>16&32767;p=r>>>16&32767;if(!p){d=!(n|q);e=d<<6;i=E(d?o:q)+32|0;d=E(d?l:n);d=e+((d|0)==32?i:d)|0;vf(j+96|0,o,l,q,n,d-15|0);q=v[j+104>>2];n=v[j+108>>2];o=v[j+96>>2];p=16-d|0;l=v[j+100>>2]}f=k?b:f;g=k?c:g;i=s&65535;if(!m){b=!(h|i);c=b<<6;d=E(b?f:h)+32|0;b=E(b?g:i);b=c+((b|0)==32?d:b)|0;vf(j+80|0,f,g,h,i,b-15|0);m=16-b|0;h=v[j+88>>2];i=v[j+92>>2];g=v[j+84>>2];f=v[j+80>>2]}b=h;k=i<<3|b>>>29;d=b<<3|g>>>29;e=k|524288;b=q;c=n<<3|b>>>29;h=b<<3|l>>>29;i=c;b=f;c=g<<3|b>>>29;b=b<<3;g=r^s;c:{if((m|0)==(p|0)){break c}f=p-m|0;if(f>>>0>127){d=0;e=0;b=1;c=0;break c}vf(j- -64|0,b,c,d,e,128-f|0);fm(j+48|0,b,c,d,e,f);b=v[j+48>>2]|(v[j+64>>2]|v[j+72>>2]|(v[j+68>>2]|v[j+76>>2]))!=0;c=v[j+52>>2];d=v[j+56>>2];e=v[j+60>>2]}m=h;q=i|524288;f=o;k=l<<3|f>>>29;n=f<<3;d:{if((g|0)<0){f=0;g=0;h=0;i=0;if(!(b^n|d^m|(c^k|e^q))){break a}o=n-b|0;l=k-((b>>>0>n>>>0)+c|0)|0;f=m-d|0;b=(c|0)==(k|0)&b>>>0>n>>>0|c>>>0>k>>>0;i=(q-((d>>>0>m>>>0)+e|0)|0)-(f>>>0<b>>>0)|0;h=f-b|0;if(i>>>0>524287){break d}b=!(h|i);c=b<<6;d=E(b?o:h)+32|0;b=E(b?l:i);b=c+((b|0)==32?d:b)|0;b=b-12|0;vf(j+32|0,o,l,h,i,b);p=p-b|0;h=v[j+40>>2];i=v[j+44>>2];o=v[j+32>>2];l=v[j+36>>2];break d}k=c+k|0;f=b+n|0;k=f>>>0<n>>>0?k+1|0:k;o=f;l=k;f=(c|0)==(k|0)&b>>>0>f>>>0|c>>>0>k>>>0;c=e+q|0;b=d+m|0;c=b>>>0<m>>>0?c+1|0:c;d=b;b=f+b|0;h=b;i=b>>>0<d>>>0?c+1|0:c;if(!(i&1048576)){break d}o=o&1|((l&1)<<31|o>>>1);c=h;l=c<<31|l>>>1;p=p+1|0;h=(i&1)<<31|c>>>1;i=i>>>1|0}d=0;e=r&-2147483648;if((p|0)>=32767){h=d;i=e|2147418112;f=0;g=0;break a}m=0;e:{if((p|0)>0){m=p;break e}vf(j+16|0,o,l,h,i,p+127|0);fm(j,o,l,h,i,1-p|0);o=v[j>>2]|(v[j+16>>2]|v[j+24>>2]|(v[j+20>>2]|v[j+28>>2]))!=0;l=v[j+4>>2];h=v[j+8>>2];i=v[j+12>>2]}c=h<<29;b=l>>>3|0;n=(l&7)<<29|o>>>3;l=o&7;g=l>>>0>4;f=n+g|0;b=b|c;k=f>>>0<g>>>0?b+1|0:b;c=f;g=k;b=(b|0)==(k|0)&c>>>0<n>>>0|b>>>0>k>>>0;c=d|((i&7)<<29|h>>>3);b=b+c|0;i=e|(i>>>3&65535|m<<16);i=b>>>0<c>>>0?i+1|0:i;h=b;f:{if((l|0)==4){c=g+0|0;e=f&1;b=f+e|0;c=b>>>0<f>>>0?c+1|0:c;f=b;g=c;c=(d|0)==(c|0)&b>>>0<e>>>0|c>>>0<d>>>0;b=c+h|0;i=b>>>0<c>>>0?i+1|0:i;h=b;break f}if(!l){break a}}}v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;jb=j+112|0}function TJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=e|0;var f=0,g=0,h=0,i=0;f=jb-144|0;jb=f;v[f+140>>2]=c;v[f+136>>2]=b;A[f+128>>3]=d;a:{if(!c){break a}g=w[Kk(b,c)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}Tk(f+104|0,b,c,c-1|0);b=v[f+108>>2];v[f+136>>2]=v[f+104>>2];v[f+140>>2]=b}b=f+104|0;Qd(b);c=v[f+104>>2];Qd(f+88|0);g=Jk(c,v[f+92>>2],f+136|0);Qd(b);b=v[f+140>>2];c=v[f+136>>2];b:{c:{d:{e:{if((g|0)==v[f+108>>2]){a=rc(f+120|0,21473);if(Mc(c,b,v[a>>2],v[a+4>>2])){b=ba(8)|0;v[23296]=0;R(912,f+88|0,f+128|0);a=v[23296];v[23296]=0;f:{g:{h:{if((a|0)!=1){v[23296]=0;U(915,f+104|0,17452,f+88|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}a=0;c=sc(b,f+104|0);v[23296]=0;U(107,c|0,61592,904);c=v[23296];v[23296]=0;if((c|0)!=1){break b}c=P()|0;O()|0;yb(f+104|0);break g}c=P()|0;O()|0;break f}c=P()|0;a=1;O()|0}yb(f+88|0);if(!a){break c}}ca(b|0);break c}if(!e){break e}b=ba(8)|0;v[23296]=0;e=Eh(f+56|0,v[f+136>>2],v[f+140>>2]);a=v[23296];v[23296]=0;i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[23296]=0;U(915,f+72|0,17488,e|0);a=v[23296];v[23296]=0;if((a|0)==1){break q}v[23296]=0;R(917,f+88|0,f+72|0);c=v[23296];v[23296]=0;a=1;if((c|0)==1){break p}v[23296]=0;R(912,f+40|0,f+128|0);a=v[23296];v[23296]=0;if((a|0)==1){break o}v[23296]=0;U(919,f+104|0,f+88|0,f+40|0);c=v[23296];v[23296]=0;a=1;if((c|0)==1){break n}a=sc(b,f+104|0);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(f+104|0);a=0;break m}c=P()|0;O()|0;break i}c=P()|0;a=1;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;a=1;O()|0;break l}c=P()|0;O()|0}yb(f+40|0)}yb(f+88|0)}yb(f+72|0)}yb(e);if(!a){break c}}ca(b|0);break c}e=rc(f+32|0,21473);if(Mc(c,b,v[e>>2],v[e+4>>2])){b=ba(8)|0;v[23296]=0;R(912,f+88|0,f+128|0);a=v[23296];v[23296]=0;r:{s:{t:{if((a|0)!=1){v[23296]=0;U(915,f+104|0,17452,f+88|0);a=v[23296];v[23296]=0;if((a|0)==1){break t}a=0;c=sc(b,f+104|0);v[23296]=0;U(107,c|0,61592,904);c=v[23296];v[23296]=0;if((c|0)!=1){break b}c=P()|0;O()|0;yb(f+104|0);break s}c=P()|0;O()|0;break r}c=P()|0;a=1;O()|0}yb(f+88|0);if(!a){break c}}ca(b|0);break c}e=rc(f+24|0,7677);if(Mc(c,b,v[e>>2],v[e+4>>2])){if(!Rd(w[a+28|0])){break e}if(d<=0|d>4){a=ba(8)|0;v[23296]=0;b=Q(54,f+104|0,7772)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}a=v[a+24>>2];h=a,i=Ie(65536/d),v[h+480244>>2]=i;yp(a);break e}e=rc(f+16|0,7729);if(Mc(c,b,v[e>>2],v[e+4>>2])){if(!Rd(w[a+28|0])){break e}if(d<=0|d>4){a=ba(8)|0;v[23296]=0;b=Q(54,f+104|0,7793)|0;c=v[23296];v[23296]=0;if((c|0)!=1){a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;ca(a|0);break c}a=v[a+24>>2];h=a,i=Ie(d*65536),v[h+480240>>2]=i;yp(a);break e}e=b;b=rc(f+8|0,7747);if(!Mc(c,e,v[b>>2],v[b+4>>2])){break e}h=v[a+24>>2],i=bm(d*65536),v[h+480236>>2]=i}jb=f+144|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function Jda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0,A=0,C=0,D=0;h=jb-4144|0;jb=h;g=Mb(w[a+14|0]|w[a+15|0]<<8);a:{if(!g|g>>>0>20){break a}j=b+480190|0;if(x[j>>1]<=w[a+23|0]){break a}pd(d,32);u[d+34>>1]=1;f=h+24|0;g=a+20|0;v[f>>2]=g;v[f+4>>2]=(g+80|0)-g>>2;WP(h+4136|0,v[h+24>>2],v[h+28>>2],Mb(w[a+14|0]|w[a+15|0]<<8));g=v[h+4136>>2];k=w[Db(g,0)+3|0];v[h+24>>2]=1;k=v[Yc($j(b,k+1|0)+24|0,f)>>2];i=f;f=v[h+4140>>2];WP(i,g,f,c?f:1);q=1/+(k>>>0);f=v[h+24>>2];g=Db(f,v[h+28>>2]);k=v[h+4136>>2];j=x[j>>1];while(1){if((f|0)==(g|0)){b:{r=Bg(d);if(!r){break b}g=v[h+4140>>2];k=h+4120|0;v[k>>2]=0;v[k+4>>2]=0;Cc(k+8|0);if(g){f=jb-16|0;jb=f;v[f+12>>2]=4925421;v[f+8>>2]=2147483647;j=v[Ib(f+12|0,f+8|0)>>2];jb=f+16|0;if(g>>>0>j>>>0){Wc();L()}if(g>>>0>=4925422){jg();L()}g=B(g,872);f=xc(g);v[k>>2]=f;v[k+4>>2]=f;C=Gb(k),D=f+g|0,v[C>>2]=D;f=jb-16|0;jb=f;v[f>>2]=k;j=v[k+4>>2];v[f+4>>2]=j;v[f+8>>2]=g+j;i=v[f+4>>2];g=v[f+8>>2];while(1){if((g|0)==(i|0)){lc(f);jb=f+16|0}else{LP(Xb(i,0,872));i=i+872|0;v[f+4>>2]=i;continue}break}}j=(e<<12>>>0)/1e4|0;s=v[k>>2];n=v[h+4136>>2];z=v[h+4140>>2];A=b+480190|0;f=0;i=0;while(1){if((f|0)==(z|0)){g=b+24648|0}else{g=Db(n,f);e=VP(s,f);l=w[g+3|0];c:{if(l>>>0>=x[A>>1]){break c}o=t[g+1|0];if((o|0)<0){break c}m=0;g=w[g+2|0];if((g+14&255)>>>0<=5){m=t[g+26638|0]}g=$j(b,l+1|0);l=v[g+24>>2];p=q*(Lj(+(m<<24>>24)/96+ +(o-t[Db(n,0)+1|0]|0)/12)*+(l>>>0));if(p<=0){break c}m=UP(p);v[e+8>>2]=m;l=mb;v[e+12>>2]=l;v[e+16>>2]=v[g+20>>2];o=v[g>>2];v[e+76>>2]=o;v[e+88>>2]=x[g+34>>1]&1023;d:{if(c){v[e+664>>2]=i;i=Ie(+(o>>>0)/Kz(m,l))+i|0;g=j;break d}g=(j>>>0)/(Mb(w[a+14|0]|w[a+15|0]<<8)>>>0)|0}v[e+20>>2]=g;v[e+24>>2]=g}f=f+1|0;continue}break}b=0;while(1){e:{a=v[d>>2];if(a>>>0>b>>>0){Xb(h+24|0,0,4096);v[h+16>>2]=512;v[h+12>>2]=a-b;c=v[Ib(h+16|0,h+12|0)>>2];C=h,D=Eb(v[k>>2]),v[C+16>>2]=D;j=Eb(v[k+4>>2]);while(1){a=v[h+16>>2];if(!Rb(a,j)){break e}f:{g:{if(!v[a+16>>2]){break g}e=v[a+664>>2];if(e>>>0>=c>>>0){v[a+664>>2]=e-c;break g}f=v[a+88>>2];v[h+12>>2]=c-e;C=h,D=Ie((+y[a+76>>2]-Kz(v[a>>2],v[a+4>>2]))/Kz(v[a+8>>2],v[a+12>>2])),v[C+8>>2]=D;i=v[Ib(h+12|0,h+8|0)>>2];v[23296]=0;X(v[((f&1|(f&64?18:16))<<2)+27232>>2],a|0,g|0,(h+24|0)+(e<<3)|0,i|0);e=v[23296];v[23296]=0;if((e|0)==1){break f}v[a+664>>2]=0;if(y[a+76>>2]>y[a+4>>2]){break g}v[a+16>>2]=0}v[h+16>>2]=v[h+16>>2]+872;continue}break}a=P()|0;O()|0;Bt(k);S(a|0);L()}Bt(k);break b}e=v[d+20>>2]+(b<<1)|0;f=h+24|0;a=jb-16|0;jb=a;v[a+12>>2]=c;yc(a+12|0,512);i=v[a+12>>2];while(1){if(i){j=id(v[f>>2]+2048|0,12);j=(j|0)<32767?j:32767;u[e>>1]=(j|0)>-32768?j:-32768;f=f+8|0;e=e+2|0;i=i-1|0;continue}break}jb=a+16|0;b=b+c|0;continue}}f=(r|0)!=0}else{i=w[f+3|0];h:{if(i>>>0>=j>>>0){break h}n=t[f+1|0];if((n|0)<0){break h}i=$j(b,i+1|0);m=v[i>>2];p=Lj(+(n-t[Db(k,0)+1|0]|0)/-12);C=d,D=v[d>>2]+Ie(q*(p*+(m>>>0)*+y[i+24>>2]))|0,v[C>>2]=D}f=f+4|0;continue}break}}jb=h+4144|0;return f|0}function wH(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=a+b|0;c=v[a+4>>2];a:{b:{if(c&1){break b}if(!(c&3)){break a}c=v[a>>2];b=c+b|0;c:{a=a-c|0;if((a|0)!=v[115809]){if(c>>>0<=255){e=v[a+8>>2];c=c>>>3|0;d=v[a+12>>2];if((d|0)!=(e|0)){break c}i=463216,j=v[115804]&Wia(-2,c),v[i>>2]=j;break b}h=v[a+24>>2];c=v[a+12>>2];d:{if((c|0)!=(a|0)){d=v[a+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break d}e:{e=a+20|0;d=v[e>>2];if(d){break e}e=a+16|0;d=v[e>>2];if(d){break e}c=0;break d}while(1){g=e;c=d;e=c+20|0;d=v[e>>2];if(d){continue}e=c+16|0;d=v[c+16>>2];if(d){continue}break}v[g>>2]=0}if(!h){break b}e=v[a+28>>2];d=(e<<2)+463520|0;f:{if(v[d>>2]==(a|0)){v[d>>2]=c;if(c){break f}i=463220,j=v[115805]&Wia(-2,e),v[i>>2]=j;break b}v[h+(v[h+16>>2]==(a|0)?16:20)>>2]=c;if(!c){break b}}v[c+24>>2]=h;d=v[a+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[a+20>>2];if(!d){break b}v[c+20>>2]=d;v[d+24>>2]=c;break b}c=v[f+4>>2];if((c&3)!=3){break b}v[115806]=b;v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[f>>2]=b;return}v[e+12>>2]=d;v[d+8>>2]=e}c=v[f+4>>2];g:{if(!(c&2)){if(v[115810]==(f|0)){v[115810]=a;b=v[115807]+b|0;v[115807]=b;v[a+4>>2]=b|1;if(v[115809]!=(a|0)){break a}v[115806]=0;v[115809]=0;return}if(v[115809]==(f|0)){v[115809]=a;b=v[115806]+b|0;v[115806]=b;v[a+4>>2]=b|1;v[a+b>>2]=b;return}b=(c&-8)+b|0;h:{if(c>>>0<=255){e=v[f+8>>2];c=c>>>3|0;d=v[f+12>>2];if((d|0)==(e|0)){i=463216,j=v[115804]&Wia(-2,c),v[i>>2]=j;break h}v[e+12>>2]=d;v[d+8>>2]=e;break h}h=v[f+24>>2];c=v[f+12>>2];i:{if((f|0)!=(c|0)){d=v[f+8>>2];v[d+12>>2]=c;v[c+8>>2]=d;break i}j:{d=f+20|0;e=v[d>>2];if(e){break j}d=f+16|0;e=v[d>>2];if(e){break j}c=0;break i}while(1){g=d;c=e;d=c+20|0;e=v[d>>2];if(e){continue}d=c+16|0;e=v[c+16>>2];if(e){continue}break}v[g>>2]=0}if(!h){break h}e=v[f+28>>2];d=(e<<2)+463520|0;k:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break k}i=463220,j=v[115805]&Wia(-2,e),v[i>>2]=j;break h}v[h+(v[h+16>>2]==(f|0)?16:20)>>2]=c;if(!c){break h}}v[c+24>>2]=h;d=v[f+16>>2];if(d){v[c+16>>2]=d;v[d+24>>2]=c}d=v[f+20>>2];if(!d){break h}v[c+20>>2]=d;v[d+24>>2]=c}v[a+4>>2]=b|1;v[a+b>>2]=b;if(v[115809]!=(a|0)){break g}v[115806]=b;return}v[f+4>>2]=c&-2;v[a+4>>2]=b|1;v[a+b>>2]=b}if(b>>>0<=255){c=(b&-8)+463256|0;d=v[115804];b=1<<(b>>>3);l:{if(!(d&b)){v[115804]=b|d;b=c;break l}b=v[c+8>>2]}v[c+8>>2]=a;v[b+12>>2]=a;v[a+12>>2]=c;v[a+8>>2]=b;return}e=31;if(b>>>0<=16777215){c=b>>>8|0;g=c+1048320>>>16&8;c=c<<g;e=c+520192>>>16&4;c=c<<e;d=c+245760>>>16&2;c=(c<<d>>>15|0)-(d|(e|g))|0;e=(c<<1|b>>>c+21&1)+28|0}v[a+28>>2]=e;v[a+16>>2]=0;v[a+20>>2]=0;g=(e<<2)+463520|0;m:{d=v[115805];c=1<<e;n:{if(!(d&c)){v[115805]=c|d;v[g>>2]=a;v[a+24>>2]=g;break n}e=b<<((e|0)==31?0:25-(e>>>1|0)|0);c=v[g>>2];while(1){d=c;if((v[c+4>>2]&-8)==(b|0)){break m}c=e>>>29|0;e=e<<1;g=d+(c&4)|0;c=v[g+16>>2];if(c){continue}break}v[g+16>>2]=a;v[a+24>>2]=d}v[a+12>>2]=a;v[a+8>>2]=a;return}b=v[d+8>>2];v[b+12>>2]=a;v[d+8>>2]=a;v[a+24>>2]=0;v[a+12>>2]=d;v[a+8>>2]=b}}function UJ(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-192|0;jb=f;v[f+188>>2]=c;v[f+184>>2]=b;t[f+183|0]=d;a:{if(!c){break a}g=w[Kk(b,c)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}Tk(f+8|0,b,c,c-1|0);b=v[f+12>>2];v[f+184>>2]=v[f+8>>2];v[f+188>>2]=b}b=f+8|0;Qd(b);c=v[f+8>>2];Qd(f+152|0);g=Jk(c,v[f+156>>2],f+184|0);Qd(b);b=v[f+188>>2];c=v[f+184>>2];b:{c:{d:{e:{f:{g:{h:{if((g|0)==v[f+12>>2]){a=rc(f+168|0,21473);if(Mc(c,b,v[a>>2],v[a+4>>2])){b=ba(8)|0;v[23296]=0;R(908,f+152|0,f+183|0);a=v[23296];v[23296]=0;if((a|0)==1){break g}v[23296]=0;U(915,f+8|0,17452,f+152|0);a=v[23296];v[23296]=0;if((a|0)==1){break f}d=0;a=sc(b,f+8|0);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(f+8|0);break e}if(!e){break h}b=ba(8)|0;v[23296]=0;d=Eh(f+120|0,v[f+184>>2],v[f+188>>2]);a=v[23296];v[23296]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((a|0)!=1){v[23296]=0;U(915,f+136|0,17488,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break p}v[23296]=0;R(917,f+152|0,f+136|0);c=v[23296];v[23296]=0;a=1;if((c|0)==1){break o}v[23296]=0;R(908,f+104|0,f+183|0);a=v[23296];v[23296]=0;if((a|0)==1){break n}v[23296]=0;U(919,f+8|0,f+152|0,f+104|0);c=v[23296];v[23296]=0;a=1;if((c|0)==1){break m}a=sc(b,f+8|0);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(f+8|0);a=0;break l}c=P()|0;O()|0;break d}c=P()|0;a=1;O()|0;break i}c=P()|0;O()|0;break j}c=P()|0;a=1;O()|0;break k}c=P()|0;O()|0}yb(f+104|0)}yb(f+152|0)}yb(f+136|0)}yb(d);if(a){break d}break c}e=rc(f+96|0,21473);if(Mc(c,b,v[e>>2],v[e+4>>2])){b=ba(8)|0;v[23296]=0;R(908,f+152|0,f+183|0);a=v[23296];v[23296]=0;q:{r:{if((a|0)!=1){v[23296]=0;U(915,f+8|0,17452,f+152|0);a=v[23296];v[23296]=0;if((a|0)==1){break r}d=0;a=sc(b,f+8|0);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(f+8|0);break q}c=P()|0;O()|0;break d}c=P()|0;d=1;O()|0}yb(f+152|0);if(d){break d}break c}s:{e=rc(f+88|0,7380);if(!Mc(c,b,v[e>>2],v[e+4>>2])){e=rc(f+80|0,7362);if(!Mc(c,b,v[e>>2],v[e+4>>2])){break s}}t[a+60|0]=d;break h}t:{e=rc(f+72|0,6895);if(!Mc(c,b,v[e>>2],v[e+4>>2])){e=rc(f- -64|0,6876);if(!Mc(c,b,v[e>>2],v[e+4>>2])){break t}}t[a+61|0]=d;break h}e=rc(f+56|0,6979);if(Mc(c,b,v[e>>2],v[e+4>>2])){t[a+62|0]=d;break h}e=rc(f+48|0,6025);if(Mc(c,b,v[e>>2],v[e+4>>2])){t[a+63|0]=d;break h}e=rc(f+40|0,7429);if(Mc(c,b,v[e>>2],v[e+4>>2])){t[a+64|0]=d;break h}e=b;b=rc(f+32|0,13234);if(!Mc(c,e,v[b>>2],v[b+4>>2])){break h}b=v[a+24>>2];c=b+24664|0;e=v[c+4>>2];v[f+24>>2]=v[c>>2];v[f+28>>2]=e;c=b+24656|0;e=v[c+4>>2];v[f+16>>2]=v[c>>2];v[f+20>>2]=e;c=v[b+24652>>2];v[f+8>>2]=v[b+24648>>2];v[f+12>>2]=c;if(d){a=vJ(v[a+56>>2])}else{a=0}v[f+28>>2]=a;if(!qx(f+8|0,b+24648|0)){break h}jy(b,f+8|0)}jb=f+192|0;return}c=P()|0;O()|0;break d}c=P()|0;d=1;O()|0}yb(f+152|0);if(!d){break c}}ca(b|0)}S(c|0)}L()}function Gia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-736|0;jb=e;Ac(b);f=jb-16|0;jb=f;h=e+120|0;pU(f+8|0,h);g=v[f+12>>2];j=b;nc(f,v[b>>2],v[b+8>>2],v[f+8>>2],v[f+12>>2]);b=v[f+4>>2];if((b|0)==(g|0)){ac(j,v[f+12>>2])}jb=f+16|0;b=(b|0)==(g|0);if(!b){oU(h)}a:{if(!b){break a}if(!qU(e+120|0)){break a}b:{if(!c){break b}Ed(a,67108864);Dg(a);b=w[e+145|0];u[a+480190>>1]=31;u[a+480188>>1]=b;v[a+480228>>2]=256/(b>>>0);b=Vb(e,8097);Hb(a+1298344|0,b);zb(b);b=Vb(e,10663);Hb(a+1298356|0,b);zb(b);d=e+96|0;sg(d,4135);f=w[e+144|0];v[e+72>>2]=f>>>4;b=0;v[23296]=0;v[e+116>>2]=f&15;X(288,e|0,d|0,e+72|0,e+116|0);d=v[23296];v[23296]=0;c:{d:{if((d|0)!=1){Hb(a+1298368|0,e);zb(e);ec(e+96|0);v[a+1298404>>2]=13;tq(Zb(v[a+484360>>2],w[a+484376|0]),e+168|0,w[e+167|0]+1|0);while(1){e:{if((b|0)==31){wu(j,a+1298308|0,32);d=1;break e}d=b+1|0;g=B(d,104)+a|0;h=g+484380|0;pd(h,1);f=(e+120|0)+(b<<2)|0;p=h,q=cc(w[f+176|0]|w[f+177|0]<<8|(w[f+178|0]<<16|w[f+179|0]<<24)),v[p>>2]=q;k=cc(w[f+300|0]|w[f+301|0]<<8|(w[f+302|0]<<16|w[f+303|0]<<24));v[g+484384>>2]=k;f=cc(w[f+424|0]|w[f+425|0]<<8|(w[f+426|0]<<16|w[f+427|0]<<24));v[g+484388>>2]=f+k;if(f){f=g+484414|0;u[f>>1]=x[f>>1]|2}lk(h);b=(e+120|0)+b|0;t[e|0]=w[b+548|0];t[e+96|0]=64;p=g+484410|0,q=w[Wb(e,e+96|0)|0]<<2,u[p>>1]=q;t[g+484417|0]=w[b+579|0]<<4;b=d;continue}break}while(1){if((d|0)!=32){nU(j,((d<<5)+a|0)+946304|0,30);d=d+1|0;continue}break}n=c&1;if(n){mg(a+484344|0,w[e+166|0]+1|0)}k=a+484344|0;m=a+480188|0;f=0;while(1){if(w[e+166|0]<f>>>0){d=1;if(!(c&2)){break a}b=_c(e,8,1,1,0);while(1){if((d|0)==32){break b}lg(b,(B(d,104)+a|0)+484380|0,j);d=d+1|0;continue}}g=Bh(e+96|0);f:{g:{if(w[e+146|0]){v[23296]=0;b=T(258,j|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break f}v[23296]=0;U(178,e+72|0,j|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break f}break g}b=x[m>>1];v[23296]=0;U(178,e+72|0,j|0,b<<8);b=v[23296];v[23296]=0;if((b|0)==1){break d}}b=e+72|0;d=jc(e,b);cd(g,d);Ab(d);Ab(b);h:{if(!n){break h}v[23296]=0;b=W(214,k|0,f&65535,64)|0;d=v[23296];v[23296]=0;if((d|0)==1){break d}if(!b){break h}b=0;if(w[e+146|0]){h=0;v[23296]=0;R(289,g|0,e|0);b=v[23296];v[23296]=0;if((b|0)==1){break d}i:while(1){if((h|0)==64){break h}i=e+h|0;b=128;d=0;l=$b(v[k>>2],f);l=Qf(v[l>>2],v[v[l+48>>2]+12>>2],h);while(1){if(x[m>>1]<=d>>>0){h=h+1|0;continue i}j:{if(!(w[i|0]&b)){break j}v[23296]=0;R(290,g|0,l+B(d,6)|0);o=v[23296];v[23296]=0;if((o|0)!=1){break j}break d}b=b>>>1|0;d=d+1|0;continue}}}k:while(1){d=0;h=b&65535;if(h>>>0>=x[m>>1]){break h}while(1){if((d|0)==64){b=b+1|0;continue k}i=$b(v[k>>2],f);i=fd(v[i>>2],v[v[i+48>>2]+12>>2],d,h);v[23296]=0;R(290,g|0,i|0);i=v[23296];v[23296]=0;if((i|0)!=1){d=d+1|0;continue}break}break}break d}Ab(g);f=f+1|0;continue}break}break d}d=P()|0;O()|0;ec(e+96|0);break c}d=P()|0;O()|0;Ab(g)}S(d|0);L()}d=1}jb=e+736|0;return d|0}function ZS(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=jb-176|0;jb=g;i=hg(g+160|0);a:{b:{c:{if(d){v[23296]=0;U(417,a|0,i|0,c|0);c=v[23296];v[23296]=0;if((c|0)!=1){break c}break b}v[23296]=0;U(418,a|0,i|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}}k=Qb(g+144|0);m=b+480192|0;n=b+1298464|0;c=1;while(1){d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{h=c&65535;if(h>>>0<=x[m>>1]){v[23296]=0;u[g+142>>1]=0;R(419,a|0,g+142|0);d=v[23296];v[23296]=0;t:{u:{v:{w:{if((d|0)!=1){j=jb-16|0;jb=j;o=x[g+142>>1];d=Wd(i);e=kc(i);f=jb-16|0;jb=f;while(1){if(d){l=mo(x[d+16>>1],o);e=l?e:d;d=v[(l?d+4|0:d)>>2];continue}break}d=v[hc(f+8|0,e)>>2];jb=f+16|0;x:{if(Rb(d,Jf(i))){if(!mo(x[g+142>>1],x[vd(d)>>1])){break x}}d=Jf(i)}d=hc(j+8|0,d);jb=j+16|0;j=((h<<2)+b|0)+900380|0;if(!v[j>>2]){break d}d=v[d>>2];if(!Ag(d,yf(i))){break u}v[23296]=0;d=Q(3,g+128|0,vd(d)+4|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break t}v[23296]=0;e=Q(1,g+112|0,16600)|0;f=v[23296];v[23296]=0;if((f|0)==1){break v}f=bq(d,e);zb(e);if(f){break p}e=v[b+4>>2];v[23296]=0;e=Q(420,e|0,d|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break r}v[v[j>>2]+44>>2]=e;if(!v[v[j>>2]+44>>2]){break w}break e}c=P()|0;O()|0;break f}v[23296]=0;e=Q(1,g+96|0,13265)|0;f=v[23296];v[23296]=0;y:{z:{A:{if((f|0)!=1){B:{if(!bq(d,e)){v[23296]=0;f=Q(1,g+80|0,13470)|0;h=v[23296];v[23296]=0;if((h|0)==1){break A}h=bq(d,f);zb(f);zb(e);if(h){break B}break s}zb(e)}v[23296]=0;e=T(421,d|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break z}v[g+56>>2]=e;e=v[b+4>>2];f=v[Tf(g+72|0,g+56|0)>>2];v[23296]=0;e=Q(422,e|0,f|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break y}ig(g+56|0);if(e){break e}break s}c=P()|0;O()|0;break g}c=P()|0;O()|0;zb(e);break g}c=P()|0;O()|0;break g}c=P()|0;O()|0;ig(g+56|0);break g}c=P()|0;O()|0;break g}d=v[j>>2];if(!d){break d}v[d+44>>2]=0;break d}c=P()|0;O()|0;break f}xl(k);YS(i);jb=g+176|0;return}e=Eb(v[k>>2]);h=Eb(v[k+4>>2]);f=jb-16|0;jb=f;v[f+8>>2]=e;while(1){C:{if(!Rb(e,h)){break C}if(bq(e,d)){break C}e=v[$p(f+8|0)>>2];continue}break}jb=f+16|0;if(Rb(e,Eb(v[k+4>>2]))){break p}v[23296]=0;R(423,k|0,d|0);e=v[23296];v[23296]=0;if((e|0)!=1){break q}}c=P()|0;O()|0;break g}v[23296]=0;e=Q(1,g+24|0,17301)|0;f=v[23296];v[23296]=0;if((f|0)==1){break o}v[23296]=0;U(424,g+40|0,e|0,d|0);f=v[23296];v[23296]=0;if((f|0)==1){break n}v[23296]=0;f=Q(1,g+8|0,16153)|0;h=v[23296];v[23296]=0;if((h|0)==1){break m}v[23296]=0;U(2,g+56|0,g+40|0,f|0);h=v[23296];v[23296]=0;if((h|0)==1){break l}h=v[n>>2];v[23296]=0;U(353,h|0,2,g+56|0);h=v[23296];v[23296]=0;if((h|0)==1){break k}zb(g+56|0);zb(f);zb(g+40|0);zb(e)}v[v[j>>2]+44>>2]=0;break e}c=P()|0;O()|0;break g}c=P()|0;O()|0;break h}c=P()|0;O()|0;break i}c=P()|0;O()|0;break j}c=P()|0;O()|0;zb(g+56|0)}zb(f)}zb(g+40|0)}zb(e)}zb(d)}xl(k);break a}zb(d)}c=c+1|0;continue}}c=P()|0;O()|0}YS(i);S(c|0);L()}function TV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=jb-32|0;jb=e;v[e+28>>2]=b;a:{if((d|0)<=0){b=0;break a}v[e+8>>2]=d;v[e+16>>2]=214748364;r=e,s=B(v[Ib(e+28|0,e+16|0)>>2],20),v[r+20>>2]=s;gn(c,v[Ib(e+8|0,e+20|0)>>2]);v[e+12>>2]=b;v[e+8>>2]=a;b=0;while(1){b:{c:{d:{e:{if((d|0)<=0){break e}a=v[e+8>>2];g=v[e+12>>2];f=eh(a,g,b);k=eh(a,g,b+4|0);o=eh(a,g,b+5|0);r=e,s=eh(a,g,b+6|0)<<8|eh(a,g,b+7|0),v[r+24>>2]=s;k=o|k<<8;q=b+8|0;f:{g:{switch(f|0){case 0:b=0;if(d>>>0<k>>>0){b=ba(8)|0;v[23296]=0;a=T(181,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break f}break d}while(1){if((b|0)!=(k|0)){r=e,s=eh(v[e+8>>2],v[e+12>>2],b+q|0),t[r+20|0]=s;fn(c,e+20|0);b=b+1|0;continue}break};o=k;break b;case 1:break g;default:break e}}Wh(e+24|0,d);o=v[e+24>>2];m=eh(a,g,b+10|0);t[e+20|0]=m;fn(c,e+20|0);h=b+11|0;k=k+3&65532;b=o-1|0;g=0;j=0;n=0;l=0;while(1){if((b|0)<=0){break c}f=pg(h,g,1,e+8|0);h:{i:{j:{k:{l:{if((j|0)<=7){if(f){a=g;break i}a=g+1|0;l=8;break l}a=g+1|0;m:{if(!f){if(!pg(h,a,1,e+8|0)){break i}i=2;n:{o:{f=g+2|0;if(!pg(h,f,1,e+8|0)){break o}i=3;f=g+3|0;if(!pg(h,f,1,e+8|0)){break o}i=pg(h,f,3,e+8|0);a=g+6|0;break n}a=f+1|0}f=4;p:{q:{r:{g=((l<<3)+i|0)-17|0;s:{if((g|0)<0){a=ba(8)|0;v[23296]=0;b=T(181,a|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break r}break s}if(g>>>0<56){break p}a=ba(8)|0;v[23296]=0;b=T(181,a|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break q}}b=P()|0;O()|0;ca(a|0);S(b|0);L()}ha(b|0,25912,156);L()}ha(b|0,25912,156);L()}l=w[g+25952|0];if((l|0)!=8){break k}break m}f=4;if((l|0)!=8){break k}}l=8;f=1;if((n|0)>19){break k}}f=0;break j}n=n+8|0}while(1){if(!((f|0)<0|(b|0)<=0)){i=(a|0)/8|0;g=i+h|0;p=eh(v[e+8>>2],v[e+12>>2],g);m=m-id((eh(v[e+8>>2],v[e+12>>2],g+1|0)<<8|p<<16|eh(v[e+8>>2],v[e+12>>2],g+2|0))<<(a-(i<<3)|0)+8,32-l|0)|0;t[e+20|0]=m;fn(c,e+20|0);f=f-1|0;b=b-1|0;a=a+l|0;continue}break}j=(j|0)==31?31:j+1|0;g=a;break h}t:{u:{v:{f=a+1|0;if(!pg(h,f,1,e+8|0)){g=2;break v}f=a+2|0;if(!pg(h,f,1,e+8|0)){g=4;break v}f=a+3|0;if(!pg(h,f,1,e+8|0)){g=6;break v}f=a+5|0;if(!pg(h,a+4|0,1,e+8|0)){a=a+8|0;f=pg(h,f,3,e+8|0)+8|0;break t}a=a+10|0;g=16;f=pg(h,f,5,e+8|0);break u}a=f+2|0;f=pg(h,f+1|0,1,e+8|0)}f=g+f|0}w:{if(pg(h,a,1,e+8|0)){i=-256;g=12;break w}a=a+1|0;g=pg(h,a,1,e+8|0);i=g?-4352:0;g=g?14:8}p=a+1|0;a=pg(h,p,g,e+8|0);if(f>>>0>=3){j=j-((f|0)!=3)|0;j=((j|0)>1?j:1)-1|0}i=(a^-1)+i|0;a=ad(v[c>>2],v[c+4>>2])+i|0;if(a>>>0<i>>>0){g=g+p|0;while(1){if((f|0)<=0|(b|0)<=0){break h}m=w[Lb(v[c>>2],a)|0];t[e+20|0]=m;fn(c,e+20|0);b=b-1|0;a=a+1|0;f=f-1|0;continue}}b=ba(8)|0;v[23296]=0;a=T(181,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}ha(a|0,25912,156);L()}n=n-(n>>3)|0;continue}}ha(a|0,25912,156);L()}b=uc(v[c>>2],v[c+4>>2])^1;break a}a=P()|0;O()|0;ca(b|0);S(a|0);L()}v[e+24>>2]=b}d=d-o|0;b=k+q|0;continue}}jb=e+32|0;return b|0}function aM(a,b){var c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=C(0),m=C(0),n=0,o=0,p=0,q=0,r=0,s=C(0),t=0;if(b){ky(a);c=a+24596|0;v[c>>2]=0;v[c+4>>2]=0;v[a+24588>>2]=0;v[a+24592>>2]=0;fM(a)}$L(a+24648|0);o=v[a+24620>>2];f=jb-144|0;jb=f;e=a+397456|0;c=v[e+4>>2];if(c>>>0>=29){v[e+4>>2]=0;c=0}h=B(c,44)+47472|0;if(!(b?0:(h|0)==v[e+8>>2])){v[e+8>>2]=h;m=C(o>>>0);c=f+8|0;d=v[h+24>>2];v[c>>2]=d;j=v[h+16>>2];v[c+4>>2]=j;v[c+8>>2]=v[h+4>>2];k=(d|0)>(j|0)?d:j;if((k|0)<=-601){i=j;j=k+600|0;v[c+4>>2]=i-j;v[c>>2]=d-j}g=C(z[h+36>>2]*C(79.30999755859375));a:{if(C(D(g))<C(2147483648)){d=~~g;break a}d=-2147483648}v[c+16>>2]=d- -8192;g=C(C(C(z[h+32>>2]*C(.0036000001709908247))+C(.15000000596046448))*C(32767));b:{if(C(D(g))<C(2147483648)){d=~~g;break b}d=-2147483648}v[c+20>>2]=(d|0)<32512?d:32512;j=0;g=z[h+8>>2];l=C(C(F(z[h+20>>2],C(.10000000149011612)))*m);c:{if(C(D(l))<C(2147483648)){d=~~l;break c}d=-2147483648}k=(d|0)>96?d:96;i=k-7500|0;n=k>>>0<i>>>0?0:i;l=C(z[h+28>>2]*m);d:{if(C(D(l))<C(2147483648)){i=~~l;break d}i=-2147483648}d=n+(i+((d|0)<96?d-96|0:0)|0)|0;i=(d|0)>128?d:128;p=i>>>0<3800?i:3800;v[c+24>>2]=p;n=(d|0)<128?d-128|0:0;g=C(g*m);e:{if(C(D(g))<C(2147483648)){q=~~g;break e}q=-2147483648}d=i-3800|0;i=(q+n|0)+(d>>>0>i>>>0?0:d)|0;v[c+32>>2]=i;n=k>>>0<7500?k:7500;while(1){if((j|0)==8){g=C(i|0);l=C(me(C(.0010000000474974513),(i|0)<4721?C(1):C(C(4720)/g))*C(32768));f:{if(C(D(l))<C(2147483648)){d=~~l;break f}d=-2147483648}v[c+12>>2]=d;g=C(z[h+12>>2]*g);r=c,s=me(C(.0010000000474974513),g<=C(4720)?C(1):C(C(4720)/g)),z[r+28>>2]=s}else{d=B(j,12);k=d+c|0;u[k+42>>1]=x[d+48762>>1];u[k+36>>1]=x[d+48756>>1];u[k+40>>1]=x[d+48760>>1];u[k+38>>1]=x[d+48758>>1];v[k+44>>2]=n+((B(v[d+48752>>2],p)+50|0)/100|0);j=j+1|0;continue}break}v[e+20>>2]=v[f+40>>2];c=dK(eK(v[f+16>>2]),m);u[e+86>>1]=c;u[e+84>>1]=c;c=x[f+24>>1]<<1;u[e+94>>1]=c;u[e+92>>1]=c;c=0;while(1){if((c|0)==8){v[e+49892>>2]=v[f+32>>2];c=v[f+12>>2];if((c|0)>-9e3){c=cK(c)}else{c=0}v[e+80>>2]=c;d=e+49948|0;c=v[f+8>>2];if((c|0)>=-8999){c=cK(c)}else{c=0}v[d>>2]=c;c=v[f+28>>2];d=e+49932|0;v[d>>2]=268464128;v[d+4>>2]=1879052288;c=c>>>0<32512?c:32512;u[e+49906>>1]=c;u[e+49904>>1]=c;u[e+49902>>1]=c;u[e+49900>>1]=c;v[f+4>>2]=v[f+20>>2];he(f+4|0,0,32752);c=x[f+4>>1];u[e+49914>>1]=c;d=e+49910|0;u[d>>1]=0;u[d+2>>1]=0;u[e+49908>>1]=c;g=z[f+36>>2];r=f,t=dK(C(g*g),m),v[r>>2]=t;he(f,256,32512);c=x[f>>1];u[e+49922>>1]=c;d=e+49918|0;u[d>>1]=0;u[d+2>>1]=0;u[e+49916>>1]=c}else{d=(c<<4)+e|0;h=(f+8|0)+B(c,12)|0;j=v[h+44>>2];v[d+100>>2]=j;v[d+104>>2]=j;u[d+108>>1]=x[h+36>>1];u[d+110>>1]=x[h+42>>1];u[d+112>>1]=x[h+40>>1];u[d+114>>1]=x[h+38>>1];c=c+1|0;continue}break}}c=a+397448|0;d=a+397452|0;if(b){v[e+16>>2]=0;hK(e,c,d)}b=B(o,5);if(b>>>0>y[e+20>>2]){v[e+20>>2]=b}jb=f+144|0;b=v[a+1298300>>2];if(xd(b)){FO(b,v[a+24620>>2])}}function kda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=jb-32|0;jb=j;a:{b:{if(rt(a)>>>0<b>>>0){if((b|0)<0){break b}n=bo(j+16|0);v[23296]=0;R(681,n|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}$k(j+8|0,v[a>>2]);gm(j,v[a>>2],v[a+4>>2]);m=jb-48|0;jb=m;c=v[n+4>>2];e=gc(m+40|0,v[j+8>>2],v[j+12>>2]);f=gc(m+32|0,v[j>>2],v[j+4>>2]);b=jb-16|0;jb=b;e=gc(b+8|0,v[e>>2],v[e+4>>2]);f=gc(b,v[f>>2],v[f+4>>2]);e=RQ(v[e>>2],v[e+4>>2],v[f>>2],v[f+4>>2]);jb=b+16|0;e=c+e|0;v[n+4>>2]=e;c:{d:{if(!c){b=e-1|0;break d}b=e-1|0;if((b^c-1)>>>0<32){break c}}v[v[n>>2]+((e>>>0<33?0:b>>>5|0)<<2)>>2]=0}f=gc(m+24|0,v[j+8>>2],v[j+12>>2]);e=gc(m+16|0,v[j>>2],v[j+4>>2]);b=m+8|0;Co(b,v[n>>2],c);c=v[f>>2];o=jb-48|0;jb=o;f=v[f+4>>2];e:{if((f|0)==v[b+4>>2]){f=gc(o+40|0,c,f);c=gc(o+32|0,v[e>>2],v[e+4>>2]);b=gc(o+24|0,v[b>>2],v[b+4>>2]);e=jb-16|0;jb=e;g=v[f>>2];d=v[f+4>>2];c=_k(v[c>>2],v[c+4>>2],g,d);v[e+12>>2]=c;f:{if((c|0)<=0){c=v[b>>2];break f}if(d){i=32-d|0;v[e+8>>2]=i;k=c;c=v[td(e+8|0,e+12|0)>>2];v[e+12>>2]=k-c;h=v[b>>2];d=-1<<d&-1>>>i-c;v[h>>2]=v[h>>2]&(d^-1)|d&v[g>>2];c=c+v[b+4>>2]|0;v[b+4>>2]=c&31;v[b>>2]=h+(c>>>3&536870908);g=v[f>>2]+4|0;v[f>>2]=g;c=v[e+12>>2]}k=g;d=(c|0)/32|0;g=d<<2;aj(v[b>>2],k,g);d=c-(d<<5)|0;v[e+12>>2]=d;c=g+v[b>>2]|0;v[b>>2]=c;if((d|0)<=0){break f}c=f;f=g+v[f>>2]|0;v[c>>2]=f;c=v[b>>2];g=-1>>>32-d|0;v[c>>2]=v[c>>2]&(g^-1)|g&v[f>>2];v[b+4>>2]=v[e+12>>2]}gc(m,c,v[b+4>>2]);break e}g=gc(o+16|0,c,f);c=gc(o+8|0,v[e>>2],v[e+4>>2]);f=gc(o,v[b>>2],v[b+4>>2]);e=jb-16|0;jb=e;k=v[c>>2];d=v[c+4>>2];b=v[g>>2];c=v[g+4>>2];d=_k(k,d,b,c);v[e+12>>2]=d;g:{if((d|0)<=0){c=v[f+4>>2];break g}h:{if(!c){c=v[f+4>>2];break h}l=32-c|0;v[e+8>>2]=l;i=e+8|0;h=v[td(i,e+12|0)>>2];v[e+12>>2]=d-h;d=v[f+4>>2];p=v[b>>2];v[e+8>>2]=h;k=32-d|0;v[e+4>>2]=k;b=v[f>>2];q=v[b>>2];i=v[Ib(i,e+4|0)>>2];l=p&(-1<<c&-1>>>l-h);v[b>>2]=(-1<<d&-1>>>k-i^-1)&q|(c>>>0<d>>>0?l<<d-c:l>>>c-d|0);d=d+i|0;c=d&31;v[f+4>>2]=c;d=b+(d>>>3&536870908)|0;v[f>>2]=d;b=h-i|0;if((b|0)>0){v[d>>2]=v[d>>2]&(-1>>>32-b^-1)|l>>>i+v[g+4>>2];v[f+4>>2]=b;c=b}b=v[g>>2]+4|0;v[g>>2]=b;d=v[e+12>>2]}h=32-c|0;i=-1<<c;l=i^-1;while(1){if((d|0)>=32){d=v[f>>2];b=v[b>>2];v[d>>2]=l&v[d>>2]|b<<c;v[f>>2]=d+4;v[d+4>>2]=i&v[d+4>>2]|b>>>h;d=v[e+12>>2]-32|0;v[e+12>>2]=d;b=v[g>>2]+4|0;v[g>>2]=b;continue}break}if((d|0)<=0){break g}l=v[b>>2];v[e+8>>2]=h;g=v[f>>2];b=v[g>>2];k=b;b=v[td(e+12|0,e+8|0)>>2];k=k&(i&-1>>>h-b^-1);h=l&-1>>>32-d;v[g>>2]=k|h<<c;d=b+c|0;c=d&31;v[f+4>>2]=c;g=g+(d>>>3&536870908)|0;v[f>>2]=g;d=v[e+12>>2]-b|0;v[e+12>>2]=d;if((d|0)<=0){break g}v[g>>2]=v[g>>2]&(-1>>>32-d^-1)|h>>>b;c=v[e+12>>2];v[f+4>>2]=c}gc(m,v[f>>2],c)}jb=e+16|0;jb=o+48|0;jb=m+48|0;xt(a,n);Le(n)}jb=j+32|0;return}Wc();L()}a=P()|0;O()|0;Le(n);S(a|0);L()}function dE(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-176|0;jb=d;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{s:{t:{u:{v:{w:{x:{y:{z:{A:{B:{C:{D:{E:{if((b|0)<=5){Gv(d+128|0,b);v[23296]=0;b=Q(1,d+112|0,17588)|0;e=v[23296];v[23296]=0;if((e|0)==1){break E}v[23296]=0;U(2,d+144|0,d+128|0,b|0);e=v[23296];v[23296]=0;if((e|0)==1){break D}v[23296]=0;c=Q(3,d+80|0,c|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break C}v[23296]=0;e=Q(1,d- -64|0,19416)|0;f=v[23296];v[23296]=0;if((f|0)==1){break B}v[23296]=0;U(4,d+96|0,c|0,e|0);f=v[23296];v[23296]=0;if((f|0)==1){break A}v[23296]=0;U(2,d+160|0,d+144|0,d+96|0);f=v[23296];v[23296]=0;if((f|0)==1){break z}zb(d+96|0);zb(e);zb(c);c=d+144|0;zb(c);zb(b);zb(d+128|0);b=v[a>>2];v[23296]=0;U(5,c|0,1,(b?b:21473)|0);b=v[23296];v[23296]=0;if((b|0)==1){break t}b=v[a+4>>2];v[23296]=0;U(5,d+128|0,1,(b?b:21473)|0);b=v[23296];v[23296]=0;if((b|0)==1){break s}a=v[a+8>>2];v[23296]=0;v[d+48>>2]=a;R(6,d+96|0,d+48|0);a=v[23296];v[23296]=0;if((a|0)==1){break r}v[23296]=0;Y(7,17467);a=v[23296];v[23296]=0;if((a|0)==1){break q}v[23296]=0;U(8,d+48|0,0,d+144|0);a=v[23296];v[23296]=0;if((a|0)==1){break p}v[23296]=0;Y(9,d+48|0);a=v[23296];v[23296]=0;if((a|0)==1){break o}v[23296]=0;Y(7,17261);a=v[23296];v[23296]=0;if((a|0)==1){break o}v[23296]=0;U(8,d+32|0,0,d+96|0);a=v[23296];v[23296]=0;if((a|0)==1){break n}v[23296]=0;Y(9,d+32|0);a=v[23296];v[23296]=0;if((a|0)==1){break m}v[23296]=0;Y(7,17259);a=v[23296];v[23296]=0;if((a|0)==1){break m}v[23296]=0;Y(7,17588);a=v[23296];v[23296]=0;if((a|0)==1){break m}v[23296]=0;U(8,d+16|0,0,d+160|0);a=v[23296];v[23296]=0;if((a|0)==1){break l}v[23296]=0;Y(9,d+16|0);a=v[23296];v[23296]=0;if((a|0)==1){break k}v[23296]=0;Y(7,13291);a=v[23296];v[23296]=0;if((a|0)==1){break k}v[23296]=0;U(8,d|0,0,d+128|0);a=v[23296];v[23296]=0;if((a|0)==1){break j}v[23296]=0;Y(9,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break i}v[23296]=0;Y(7,13289);a=v[23296];v[23296]=0;if((a|0)==1){break i}v[23296]=0;Z(10);a=v[23296];v[23296]=0;if((a|0)==1){break i}yb(d);yb(d+16|0);yb(d+32|0);yb(d+48|0);zb(d+96|0);zb(d+128|0);zb(d+144|0);zb(d+160|0)}jb=d+176|0;return}a=P()|0;O()|0;break u}a=P()|0;O()|0;break v}a=P()|0;O()|0;break w}a=P()|0;O()|0;break x}a=P()|0;O()|0;break y}a=P()|0;O()|0;zb(d+96|0)}zb(e)}zb(c)}zb(d+144|0)}zb(b)}zb(d+128|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;break h}a=P()|0;O()|0;yb(d)}yb(d+16|0)}yb(d+32|0)}yb(d+48|0)}zb(d+96|0)}zb(d+128|0)}zb(d+144|0)}zb(d+160|0)}S(a|0);L()}function ZV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb-160|0;jb=d;Ac(b);No(a);a:{if(!iv(b,d+120|0)){break a}if(!jD(d+120|0)){break a}j=v[b+8>>2];b:{if(!$c(b,w[d+136|0]|w[d+137|0]<<8|(w[d+138|0]<<16|w[d+139|0]<<24))){break b}while(1){c:{if((w[d+132|0]|w[d+133|0]<<8|(w[d+134|0]<<16|w[d+135|0]<<24))>>>0>h>>>0){if(Ob(v[b>>2],v[b+8>>2],5)){break c}}f=i&1;break b}f=0;g=1;d:{if((w[d+124|0]|w[d+125|0]<<8)>>>0>=64){if((ni(b)|0)<=0){break d}}while(1){l=Ee(b);if(l){m=f>>>0>4;e=m&g;if(!((g^1)&1|m)){e=(xp(l<<24>>24)&255)==w[f+12955|0]}g=e;f=f+1|0;continue}break}ac(b,4);i=(f|0)==5?g&1?1:i:i}h=h+1|0;continue}}$c(b,j);if(!f){break a}if(!Ob(v[b>>2],v[b+8>>2],iD(d+120|0))){break a}if(!c){k=1;break a}g=jb-16|0;jb=g;e=d+120|0;$c(b,w[e+16|0]|w[e+17|0]<<8|(w[e+18|0]<<16|w[e+19|0]<<24));i=d+104|0;f=Qb(i);c=w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24);v[23296]=0;R(169,f|0,c|0);c=v[23296];v[23296]=0;e:{f:{g:{if((c|0)!=1){c=0;h:{i:{while(1){if((w[e+12|0]|w[e+13|0]<<8|(w[e+14|0]<<16|w[e+15|0]<<24))>>>0<=c>>>0){break h}h=v[b+8>>2];j=v[b>>2];v[23296]=0;h=W(144,j|0,h|0,5)|0;j=v[23296];v[23296]=0;if((j|0)==1){break g}if(!h){break h}h=w[e+4|0]|w[e+5|0]<<8;v[23296]=0;U(170,g|0,b|0,h|0);h=v[23296];v[23296]=0;if((h|0)!=1){v[23296]=0;R(171,f|0,g|0);h=v[23296];v[23296]=0;if((h|0)==1){break i}c=c+1|0;yb(g);continue}break}c=P()|0;O()|0;break f}c=P()|0;O()|0;yb(g);break f}jb=g+16|0;break e}c=P()|0;O()|0;break f}c=P()|0;O()|0}Me(f);S(c|0);L()}v[23296]=0;X(164,d+88|0,b|0,e|0,i|0);c=v[23296];v[23296]=0;j:{if((c|0)!=1){v[23296]=0;Q(143,b|0,v[d+144>>2])|0;c=v[23296];v[23296]=0;k:{if((c|0)!=1){g=d+36|0;l:{m:{n:{o:{while(1){p:{q:{if(y[d+140>>2]>k>>>0){c=v[b+8>>2];e=v[b>>2];v[23296]=0;c=W(144,e|0,c|0,8)|0;e=v[23296];v[23296]=0;if((e|0)==1){break q}if(c){break p}}k=uc(v[a>>2],v[a+4>>2])^1;vc(d+88|0);Me(d+104|0);break a}b=P()|0;O()|0;break k}v[23296]=0;da(165,d- -64|0,b|0,d+120|0,d+88|0,d+104|0);c=v[23296];v[23296]=0;if((c|0)!=1){e=Oo(d- -64|0);v[23296]=0;c=T(166,v[d+64>>2])|0;f=v[23296];v[23296]=0;if((f|0)==1){break o}if(c){v[23296]=0;c=T(167,d+24|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break n}e=v[e>>2];r:{if((e|0)<0){break r}f=v[d+104>>2];if(wd(f,v[d+108>>2])>>>0<=e>>>0){break r}v[23296]=0;U(11,d+8|0,8,Hd(f,e)|0);e=v[23296];v[23296]=0;if((e|0)==1){break m}e=d+8|0;Hb(c,e);zb(e)}gv(g,d- -64|0);v[23296]=0;R(168,a|0,c|0);e=v[23296];v[23296]=0;if((e|0)==1){break m}_q(c)}k=k+1|0;Ab(d- -64|0);continue}break}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;break l}b=P()|0;O()|0;_q(c)}Ab(d- -64|0);break k}b=P()|0;O()|0}vc(d+88|0);break j}b=P()|0;O()|0}Me(d+104|0);S(b|0);L()}jb=d+160|0;return k|0}function mK(a){var b=C(0),c=C(0),d=0,e=C(0),f=C(0),g=0,h=0,i=C(0),k=0,m=C(0),r=C(0),s=0,t=C(0),u=0,w=C(0),x=C(0);d=a+4208|0;LN(Db(d,0),z[a+4272>>2]);b=C(C(z[Db(d,0)>>2]*C(15920))+C(80));t=me(C(10),C(C(C(z[Db(d,2)>>2]+C(-.5))*C(30))/C(40)));c=C(C(b/C(y[v[a+16>>2]+24620>>2]))*C(6.2831854820251465));b=FK(c);w=pp(c);x=b;f=C(C(c*C(C(C(z[Db(d,1)>>2]*C(35))+C(1))*C(.02888113260269165)))/b);m=(l(2,(p(f),j(2))&-2147483648|1056964608),q());g=(p(f),j(2))&2147483647;c=(l(2,g),q());a:{if(g>>>0<=1118925334){b:{c:{d:{e:{f:{g:{h=(p(c),j(2));d=h&2147483647;if(d>>>0>=1100331076){if(d>>>0>2139095040){break c}b=C(-1);if((h|0)<0){break b}if(!(c>C(88.7216796875))){break g}b=C(c*C(17014118346046923e22));break b}if(d>>>0<1051816473){break e}if(d>>>0>1065686417){break g}if((h|0)>=0){d=1;e=C(905800061445916e-20);b=C(c+C(-.6931381225585938));break f}d=-1;e=C(-905800061445916e-20);b=C(c+C(.6931381225585938));break f}b=C(C(c*C(1.4426950216293335))+(l(2,(p(c),j(2))&-2147483648|1056964608),q()));h:{if(C(D(b))<C(2147483648)){d=~~b;break h}d=-2147483648}b=C(d|0);e=C(b*C(905800061445916e-20));b=C(c+C(b*C(-.6931381225585938)))}c=C(b-e);e=C(C(b-c)-e);break d}if(d>>>0<855638016){break c}d=0}b=C(c*C(.5));i=C(c*b);r=C(C(i*C(C(i*C(.0015807170420885086))+C(-.03333321213722229)))+C(1));b=C(C(3)-C(r*b));r=C(i*C(C(r-b)/C(C(6)-C(c*b))));b=C(c-C(C(c*r)-i));if(!d){break b}e=C(C(C(c*C(r-e))-e)-i);i:{switch(d+1|0){case 0:b=C(C(C(c-e)*C(.5))+C(-.5));break b;case 2:b=C(C(e-C(c+C(.5)))*C(-2));if(c<C(-.25)){break b}b=C(c-e);b=C(C(b+b)+C(1));break b;default:break i}}h=d<<23;b=(l(2,h+1065353216|0),q());if(d>>>0>=57){c=C(C(c-e)+C(1));b=C(((d|0)==128?C(C(c+c)*C(17014118346046923e22)):C(c*b))+C(-1));break b}i=(l(2,1065353216-h|0),q());c=C((d>>>0<=22?C(C(C(1)-i)+C(c-e)):C(C(c-C(e+i))+C(1)))*b)}b=c}if(g>>>0<=1065353215){if(g>>>0<964689920){break a}f=C(m*C(C(b+b)-C(C(b*b)/C(b+C(1)))));break a}f=C(m*C(b+C(b/C(b+C(1)))));break a}m=C(C(m+m)*C(1661534994731145e20));b=C(c+C(-162.88958740234375));d=Rw(b)&2047;j:{k:{if(Rw(C(88))>>>0>d>>>0){break k}c=C(0);if(((p(b),j(2))|0)==-8388608){break j}c=C(b+b);if(Rw(C(N))>>>0<=d>>>0){break j}if(b>C(88.72283172607422)){c=tD(0);break j}if(!(b<C(-103.97207641601562))){break k}c=VC(0);break j}k=A[165]*+b;s=A[164];u=k+s;k=k-(u-s);s=(A[166]*k+A[167])*(k*k)+(A[168]*k+1);o(+u);j(1)|0;d=j(0)|0;h=d<<15;d=((d&31)<<3)+1024|0;g=v[d>>2];d=v[d+4>>2]+h|0;l(0,g|0);l(1,(g>>>0<g>>>0?d+1|0:d)|0);c=C(s*+n())}f=C(C(m*c)*C(1661534994731145e20))}c=C(x*f);f=C(c/t);b=C(f+C(1));z[a+4236>>2]=C(C(1)-f)/b;f=C(C(w*C(-2))/b);z[a+4232>>2]=f;c=C(c*t);z[a+4228>>2]=C(C(1)-c)/b;z[a+4224>>2]=f;z[a+4220>>2]=C(c+C(1))/b}function Xv(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-96|0;jb=f;a:{if(i=1,j=hd(a,11),k=v[a+4>>2],k?i:j){e=v[a+28>>2];d=v[a+12>>2];b=v[a+64>>2];g=b+v[a+8>>2]|0;g=jh(f+80|0,g,b>>>0>g>>>0?d+1|0:d);b=v[g+12>>2];v[f+32>>2]=v[g+8>>2];v[f+36>>2]=b;b=v[g+4>>2];v[f+24>>2]=v[g>>2];v[f+28>>2]=b;Gj(e,f+24|0);b=v[a+28>>2];if(Hk(v[(v[v[b>>2]-12>>2]+b|0)+16>>2])){kh(a,1073741826);break a}c=v[a+92>>2];h=a+44|0;b=v[h>>2];d=hh(b,v[h+4>>2]);b:{if(c>>>0>d>>>0){g=jb-32|0;jb=g;c=c-d|0;b=v[Gb(h)>>2];e=v[h+4>>2];c:{if(c>>>0<=b-e>>4>>>0){e=jb-16|0;jb=e;d=To(e,h,c);c=v[d+4>>2];b=v[d+8>>2];while(1){if((b|0)==(c|0)){lc(d);jb=e+16|0}else{iE(c);c=c+16|0;v[d+4>>2]=c;continue}break}break c}b=Gb(h);d=Iv(g+8|0,Jv(h,hh(v[h>>2],e)+c|0),hh(v[h>>2],v[h+4>>2]),b);b=jb-16|0;jb=b;c=gE(b,d+8|0,c);e=v[c>>2];while(1){if(v[c+4>>2]!=(e|0)){iE(e);e=v[c>>2]+16|0;v[c>>2]=e;continue}break}Id(c);jb=b+16|0;Ad(h,d);jE(d)}jb=g+32|0;break b}if(d>>>0>c>>>0){Nd(h,b+(c<<4)|0)}}g=a+32|0;gn(g,v[a+92>>2]<<2);d=0;while(1){if(y[a+92>>2]>d>>>0){b=v[a+28>>2];if(Hk(v[(v[v[b>>2]-12>>2]+b|0)+16>>2])){kh(a,1073741828);break a}c=x[a+16>>1];u[f+78>>1]=c;if((c|0)==65535){Yv(b,f+78|0);c=x[f+78>>1]}e=ad(v[a+32>>2],v[a+36>>2]);b=c&65535;d:{if(!b){c=0;break d}if(b>>>0>(e^-1)>>>0){break d}Li(g,b+e|0);Bk(v[a+28>>2],Lb(v[a+32>>2],e),b)}b=ed(v[a+44>>2],d);v[b>>2]=e;u[b+12>>1]=c;if(hd(a,6)){rk(v[a+28>>2],f+56|0);b=v[f+56>>2];if(v[f+60>>2]<0){kh(a,1073741829);break a}i=ed(v[a+44>>2],d),j=b,v[i+4>>2]=j}b=v[a+4>>2];e:{if(b){c=ed(v[a+44>>2],d);v[c+8>>2]=b;break e}if(!hd(a,7)){c=ed(v[a+44>>2],d);break e}rk(v[a+28>>2],f+56|0);b=v[f+56>>2];if(v[f+60>>2]<0){kh(a,1073741829);break a}c=ed(v[a+44>>2],d);v[c+8>>2]=b}f:{if(v[c+8>>2]==-1){break f}if(hd(a,6)){break f}g:{if(!d){c=0;b=ed(v[a+44>>2],0);break g}e=v[a+44>>2];b=ed(e,d-1|0);c=v[b+8>>2]+v[b+4>>2]|0;b=ed(e,d)}v[b+4>>2]=c}if(hd(a,8)){u[f+56>>1]=0;Yv(v[a+28>>2],f+56|0);b=hd(a,9);Gl(v[a+28>>2],x[f+56>>1]<<b)}d=d+1|0;continue}break}ae(f+56|0,v[a+28>>2]);b=v[f+68>>2];v[a+72>>2]=v[f+64>>2];v[a+76>>2]=b}sk(a,4,1);e=v[a+76>>2];b=v[a+88>>2];g=b+v[a+8>>2]|0;d=v[a+12>>2];d=b>>>0>g>>>0?d+1|0:d;b=(b|0)==v[a+64>>2];g=b?v[a+72>>2]:g;v[a+80>>2]=g;b=b?e:d;v[a+84>>2]=b;e=v[a+28>>2];g=jh(f+40|0,g,b);b=v[g+12>>2];v[f+16>>2]=v[g+8>>2];v[f+20>>2]=b;b=v[g+4>>2];v[f+8>>2]=v[g>>2];v[f+12>>2]=b;Gj(e,f+8|0);if(hd(a,6)){break a}if(!(i=1,j=hd(a,7),k=v[a+4>>2],k?i:j)){break a}e=v[a+80>>2];b=v[a+8>>2];d=e-b|0;g=v[a+44>>2];e=v[a+92>>2];a=0;while(1){if((a|0)==(e|0)){break a}b=ed(g,a);v[b+4>>2]=d+v[b+4>>2];a=a+1|0;continue}}jb=f+96|0}function U9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0;v[a+24588>>2]=0;v[a+24592>>2]=0;v[a+8>>2]=43568;v[a+4>>2]=0;v[a>>2]=32e3;b=a+24596|0;v[b>>2]=0;v[b+4>>2]=0;Np(a+24604|0);IM(a+24648|0,0);v[a+397448>>2]=0;v[a+397452>>2]=0;b=a+397456|0;v[b>>2]=8;v[b+4>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;t[b+12|0]=0;v[b+8>>2]=0;u[b+24>>1]=0;Xb(b+28|0,0,40);Xb(b+68|0,0,49824);Xb(b+49892|0,0,32832);t[a+480224|0]=0;u[a+480212>>1]=0;v[a+480204>>2]=0;v[a+480208>>2]=0;v[a+480180>>2]=0;v[a+480184>>2]=0;b=a+480186|0;u[b>>1]=0;u[b+2>>1]=0;u[b+4>>1]=0;u[b+6>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;i=Qb(a+480248|0);v[a+480272>>2]=0;c=a+484344|0;b=a+480280|0;while(1){t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;EC(b+9|0);b=b+32|0;if((c|0)!=(b|0)){continue}break}f=Qb(c);v[f+12>>2]=a;v[23296]=0;j=Q(761,a+484360|0,a|0)|0;b=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((b|0)!=1){d=a+900380|0;b=a+484380|0;while(1){v[23296]=0;b=T(632,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break i}b=b+104|0;if((d|0)!=(b|0)){continue}break}v[23296]=0;T(762,a+901404|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break h}c=a+946300|0;g=a+906300|0;b=g;while(1){b=HM(b)+160|0;if((c|0)!=(b|0)){continue}break}v[a+946300>>2]=0;e=a+1074304|0;h=a+946304|0;b=h;while(1){b=ot(b)+32|0;if((e|0)!=(b|0)){continue}break}v[a+1074304>>2]=0;v[a+1074308>>2]=0;Zq(a+1074312|0);v[23296]=0;Z(763);b=v[23296];v[23296]=0;if((b|0)==1){break g}s=a,w=CM(),v[s+1074328>>2]=w;b=a+1074332|0;v[b+12>>2]=1065353216;rM(b,4);v[23296]=0;e=T(764,a+1074376|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break g}v[23296]=0;k=W(532,a+1298264|0,a|0,255)|0;b=v[23296];v[23296]=0;if((b|0)==1){break f}l=Cc(a+1298300|0);m=Cc(a+1298304|0);n=Kb(a+1298308|0);o=Kb(a+1298320|0);p=Kb(a+1298332|0);q=GM(a+1298344|0);r=Qb(a+1298408|0);t[a+1298420|0]=0;b=a+1298424|0;v[b>>2]=0;v[b+4>>2]=0;v[b+32>>2]=0;v[b+36>>2]=1072693248;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[a+1298464>>2]=0;zp(a+12|0);ty(a+8204|0);ty(a+12300|0);b=a+1074408|0;v[b>>2]=4;v[b+4>>2]=16;v[a+480216>>2]=4;v[a+480220>>2]=16;Xb(d,0,1024);BM(h);v[23296]=0;b=T(765,12)|0;d=v[23296];v[23296]=0;if((d|0)==1){break e}v[b>>2]=0;v[b+4>>2]=0;v[b+8>>2]=0;s=a,w=Qb(b),v[s+4>>2]=w;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;FM(r);wy(q);yb(p);zb(o);yb(n);vy(m);uy(l);at(k)}Iy(e)}while(1){c=Ss(c-160|0);if((g|0)!=(c|0)){continue}break}}rz(j)}xM(f);vc(i);S(b|0);L()}function dF(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0;i=jb-48|0;jb=i;o(+a);e=j(1)|0;d=j(0)|0;a:{b:{h=e;k=e&2147483647;c:{if(k>>>0<=1074752122){if((h&1048575)==598523){break c}if(k>>>0<=1073928572){if((e|0)>0|(e|0)>=0){a=a+-1.5707963267341256;c=a+-6077100506506192e-26;A[b>>3]=c;A[b+8>>3]=a-c+-6077100506506192e-26;d=1;break a}a=a+1.5707963267341256;c=a+6077100506506192e-26;A[b>>3]=c;A[b+8>>3]=a-c+6077100506506192e-26;d=-1;break a}if((e|0)>0|(e|0)>=0){a=a+-3.1415926534682512;c=a+-1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.2154201013012384e-10;d=2;break a}a=a+3.1415926534682512;c=a+1.2154201013012384e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.2154201013012384e-10;d=-2;break a}if(k>>>0<=1075594811){if(k>>>0<=1075183036){if((k|0)==1074977148){break c}if((e|0)>0|(e|0)>=0){a=a+-4.712388980202377;c=a+-1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+-1.8231301519518578e-10;d=3;break a}a=a+4.712388980202377;c=a+1.8231301519518578e-10;A[b>>3]=c;A[b+8>>3]=a-c+1.8231301519518578e-10;d=-3;break a}if((k|0)==1075388923){break c}if((e|0)>0|(e|0)>=0){a=a+-6.2831853069365025;c=a+-2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+-2.430840202602477e-10;d=4;break a}a=a+6.2831853069365025;c=a+2.430840202602477e-10;A[b>>3]=c;A[b+8>>3]=a-c+2.430840202602477e-10;d=-4;break a}if(k>>>0>1094263290){break b}}f=a*.6366197723675814+6755399441055744+-6755399441055744;c=a+f*-1.5707963267341256;g=f*6077100506506192e-26;p=c-g;e=p<-.7853981633974483;if(D(f)<2147483648){d=~~f}else{d=-2147483648}d:{if(e){d=d-1|0;f=f+-1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256;break d}if(!(p>.7853981633974483)){break d}d=d+1|0;f=f+1;g=f*6077100506506192e-26;c=a+f*-1.5707963267341256}a=c-g;A[b>>3]=a;o(+a);h=j(1)|0;j(0)|0;e=k>>>20|0;e:{if((e-(h>>>20&2047)|0)<17){break e}g=c;a=f*6077100506303966e-26;c=c-a;g=f*20222662487959506e-37-(g-c-a);a=c-g;A[b>>3]=a;h=e;o(+a);e=j(1)|0;j(0)|0;if((h-(e>>>20&2047)|0)<50){break e}g=c;a=f*20222662487111665e-37;c=c-a;g=f*84784276603689e-45-(g-c-a);a=c-g;A[b>>3]=a}A[b+8>>3]=c-a-g;break a}if(k>>>0>=2146435072){a=a-a;A[b>>3]=a;A[b+8>>3]=a;d=0;break a}l(0,d|0);l(1,e&1048575|1096810496);a=+n();d=0;h=1;while(1){m=(i+16|0)+(d<<3)|0;if(D(a)<2147483648){d=~~a}else{d=-2147483648}c=+(d|0);A[m>>3]=c;a=(a-c)*16777216;d=1;m=h;h=0;if(m){continue}break}A[i+32>>3]=a;d=2;while(1){h=d;d=d-1|0;if(A[(i+16|0)+(h<<3)>>3]==0){continue}break}d=DH(i+16|0,i,(k>>>20|0)-1046|0,h+1|0,1);a=A[i>>3];if((e|0)<0){A[b>>3]=-a;A[b+8>>3]=-A[i+8>>3];d=0-d|0;break a}A[b>>3]=a;A[b+8>>3]=A[i+8>>3]}jb=i+48|0;return d}function SJ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-128|0;jb=g;v[g+124>>2]=c;v[g+120>>2]=b;v[g+112>>2]=d;v[g+116>>2]=e;a:{if(!c){break a}h=w[Kk(b,c)|0];if((h|0)==33){f=1}else{if((h|0)!=63){break a}f=0}Tk(g+88|0,b,c,c-1|0);b=v[g+92>>2];v[g+120>>2]=v[g+88>>2];v[g+124>>2]=b}b=g+88|0;Qd(b);c=v[g+88>>2];Qd(g+72|0);h=Jk(c,v[g+76>>2],g+120|0);Qd(b);b=v[g+124>>2];c=v[g+120>>2];b:{c:{d:{e:{f:{g:{h:{if((h|0)==v[g+92>>2]){a=rc(g+104|0,21473);if(Mc(c,b,v[a>>2],v[a+4>>2])){b=ba(8)|0;v[23296]=0;R(910,g+72|0,g+112|0);a=v[23296];v[23296]=0;if((a|0)==1){break g}v[23296]=0;U(915,g+88|0,17452,g+72|0);a=v[23296];v[23296]=0;if((a|0)==1){break f}a=0;c=sc(b,g+88|0);v[23296]=0;U(107,c|0,61592,904);c=v[23296];v[23296]=0;if((c|0)!=1){break b}c=P()|0;O()|0;yb(g+88|0);break e}if(!f){break h}b=ba(8)|0;v[23296]=0;a=Eh(g+40|0,v[g+120>>2],v[g+124>>2]);c=v[23296];v[23296]=0;i:{j:{k:{l:{m:{n:{o:{p:{if((c|0)!=1){v[23296]=0;U(915,g+56|0,17488,a|0);c=v[23296];v[23296]=0;if((c|0)==1){break p}v[23296]=0;R(917,g+72|0,g+56|0);c=v[23296];v[23296]=0;f=1;if((c|0)==1){break o}v[23296]=0;R(910,g+24|0,g+112|0);c=v[23296];v[23296]=0;if((c|0)==1){break n}v[23296]=0;U(919,g+88|0,g+72|0,g+24|0);c=v[23296];v[23296]=0;if((c|0)==1){break m}c=sc(b,g+88|0);v[23296]=0;U(107,c|0,61592,904);c=v[23296];v[23296]=0;if((c|0)!=1){break b}c=P()|0;O()|0;yb(g+88|0);f=0;break l}c=P()|0;O()|0;break d}c=P()|0;f=1;O()|0;break i}c=P()|0;O()|0;break j}c=P()|0;O()|0;break k}c=P()|0;O()|0}yb(g+24|0)}yb(g+72|0)}yb(g+56|0)}yb(a);if(f){break d}break c}f=rc(g+16|0,21473);if(Mc(c,b,v[f>>2],v[f+4>>2])){b=ba(8)|0;v[23296]=0;R(910,g+72|0,g+112|0);a=v[23296];v[23296]=0;q:{r:{if((a|0)!=1){v[23296]=0;U(915,g+88|0,17452,g+72|0);a=v[23296];v[23296]=0;if((a|0)==1){break r}a=0;c=sc(b,g+88|0);v[23296]=0;U(107,c|0,61592,904);c=v[23296];v[23296]=0;if((c|0)!=1){break b}c=P()|0;O()|0;yb(g+88|0);break q}c=P()|0;O()|0;break d}c=P()|0;a=1;O()|0}yb(g+72|0);if(a){break d}break c}f=rc(g+8|0,10833);if(Mc(c,b,v[f>>2],v[f+4>>2])){MJ(a,Ic(d,e));break h}f=b;b=rc(g,8529);if(!Mc(c,f,v[b>>2],v[b+4>>2])){break h}a=v[a+32>>2];b=Vy(d,e);b=b>>>0<4?b:1;c=jb-16|0;jb=c;s:{if((Oj(w[a+140|0])|0)==(b|0)){d=a+120|0;ns(w[d+20|0]);b=jb-16|0;jb=b;v[b+8>>2]=c+8;a=jb-16|0;jb=a;e=v[15326];v[a+8>>2]=v[15325];v[a+12>>2]=e;e=v[15324];v[a>>2]=v[15323];v[a+4>>2]=e;nb[v[jp(a,Oj(w[d+20|0]))>>2]](b+8|0,d);jb=a+16|0;jb=b+16|0;break s}tJ(a,b,uJ(a))}jb=c+16|0}jb=g+128|0;return}c=P()|0;O()|0;break d}c=P()|0;a=1;O()|0}yb(g+72|0);if(!a){break c}}ca(b|0)}S(c|0)}L()}function em(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-80|0;jb=e;h=Qb(a);v[23296]=0;a=T(266,b|0)|0;c=v[23296];v[23296]=0;a:{b:{c:{d:{e:{if((c|0)==1){break e}c=v[b+8>>2];d=v[b>>2];v[23296]=0;c=W(144,d|0,c|0,a|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break e}if(c){break d}v[23296]=0;a=T(190,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break e}v[23296]=0;Q(176,b|0,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break c}}a=P()|0;O()|0;break a}v[23296]=0;U(178,e+32|0,b|0,a|0);b=v[23296];v[23296]=0;f:{g:{h:{if((b|0)!=1){b=e+32|0;c=jc(e+56|0,b);Ab(b);if(a>>>0<10){break g}v[23296]=0;b=T(658,c|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break b}if(!b){break g}v[23296]=0;b=T(266,c|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break b}v[e+28>>2]=b;a=a-10|0;yc(e+28|0,a>>>0>25264513?-1:B(a,170));v[23296]=0;d=v[e+28>>2];R(272,h|0,d|0);a=v[23296];v[23296]=0;if((a|0)!=1){break h}break b}a=P()|0;O()|0;break a}b=0;i:while(1){f=0;j:{k:{while(1){if(f){break j}a=v[c+8>>2];f=v[c>>2];v[23296]=0;a=Q(659,f|0,a|0)|0;f=v[23296];v[23296]=0;l:{m:{n:{o:{if((f|0)!=1){if(a){break j}v[23296]=0;a=T(469,c|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break b}f=1;switch(a|0){case 3:break l;case 2:break m;case 1:break n;case 0:break o;default:continue}}break b}v[23296]=0;a=T(194,c|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}g=v[c+8>>2];i=v[c>>2];v[23296]=0;g=W(144,i|0,g|0,a|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break b}if(!g){continue}ke(e+32|0,v[h>>2],v[h+4>>2]);lq(e+16|0,v[e+32>>2],v[e+36>>2],b,a);v[23296]=0;_m(406,e+8|0,c,v[e+16>>2],v[e+20>>2]);f=v[23296];v[23296]=0;if((f|0)!=1){d=d-a|0;b=a+b|0;continue i}break b}v[23296]=0;a=T(194,c|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}g=a<<2;if(g>>>0>d>>>0){continue}v[23296]=0;i=Q(660,c|0,e+24|0)|0;j=v[23296];v[23296]=0;if((j|0)==1){break b}if(!i){continue}while(1){if(!(a&255)){break k}f=e+24|0;i=kc(f);ch(f,i,$g(Eb(v[h>>2]),b));b=b+4|0;a=a-1|0;continue}}if(d>>>0<8){continue}v[23296]=0;a=Q(660,c|0,e+24|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}if(!a){continue}a=e+24|0;f=kc(a);ch(a,f,$g(Eb(v[h>>2]),b));ch(a,f,$g($g(Eb(v[h>>2]),b),4));d=d-8|0;b=b+8|0;continue i}v[23296]=0;a=T(194,c|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}if(a>>>0>d>>>0){continue}break}d=d-a|0;b=a+b|0;continue}d=d-g|0;continue}break}if(!d){break f}a=Qb(e+32|0);xt(a,h);fc(a);break f}v[23296]=0;U(313,c|0,h|0,a|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}}Ab(c)}jb=e+80|0;return}a=P()|0;O()|0;Ab(c)}fc(h);S(a|0);L()}function ofa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;f=jb-560|0;jb=f;a:{if(!$c(b,1464)){break a}if(!no(b,f+556|0)){break a}Ed(a,1);Nb(Nb(Bf(a+1074312|0,83),84,1),85,1);b:{if(fe(f+556|0,26729)){d=f+32|0;e=Vb(d,8348);Hb(a+1298344|0,e);zb(e);e=Vb(d,14663);Hb(a+1298356|0,e);zb(e);d=Vb(d,14728);Hb(a+1298368|0,d);break b}if(!fe(f+556|0,15351)){break a}d=f+32|0;e=Vb(d,8506);Hb(a+1298344|0,e);zb(e);e=Vb(d,12130);Hb(a+1298356|0,e);zb(e);d=Vb(d,15197);Hb(a+1298368|0,d)}zb(d);v[a+1298404>>2]=13;$c(b,0);NA(b,a+1298308|0,20);u[a+480190>>1]=31;d=1;while(1)if((d|0)==32){if(g>>>0>40){break a}d=f+552|0;Ru(d,b);m=kd(d);if(w[f+552|0]>128){break a}e=f+32|0;d=jb-16|0;jb=d;c:{if(!Ob(v[b>>2],v[b+8>>2],512)){xR(e);break c}xu(d+8|0,e);qd(d,b,v[d+8>>2],v[d+12>>2])}jb=d+16|0;d=0;e=w[m|0];while(1){n=(d|0)==512;if(!n){i=(f+32|0)+d|0;d=d+1|0;if(e>>>0>=w[i|0]){continue}break a}break}if(!c){break a}v[a+480260>>2]=56;v[a+480264>>2]=13696;v[a+480204>>2]=125e4;v[a+480196>>2]=6;u[a+480192>>1]=0;u[a+480188>>1]=4;v[a+480228>>2]=64;v[a+480208>>2]=v[a+480208>>2]|18874368;xh(a,0);o=a+484376|0;kg(Zb(v[a+484360>>2],w[o|0]),w[f+552|0]);k=a+484344|0;mg(k,w[f+552|0]);e=0;while(1){if(w[f+552|0]<=e>>>0){if(!(c&2)){break a}$c(b,(w[m|0]<<8)+1468|0);d=1;while(1){if((d|0)==32){break a}c=(B(d,104)+a|0)+484380|0;if(v[c>>2]){lg(_c(f+8|0,8,1,0,0),c,b)}d=d+1|0;continue}}r=dc(v[Zb(v[a+484360>>2],w[o|0])>>2],e),s=e,u[r>>1]=s;d:{if(!bh(k,e&65535,64)){break d}l=e<<2;i=0;e:while(1){if((i|0)==4){r=f,s=Eb(v[$b(v[k>>2],e)>>2]),v[r+24>>2]=s;i=0;while(1){if((i|0)==64){break d}d=0;f:{while(1){if((d&65535)>>>0>=4){g:{t[f+31|0]=p;t[f+30|0]=q;d=h&255;if(d){break g}h=0;break f}}else{g=v[f+24>>2];h:{if((w[g+3|0]&254)!=16){break h}t[g+3|0]=16;h=0;j=w[g+5|0];if(j>>>0<16){break h}h=j>>>4|0;t[g+5|0]=h;l=h;h=j&15;g=(l|0)==(h|0)|!h;q=g?q:l;p=g?p:h;h=!g}d=d+1|0;$z(f+24|0);continue}break}qe($b(v[k>>2],e),Ke(Fe(f+8|0,16,w[(d+f|0)+29|0]),i));h=h+1|0;h=(h&255)==3?1:h}i=i+1|0;continue}}$c(b,(w[f+32+(i+l)|0]<<8)+1468|0);g=0;d=$b(v[k>>2],e);d=fd(v[d>>2],v[v[d+48>>2]+12>>2],0,i&65535);while(1)if((g|0)==64){i=i+1|0;continue e}else{ru(b,d);i:{j:{j=w[d+3|0];k:{if((j|0)!=14){if(!j){if(w[d+5|0]){break j}break k}if((j-5&255)>>>0<5){break k}break j}if(w[d+5|0]<=15){break j}}t[d+3|0]=0;break i}Of(d)}d=d+24|0;g=g+1|0;continue}}}e=e+1|0;continue}}else{g=hA(b,f+32|0,(B(d,104)+a|0)+484380|0,((d<<5)+a|0)+946304|0,1)+g|0;d=d+1|0;continue}}jb=f+560|0;return n|0}function eaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,y=0,z=0,A=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;j=jb-32|0;jb=j;r=v[a+4>>2];e=Re(v[a+8>>2],b);u=v[e>>2];a:{if(u+1>>>0<2){break a}i=(B(b,872)+r|0)+616|0;if(!(H=1,I=qi(v[i+8>>2],v[i+12>>2]),J=w[e+4|0],J?H:I)){break a}f=B(b,872)+r|0;if(!v[f+720>>2]){break a}h=v[f+704>>2]&2;e=v[(h?f+700|0:f+692|0)>>2];l=v[f+700>>2];g=v[f+696>>2];Bb(j+8|0,v[a>>2]+1074312|0,31);y=Cb(v[v[j+8>>2]>>2],v[j+12>>2]);n=ff(v[f+624>>2],v[f+628>>2],c);p=n;m=w[f+704|0]&128;n=m?0-n|0:n;k=mb;m=m?0-(k+((p|0)!=0)|0)|0:k;k=0;D=k;p=e;z=h?k:0;e=g;q=h?e:0;k=l-e|0;E=k<<1;F=f+1316|0;o=f+1467|0;A=f+1362|0;G=(w[A|0]&17)!=1;b:{while(1){if((s|0)==(u|0)){break b}c:{if(d>>>0>s>>>0){g=(w[A|0]&17)==1;break c}t[o|0]=w[o|0]&254;g=v[a>>2];e=v[a+4>>2];h=$b(v[g+484344>>2],x[e+70>>1]);e=fd(v[h>>2],v[v[h+48>>2]+12>>2],v[e+48>>2],b);h=w[e+3|0];if(w[e+2|0]==11){l=j+8|0;Ny(l,g,h,w[e+4|0],0);l=Ue(l);On(v[a>>2],i,x[j+8>>1]);g=1;if(w[l|0]){break c}}g=1;d:{switch(h-4|0){case 0:On(v[a>>2],i,w[e+5|0]);break c;case 2:break d;default:break c}}On(v[a>>2],i,0)}v[j+28>>2]=v[F>>2];if(y){Zs(v[a>>2],i)}if(!G){kN(v[a>>2],i,j+28|0);g=1}if(!y){Zs(v[a>>2],i)}v[j+24>>2]=0;jN(i,j+24|0);e:{f:{if(w[f+705|0]&2){break f}g:{if(!g){if(!w[Re(v[a+8>>2],b)+4|0]){break g}}if(w[o|0]&96){hP(i,C(1),0,v[a>>2]);e=w[o|0];t[o|0]=(e&64?-65:-33)&e}Qy(j+8|0,v[a>>2],i,v[j+28>>2],0);e=v[j+12>>2];v[f+624>>2]=v[j+8>>2];v[f+628>>2]=e;H=Re(v[a+8>>2],b),I=0,t[H+4|0]=I;e=ff(v[f+624>>2],v[f+628>>2],c);g=w[f+704|0]&128;n=g?0-e|0:e;h=mb;m=g?0-(h+((e|0)!=0)|0)|0:h}Sb(i,n,m);l=v[i>>2];e=v[i+4>>2];if((l>>>0<D>>>0&(e|0)<=(p|0)|(e|0)<(p|0))&((e|0)>=(q|0)&l>>>0>=z>>>0|(e|0)>(q|0)|((m|0)>0|(m|0)>=0))){break f}h=v[f+704>>2];if(!(h&2)){break e}if(h&4){g=v[f+696>>2];if(l>>>0<z>>>0&(e|0)<=(q|0)|(e|0)<(q|0)){H=i,I=Gg(0,g<<1,l,e),v[H>>2]=I;e=mb;v[i+4>>2]=e;v[f+704>>2]=h^128;h=n;n=0-h|0;m=0-(((h|0)!=0)+m|0)|0}Bb(j+8|0,v[a>>2]+1074312|0,33);e=(e-g>>>0)%(E-Cb(v[v[j+8>>2]>>2],v[j+12>>2])>>>0)|0;h:{if(e>>>0<k>>>0){g=e+v[f+696>>2]|0;break h}g=v[f+700>>2]+(k-e|0)|0}v[i+4>>2]=g;g=v[f+704>>2];if((g&128)>>>7^e>>>0<k>>>0){break f}v[f+704>>2]=g^128;e=n;n=0-e|0;m=0-(((e|0)!=0)+m|0)|0;break f}g=e;h=v[f+700>>2];if(e>>>0>=h+k>>>0){g=h+((g-h>>>0)%(k>>>0)|0)|0}while(1){e=g;g=e-k|0;if(e>>>0>=h>>>0){continue}break}v[i>>2]=l;v[i+4>>2]=e}s=s+1|0;continue}break}lP(i);v[(B(b,872)+r|0)+1324>>2]=0}H=Re(v[a+8>>2],b),I=0,v[H>>2]=I}jb=j+32|0}function X1(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0,g=0;d=jb-192|0;jb=d;v[d+184>>2]=c;a:{b:{c:{if(b>=.8){v[23296]=0;e=ga(1025)|0;f=v[23296];v[23296]=0;d:{e:{f:{if((f|0)!=1){v[d+80>>2]=e;v[23296]=0;c=T(1026,c|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break e}v[d+176>>2]=c;zn(e,c);a=ie(d+152|0,a);v[23296]=0;f=v[a+12>>2];c=d- -64|0;v[c>>2]=v[a+8>>2];v[c+4>>2]=f;v[d+72>>2]=v[a+16>>2];c=v[a+4>>2];v[d+56>>2]=v[a>>2];v[d+60>>2]=c;a=W(1018,e|0,d+56|0,15)|0;c=v[23296];v[23296]=0;if((c|0)==1){break f}if(a){v[23296]=0;Y(766,e|0);a=v[23296];v[23296]=0;g=1;if((a|0)==1){break f}}cj(d+176|0);dj(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;cj(d+176|0);break d}c=V(0)|0;O()|0}dj(d+80|0);break c}if(b>=.6){v[23296]=0;e=ga(1025)|0;f=v[23296];v[23296]=0;g:{h:{i:{if((f|0)!=1){v[d+80>>2]=e;v[23296]=0;c=T(1026,c|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break h}v[d+176>>2]=c;zn(e,c);a=ie(d+128|0,a);v[23296]=0;c=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=c;v[d+48>>2]=v[a+16>>2];c=v[a+4>>2];v[d+32>>2]=v[a>>2];v[d+36>>2]=c;a=W(1018,e|0,d+32|0,2)|0;c=v[23296];v[23296]=0;if((c|0)==1){break i}if(a){v[23296]=0;Y(766,e|0);a=v[23296];v[23296]=0;g=.8;if((a|0)==1){break i}}cj(d+176|0);dj(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;cj(d+176|0);break g}c=V(0)|0;O()|0}dj(d+80|0);break c}g=.2;if(b>=.2){v[23296]=0;e=ga(1025)|0;f=v[23296];v[23296]=0;j:{k:{l:{if((f|0)!=1){v[d+80>>2]=e;v[23296]=0;c=T(1026,c|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break k}v[d+176>>2]=c;zn(e,c);a=ie(d+104|0,a);v[23296]=0;c=v[a+12>>2];v[d+16>>2]=v[a+8>>2];v[d+20>>2]=c;v[d+24>>2]=v[a+16>>2];c=v[a+4>>2];v[d+8>>2]=v[a>>2];v[d+12>>2]=c;a=W(1018,e|0,d+8|0,0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break l}g=0;if(a){v[23296]=0;Y(766,e|0);a=v[23296];v[23296]=0;g=.6;if((a|0)==1){break l}}cj(d+176|0);dj(d+80|0);break b}c=V(0)|0;O()|0;break c}c=V(0)|0;O()|0;cj(d+176|0);break j}c=V(0)|0;O()|0}dj(d+80|0);break c}if(!(b>=.1)){break b}v[23296]=0;U(191,d+80|0,a|0,2048);c=v[23296];v[23296]=0;if((c|0)!=1){c=ye(d+80|0);a=v[a>>2];v[23296]=0;e=v[d+80>>2];a=T(148,a|0)|0;f=v[23296];v[23296]=0;m:{if((f|0)==1){break m}v[23296]=0;a=YE(1027,c,e,a,0);c=v[23296];v[23296]=0;if((c|0)==1){break m}g=A[(a<<3)+61320>>3];Pc(d+80|0);break b}c=V(0)|0;O()|0;Pc(d+80|0);break c}c=V(0)|0;O()|0}_(c|0)|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;g=0;if((a|0)==1){break a}}te(d+184|0);jb=d+192|0;return+g}a=P()|0;O()|0;te(d+184|0);S(a|0);L()}function dda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb+-64|0;jb=d;u[d+62>>1]=c;ug(d+62|0,32);j=Qb(a);v[23296]=0;o=x[d+62>>1];R(473,j|0,o|0);a=v[23296];v[23296]=0;a:{b:{if((a|0)!=1){k=b+480190|0;p=b+480192|0;c:{d:{while(1){if((q&65535)>>>0>=o>>>0){break d}e=1;c=x[k>>1];a=c+1|0;u[d+60>>1]=a;e:{f:{g:{if((a&65535)>>>0<4e3){break g}h:{while(1){f=e&65535;if(f>>>0>c>>>0){break h}i:{g=$j(b,f);if(!Ud(v[g>>2],v[g+20>>2])){if(!Rb(aA(Eb(v[j>>2]),Eb(v[j+4>>2]),e),Eb(v[j+4>>2]))){break i}c=x[k>>1]}e=e+1|0;continue}break}u[d+60>>1]=e;a=1;while(1){if(x[p>>1]<a>>>0){a=e;break h}j:{c=v[((a<<2)+b|0)+900380>>2];if(!c){break j}c=c+236|0;g=hq(c);while(1){if((c|0)==(g|0)){break j}if((f|0)==x[c>>1]){u[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}}if((a&65535)>>>0<4e3){break g}e=bo(d+48|0);v[23296]=0;a=Q(698,b|0,e|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break b}if(!a){break e}v[23296]=0;R(699,b|0,e|0);c=v[23296];v[23296]=0;a=1;if((c|0)==1){break b}while(1){c=a&65535;if(c>>>0<=x[p>>1]){k:{c=v[((c<<2)+b|0)+900380>>2];if(!c){break k}c=c+236|0;f=hq(c);while(1){if((c|0)==(f|0)){break k}g=x[c>>1];l:{if(g>>>0>=y[d+52>>2]){break l}Bb(d+40|0,v[e>>2],g);if(Cb(v[v[d+40>>2]>>2],v[d+44>>2])){break l}u[c>>1]=0}c=c+2|0;continue}}a=a+1|0;continue}break}$k(d+24|0,v[e>>2]);xP(d+32|0,v[d+24>>2],v[d+28>>2],1);gm(d+16|0,v[e>>2],v[d+52>>2]);m=jb-16|0;jb=m;g=d+40|0;c=gc(m,v[d+32>>2],v[d+36>>2]);a=_k(v[d+16>>2],v[d+20>>2],v[d+32>>2],v[d+36>>2]);f=jb-16|0;jb=f;v[f+12>>2]=a;h=v[c+4>>2];m:{if(h){i=32-h|0;v[f+8>>2]=i;n=v[Ib(f+8|0,f+12|0)>>2];l=-1<<h&-1>>>i-n;i=v[c>>2];l=l&(v[i>>2]^-1);if(l){gc(g,i,Ria(l));break m}if((a|0)==(n|0)){xP(g,i,h,a);break m}a=a-n|0;v[f+12>>2]=a;v[c>>2]=i+4}while(1){if(a>>>0>=32){h=v[c>>2];i=v[h>>2];if((i|0)!=-1){gc(g,h,Ria(i^-1));break m}else{v[c>>2]=h+4;a=a-32|0;v[f+12>>2]=a;continue}}break}if(!a){gc(g,v[c>>2],0);break m}c=v[c>>2];h=(v[c>>2]^-1)&-1>>>32-a;if(!h){gc(g,c,a);break m}gc(g,c,Ria(h))}jb=f+16|0;jb=m+16|0;$k(d+8|0,v[e>>2]);a=_k(v[d+40>>2],v[d+44>>2],v[d+8>>2],v[d+12>>2]);u[d+60>>1]=a;Le(e);if((a&65535)>>>0>3999){break f}}v[23296]=0;R(245,j|0,d+60|0);c=v[23296];v[23296]=0;if((c|0)==1){break c}if(x[k>>1]>=(a&65535)>>>0){break f}u[k>>1]=a}q=q+1|0;continue}break}Le(e)}jb=d- -64|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;Le(e)}ud(j);S(c|0);L()}function v2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=jb-192|0;jb=d;h=kJ(d+176|0);v[h>>2]=49284;Qb(h+4|0);zn(v[a+24>>2],h);e=v[a+24>>2];i=w[a+62|0];f=w[a+61|0];g=w[a+60|0];b=ie(d+152|0,b);v[23296]=0;j=v[b+12>>2];v[d+16>>2]=v[b+8>>2];v[d+20>>2]=j;v[d+24>>2]=v[b+16>>2];j=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=j;b=g?13:15;b=f?b&14:b;b=W(1018,e|0,d+8|0,(i?b&3:b)|0)|0;e=v[23296];v[23296]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}if(!b){b=ba(8)|0;v[23296]=0;c=Q(54,d+136|0,11868)|0;a=v[23296];v[23296]=0;if((a|0)!=1){a=sc(b,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=P()|0;O()|0;ca(b|0);break b}if(!w[a+63|0]){v[23296]=0;R(1019,a|0,a+36|0);b=v[23296];v[23296]=0;if((b|0)==1){break e}}t[a+28|0]=1;zn(v[a+24>>2],v[a+4>>2]);v[23296]=0;R(1020,d+136|0,h|0);b=v[23296];v[23296]=0;if((b|0)==1){break c}k=d,l=Eb(v[d+136>>2]),v[k+128>>2]=l;e=a+68|0;i=Eb(v[d+140>>2]);f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{while(1){b=v[d+128>>2];if(!Rb(b,i)){k=d,l=qj(v[c>>2]),v[k+112>>2]=l;c=yf(c);while(1){b=v[d+112>>2];if(!Ag(b,c)){break d}v[23296]=0;e=vd(b);b=Q(53,d+32|0,e|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break h}v[23296]=0;X(916,a|0,b|0,e+12|0,0);e=v[23296];v[23296]=0;if((e|0)==1){break g}yb(b);Xg(d+112|0);continue}}f=v[a+24>>2];g=v[b>>2];v[23296]=0;j=f;f=b+4|0;U(1021,j|0,g|0,f|0);g=v[23296];v[23296]=0;if((g|0)!=1){b=v[b>>2];v[23296]=0;R(1022,d- -64|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break r}v[23296]=0;R(962,d+80|0,d- -64|0);b=v[23296];v[23296]=0;if((b|0)==1){break q}v[23296]=0;b=Q(54,d+48|0,17588)|0;g=v[23296];v[23296]=0;if((g|0)==1){break p}v[23296]=0;U(919,d+96|0,d+80|0,b|0);g=v[23296];v[23296]=0;if((g|0)==1){break o}v[23296]=0;U(479,d+112|0,d+96|0,f|0);f=v[23296];v[23296]=0;if((f|0)==1){break n}v[23296]=0;R(171,e|0,d+112|0);f=v[23296];v[23296]=0;if((f|0)==1){break m}yb(d+112|0);yb(d+96|0);yb(b);yb(d+80|0);zb(d- -64|0);eo(d+128|0);continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;break l}a=P()|0;O()|0;yb(d+112|0)}yb(d+96|0)}yb(b)}yb(d+80|0)}zb(d- -64|0);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;yb(b)}nx(d+136|0);break b}a=P()|0;O()|0;break b}nx(d+136|0);ks(h);jb=d+192|0;return}a=P()|0;O()|0}ks(h);S(a|0)}L()}function cY(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-320|0;jb=d;e=jb-16|0;jb=e;v[a>>2]=0;f=a+32|0;gn(f,32);t[e+15|0]=0;fn(f,e+15|0);jb=e+16|0;e=v[a+28>>2];a:{if(!Kg(v[v[e>>2]-12>>2]+e|0)){kh(a,1073741825);break a}f=d+56|0;ae(f,e);e=v[f+12>>2];v[a+8>>2]=v[f+8>>2];v[a+12>>2]=e;v[f>>2]=3;h=v[a+28>>2];g=d+16|0;e=0;while(1){if(y[f>>2]>e>>>0){di(h,e+g|0);e=e+1|0;continue}break}if(Pb(g,25808,3)){kh(a,1073741827);break a}t[d+319|0]=0;di(v[a+28>>2],d+319|0);Xb(d+56|0,0,256);e=w[d+319|0];if(e){Bk(v[a+28>>2],d+56|0,e)}f=b;b=$m(d+16|0,d+56|0,e);e=aw(f,b);Tb(b);if(!e){kh(a,1073741830)}if(w[a+3|0]&64){break a}di(v[a+28>>2],d+55|0);b=w[d+55|0];e=b&3;u[a+16>>1]=(e|0)==3?4:e;if(Ni(b,6)){sk(a,9,1)}v[d+48>>2]=0;$E(v[a+28>>2],d+48|0);f=v[d+48>>2];t[d+47|0]=0;if(f>>>0>=2){di(v[a+28>>2],d+55|0);e=-1;if(!w[d+55|0]){di(v[a+28>>2],d+47|0);e=-2}Gl(v[a+28>>2],e+f|0)}v[d+32>>2]=0;v[d+36>>2]=0;b:{if(!Ni(b,4)){break b}rk(v[a+28>>2],d+32|0);e=v[d+36>>2];f=v[d+32>>2];v[a+56>>2]=f;v[a+60>>2]=e;g=v[c+4>>2];if((g|0)==(e|0)&y[c>>2]>=f>>>0|e>>>0<g>>>0){break b}kh(a,536871424)}if(Ni(b,5)){di(v[a+28>>2],d+55|0);Gl(v[a+28>>2],w[d+55|0])}e=w[d+47|0];c:{if(!Ni(e,0)){break c}di(v[a+28>>2],d+55|0);c=w[d+55|0];c=c&1?-1:c>>>1|0;u[a+16>>1]=c;if(c){break c}kh(a,536871168)}v[a+4>>2]=0;c=1;if(Ni(e,1)){$E(v[a+28>>2],a+4|0)}sk(a,6,Ni(b,2));sk(a,7,Ni(b,3));sk(a,5,x[a+16>>1]!=0);sk(a,8,Ni(b,7));d:{if(hd(a,5)){break d}if(hd(a,6)){break d}if(hd(a,7)){break d}c=hd(a,8)}sk(a,11,c);hd(a,11);if(Ni(e,2)){u[d+16>>1]=0;Yv(v[a+28>>2],d+16|0);Gl(v[a+28>>2],B(x[d+16>>1],hd(a,9)?2:1))}if(Ni(e,3)){Gl(v[a+28>>2],5)}rk(v[a+28>>2],d+32|0);c=v[d+36>>2];b=v[d+32>>2];if(!c&b>>>0>=16001|c){kh(a,1073741831);break a}v[a+92>>2]=b;if(!b){kh(a,536871040)}e:{if(!hd(a,11)){break e}rk(v[a+28>>2],d+32|0);b=v[d+32>>2];c=v[d+36>>2];if((c|0)>0|(c|0)>=0){break e}kh(a,1073741829);break a}ae(d,v[a+28>>2]);c=v[a+8>>2];e=v[a+12>>2];f=v[d+4>>2];v[d+16>>2]=v[d>>2];v[d+20>>2]=f;f=v[d+12>>2];v[d+24>>2]=v[d+8>>2];v[d+28>>2]=f;f=v[d+24>>2];e=v[d+28>>2]-(e+(c>>>0>f>>>0)|0)|0;v[d+24>>2]=f-c;v[d+28>>2]=e;c=v[d+24>>2];e=v[d+28>>2];if((e|0)==1|e>>>0>1){kh(a,1073741832);break a}v[a+88>>2]=c;c=hd(a,11);v[a+64>>2]=c?b:v[a+88>>2];if(!hd(a,11)){b=v[a+12>>2];e=v[a+88>>2];c=e+v[a+8>>2]|0;v[a+72>>2]=c;v[a+76>>2]=c>>>0<e>>>0?b+1|0:b}sk(a,10,1)}jb=d+320|0}function Kea(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;g=jb-16|0;jb=g;a:{if(!Ob(v[a>>2],v[a+8>>2],2)){bh(c+484344|0,b,64);break a}l=c+484344|0;m=Xd(yq(a),1,1024);if(!bh(l,b,m)){break a}p=x[c+480188>>1];q=c+480190|0;b:while(1){if((k|0)==(m|0)){break a}i=0;e=$b(v[l>>2],b);n=Qf(v[e>>2],v[v[e+48>>2]+12>>2],k);while(1)if((i|0)==(p|0)){k=k+1|0;continue b}else{f=g+8|0;zm(f,a);e=B(i,6)+n|0;r=Ue(f);f=Ci(f);h=w[g+8|0];c:{if((h-1&255)>>>0>35){break c}t[e|0]=h+48;o=w[kd(g+8|0)|0];h=o+1|0;t[e+1|0]=h;j=h;h=h&255;if((j|0)!=(h|0)|h>>>0>x[q>>1]){break c}h=$j(c,h);j=Lb(d,i);if(!(!w[j|0]|x[h+30>>1]>255)){t[e+4|0]=64;t[e+2|0]=1}h=v[Db(h+68|0,0)>>2];if(!(w[j|0]|h?w[j|0]?(h|0)==1:0:1)){break c}t[e+1|0]=o+101}d:{e:{switch(w[r|0]){case 1:if(!w[f|0]){break d}t[e+3|0]=2;t[e+5|0]=w[f|0];break d;case 2:if(!w[f|0]){break d}t[e+3|0]=3;t[e+5|0]=w[f|0];break d;case 12:if(!w[f|0]){break d}t[e+3|0]=1;t[e+5|0]=w[f|0];break d;case 13:if(!w[f|0]){break d}t[e+3|0]=39;t[g+7|0]=15;s=e,u=w[Wb(g+7|0,f)|0]|16,t[s+5|0]=u;break d;case 30:if(!w[f|0]){break d}t[e+3|0]=38;t[g+6|0]=15;s=e,u=w[Wb(g+6|0,f)|0]|16,t[s+5|0]=u;break d;case 21:if(!w[f|0]){break d}t[e+3|0]=39;t[g+5|0]=15;s=e,u=w[Wb(g+5|0,f)|0]|80,t[s+5|0]=u;break d;case 17:if(!w[f|0]){break d}t[e+3|0]=38;t[g+4|0]=15;s=e,u=w[Wb(g+4|0,f)|0]|80,t[s+5|0]=u;break d;case 15:t[e+3|0]=19;t[e+5|0]=w[f|0]!=0;break d;case 25:t[e+3|0]=12;t[e+5|0]=w[f|0];break d;case 27:fo(e);t[e|0]=255;break d;case 28:if(w[f|0]>31){break d}t[e+3|0]=16;t[e+5|0]=w[f|0];break d;case 31:h=w[f|0];if(h&15){s=e,u=w[Lb(d,i)|0]?22:11,t[s+3|0]=u;t[e+5|0]=w[f|0]&15;h=w[f|0]}f:{g:{switch(h>>>4|0){case 4:if((h|0)!=64){break f}case 0:case 1:case 2:case 3:if(w[Lb(d,i)|0]){t[e+3|0]=21;t[e+5|0]=w[f|0];break f}t[e+2|0]=1;f=w[f|0];t[e+3|0]=0;t[e+4|0]=f;break f;case 5:t[e+5|0]=w[e+5|0]<<4;break f;case 6:t[g+3|0]=w[e+5|0];t[g+2|0]=14;s=e,u=w[Wb(g+3|0,g+2|0)|0]|240,t[s+5|0]=u;break f;case 7:t[g+1|0]=w[e+5|0];t[g|0]=14;s=e,u=w[Wb(g+1|0,g)|0]<<4|15,t[s+5|0]=u;break f;default:break g}}t[e+3|0]=0}if((w[e+3|0]-21&255)>>>0>1){break d}f=B(t[Lb(d,i)|0]+i|0,6)+n|0;if(Dq(f+3|0,f+5|0,1)){t[f+2|0]=w[f+3|0];t[f+4|0]=w[f+5|0]}t[f+3|0]=w[e+3|0];t[f+5|0]=w[e+5|0];break d;case 0:break d;default:break e}}t[e+3|0]=0}i=i+1|0;continue}}}jb=g+16|0}function Xfa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=jb-32|0;jb=e;a:{b:{if(!c){break b}s=e,u=Ee(a),t[s+16|0]=u;fn(b,e+16|0);k=c-1|0;c=0;while(1){g=1;if(!k){break a}c:{d:{d=c<<1;c=d&254;if(!c){if(!bf(a,e+16|0)){break b}i=1;d=w[e+16|0]<<1|1;c=d&255;if(d>>>0<=255){break d}break c}if((d&65535)>>>0<=255){break d}i=1;break c}if(!bf(a,e+16|0)){break b}HT(b,e+16|0);k=k-1|0;continue}while(1){e:{f:{g:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!bf(a,e+16|0)){break g}c=w[e+16|0]<<1|1;d=c&255;c=c>>>0>255}i=Vp(i,1)+c|0;c=d<<1&254;if(c){break f}if(!bf(a,e+16|0)){break g}d=w[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break e}c=0;break e}if(d>>>0>127){continue}}break}h:{if((i|0)<=2){j=0;h=i-2|0;break h}if(!bf(a,e+16|0)){break b}d=Vp(i-3|0,8)|w[e+16|0];j=((d|0)>1279?2:1)+((d|0)>31999)|0;n=d^-1;h=0}d=c<<1&254;if(d){f=c>>>0>127}else{if(!bf(a,e+16|0)){break b}c=w[e+16|0]<<1|1;d=c&255;f=c>>>0>255}g=Vp(h,1);c=d<<1&254;if(c){d=d>>>0>127}else{if(!bf(a,e+16|0)){break b}d=w[e+16|0]<<1|1;c=d&255;d=d>>>0>255}i=1;h=k;d=Vp(f+g|0,1)+d|0;if(!d){while(1){i:{j:{k:{d=c<<1&254;if(d){c=(c&65535)>>>0>127}else{if(!bf(a,e+16|0)){break k}c=w[e+16|0]<<1|1;d=c&255;c=c>>>0>255}i=Vp(i,1)+c|0;c=d<<1&254;if(c){break j}if(!bf(a,e+16|0)){break k}d=w[e+16|0]<<1|1;c=d&255;if(d>>>0>255){continue}break i}c=0;break i}if(d>>>0>127){continue}}break}d=i+2|0}f=h;h=d+j|0;g=0;if(f>>>0<h>>>0|(h|0)<=0|(n|0)>=0){break a}d=v[b+4>>2];g=0;if((0-ad(v[b>>2],d)|0)>(n|0)){break a}d=hc(e+24|0,Eb(d));t[e+16|0]=0;l=e+16|0;o=jb-32|0;jb=o;f=v[d>>2];d=v[b>>2];j=Xe(f,Eb(d))+d|0;f=v[Gb(b)>>2];g=v[b+4>>2];l:{if(h>>>0<=f-g>>>0){d=h;f=g-j|0;if(d>>>0>f>>>0){Do(b,h-f|0,l);d=f;if(!d){break l}}p=jb-16|0;jb=p;f=g;r=v[b+4>>2];g=(r-(h+j|0)|0)+j|0;q=uk(p,b,f-g|0);m=v[q+4>>2];i=g;while(1){if(i>>>0>=f>>>0){lc(q);kq(j,g,r);jb=p+16|0}else{Hj(m,w[i|0]);m=m+1|0;v[q+4>>2]=m;i=i+1|0;continue}break}Yh(j,d,(j>>>0<=l>>>0?y[b+4>>2]>l>>>0?h:0:0)+l|0);break l}d=Gb(b);d=Bl(o+8|0,zl(b,ad(v[b>>2],g)+h|0),j-v[b>>2]|0,d);KS(d,h,l);j=IT(b,d,j);Al(d)}Eb(j);jb=o+32|0;s=e,u=$g(WR(Eb(v[b+4>>2]),h),n),v[s+16>>2]=u;s=e,u=WR(Eb(v[b+4>>2]),h),v[s+8>>2]=u;d=h;while(1){f=w[VR(e+16|0)|0];s=VR(e+8|0),u=f,t[s|0]=u;f=d>>>0>1;d=d-1|0;if(f){continue}break}k=k-h|0;continue}}g=0}f=g;jb=e+32|0;return f|0}function X8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-48|0;jb=c;a:{b:{if(!Rb(v[b>>2],v[b+4>>2])){break b}l=v[b+12>>2];k=Eg(v[v[b+48>>2]+12>>2]);d=k;f=c+32|0;v[f>>2]=0;v[f+4>>2]=0;Cc(f+8|0);if(d){cu(f,d);g=jb-16|0;jb=g;e=oq(g,f,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){lc(e);jb=g+16|0}else{wh(d);d=d+6|0;v[e+4>>2]=d;continue}break}}while(1){c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{r:{if(j>>>0>=l>>>0){break r}if(!Kg(v[v[a>>2]-12>>2]+a|0)){break r}v[23296]=0;t[c+31|0]=0;Q(828,a|0,c+31|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}d=t[c+31|0];if(!d){j=j+1|0;continue}t[c+30|0]=0;s:{if((d|0)>=0){break s}v[23296]=0;Q(828,a|0,c+30|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break s}break a}t[c+29|0]=0;wh(c+16|0);t:{d=d&127;g=(d?d-1|0:0)&65535;i=g>>>0>=k>>>0;u:{v:{if(!i){h=fd(v[b>>2],v[v[b+48>>2]+12>>2],j,g);d=w[c+30|0];if(d&1){break v}e=Dd(v[f>>2],g);break u}h=c+16|0;d=w[c+30|0];if(!(d&1)){break t}}v[23296]=0;Q(828,a|0,c+29|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break a}if(i){break t}e=Dd(v[f>>2],g);t[e|0]=w[c+29|0]}t[h|0]=w[e|0];d=w[c+30|0];if(!(d&2)){break p}break q}if(d&2){break q}break o}gk(f);break b}v[23296]=0;Q(828,a|0,c+29|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break a}if(i){break o}e=Dd(v[f>>2],g);t[e+1|0]=w[c+29|0]}t[h+1|0]=w[e+1|0];if(d&4){break n}break m}if(!(d&4)){break l}}v[23296]=0;Q(828,a|0,c+29|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break a}if(i){break l}e=Dd(v[f>>2],g);t[e+2|0]=w[c+29|0]}t[h+2|0]=w[e+2|0];if(!(d&8)){break j}break k}if(!(d&8)){break i}}v[23296]=0;Q(828,a|0,c+29|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break a}if(i){break i}e=Dd(v[f>>2],g);t[e+4|0]=w[c+29|0]}t[h+4|0]=w[e+4|0];if(d&16){break h}break g}if(!(d&16)){break f}}v[23296]=0;Q(828,a|0,c+29|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break a}if(i){break f}e=Dd(v[f>>2],g);t[e+3|0]=w[c+29|0]}t[h+3|0]=w[e+3|0];if(!(d&32)){break d}break e}if(!(d&32)){break c}}v[23296]=0;Q(828,a|0,c+29|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break a}if(i){break c}e=Dd(v[f>>2],g);t[e+5|0]=w[c+29|0]}t[h+5|0]=w[e+5|0]}if(!(d&64)){continue}v[23296]=0;Q(828,a|0,c+15|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){v[23296]=0;Q(829,a|0,w[c+15|0])|0;d=v[23296];v[23296]=0;if((d|0)!=1){continue}}break}break a}jb=c+48|0;return}a=P()|0;O()|0;gk(f);S(a|0);L()}function x5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-128|0;jb=e;v[e+124>>2]=c;v[e+120>>2]=b;a:{if(!c){break a}f=w[Kk(b,c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Tk(e+96|0,b,c,c-1|0);b=v[e+100>>2];v[e+120>>2]=v[e+96>>2];v[e+124>>2]=b}c=e+96|0;Qd(c);b=v[e+96>>2];Qd(e+80|0);b=Jk(b,v[e+84>>2],e+120|0);Qd(c);b:{c:{d:{e:{if((b|0)==v[e+100>>2]){b=v[e+120>>2];c=v[e+124>>2];a=rc(e+112|0,21473);if(Mc(b,c,v[a>>2],v[a+4>>2])){a=ba(8)|0;v[23296]=0;b=Q(54,e+96|0,10374)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}b=0;if(!d){break e}b=ba(8)|0;v[23296]=0;d=Eh(e+80|0,v[e+120>>2],v[e+124>>2]);a=v[23296];v[23296]=0;f:{g:{h:{if((a|0)!=1){v[23296]=0;U(915,e+96|0,17488,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}a=0;c=sc(b,e+96|0);v[23296]=0;U(107,c|0,61592,904);c=v[23296];v[23296]=0;if((c|0)!=1){break b}c=P()|0;O()|0;yb(e+96|0);break g}c=P()|0;O()|0;break f}c=P()|0;a=1;O()|0}yb(d);if(!a){break c}}ca(b|0);break c}if(v[b+4>>2]){a=ba(8)|0;v[23296]=0;b=Q(54,e+96|0,11442)|0;c=v[23296];v[23296]=0;if((c|0)!=1){a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;ca(a|0);break c}c=v[e+120>>2];d=v[e+124>>2];b=rc(e+72|0,21473);if(Mc(c,d,v[b>>2],v[b+4>>2])){a=ba(8)|0;v[23296]=0;b=Q(54,e+96|0,10374)|0;c=v[23296];v[23296]=0;if((c|0)!=1){a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;ca(a|0);break c}i:{b=rc(e- -64|0,7380);if(!Mc(c,d,v[b>>2],v[b+4>>2])){b=rc(e+56|0,7362);if(!Mc(c,d,v[b>>2],v[b+4>>2])){break i}}b=w[a+60|0]!=0;break e}j:{b=rc(e+48|0,6895);if(!Mc(c,d,v[b>>2],v[b+4>>2])){b=rc(e+40|0,6876);if(!Mc(c,d,v[b>>2],v[b+4>>2])){break j}}b=w[a+61|0]!=0;break e}b=rc(e+32|0,6979);if(Mc(c,d,v[b>>2],v[b+4>>2])){b=w[a+62|0]!=0;break e}b=rc(e+24|0,6025);if(Mc(c,d,v[b>>2],v[b+4>>2])){b=w[a+63|0]!=0;break e}b=rc(e+16|0,7429);if(Mc(c,d,v[b>>2],v[b+4>>2])){b=w[a+64|0]!=0;break e}f=c;c=rc(e+8|0,13234);b=0;if(!Mc(f,d,v[c>>2],v[c+4>>2])){break e}b=v[v[a+24>>2]+24668>>2]!=0}jb=e+128|0;return b|0}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function FV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=jb-384|0;jb=f;Ac(b);d=jb-16|0;jb=d;h=f+344|0;AC(d+8|0,h);e=v[d+12>>2];nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2]);i=v[d+4>>2];if((i|0)==(e|0)){ac(b,v[d+12>>2])}jb=d+16|0;d=(e|0)==(i|0);if(!d){zC(h)}a:{if(!d){break a}if(!CC(f+344|0)){break a}if(!Ob(v[b>>2],v[b+8>>2],Vc(BC(w[f+379|0]),mb))){break a}b:{if(!c){break b}Ed(a,2097152);Dg(a);xh(a,1);u[a+480188>>1]=8;v[a+480196>>2]=w[f+376|0];v[a+480204>>2]=B(w[f+377|0],1e4);j=a+480190|0;u[j>>1]=w[f+378|0];d=w[f+381|0];if(d>>>0<w[f+380|0]){_e(Zb(v[a+484360>>2],w[a+484376|0]),d)}d=f+80|0;g=Vb(d,6480);Hb(a+1298344|0,g);zb(g);g=Vb(d,11008);Hb(a+1298356|0,g);zb(g);v[a+1298404>>2]=5;Su(b,d);Kq(Zb(v[a+484360>>2],w[a+484376|0]),d,w[f+380|0],65535,65535);g=1;while(1){i=g&65535;if(i>>>0>x[j>>1]){ac(b,B(64-w[f+378|0]|0,37));h=a+484344|0;mg(h,w[f+379|0]);i=c&1;g=0;while(1){if(w[f+379|0]<=g>>>0){if(!(c&2)){break b}c=_c(f+40|0,8,1,0,0);d=a+480190|0;g=1;while(1){e=g&65535;if(e>>>0>x[d>>1]){break b}lg(c,(B(e,104)+a|0)+484380|0,b);g=g+1|0;continue}}c:{d:{if(i){if(bh(h,g&65535,64)){break d}}ac(b,2048);break c}d=$b(v[h>>2],g);n=f,o=Eb(v[d>>2]),v[n+40>>2]=o;j=Eb(v[d+4>>2]);while(1){d=v[f+40>>2];if(!Rb(d,j)){break c}e=f+24|0;zm(e,b);k=kd(e);m=Ue(e);e=Ci(e);l=w[f+24|0];if((l-1&255)>>>0<=106){t[d|0]=l+13}t[d+1|0]=w[k|0];t[d+3|0]=w[m|0];t[d+5|0]=w[e|0];Of(d);kk(f+40|0);continue}}g=g+1|0;continue}}else{d=f+40|0;yC(b,d);h=jb-16|0;jb=h;e=(B(i,104)+a|0)+484380|0;pd(e,0);t[e+37|0]=w[d+22|0]<<4;t[h+15|0]=w[d+23|0];t[h+14|0]=64;n=e,o=w[Wb(h+15|0,h+14|0)|0]<<2,u[n+30>>1]=o;t[e+36|0]=w[d+24|0];v[e>>2]=w[d+25|0]|w[d+26|0]<<8|(w[d+27|0]<<16|w[d+28|0]<<24);k=w[d+33|0]|w[d+34|0]<<8|(w[d+35|0]<<16|w[d+36|0]<<24);if(!(k>>>0<3|k+(w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24))>>>0>(w[d+25|0]|w[d+26|0]<<8|(w[d+27|0]<<16|w[d+28|0]<<24))>>>0)){u[e+34>>1]=x[e+34>>1]|2;v[e+4>>2]=w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24);v[e+8>>2]=(w[d+33|0]|w[d+34|0]<<8|(w[d+35|0]<<16|w[d+36|0]<<24))+(w[d+29|0]|w[d+30|0]<<8|(w[d+31|0]<<16|w[d+32|0]<<24))}jb=h+16|0;e=f+8|0;jl(e,2,d);d=f+24|0;Gc(d,e);Ec(((i<<5)+a|0)+946304|0,d);g=g+1|0;yb(d);continue}}}g=1}jb=f+384|0;return g|0}function k9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=jb-16|0;jb=h;f=v[a+8>>2];e=v[a>>2];v[23296]=0;f=Q(551,e|0,f|0)|0;e=v[23296];v[23296]=0;a:{b:{if((e|0)!=1){if(f){break b}v[23296]=0;f=T(194,a|0)|0;e=v[23296];v[23296]=0;c:{if((e|0)==1){break c}v[23296]=0;j=d+484344|0;k=Xd(f+1|0,1,1024);f=W(214,j|0,b|0,k|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break c}if(!f){break b}d=x[d+480188>>1];if(!d){break b}l=d-1|0;d=0;d:while(1){if(d>>>0>=k>>>0){break b}while(1){f=v[a+8>>2];e=v[a>>2];v[23296]=0;f=W(144,e|0,f|0,1)|0;e=v[23296];v[23296]=0;e:{if((e|0)!=1){if(!f){break b}v[23296]=0;i=T(194,a|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break a}if(i){break e}d=d+1|0;continue d}break a}e=v[j>>2];u[h+14>>1]=i&31;u[h+12>>1]=l;e=$b(e,b);e=fd(v[e>>2],v[v[e+48>>2]+12>>2],d,x[Zc(h+14|0,h+12|0)>>1]);if(!(i&224)){continue}break}f:{if(!(i&128)){break f}v[23296]=0;g=T(194,a|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break a}t[e+5|0]=g;v[23296]=0;g=T(194,a|0)|0;f=v[23296];v[23296]=0;g:{h:{if((f|0)!=1){if(g>>>0<26){break h}break g}break a}f=w[g+42688|0];t[e+3|0]=f;i:{switch(f-1|0){case 0:if(!w[e+5|0]){break g}break f;case 12:if(w[e+2|0]){break f}t[e+2|0]=1;f=w[e+5|0];t[e+5|0]=0;t[e+3|0]=0;m=e,n=Xd(f,0,64),t[m+4|0]=n;break f;case 5:case 6:case 10:case 23:case 28:f=w[e+5|0]&240;if(!f){break f}t[e+5|0]=f;break f;case 8:f=w[e+5|0];if(f>>>0<=128){m=e,n=xi(f<<1),t[m+5|0]=n;break f}if((f|0)!=164){break f}t[e+5|0]=145;t[e+3|0]=20;break f;case 13:f=w[e+5|0];t[e+5|0]=B(f>>>4|0,10)+(f&15);break f;case 18:Hu(e);break f;case 16:if(w[e+5|0]>31){break f}t[e+3|0]=16;break f;case 27:break i;default:break f}}g=w[e+5|0];f=g&240;j:{if((f|0)==16){f=2}else{if((f|0)!=32){break j}f=3}t[e+3|0]=f}t[e+5|0]=g&15|224;break f}t[e+3|0]=0}k:{l:{if(!(i&64)){break l}v[23296]=0;R(247,h+8|0,a|0);f=v[23296];v[23296]=0;if((f|0)==1){break k}t[e+1|0]=w[h+8|0];g=w[kd(h+8|0)|0];t[e|0]=g;f=255;if((g|0)!=128){f=253;if(g>>>0<129){break l}}t[e|0]=f}if(!(i&32)){continue}t[e+2|0]=1;v[23296]=0;g=T(194,a|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break a}t[e+4|0]=g;if(!c){continue}t[e+4|0]=(g<<6>>>0)/127;continue}break}break a}break a}break a}Ab(a);jb=h+16|0;return}b=P()|0;O()|0;Ab(a);S(b|0);L()}function V2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a=Kb(a);v[23296]=0;Z(93);c=v[23296];v[23296]=0;a:{b:{if((c|0)==1){c=Wa(61592,91780,92364,0)|0;d=O()|0;c:{d:{e:{if((ea(61592)|0)==(d|0)){c=_(c|0)|0;v[23296]=0;b=Q(889,a|0,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break e}v[23296]=0;b=Q(889,b|0,17588)|0;d=v[23296];v[23296]=0;if((d|0)==1){break e}v[23296]=0;d=Q(889,b|0,17564)|0;b=v[23296];v[23296]=0;if((b|0)==1){break e}b=nb[v[v[c>>2]+8>>2]](c)|0;v[23296]=0;Q(889,d|0,(b?b:21473)|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break e}v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}f:{if((ea(91780)|0)==(d|0)){c=_(c|0)|0;v[23296]=0;b=Q(889,a|0,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break f}v[23296]=0;b=Q(889,b|0,17588)|0;d=v[23296];v[23296]=0;if((d|0)==1){break f}v[23296]=0;d=Q(889,b|0,17539)|0;b=v[23296];v[23296]=0;if((b|0)==1){break f}b=nb[v[v[c>>2]+8>>2]](c)|0;v[23296]=0;Q(889,d|0,(b?b:21473)|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break f}v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}e=ea(92364)|0;c=_(c|0)|0;g:{if((d|0)==(e|0)){v[23296]=0;b=Q(889,a|0,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break g}v[23296]=0;b=Q(889,b|0,17588)|0;d=v[23296];v[23296]=0;if((d|0)==1){break g}v[23296]=0;d=Q(889,b|0,17555)|0;b=v[23296];v[23296]=0;if((b|0)==1){break g}b=nb[v[v[c>>2]+8>>2]](c)|0;v[23296]=0;Q(889,d|0,(b?b:21473)|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break g}v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}v[23296]=0;b=Q(889,a|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}v[23296]=0;b=Q(889,b|0,17588)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}v[23296]=0;Q(889,b|0,13557)|0;b=v[23296];v[23296]=0;if((b|0)==1){break d}v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break b}b=P()|0;O()|0;break a}b=P()|0;O()|0;v[23296]=0;Z(17);c=v[23296];v[23296]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[23296]=0;Z(17);c=v[23296];v[23296]=0;if((c|0)!=1){break a}break c}b=P()|0;O()|0;v[23296]=0;Z(17);c=v[23296];v[23296]=0;if((c|0)==1){break c}break a}b=P()|0;O()|0;v[23296]=0;Z(17);c=v[23296];v[23296]=0;if((c|0)!=1){break a}}V(0)|0;O()|0;Ub()}L()}return}yb(a);S(b|0);L()}function cba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=jb-48|0;jb=f;s=v[a+16>>2];u=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;o=v[a+128>>2];if(o){e=v[a+8>>2];k=v[a+12>>2];p=bg(e,k,o);q=mb;i=v[a+76>>2];Ff(v[a>>2],v[a+4>>2],ff(e,k,d),mb);k=i>>>0<mb>>>0?d:0}else{k=0}j=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}l=v[a+40>>2];m=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;k=k-1|0;p=k?p:0;q=k?q:0;n=(((b&2147483647)<<1|e>>>31)&-2)+s|0;e=o;a:{b:while(1){c:{if((e|0)<=0){Sb(j,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(!h){break a}e=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;g=0;b=0;break c}h=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Ld(j,(g|0)/8<<16>>16);Kd(j,4);Sb(f+40|0,p,q);e=e-1|0;continue b}else{g=(t[n+(b+h|0)|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[n+(b+e|0)|0]<<8)+g|0;b=b+1|0;continue}break}Ld(j,(g|0)/8<<16>>16);Kd(j,h);v[j>>2]=v[j>>2];v[j+4>>2]=0}b=$f(j,u);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){r=(b<<2)+f|0;e=v[r>>2];i=(f+16|0)+(b<<3)|0;G=v[i+8>>2];g=v[i+4>>2];v[i+8>>2]=g;n=e<<8;e=n;e=Sia(E,F,e,e>>31);h=mb;H=i;i=e;e=Yb(g,-16777216,16776704);e=Sia(C,D,e,e>>31);g=i+e|0;i=mb+h|0;i=e>>>0>g>>>0?i+1|0:i;e=Yb(G,-16777216,16776704);h=Sia(z,A,e,e>>31);g=h+g|0;e=mb+i|0;e=g>>>0<h>>>0?e+1|0:e;h=g+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Rc(h,e,24);v[H+4>>2]=e-(n&y);v[r>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];m=v[a+28>>2]+m|0;v[c>>2]=v[c>>2]+B(v[f>>2],m>>12);l=b+l|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],l>>12);Sb(f+8|0,w,x);c=c+8|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+24>>2]=l>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=f+48|0}function jV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,z=0,A=0,C=0,D=0,E=0;f=jb-32|0;jb=f;k=Th(f+24|0);p=k+3|0;q=k+5|0;r=k+4|0;s=k+2|0;x=k+1|0;d=f+16|0;z=d|5;A=d|3;while(1){a:{if(y[a+12>>2]>m>>>0){C=Qf(v[a>>2],v[v[a+48>>2]+12>>2],m);b:while(1){if(!Ob(v[c>>2],v[c+8>>2],1)){break a}l=Ee(c);if((l|0)==255){break a}d=l&31;h=B(d,6)+C|0;i=Eg(v[v[a+48>>2]+12>>2])>>>0>d>>>0;j=i?h:k;e=1;if(!(l&64)){d=Ee(c);g=d<<24>>24;e=255;d=d&127;c:{d:{if((d|0)==1){break d}e=d-1|0;if(b?e>>>0<=120:0){break d}if((d-109&255)>>>0<159|b){break c}e=d+13|0}t[j|0]=e}D=i?h+1|0:x,E=Ee(c),t[D|0]=E;e=(g|0)<0}g=i?h+3|0:p;d=i?h+5|0:q;n=i?h+4|0:r;i=i?h+2|0:s;while(1){e:{f:{g:{if(e&1){v[f+16>>2]=w[j|0]|w[j+1|0]<<8|(w[j+2|0]<<16|w[j+3|0]<<24);u[f+20>>1]=w[j+4|0]|w[j+5|0]<<8;o=Ee(c);h=o&63;if(o&64){t[i|0]=1;t[n|0]=h;break e}e=Ee(c);t[d|0]=e;if(h>>>0<=15){t[g|0]=h;Of(j);h:{i:{j:{e=w[g|0];switch(e-9|0){case 1:case 2:case 3:break f;case 4:break i;case 0:break j;default:break h}}t[g|0]=9;t[d|0]=B(w[d|0]&15,17);break f}t[g|0]=0;t[i|0]=1;v[f+12>>2]=w[d|0]+1>>>1;v[f+8>>2]=64;D=n,E=v[td(f+12|0,f+8|0)>>2],t[D|0]=E;break f}if((e|0)!=19){break f}if(w[d|0]==128){break g}Hu(j);break f}if(h>>>0>44){break f}t[g|0]=w[h+26064|0];k:{switch(h-16|0){case 0:if(e>>>0>1){break g}t[d|0]=e|158;break f;case 1:case 2:t[f+12|0]=15;D=d,E=w[Wb(f+12|0,d)|0]|224,t[D|0]=E;break f;case 5:case 6:v[f+12>>2]=16;v[f+8>>2]=e+1;D=d,E=v[td(f+12|0,f+8|0)>>2]/2|240,t[D|0]=E;break f;case 14:l:{m:{n:{o:{p:{h=e>>>4|0;switch(h-1|0){case 1:break n;case 0:break o;default:break p}}switch(h-10|0){case 1:break l;case 0:break m;default:break g}}t[g|0]=2;t[d|0]=e|240;break f}t[g|0]=3;t[d|0]=e|240;break f}t[g|0]=11;t[d|0]=(e<<3&120)+8|15;break f}t[g|0]=11;t[d|0]=(e&15)+1>>>1|240;break f;case 12:break k;default:break f}}v[f+12>>2]=e+1>>>1;v[f+8>>2]=64;D=d,E=v[td(f+12|0,f+8|0)>>2],t[D|0]=E;break f}if(!(l&128)){continue b}break a}t[g|0]=0}Gu(g,d,A,z);e=w[f+19|0];if(Bi(e)>>>0<=Bi(w[g|0])>>>0){break e}q:{if(w[i|0]){break q}if(!Dq(g,d,1)){break q}t[i|0]=w[g|0];t[n|0]=w[d|0]}t[g|0]=e;t[d|0]=w[f+21|0]}e=o>>>7|0;continue}}}jb=f+32|0;return}m=m+1|0;continue}}function gt(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-16|0;jb=i;f=v[a+24>>2];h=dz(f,w[a+32|0]);j=v[h>>2];a:{if(Nc(j,v[h+4>>2])>>>0<=b>>>0){break a}if(jO(f,x[dc(j,b)>>1])>>>0<=c>>>0){break a}h=v[a>>2];b:{if(wd(h,v[a+4>>2])>>>0>b>>>0){if(y[Hd(h,b)+4>>2]>c>>>0){break b}}Xn(a,0);if(wd(v[a>>2],v[a+4>>2])>>>0<=b>>>0){break a}f=v[a+24>>2]}ic(i,v[d>>2],x[f+480188>>1]);d=i+8|0;h=v[i>>2];f=e?-2046629010:-2078137563;e=e?-1352371636:-873292572;j=v[i+4>>2];while(1){if(!g&(k|0)==(j|0)){v[d>>2]=f;v[d+4>>2]=e}else{l=w[VP(h,k)+841|0];m=l^Sia(f^k,e^g,435,256);l=!l;f=(q=f,r=Sia(m,mb,435,256),s=l,s?q:r);e=l?e:mb;k=k+1|0;g=k?g:g+1|0;continue}break}e=d;d=0;f=$l(i,b,c);h=jb-16|0;jb=h;k=a+12|0;g=aO(x[f>>1],v[f+4>>2],Wd(k),kc(k));c:{if(Rb(g,Jf(k))){j=x[f>>1];l=v[f+4>>2];f=vd(g);if(!Vk(j,l,x[f>>1],v[f+4>>2])){break c}}g=Jf(k)}f=v[hc(h+8|0,g)>>2];jb=h+16|0;if(Ag(f,yf(k))){d=vd(f);d=uc(v[d+8>>2],v[d+12>>2])^1}h=v[e>>2]!=-2078137563|v[e+4>>2]!=-873292572;Bb(i,v[Hd(v[a>>2],b)>>2],c);g=1;j=d|h;m=Cb(v[v[i>>2]>>2],v[i+4>>2])^1;if(!(m?1:j)){break a}d:{e:{f:{g:{if(d){l=vd(f);f=Eb(v[l+8>>2]);n=Eb(v[l+12>>2]);o=v[e>>2];p=v[e+4>>2];j=jb-16|0;jb=j;v[j+8>>2]=f;while(1){if(!(!Rb(f,n)|v[f>>2]==(o|0)&v[f+4>>2]==(p|0))){f=v[it(j+8|0)>>2];continue}break}jb=j+16|0;if(Rb(f,Eb(v[l+12>>2]))){break a}if(!h){break e}break g}if(h){break g}if(!j){break d}break f}v[a+28>>2]=v[a+28>>2]+1}if(d|m){break e}d=ZN(k,$l(i,b,c));h:{if(y[d+4>>2]<y[Gb(d)>>2]){g=jb-16|0;jb=g;d=YN(g,d);XN(v[d+4>>2]);v[d+4>>2]=v[d+4>>2]+8;lc(d);jb=g+16|0;break h}f=jb-32|0;jb=f;g=Gb(d);g=cr(f+8|0,dr(d,Hg(v[d>>2],v[d+4>>2])+1|0),Hg(v[d>>2],v[d+4>>2]),g);XN(v[g+8>>2]);v[g+8>>2]=v[g+8>>2]+8;Ad(d,g);br(g);jb=f+32|0}}d=ZN(k,$l(i,b,c));i:{if(y[d+4>>2]<y[Gb(d)>>2]){g=jb-16|0;jb=g;d=YN(g,d);ZM(v[d+4>>2],v[e>>2],v[e+4>>2]);v[d+4>>2]=v[d+4>>2]+8;lc(d);jb=g+16|0;break i}f=jb-32|0;jb=f;g=Gb(d);g=cr(f+8|0,dr(d,Hg(v[d>>2],v[d+4>>2])+1|0),Hg(v[d>>2],v[d+4>>2]),g);ZM(v[g+8>>2],v[e>>2],v[e+4>>2]);v[g+8>>2]=v[g+8>>2]+8;Ad(d,g);br(g);jb=f+32|0}}Bb(i,v[Hd(v[a>>2],b)>>2],c);xg(i,1);g=0}jb=i+16|0;return g|0}function xx(a){a=a|0;var b=0,c=0,d=C(0),e=0;Xb(a+4960|0,0,76);t[a+5044|0]=0;v[a+5036>>2]=0;v[a+5040>>2]=0;b=v[a+4292>>2];d=z[a+4268>>2];v[23296]=0;e=a+4504|0;if(d<C(4294967296)&d>=C(0)){c=~~d>>>0}else{c=0}da(877,e|0,67,5,c|0,b|0);b=v[23296];v[23296]=0;a:{if((b|0)==1){break a}b=v[a+4296>>2];v[23296]=0;da(877,a+4528|0,62,5,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}b=v[a+4300>>2];v[23296]=0;da(877,a+4552|0,53,5,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}b=v[a+4304>>2];v[23296]=0;da(877,a+4576|0,43,5,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}b=v[a+4308>>2];v[23296]=0;da(877,a+4600|0,32,5,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}b=v[a+4312>>2];v[23296]=0;da(877,a+4624|0,22,5,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}b=v[a+4316>>2];v[23296]=0;da(877,a+4648|0,75,5,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}b=v[a+4320>>2];v[23296]=0;da(877,a+4672|0,69,5,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}b=v[a+4324>>2];v[23296]=0;da(877,a+4696|0,60,5,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}b=v[a+4328>>2];v[23296]=0;da(877,a+4720|0,48,5,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}b=v[a+4332>>2];v[23296]=0;da(877,a+4744|0,36,5,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}b=v[a+4336>>2];v[23296]=0;da(877,a+4768|0,25,5,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}v[23296]=0;da(877,a+4792|0,0,0,0,0);b=v[23296];v[23296]=0;if((b|0)==1){break a}b=v[a+4344>>2];v[23296]=0;da(877,a+4816|0,3,0,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}b=v[a+4348>>2];v[23296]=0;da(877,a+4840|0,3,0,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}v[23296]=0;da(877,a+4864|0,407,1,c|0,0);b=v[23296];v[23296]=0;if((b|0)==1){break a}v[23296]=0;da(877,a+4888|0,400,1,c|0,0);b=v[23296];v[23296]=0;if((b|0)==1){break a}v[23296]=0;da(877,a+4912|0,10,0,c|0,-1);b=v[23296];v[23296]=0;if((b|0)==1){break a}v[23296]=0;da(877,a+4936|0,10,0,c|0,-1);c=v[23296];v[23296]=0;if((c|0)==1){break a}t[a+5045|0]=1;return}c=V(91780)|0;if((O()|0)==(ea(91780)|0)){_(c|0)|0;t[a+5045|0]=0;$();return}S(c|0);L()}function Dda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-128|0;jb=d;a:{b:{c:{d:{switch(w[a|0]-23|0){case 0:e=t[a+1|0];f=d,g=pR(c,+w[a+2|0]*1e4/240),t[f|0]=g;v[d+96>>2]=127;v[d+80>>2]=(B(w[a+3|0],127)>>>0)/185;f=d,g=v[td(d+96|0,d+80|0)>>2],t[f+127|0]=g;e:{switch(((e>>>0)%5|0)-1|0){case 0:tu(d+80|0,15426);v[23296]=0;R(495,d- -64|0,d|0);a=v[23296];v[23296]=0;f:{g:{h:{i:{if((a|0)!=1){v[23296]=0;R(495,d+48|0,d+127|0);a=v[23296];v[23296]=0;if((a|0)==1){break i}v[23296]=0;X(496,d+96|0,d+80|0,d- -64|0,d+48|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}a=d+96|0;ve(d+112|0,a);Ye(b,v[d+112>>2],v[d+116>>2]);yb(a);yb(d+48|0);yb(d- -64|0);Tb(d+80|0);break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(d+48|0)}yb(d- -64|0)}break c;case 1:tu(d+80|0,15366);v[23296]=0;R(495,d- -64|0,d|0);a=v[23296];v[23296]=0;j:{k:{l:{m:{if((a|0)!=1){v[23296]=0;R(495,d+48|0,d+127|0);a=v[23296];v[23296]=0;if((a|0)==1){break m}v[23296]=0;X(496,d+96|0,d+80|0,d- -64|0,d+48|0);a=v[23296];v[23296]=0;if((a|0)==1){break l}a=d+96|0;ve(d+40|0,a);Ye(b,v[d+40>>2],v[d+44>>2]);yb(a);yb(d+48|0);yb(d- -64|0);Tb(d+80|0);break b}a=P()|0;O()|0;break j}a=P()|0;O()|0;break k}a=P()|0;O()|0;yb(d+48|0)}yb(d- -64|0)}break c;default:break e}}a=rc(d+32|0,15453);Ye(b,v[a>>2],v[a+4>>2]);break b;case 1:break d;default:break a}}c=t[a+1|0];t[d+127|0]=(c|0)<5?c:0;c=t[a+2|0];t[d+31|0]=(c|0)>=0?c:127;a=t[a+3|0];t[d+30|0]=(a|0)>=0?a:127;a=jb-16|0;jb=a;c=Vb(a,4009);Sc(d+80|0,c);yb(c);jb=a+16|0;v[23296]=0;R(495,d- -64|0,d+127|0);a=v[23296];v[23296]=0;n:{o:{p:{q:{r:{s:{if((a|0)!=1){v[23296]=0;R(495,d+48|0,d+31|0);a=v[23296];v[23296]=0;if((a|0)==1){break s}v[23296]=0;R(495,d|0,d+30|0);a=v[23296];v[23296]=0;if((a|0)==1){break r}v[23296]=0;da(661,d+96|0,d+80|0,d- -64|0,d+48|0,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break q}a=d+96|0;ve(d+16|0,a);Ye(b,v[d+16>>2],v[d+20>>2]);yb(a);yb(d);yb(d+48|0);yb(d- -64|0);Tb(d+80|0);break b}a=P()|0;O()|0;break n}a=P()|0;O()|0;break o}a=P()|0;O()|0;break p}a=P()|0;O()|0;yb(d)}yb(d+48|0)}yb(d- -64|0)}}Tb(d+80|0);S(a|0);L()}e=1}jb=d+128|0;return e|0}function bba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=jb-48|0;jb=f;s=v[a+16>>2];t=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;o=v[a+128>>2];if(o){e=v[a+8>>2];j=v[a+12>>2];p=bg(e,j,o);q=mb;g=v[a+76>>2];Ff(v[a>>2],v[a+4>>2],ff(e,j,d),mb);j=g>>>0<mb>>>0?d:0}else{j=0}i=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];a:while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;j=j-1|0;p=j?p:0;q=j?q:0;l=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+s|0;b=o;while(1)if((b|0)<=0){Sb(i,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(h){b=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Ld(i,(u[(b<<1|2)+l>>1]+u[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Kd(i,h);v[i>>2]=v[i>>2];v[i+4>>2]=0}b=$f(i,t);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){r=(b<<2)+f|0;e=v[r>>2];g=(f+16|0)+(b<<3)|0;G=v[g+8>>2];k=v[g+4>>2];v[g+8>>2]=k;l=e<<8;e=l;e=Sia(E,F,e,e>>31);h=mb;H=g;g=e;e=Yb(k,-16777216,16776704);e=Sia(C,D,e,e>>31);k=g+e|0;g=mb+h|0;g=e>>>0>k>>>0?g+1|0:g;e=Yb(G,-16777216,16776704);h=Sia(z,A,e,e>>31);k=h+k|0;e=mb+g|0;e=h>>>0>k>>>0?e+1|0:e;h=k+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Rc(h,e,24);v[H+4>>2]=e-(l&y);v[r>>2]=(e|0)/256;b=b+1|0;continue}break}b=v[a+32>>2];n=v[a+28>>2]+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],n>>12);m=b+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],m>>12);Sb(f+8|0,w,x);c=c+8|0;continue a}else{e=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Ld(i,(u[(e<<1|2)+l>>1]+u[l+((e&2147483646)<<1)>>1]|0)/8<<16>>16);Kd(i,4);Sb(f+40|0,p,q);b=b-1|0;continue}}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=f+48|0}function l7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=0,u=0,x=0,y=C(0),A=0,B=0,E=0,F=0,G=0,H=0,I=C(0),J=0,K=0,L=0,M=0,N=0,O=C(0),P=0,Q=C(0);a:{if(!v[a+4316>>2]){break a}if(!Vh(a+44|0)){break a}G=a+4300|0;H=a+4288|0;J=a+4264|0;K=a+4276|0;e=v[a+44>>2];s=Fc(e,0);t=Fc(e,1);e=v[a+56>>2];u=Fc(e,0);x=Fc(e,1);L=nb[v[v[a>>2]+192>>2]](a)|0;y=C(C(nb[v[v[a>>2]+200>>2]](a))/C(100));I=C(nb[v[v[a>>2]+188>>2]](a));A=nb[v[v[a>>2]+212>>2]](a)|0;M=A&1;o=v[a+4324>>2];i=v[a+4320>>2];m=v[a+4328>>2];k=v[a+4312>>2];N=v[a+4276>>2];p=v[a+4264>>2];B=v[a+4256>>2];E=w[a+4260|0];r=a+4316|0;F=d;while(1){if(F){h=z[t>>2];l=z[s>>2];j=v[r>>2];e=Fn(j,k+B|0);j=Fn(j,k);b:{if(E){P=Db(H,m),Q=l,z[P>>2]=Q;P=Db(G,m),Q=h,z[P>>2]=Q;q=Db(p,e);P=Db(p,j),Q=C(C(z[q>>2]*y)+l),z[P>>2]=Q;g=C(C(z[Db(N,e)>>2]*y)+h);e=K;break b}g=C(C(z[Db(p,e)>>2]*y)+C(C(l+h)*C(.5)));e=J}P=Db(v[e>>2],j),Q=g,z[P>>2]=Q;c:{if(L){f=z[a+4244>>2];g=C(f+z[a+4236>>2]);z[a+4236>>2]=g;f=C(f+z[a+4240>>2]);z[a+4240>>2]=f;if(g>C(1)){g=C(g+C(-2));z[a+4236>>2]=g}if(f>C(1)){f=C(f+C(-2));z[a+4240>>2]=f}g=C(D(g));g=C(C(g+g)+C(-1));f=C(D(f));f=C(C(f+f)+C(-1));break c}f=z[a+4240>>2];n=z[a+4244>>2];g=C(C(f*n)+z[a+4236>>2]);z[a+4236>>2]=g;f=C(f-C(g*n));z[a+4240>>2]=f}if(E){e=(m+2|0)%3|0;l=z[Db(H,e)>>2];h=z[Db(G,e)>>2]}e=v[r>>2];j=Db(p,Fn(e,i+k|0));q=e;e=k+4096|0;O=z[Db(p,Fn(q,e+i|0))>>2];n=z[j>>2];z[u>>2]=C(C(C(C(C(O-n)*C(C(i&4095)*C(.000244140625)))+n)-l)*I)+l;i=v[(E?4276:4264)+a>>2];j=v[r>>2];q=Db(i,Fn(j,k+o|0));n=z[Db(i,Fn(j,e+o|0))>>2];l=z[q>>2];z[x>>2]=C(C(C(C(C(n-l)*C(C(o&4095)*C(.000244140625)))+l)-h)*I)+h;m=((m|0)<=0?m+3|0:m)-1|0;v[a+4328>>2]=m;k=(((k|0)>0?0:v[r>>2]<<12)+k|0)-4096|0;v[a+4312>>2]=k;h=M?f:g;f=z[a+4248>>2];h=C(h*f);d:{if(C(D(h))<C(2147483648)){e=~~h;break d}e=-2147483648}o=(A>>>0>1?e:0-e|0)+B|0;v[a+4324>>2]=o;i=A>>>0<4;t=t+4|0;s=s+4|0;g=C(g*f);e:{if(C(D(g))<C(2147483648)){e=~~g;break e}e=-2147483648}i=(i?e:0-e|0)+B|0;v[a+4320>>2]=i;F=F-1|0;x=x+4|0;u=u+4|0;continue}else{e=a;a=v[a+56>>2];ji(e,b,c,Fc(a,0),Fc(a,1),d)}break}}}function Z5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=0,h=0,i=0,j=0,k=C(0),l=0,m=C(0),n=0,o=C(0),p=C(0),q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,A=C(0),B=0,D=0,E=0,F=0,G=C(0),H=0,I=0,J=0,K=0,L=C(0),M=C(0),N=C(0),O=C(0),P=C(0),Q=0,R=C(0);if(Vh(a+44|0)){f=v[a+44>>2];B=Fc(f,0);D=Fc(f,1);f=v[a+56>>2];E=Fc(f,0);F=Fc(f,1);s=v[a+4296>>2];g=s+1|0;l=a+4304|0;f=a+4272|0;u=g+v[Db(f,0)>>2]&4095;q=l+(u<<4)|0;w=g+v[Db(f,1)>>2]&4095;n=((w<<4)+l|0)+4|0;x=g+v[Db(f,2)>>2]&4095;j=((x<<4)+l|0)+8|0;h=Db(f,3);i=v[Db(f,4)>>2];r=v[a+4300>>2];i=i+r|0;y=g+v[h>>2]&4095;h=((y<<4)+l|0)+12|0;t=v[Db(f,5)>>2]+r|0;g=a+4232|0;H=a+69840|0;I=a+78032|0;f=d;while(1){if(f){L=z[h>>2];M=z[j>>2];N=z[n>>2];O=z[q>>2];A=z[D>>2];P=z[B>>2];J=i&1023;j=(J<<3)+H|0;k=z[j+4>>2];u=u-1&4095;q=(u<<4)+l|0;e=z[q>>2];h=r<<3;i=h+H|0;w=w-1&4095;n=(w<<4)+l|0;m=z[n+4>>2];o=m;p=C(m*C(.6180340051651001));G=z[j>>2];m=z[Db(g,0)>>2];p=C(p+C(G*m));z[i+4>>2]=o+C(p*C(-.6180340051651001));o=e;e=C(C(k*m)+C(e*C(-.6180340051651001)));z[i>>2]=o+C(e*C(.6180340051651001));z[q>>2]=p;z[n+4>>2]=e;t=t&1023;K=(t<<3)+I|0;m=z[K+4>>2];x=x-1&4095;i=(x<<4)+l|0;e=z[i+8>>2];h=h+I|0;y=y-1&4095;j=(y<<4)+l|0;k=z[j+12>>2];o=k;G=z[K>>2];p=z[Db(g,1)>>2];k=C(C(k*C(.6180340051651001))+C(G*p));z[h+4>>2]=o+C(k*C(-.6180340051651001));o=e;e=C(C(m*p)+C(e*C(-.6180340051651001)));z[h>>2]=o+C(e*C(.6180340051651001));z[i+8>>2]=k;z[j+12>>2]=e;e=C(P+C(1.0000000031710769e-30));z[E>>2]=k+C(C(e*z[a+4224>>2])+z[q>>2]);k=C(A+C(1.0000000031710769e-30));z[F>>2]=C(C(k*z[a+4224>>2])+z[n+4>>2])+z[j+12>>2];h=(s<<4)+l|0;m=e;e=z[a+4228>>2];A=C(m*e);Q=h,R=C(A+C(C(z[q>>2]*z[Db(g,2)>>2])+C(O*z[Db(g,3)>>2]))),z[Q>>2]=R;e=C(k*e);Q=h,R=C(e+C(C(z[n+4>>2]*z[Db(g,4)>>2])+C(N*z[Db(g,5)>>2]))),z[Q+4>>2]=R;Q=h,R=C(C(C(z[i+8>>2]*z[Db(g,6)>>2])+C(M*z[Db(g,7)>>2]))-e),z[Q+8>>2]=R;Q=h,R=C(A+C(C(z[j+12>>2]*z[Db(g,8)>>2])+C(L*z[Db(g,9)>>2]))),z[Q+12>>2]=R;h=j+12|0;j=i+8|0;n=n+4|0;f=f-1|0;F=F+4|0;E=E+4|0;D=D+4|0;B=B+4|0;t=t-1|0;i=J-1|0;r=r-1&1023;s=s-1&4095;continue}else{v[a+4300>>2]=r;v[a+4296>>2]=s;f=a;a=v[a+56>>2];ji(f,b,c,Fc(a,0),Fc(a,1),d)}break}}}function gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=jb-48|0;jb=f;q=v[a+16>>2];r=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;m=v[a+128>>2];if(m){e=v[a+8>>2];k=v[a+12>>2];n=bg(e,k,m);o=mb;i=v[a+76>>2];Ff(v[a>>2],v[a+4>>2],ff(e,k,d),mb);k=i>>>0<mb>>>0?d:0}else{k=0}j=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];u=v[a+20>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;k=k-1|0;n=k?n:0;o=k?o:0;l=(((b&2147483647)<<1|e>>>31)&-2)+q|0;e=m;a:{b:while(1){c:{if((e|0)<=0){Sb(j,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(!h){break a}e=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;g=0;b=0;break c}h=((v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Ld(j,(g|0)/8<<16>>16);Kd(j,4);Sb(f+40|0,n,o);e=e-1|0;continue b}else{g=(t[l+(b+h|0)|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[l+(b+e|0)|0]<<8)+g|0;b=b+1|0;continue}break}Ld(j,(g|0)/8<<16>>16);Kd(j,h);v[j>>2]=v[j>>2];v[j+4>>2]=0}b=$f(j,r);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=v[p>>2];i=(f+16|0)+(b<<3)|0;G=v[i+8>>2];g=v[i+4>>2];v[i+8>>2]=g;l=e<<8;e=l;e=Sia(E,F,e,e>>31);h=mb;H=i;i=e;e=Yb(g,-16777216,16776704);e=Sia(C,D,e,e>>31);g=i+e|0;i=mb+h|0;i=e>>>0>g>>>0?i+1|0:i;e=Yb(G,-16777216,16776704);h=Sia(z,A,e,e>>31);g=h+g|0;e=mb+i|0;e=g>>>0<h>>>0?e+1|0:e;h=g+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Rc(h,e,24);v[H+4>>2]=e-(l&y);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],u);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],s);Sb(f+8|0,w,x);c=c+8|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=f+48|0}function oO(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;j=jb-128|0;jb=j;a:{b:{c:{if(!km(f,g,h,i,0,0,0,0)){break c}m=i&65535;n=i>>>16&32767;d:{e:{if((n|0)!=32767){l=4;if(n){break e}l=f|h|(g|m)?3:2;break d}l=!(f|h|(g|m))}}r=e>>>16|0;o=r&32767;if((o|0)==32767){break c}if(l){break b}}Fd(j+16|0,b,c,d,e,f,g,h,i);e=v[j+16>>2];d=v[j+20>>2];c=v[j+24>>2];b=v[j+28>>2];eP(j,e,d,c,b,e,d,c,b);d=v[j+8>>2];e=v[j+12>>2];h=v[j>>2];i=v[j+4>>2];break a}m=e&65535|o<<16;p=m;l=d;m=h;q=i>>>16&32767;k=i&65535|q<<16;if((km(b,c,l,p,f,g,h,k)|0)<=0){if(km(b,c,l,p,f,g,m,k)){h=b;i=c;break a}Fd(j+112|0,b,c,d,e,0,0,0,0);d=v[j+120>>2];e=v[j+124>>2];h=v[j+112>>2];i=v[j+116>>2];break a}if(o){i=c;h=b}else{Fd(j+96|0,b,c,l,p,0,0,0,1081540608);h=v[j+108>>2];p=h;l=v[j+104>>2];o=(h>>>16|0)-120|0;i=v[j+100>>2];h=v[j+96>>2]}if(!q){Fd(j+80|0,f,g,m,k,0,0,0,1081540608);f=v[j+92>>2];k=f;m=v[j+88>>2];q=(k>>>16|0)-120|0;g=v[j+84>>2];f=v[j+80>>2]}s=k&65535|65536;p=p&65535|65536;if((o|0)>(q|0)){while(1){t=l-m|0;k=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;n=(p-((l>>>0<m>>>0)+s|0)|0)-(t>>>0<k>>>0)|0;k=t-k|0;f:{if((n|0)>0|(n|0)>=0){l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(!(h|k|(i|n))){Fd(j+32|0,b,c,d,e,0,0,0,0);d=v[j+40>>2];e=v[j+44>>2];h=v[j+32>>2];i=v[j+36>>2];break a}n=n<<1|k>>>31;l=k<<1|i>>>31;p=n;break f}n=p<<1|l>>>31;l=l<<1|i>>>31;p=n}n=i<<1|h>>>31;h=h<<1;i=n;o=o-1|0;if((q|0)<(o|0)){continue}break}o=q}q=l-m|0;n=(g|0)==(i|0)&f>>>0>h>>>0|g>>>0>i>>>0;k=(p-((l>>>0<m>>>0)+s|0)|0)-(q>>>0<n>>>0)|0;m=q-n|0;g:{if((k|0)<0){m=l;k=p;break g}l=h;h=h-f|0;i=i-((f>>>0>l>>>0)+g|0)|0;if(h|m|(i|k)){break g}Fd(j+48|0,b,c,d,e,0,0,0,0);d=v[j+56>>2];e=v[j+60>>2];h=v[j+48>>2];i=v[j+52>>2];break a}if((k|0)==65535|k>>>0<65535){while(1){b=i>>>31|0;o=o-1|0;p=i<<1|h>>>31;h=h<<1;i=p;c=b;b=m;k=k<<1|b>>>31;m=c|b<<1;if(k>>>0<65536){continue}break}}b=r&32768;if((o|0)<=0){Fd(j- -64|0,h,i,m,k&65535|(b|o+120)<<16,0,0,0,1065811968);d=v[j+72>>2];e=v[j+76>>2];h=v[j+64>>2];i=v[j+68>>2];break a}d=m;e=k&65535|(b|o)<<16}v[a>>2]=h;v[a+4>>2]=i;v[a+8>>2]=d;v[a+12>>2]=e;jb=j+128|0}function Iba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;e=jb-48|0;jb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}s=b;t=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;w=v[a+32>>2];x=v[a+28>>2];y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;while(1){if(d){b=v[e+16>>2];G=((((v[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+t|0;b=(b>>>16&65520)+s|0;H=u[b+14>>1];g=u[b+12>>1];q=u[b+10>>1];r=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];o=0;p=0;while(1){if((p|0)!=2){i=G+(p<<1)|0;v[(e+8|0)+(p<<2)>>2]=(((((((B(u[i-8>>1],f)+B(u[i-12>>1],b)|0)+B(u[i-4>>1],k)|0)+B(u[i>>1],h)|0)+B(u[i+4>>1],r)|0)+B(u[i+8>>1],q)|0)+B(g,u[i+12>>1])|0)+B(H,u[i+16>>1])|0)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){q=(e+8|0)+(o<<2)|0;b=v[q>>2];g=(e+24|0)+(o<<3)|0;r=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Sia(E,F,b,b>>31);f=mb;i=g;g=b;b=Yb(h,-16777216,16776704);b=Sia(C,D,b,b>>31);h=g+b|0;g=mb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Yb(r,-16777216,16776704);f=Sia(z,A,b,b>>31);h=f+h|0;b=mb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);v[i+4>>2]=b-(k&y);v[q>>2]=(b|0)/256;o=o+1|0;continue}break}n=n+x|0;v[c>>2]=v[c>>2]+B(v[e+8>>2],n>>12);m=m+w|0;v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],m>>12);Sb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=e+48|0}function dha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0),h=0,i=C(0);d=jb-112|0;jb=d;c=jb-16|0;jb=c;e=b+16|0;GS(c+8|0,e);f=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);h=v[c+4>>2];if((h|0)==(f|0)){ac(a,v[c+12>>2])}jb=c+16|0;if((f|0)!=(h|0)){Xb(e,0,128)}t[b+79|0]=0;t[b+143|0]=0;v[b+152>>2]=-2147483648;v[b+156>>2]=-2147483648;c=d- -64|0;Yd(c,a,qg(a));f=jc(d+88|0,c);Ab(c);v[23296]=0;c=T(190,f|0)|0;e=v[23296];v[23296]=0;a:{b:{if((e|0)==1){break b}v[23296]=0;R(272,b+4|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}ke(d+56|0,v[b+4>>2],v[b+8>>2]);v[23296]=0;_m(406,d- -64|0,f,v[d+56>>2],v[d+60>>2]);c=v[23296];v[23296]=0;if((c|0)!=1){v[23296]=0;c=T(145,a|0)|0;e=v[23296];v[23296]=0;c:{if((e|0)==1){break c}v[23296]=0;U(178,d+32|0,a|0,c|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}a=d+32|0;c=jc(d- -64|0,a);Ab(a);a=v[c>>2];v[23296]=0;a=T(166,a|0)|0;e=v[23296];v[23296]=0;d:{if((e|0)!=1){e:{f:{if(!a){break f}while(1){g:{a=v[c+8>>2];e=v[c>>2];v[23296]=0;a=W(144,e|0,a|0,5)|0;e=v[23296];v[23296]=0;if((e|0)==1){break e}if(!a){break f}v[23296]=0;Q(407,c|0,d+28|0)|0;a=v[23296];v[23296]=0;h:{if((a|0)!=1){a=4;if(!Pb(d+28|0,13448,4)){break h}if(!Pb(d+28|0,13960,4)){break h}v[23296]=0;a=T(145,c|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break h}a=P()|0;O()|0;break d}a=P()|0;O()|0;break d}v[23296]=0;U(178,d+8|0,c|0,a|0);a=v[23296];v[23296]=0;i:{j:{k:{if((a|0)!=1){a=d+8|0;e=jc(d+32|0,a);Ab(a);if(Pb(d+28|0,13448,4)){break k}v[23296]=0;g=C(Ca(408,e|0));a=v[23296];v[23296]=0;if((a|0)==1){break g}z[d+8>>2]=g;v[d+4>>2]=0;v[d>>2]=1065353216;g=z[Xp(d+8|0,d+4|0,d)>>2];z[b+144>>2]=g;i=C(D(g));if((i<C(11754943508222875e-54)^-1)&(!(i>=C(N))&g==g)){break j}v[b+144>>2]=0;break j}a=P()|0;O()|0;break d}if(Pb(d+28|0,13960,4)){break j}v[23296]=0;a=T(145,e|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break i}v[b+148>>2]=a}Ab(e);continue}}break}a=P()|0;O()|0;Ab(e);break d}Ab(c);Ab(f);jb=d+112|0;return}a=P()|0;O()|0;break d}a=P()|0;O()|0}Ab(c);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}Ab(f);S(a|0);L()}function Oaa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;i=jb-16|0;jb=i;c=gf(a,c);ae(i,v[a+28>>2]);j=a;a:{if(!c){e=0;if(hd(a,5)){break a}}e=jb-224|0;jb=e;g=Dl(e+120|0,v[a+28>>2]);v[23296]=0;f=Q(396,e+104|0,27640)|0;a=v[23296];v[23296]=0;b:{c:{d:{e:{if((a|0)!=1){v[23296]=0;v[e+88>>2]=19923969;v[e+92>>2]=0;U(397,g|0,f|0,e+88|0);a=v[23296];v[23296]=0;if((a|0)==1){break e}Tb(f);if(!(w[g+3|0]&64)){break d}break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;Tb(f);break c}t[e+103|0]=0;v[23296]=0;f=Q(396,e+88|0,5466)|0;a=v[23296];v[23296]=0;f:{g:{h:{i:{j:{k:{l:{m:{n:{o:{p:{q:{if((a|0)!=1){v[23296]=0;U(398,g|0,e+103|0,f|0);a=v[23296];v[23296]=0;if((a|0)==1){break q}Tb(f);f=Kb(e+72|0);v[23296]=0;a=Q(396,e+56|0,9986)|0;h=v[23296];v[23296]=0;if((h|0)==1){break p}v[23296]=0;U(707,g|0,f|0,a|0);h=v[23296];v[23296]=0;if((h|0)==1){break o}Tb(a);v[23296]=0;U(11,e+40|0,(w[e+103|0]?0:d)|0,f|0);d=v[23296];v[23296]=0;if((d|0)==1){break n}v[23296]=0;R(260,b|0,e+40|0);d=v[23296];v[23296]=0;if((d|0)==1){break m}d=e+40|0;zb(d);u[e+38>>1]=0;v[23296]=0;d=Q(396,d|0,10646)|0;a=v[23296];v[23296]=0;if((a|0)==1){break g}v[23296]=0;W(426,g|0,e+38|0,d|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break l}Tb(d);ug(e+38|0,4e3);v[23296]=0;d=Q(396,e+24|0,13263)|0;a=v[23296];v[23296]=0;if((a|0)==1){break k}h=x[e+38>>1];a=v[hc(e+16|0,h)>>2];v[23296]=0;X(708,g|0,b|0,d|0,a|0);a=v[23296];v[23296]=0;if((a|0)==1){break j}Tb(d);u[e+14>>1]=65535;v[23296]=0;d=Q(396,e|0,8866)|0;a=v[23296];v[23296]=0;if((a|0)==1){break i}v[23296]=0;k=W(426,g|0,e+14|0,d|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break h}a=x[e+14>>1];Tb(d);if(!((k|0)==1|a>>>0>=h>>>0)){_e(b,a)}yb(f);break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;Tb(f);break c}b=P()|0;O()|0;break f}b=P()|0;O()|0;Tb(a);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;zb(e+40|0);break f}b=P()|0;O()|0;Tb(d);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;Tb(d);break f}b=P()|0;O()|0;break f}b=P()|0;O()|0;Tb(d);break f}b=P()|0;O()|0}yb(f)}_g(g);S(b|0);L()}_g(g);jb=e+224|0;e=c}$e(j,e);jb=i+16|0}function Jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=jb-48|0;jb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}s=b;w=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}m=v[a+40>>2];n=v[a+36>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;x=v[a+32>>2];y=v[a+28>>2];z=v[a+72>>2];b=v[a+68>>2];A=b;C=b>>31;b=v[a+64>>2];D=b;E=b>>31;b=v[a+60>>2];F=b;G=b>>31;while(1){if(d){b=v[e+16>>2];H=(((v[e+20>>2]&2147483647)<<1|b>>>31)&-2)+w|0;b=(b>>>16&65520)+s|0;I=u[b+14>>1];g=u[b+12>>1];q=u[b+10>>1];r=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];o=0;p=0;while(1){if((p|0)!=2){i=p+H|0;v[(e+8|0)+(p<<2)>>2]=(((((((B(t[i-4|0],f)+B(t[i-6|0],b)|0)+B(t[i-2|0],k)|0)+B(t[i|0],h)|0)+B(t[i+2|0],r)|0)+B(t[i+4|0],q)|0)+B(g,t[i+6|0])|0)+B(I,t[i+8|0])<<8)/32768;p=p+1|0;continue}break}while(1){if((o|0)!=2){q=(e+8|0)+(o<<2)|0;b=v[q>>2];g=(e+24|0)+(o<<3)|0;r=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Sia(F,G,b,b>>31);f=mb;i=g;g=b;b=Yb(h,-16777216,16776704);b=Sia(D,E,b,b>>31);h=g+b|0;g=mb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Yb(r,-16777216,16776704);f=Sia(A,C,b,b>>31);h=f+h|0;b=mb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);v[i+4>>2]=b-(k&z);v[q>>2]=(b|0)/256;o=o+1|0;continue}break}n=n+y|0;v[c>>2]=v[c>>2]+B(v[e+8>>2],n>>12);m=m+x|0;v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],m>>12);Sb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;v[a+40>>2]=m;v[a+20>>2]=n>>12;v[a+36>>2]=n;v[a+24>>2]=m>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=e+48|0}function g5(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=jb-96|0;jb=j;a:{b:{c:{k=np(1,32);d:{e:{if(!k){a=Nl(ba(4)|0);v[23296]=0;U(107,a|0,91780,25);a=v[23296];v[23296]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:881;c=hg(j+80|0);f:{g:{h:{if(!i){break h}while(1){d=v[i>>2];if(!d){break h}e=v[i+4>>2];i:{if(e){v[23296]=0;d=Q(54,j- -64|0,d|0)|0;f=v[23296];v[23296]=0;j:{if((f|0)!=1){v[23296]=0;f=Q(892,c|0,d|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break j}v[23296]=0;R(257,f|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(d);break f}v[23296]=0;d=Q(54,j+48|0,d|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break g}zs(c,d)}yb(d);i=i+8|0;continue}}d=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[23296]=0;a=T(765,96)|0;i=v[23296];v[23296]=0;k:{l:{m:{if((i|0)!=1){v[j+44>>2]=d;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=v[k+4>>2];d=v[k>>2];v[23296]=0;b=Q(893,d|0,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break m}v[j+16>>2]=b;b=v[Tf(j+24|0,j+16|0)>>2];d=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=d;v[23296]=0;d=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=d;b=fa(923,a|0,j|0,b|0,c|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break k}i=V(0)|0;O()|0;te(j+16|0);break l}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0}Jb(a);break f}v[k+28>>2]=b;te(j+16|0);a=v[k+28>>2];v[k+24>>2]=a?a+8|0:0;Uk(c);break d}i=V(0)|0;O()|0}Uk(c);_(i|0)|0;v[23296]=0;X(887,11198,k|0,g|0,h|0);a=v[23296];v[23296]=0;if((a|0)!=1){v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)!=1){a=v[k+28>>2];if(a){nb[v[v[a>>2]+4>>2]](a)}v[k+24>>2]=0;v[k+28>>2]=0;a=v[k+20>>2];if(a){Jb(a);v[k+20>>2]=0}Jb(k);k=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)==1){break b}}_(i|0)|0;k=0;v[23296]=0;X(887,11198,0,g|0,h|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}$()}jb=j+96|0;return k|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ub()}L()}function v5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-80|0;jb=e;v[e+76>>2]=c;v[e+72>>2]=b;a:{if(!c){break a}g=w[Kk(b,c)|0];if((g|0)==33){d=1}else{if((g|0)!=63){break a}d=0}Tk(e+48|0,b,c,c-1|0);b=v[e+52>>2];v[e+72>>2]=v[e+48>>2];v[e+76>>2]=b}c=e+48|0;Qd(c);b=v[e+48>>2];Qd(e+32|0);b=Jk(b,v[e+36>>2],e+72|0);Qd(c);b:{c:{d:{e:{if((b|0)==v[e+52>>2]){b=v[e+72>>2];c=v[e+76>>2];a=rc(e- -64|0,21473);if(Mc(b,c,v[a>>2],v[a+4>>2])){a=ba(8)|0;v[23296]=0;b=Q(54,e+48|0,10374)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}f=0;if(!d){break e}a=ba(8)|0;v[23296]=0;b=Eh(e+32|0,v[e+72>>2],v[e+76>>2]);c=v[23296];v[23296]=0;f:{g:{h:{if((c|0)!=1){v[23296]=0;U(915,e+48|0,17488,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break h}d=0;c=sc(a,e+48|0);v[23296]=0;U(107,c|0,61592,904);c=v[23296];v[23296]=0;if((c|0)!=1){break b}c=P()|0;O()|0;yb(e+48|0);break g}c=P()|0;O()|0;break f}c=P()|0;d=1;O()|0}yb(b);if(!d){break c}}ca(a|0);break c}if(v[b+4>>2]!=2){a=ba(8)|0;v[23296]=0;b=Q(54,e+48|0,11442)|0;c=v[23296];v[23296]=0;if((c|0)!=1){a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;ca(a|0);break c}b=v[e+72>>2];c=v[e+76>>2];d=rc(e+24|0,21473);if(Mc(b,c,v[d>>2],v[d+4>>2])){a=ba(8)|0;v[23296]=0;b=Q(54,e+48|0,10374)|0;c=v[23296];v[23296]=0;if((c|0)!=1){a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;ca(a|0);break c}d=rc(e+16|0,7677);if(Mc(b,c,v[d>>2],v[d+4>>2])){f=1;if(!Rd(w[a+28|0])){break e}f=65536/+y[v[a+24>>2]+480244>>2];break e}d=rc(e+8|0,7729);if(Mc(b,c,v[d>>2],v[d+4>>2])){f=1;if(!Rd(w[a+28|0])){break e}f=+y[v[a+24>>2]+480240>>2]*152587890625e-16;break e}d=b;b=rc(e,7747);f=0;if(!Mc(d,c,v[b>>2],v[b+4>>2])){break e}f=+y[v[a+24>>2]+480236>>2]*152587890625e-16}jb=e+80|0;return+f}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function sO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0;c=jb-176|0;jb=c;i=1;p=2;d=v[a+12>>2];q=1<<d;m=q;a:while(1){if(d>>>0>=p>>>0){m=m>>>2|0;w=B(i,3);x=i<<1;h=0;b:while(1){if((h|0)==(m|0)){p=p+2|0;i=i<<2;d=v[a+12>>2];continue a}d=v[a>>2];e=ed(d,h<<1);OL(c+160|0,A[e>>3],A[e+8>>3]);d=ed(d,h);OL(c+144|0,A[d>>3],A[d+8>>3]);oi(c+128|0,A[c+144>>3],A[c+152>>3],A[c+160>>3],A[c+168>>3]);d=h<<p;e=i+d|0;y=d>>>0>e>>>0?d:e;while(1)if((d|0)==(y|0)){h=h+1|0;continue b}else{f=v[b>>2];e=ed(f,d);g=e+8|0;j=v[g+4>>2];v[c+120>>2]=v[g>>2];v[c+124>>2]=j;g=v[e+4>>2];v[c+112>>2]=v[e>>2];v[c+116>>2]=g;k=d+i|0;g=ed(f,k);n=A[g+8>>3];o=A[g>>3];r=d+x|0;g=ed(f,r);j=v[g+12>>2];v[c+104>>2]=v[g+8>>2];v[c+108>>2]=j;j=v[g+4>>2];v[c+96>>2]=v[g>>2];v[c+100>>2]=j;s=d+w|0;f=ed(f,s);t=A[f+8>>3];u=A[f>>3];g=c+80|0;f=c+112|0;Ok(g,f,o,n);j=c- -64|0;ej(j,f,o,n);l=c+96|0;Ok(c+48|0,l,u,t);f=c+16|0;ej(f,l,u,t);oi(c+32|0,0,1,A[c+16>>3],A[c+24>>3]);Ok(f,g,A[c+48>>3],A[c+56>>3]);l=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=l;l=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=l;Ok(c,j,A[c+32>>3],A[c+40>>3]);oi(f,A[c+160>>3],A[c+168>>3],A[c>>3],A[c+8>>3]);e=ed(v[b>>2],k);k=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=k;k=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=k;ej(c,g,A[c+48>>3],A[c+56>>3]);oi(f,A[c+144>>3],A[c+152>>3],A[c>>3],A[c+8>>3]);e=ed(v[b>>2],r);g=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=g;g=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=g;ej(c,j,A[c+32>>3],A[c+40>>3]);oi(f,A[c+128>>3],A[c+136>>3],A[c>>3],A[c+8>>3]);e=ed(v[b>>2],s);f=v[c+28>>2];v[e+8>>2]=v[c+24>>2];v[e+12>>2]=f;f=v[c+20>>2];v[e>>2]=v[c+16>>2];v[e+4>>2]=f;d=d+1|0;continue}}}break}c:{if(!(d&1)){break c}i=q>>>1|0;d=0;while(1){if((d|0)==(i|0)){break c}h=v[b>>2];a=ed(h,d+i|0);m=ed(h,d);n=A[a>>3];o=A[a+8>>3];ej(c+160|0,m,n,o);h=v[c+172>>2];v[a+8>>2]=v[c+168>>2];v[a+12>>2]=h;h=v[c+164>>2];v[a>>2]=v[c+160>>2];v[a+4>>2]=h;Yx(ed(v[b>>2],d),n,o);d=d+1|0;continue}}jb=c+176|0}function fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;f=jb-48|0;jb=f;q=v[a+16>>2];r=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);b=0;m=v[a+128>>2];if(m){e=v[a+8>>2];j=v[a+12>>2];n=bg(e,j,m);o=mb;g=v[a+76>>2];Ff(v[a>>2],v[a+4>>2],ff(e,j,d),mb);j=g>>>0<mb>>>0?d:0}else{j=0}i=a+112|0;while(1){if((b|0)!=2){e=b<<3;h=e+(f+16|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];t=v[a+20>>2];b=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=b;w=v[a+8>>2];x=v[a+12>>2];a:while(1){if(d){d=d-1|0;b=v[f+12>>2];e=v[f+8>>2];v[f+40>>2]=e;v[f+44>>2]=0;j=j-1|0;n=j?n:0;o=j?o:0;l=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=m;while(1)if((b|0)<=0){Sb(i,v[a+120>>2],v[a+124>>2]);h=v[a+116>>2];if(h){b=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Ld(i,(u[(b<<1|2)+l>>1]+u[l+((b&2147483646)<<1)>>1]|0)/8<<16>>16);Kd(i,h);v[i>>2]=v[i>>2];v[i+4>>2]=0}b=$f(i,r);v[f+4>>2]=b;v[f>>2]=b;y=v[a+72>>2];b=v[a+68>>2];z=b;A=b>>31;b=v[a+64>>2];C=b;D=b>>31;b=v[a+60>>2];E=b;F=b>>31;b=0;while(1){if((b|0)!=2){p=(b<<2)+f|0;e=v[p>>2];g=(f+16|0)+(b<<3)|0;G=v[g+8>>2];k=v[g+4>>2];v[g+8>>2]=k;l=e<<8;e=l;e=Sia(E,F,e,e>>31);h=mb;H=g;g=e;e=Yb(k,-16777216,16776704);e=Sia(C,D,e,e>>31);k=g+e|0;g=mb+h|0;g=e>>>0>k>>>0?g+1|0:g;e=Yb(G,-16777216,16776704);h=Sia(z,A,e,e>>31);k=h+k|0;e=mb+g|0;e=h>>>0>k>>>0?e+1|0:e;h=k+8388608|0;e=h>>>0<8388608?e+1|0:e;e=Rc(h,e,24);v[H+4>>2]=e-(l&y);v[p>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],t);v[c+4>>2]=v[c+4>>2]+B(s,v[f+4>>2]);Sb(f+8|0,w,x);c=c+8|0;continue a}else{e=(v[f+44>>2]&2147483647)<<1|v[f+40>>2]>>>31;Ld(i,(u[(e<<1|2)+l>>1]+u[l+((e&2147483646)<<1)>>1]|0)/8<<16>>16);Kd(i,4);Sb(f+40|0,n,o);b=b-1|0;continue}}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(f+16|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=f+48|0}function qe(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-16|0;jb=h;e=v[a>>2];a:{if(uc(e,v[a+4>>2])){break a}f=v[b+4>>2];if(f>>>0>=y[a+12>>2]){break a}c=x[b+8>>1];i=v[v[a+48>>2]+12>>2];g=Eg(i);if(c>>>0>=g>>>0&(c|0)!=65535){break a}d=(c|0)==65535;l=d?g-1|0:c;g=f;f=d?0:c;c=fd(e,i,g,f);g=w[b+12|0];j=g&4;b:{c:{if(g&2){break c}k=w[b+10|0];e=c;d=f;while(1){if((d&65535)>>>0>(l&65535)>>>0){break c}d:{if(!j){if((k|0)!=w[e+3|0]){break d}break b}if((k|0)==w[e+2|0]){break b}}e=e+6|0;d=d+1|0;continue}}k=l&65535;d=c;e=f;while(1){if(k>>>0>=(e&65535)>>>0){e:{if(!j){if(w[d+3|0]){break e}t[d+3|0]=w[b+10|0];t[d+5|0]=w[b+11|0];break b}if(w[d+2|0]){break e}t[d+2|0]=w[b+10|0];t[d+4|0]=w[b+11|0];break b}d=d+6|0;e=e+1|0;continue}break}f:{if(!(g&1)){break f}d=v[i+480180>>2]&2;g:{h:{if(!j){while(1){if((f&65535)>>>0<=(l&65535)>>>0){i:{j:{switch(w[c+3|0]-9|0){case 4:if(!nT(v[v[i+8>>2]+88>>2])){break i}d=1;t[c+2|0]=1;t[c+4|0]=w[c+5|0];t[c+3|0]=w[b+10|0];t[c+5|0]=w[b+11|0];break a;case 0:break j;default:break i}}k:{if(d){e=w[c+5|0];if(e>>>0>128){break i}t[c+2|0]=2;t[c+3|0]=w[b+10|0];a=1;break k}t[c+2|0]=2;t[c+3|0]=w[b+10|0];e=w[c+5|0];a=2}t[c+4|0]=a+e>>>a;t[c+5|0]=w[b+11|0];break b}c=c+6|0;f=f+1|0;continue}break}if(!j){break h}}e=w[b+11|0];f=13;l:{switch(w[b+10|0]-1|0){case 1:f=9;e=Bm(B(d?2:4,e));break;case 0:break l;default:break g}}t[b+11|0]=e;t[b+10|0]=f;g=g&254;t[b+12|0]=g;break g}c=w[b+11|0];t[h+14|0]=c;f=!d;d=w[b+10|0];m:{n:{if(!(f|(d|0)!=9)){if(c>>>0>128){break m}d=2;f=(c&254)>>>1|0;break n}t[h+15|0]=d;if(!Dq(h+15|0,h+14|0,1)){break m}d=w[h+15|0];if(!d){break m}g=w[b+12|0];f=w[h+14|0]}t[b+11|0]=f;t[b+10|0]=d;t[b+12|0]=g&254}g=w[b+12|0]}d=1;if(g&1){break f}t[b+12|0]=g^4;if(qe(a,b)){break a}}d=0;o:{p:{switch(v[b>>2]-1|0){case 0:c=v[b+4>>2]+1|0;if(c>>>0>=y[a+12>>2]){break a}v[b+4>>2]=c;break o;case 1:break p;default:break a}}c=v[b+4>>2];if(!c){break a}v[b+4>>2]=c-1}t[b+12|0]=w[b+12|0]|1;d=qe(a,b);break a}d=1}jb=h+16|0;return d}function XJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=jb-96|0;jb=j;a:{b:{c:{d:{e:{f:{k=np(1,28);if(!k){a=Nl(ba(4)|0);v[23296]=0;U(107,a|0,91780,25);a=v[23296];v[23296]=0;if((a|0)!=1){break a}break f}v[k+12>>2]=f;v[k+8>>2]=e;v[k+4>>2]=d;v[k>>2]=c?c:881;c=hg(j+80|0);g:{h:{i:{if(!i){break i}while(1){d=v[i>>2];if(!d){break i}e=v[i+4>>2];j:{if(e){v[23296]=0;d=Q(54,j- -64|0,d|0)|0;f=v[23296];v[23296]=0;k:{if((f|0)!=1){v[23296]=0;f=Q(892,c|0,d|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break k}v[23296]=0;R(257,f|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(d);break g}v[23296]=0;d=Q(54,j+48|0,d|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break h}zs(c,d)}yb(d);i=i+8|0;continue}}d=v[a+8>>2];e=v[a+4>>2];f=v[a>>2];v[23296]=0;a=T(765,80)|0;i=v[23296];v[23296]=0;l:{m:{n:{if((i|0)!=1){v[j+44>>2]=d;v[j+40>>2]=e;v[j+36>>2]=f;v[j+32>>2]=b;b=v[k+4>>2];d=v[k>>2];v[23296]=0;b=Q(893,d|0,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break n}v[j+16>>2]=b;b=v[Tf(j+24|0,j+16|0)>>2];d=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=d;v[23296]=0;d=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=d;b=fa(894,a|0,j|0,b|0,c|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break l}i=V(0)|0;O()|0;te(j+16|0);break m}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0}Jb(a);break g}v[k+24>>2]=b;te(j+16|0);Uk(c);i=k;break d}i=V(0)|0;O()|0}Uk(c);_(i|0)|0;v[23296]=0;X(887,14976,k|0,g|0,h|0);a=v[23296];v[23296]=0;if((a|0)!=1){v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)==1){break f}a=v[k+24>>2];if(a){Jb(ys(a))}i=0;v[k+24>>2]=0;a=v[k+20>>2];if(a){Jb(a);v[k+20>>2]=0}Jb(k);break d}i=V(0)|0;O()|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;i=0;v[23296]=0;X(887,14976,0,g|0,h|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}$()}jb=j+96|0;return i|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ub()}L()}function vG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=v[b>>2];a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{if(!d){break k}h=v[d>>2];if(!h){break k}if(!a){g=c;break j}v[d>>2]=0;g=c;break i}l:{if(!v[v[115798]>>2]){if(!a){break l}if(!c){break a}d=c;while(1){g=t[e|0];if(g){v[a>>2]=g&57343;a=a+4|0;e=e+1|0;d=d-1|0;if(d){continue}break a}break}v[a>>2]=0;v[b>>2]=0;return c-d|0}if(!a){g=c;d=0;break g}g=c;d=0;break h}return Ef(e)}d=1;break g}d=1}while(1){if(!d){if(!g){break a}while(1){m:{f=w[e|0];h=f-1|0;n:{o:{if(h>>>0>126){d=f;break o}if(e&3|g>>>0<5){break n}p:{while(1){d=v[e>>2];if((d|d-16843009)&-2139062144){break p}v[a>>2]=d&255;v[a+4>>2]=w[e+1|0];v[a+8>>2]=w[e+2|0];v[a+12>>2]=w[e+3|0];a=a+16|0;e=e+4|0;g=g-4|0;if(g>>>0>4){continue}break}d=w[e|0]}f=d&255;h=f-1|0}if(h>>>0>126){break m}}v[a>>2]=f;a=a+4|0;e=e+1|0;g=g-1|0;if(g){continue}break a}break}f=f-194|0;if(f>>>0>50){break e}e=e+1|0;h=v[(f<<2)+81600>>2];d=1;continue}d=w[e|0];f=d>>>3|0;if((f-16|f+(h>>26))>>>0>7){break f}q:{r:{f=e+1|0;d=d-128|h<<6;s:{if((d|0)>=0){break s}i=w[f|0]-128|0;if(i>>>0>63){break r}f=e+2|0;d=i|d<<6;if((d|0)>=0){break s}f=w[f|0]-128|0;if(f>>>0>63){break r}d=f|d<<6;f=e+3|0}e=f;v[a>>2]=d;g=g-1|0;a=a+4|0;break q}v[115772]=25;e=e-1|0;break c}d=0;continue}}while(1){t:{if(!d){u:{v:{d=w[e|0];if(!(e&3|d-1>>>0>126)){d=v[e>>2];if(!((d|d-16843009)&-2139062144)){break v}}f=e;break u}while(1){g=g-4|0;d=v[e+4>>2];f=e+4|0;e=f;if(!((d-16843009|d)&-2139062144)){continue}break}}e=d&255;if(e-1>>>0<=126){e=f+1|0;g=g-1|0;break t}h=e-194|0;if(h>>>0>50){e=f;break e}e=f+1|0;h=v[(h<<2)+81600>>2];d=1;continue}d=w[e|0]>>>3|0;if((d-16|d+(h>>26))>>>0>7){break f}d=e+1|0;w:{if(!(h&33554432)){break w}if((w[d|0]&192)!=128){e=e-1|0;break d}d=e+2|0;if(!(h&524288)){break w}if((w[d|0]&192)!=128){e=e-1|0;break d}d=e+3|0}e=d;g=g-1|0}d=0;continue}}e=e-1|0;if(h){break d}d=w[e|0]}if(d&255){break d}if(a){v[a>>2]=0;v[b>>2]=0}return c-g|0}v[115772]=25;if(!a){break b}}v[b>>2]=e}return-1}v[b>>2]=e;return c}function ji(a,b,c,d,e,f){var g=0,h=0,i=0,j=C(0),k=C(0),l=0,m=0,n=C(0),o=C(0),p=C(0),q=0,r=C(0);m=nb[v[v[a>>2]+136>>2]](a)|0;g=v[a+20>>2];h=m?h:w[g+25|0];j=z[g+144>>2];k=C(1);if(!(nb[v[v[a>>2]+136>>2]](a)|0)){k=z[v[a+20>>2]+144>>2]}j=C(C(1)-j);a:{if((nb[v[v[a>>2]+152>>2]](a)|0)<=0){break a}if(!SK(w[v[a+20>>2]+24|0])){break a}j=C(C(j+j)+C(-1));k=C(-j)}n=z[a+4196>>2];k=C(k*n);j=C(j*n);g=0;l=v[a+44>>2];m=Fc(l,0);l=Fc(l,1);b:{c:{d:{e:{f:{g:{h:{h=h&255;switch(h|0){case 0:break h;case 5:break c;case 4:break d;case 3:break e;case 2:break f;case 1:break g;default:break b}}while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;z[i>>2]=z[i>>2]+C(C(z[d+g>>2]*j)+C(k*z[g+m>>2]));i=c+g|0;z[i>>2]=z[i>>2]+C(C(z[e+g>>2]*j)+C(k*z[g+l>>2]));h=h+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;z[i>>2]=z[i>>2]+C(z[h+m>>2]-C(z[d+h>>2]*j));i=c+h|0;z[i>>2]=z[i>>2]+C(z[h+l>>2]-C(z[e+h>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;z[i>>2]=z[i>>2]+C(z[d+h>>2]-C(z[h+m>>2]*k));i=c+h|0;z[i>>2]=z[i>>2]+C(z[e+h>>2]-C(z[h+l>>2]*k));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;z[i>>2]=z[i>>2]-C(z[d+h>>2]-C(z[h+m>>2]*j));i=c+h|0;z[i>>2]=z[i>>2]-C(z[e+h>>2]-C(z[h+l>>2]*j));g=g+1|0;continue}}while(1){if((f|0)==(g|0)){break b}h=g<<2;i=h+b|0;k=z[i>>2];q=i;r=k;n=z[h+m>>2];i=c+h|0;o=z[i>>2];p=z[h+l>>2];k=C(C(C(C(k+n)+o)+p)*C(.5));z[q>>2]=r-C(C(k+C(k-C(z[d+h>>2]*j)))-n);z[i>>2]=o-C(C(k+C(k-C(z[e+h>>2]*j)))-p);g=g+1|0;continue}}g=SK(w[v[a+20>>2]+24|0]);j=g?C(j*C(.5)):j;k=g?C(k*C(.5)):k;h=0;while(1){if((f|0)==(h|0)){break b}g=h<<2;i=g+b|0;n=C(z[d+g>>2]-z[g+m>>2]);o=C(z[g+l>>2]-z[e+g>>2]);z[i>>2]=z[i>>2]+C(C(j*n)+C(k*o));g=c+g|0;z[g>>2]=z[g>>2]+C(C(k*n)+C(j*o));h=h+1|0;continue}}i:{if(!((w[v[a+20>>2]+24|0]&4)>>>2|0)){break i}if(nb[v[v[a>>2]+136>>2]](a)|0){break i}g=0;while(1){if((f|0)==(g|0)){break i}a=g<<2;d=a+b|0;z[d>>2]=z[a+m>>2]+z[d>>2];d=a+c|0;z[d>>2]=z[a+l>>2]+z[d>>2];g=g+1|0;continue}}}function Mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;e=jb-48|0;jb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}q=b;r=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];t=v[a+20>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;w=v[a+72>>2];b=v[a+68>>2];x=b;y=b>>31;b=v[a+64>>2];z=b;A=b>>31;b=v[a+60>>2];C=b;D=b>>31;while(1){if(d){b=v[e+16>>2];E=((((v[e+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+r|0;b=(b>>>16&65520)+q|0;F=u[b+14>>1];g=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];m=0;n=0;while(1){if((n|0)!=2){i=E+(n<<1)|0;v[(e+8|0)+(n<<2)>>2]=(((((((B(u[i-8>>1],f)+B(u[i-12>>1],b)|0)+B(u[i-4>>1],k)|0)+B(u[i>>1],h)|0)+B(u[i+4>>1],p)|0)+B(u[i+8>>1],o)|0)+B(g,u[i+12>>1])|0)+B(F,u[i+16>>1])|0)/32768;n=n+1|0;continue}break}while(1){if((m|0)!=2){o=(e+8|0)+(m<<2)|0;b=v[o>>2];g=(e+24|0)+(m<<3)|0;p=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Sia(C,D,b,b>>31);f=mb;i=g;g=b;b=Yb(h,-16777216,16776704);b=Sia(z,A,b,b>>31);h=g+b|0;g=mb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Yb(p,-16777216,16776704);f=Sia(x,y,b,b>>31);h=f+h|0;b=mb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);v[i+4>>2]=b-(k&w);v[o>>2]=(b|0)/256;m=m+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],t);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],s);Sb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=e+48|0}function ph(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Fb(c);v[23296]=0;R(45,a|0,d|0);d=v[23296];v[23296]=0;d:{if((d|0)!=1){e:{while(1){if(Fb(c)>>>0>b>>>0){d=v[ij(c,b)>>2];v[23296]=0;R(46,a|0,(d>>>0<128?d:63)<<24>>24);d=v[23296];v[23296]=0;if((d|0)==1){break e}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Kb(a);d=Fb(c);v[23296]=0;R(45,a|0,d|0);d=v[23296];v[23296]=0;f:{if((d|0)!=1){g:{while(1){if(Fb(c)>>>0>b>>>0){d=v[ij(c,b)>>2];v[23296]=0;R(46,a|0,(d>>>0<256?d:63)<<24>>24);d=v[23296];v[23296]=0;if((d|0)==1){break g}b=b+1|0;continue}break}break f}}break a}return;case 3:_l(a,c,49504);return;case 5:_l(a,c,50528);return;case 4:_l(a,c,51552);return;case 6:_l(a,c,52576);return;case 7:_l(a,c,53600);return;case 8:_l(a,c,54624);return;case 9:Zy(a,c,55648);return;case 10:Zy(a,c,49504);return;case 11:Zy(a,c,53600);return;default:a=ba(8)|0;v[23296]=0;b=Q(44,a|0,10965)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break b}b=P()|0;O()|0;ca(a|0);S(b|0);L();case 0:break c}}e=jb-16|0;jb=e;f=Kb(a);h:{while(1){i:{j:{k:{if(Fb(c)>>>0>g>>>0){b=v[ij(c,g)>>2];if(b>>>0>=2097152){v[23296]=0;R(46,f|0,63);a=v[23296];v[23296]=0;if((a|0)!=1){break j}break i}a=0;while(1){if((a|0)==6){b=7;a=6;break k}d=b&63;t[(e+10|0)+a|0]=d;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break k}a=1;b=2;if((d|0)!=1){break k}a=w[e+10|0]|64}else{a=w[e+10|0]}v[23296]=0;R(46,f|0,a<<24>>24);a=v[23296];v[23296]=0;if((a|0)!=1){break j}break i}jb=e+16|0;break h}i=(-1<<b^-1)<<7-a;d=b-1|0;j=d+(e+10|0)|0;a=b;while(1){if(!a){break j}l:{if((a|0)==(b|0)){a=w[j|0];v[23296]=0;R(46,f|0,(a|i)<<24>>24);h=v[23296];v[23296]=0;a=d;break l}v[23296]=0;a=a-1|0;R(46,f|0,t[a+(e+10|0)|0]|-128);h=v[23296];v[23296]=0}if((h|0)!=1){continue}break}break i}g=g+1|0;continue}break}a=P()|0;O()|0;yb(f);S(a|0);L()}return}ha(b|0,91912,24);L()}b=P()|0;O()|0;yb(a);S(b|0);L()}function Nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;e=jb-48|0;jb=e;a:{b:{c:{j=v[a+12>>2];l=v[a+8>>2];d:{if((j|0)<=1&l>>>0<=805306368|(j|0)<=0){if((j|0)>=-2&l>>>0>=3489660928|(j|0)>-2){break c}if((j|0)==-2&l>>>0>2147483647|j>>>0>4294967294){break d}break b}if((j|0)==1&l>>>0>2147483648|j>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}q=b;r=v[a+16>>2];b=0;while(1){if((b|0)!=2){f=b<<3;k=f+(e+24|0)|0;f=a+f|0;v[k+4>>2]=v[f+44>>2];v[k+8>>2]=v[f+48>>2];b=b+1|0;continue}break}s=v[a+24>>2];w=v[a+20>>2];b=v[a+4>>2];v[e+16>>2]=v[a>>2];v[e+20>>2]=b;x=v[a+72>>2];b=v[a+68>>2];y=b;z=b>>31;b=v[a+64>>2];A=b;C=b>>31;b=v[a+60>>2];D=b;E=b>>31;while(1){if(d){b=v[e+16>>2];F=(((v[e+20>>2]&2147483647)<<1|b>>>31)&-2)+r|0;b=(b>>>16&65520)+q|0;G=u[b+14>>1];g=u[b+12>>1];o=u[b+10>>1];p=u[b+8>>1];h=u[b+6>>1];k=u[b+4>>1];f=u[b+2>>1];b=u[b>>1];m=0;n=0;while(1){if((n|0)!=2){i=n+F|0;v[(e+8|0)+(n<<2)>>2]=(((((((B(t[i-4|0],f)+B(t[i-6|0],b)|0)+B(t[i-2|0],k)|0)+B(t[i|0],h)|0)+B(t[i+2|0],p)|0)+B(t[i+4|0],o)|0)+B(g,t[i+6|0])|0)+B(G,t[i+8|0])<<8)/32768;n=n+1|0;continue}break}while(1){if((m|0)!=2){o=(e+8|0)+(m<<2)|0;b=v[o>>2];g=(e+24|0)+(m<<3)|0;p=v[g+8>>2];h=v[g+4>>2];v[g+8>>2]=h;k=b<<8;b=k;b=Sia(D,E,b,b>>31);f=mb;i=g;g=b;b=Yb(h,-16777216,16776704);b=Sia(A,C,b,b>>31);h=g+b|0;g=mb+f|0;g=b>>>0>h>>>0?g+1|0:g;b=Yb(p,-16777216,16776704);f=Sia(y,z,b,b>>31);h=f+h|0;b=mb+g|0;b=f>>>0>h>>>0?b+1|0:b;f=h+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);v[i+4>>2]=b-(k&x);v[o>>2]=(b|0)/256;m=m+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e+8>>2],w);v[c+4>>2]=v[c+4>>2]+B(v[e+12>>2],s);Sb(e+16|0,l,j);c=c+8|0;d=d-1|0;continue}break}b=v[e+20>>2];v[a>>2]=v[e+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(e+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=e+48|0}function K_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=jb-16|0;jb=j;k=Cw(g);o=kw(g);Ng(j,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[23296]=0;g=Q(1102,k|0,g<<24>>24)|0;i=v[23296];v[23296]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[23296]=0;g=Q(1102,k|0,48)|0;h=v[23296];v[23296]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;g=t[i+1|0];v[23296]=0;g=Q(1102,k|0,g|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Bd();if(!IG(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Bd();if(!Mj(h)){break d}g=g+1|0;continue}}e:{if(De(j)){h=v[f>>2];v[23296]=0;X(1096,k|0,i|0,g|0,h|0);h=v[23296];v[23296]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i<<2);break e}Cl(i,g);v[23296]=0;q=T(1094,o|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Fr((i-a<<2)+d|0,v[f>>2]);break e}f:{if(t[Oc(j,l)|0]<=0){break f}if(t[Oc(j,l)|0]!=(m|0)){break f}m=v[f>>2];v[f>>2]=m+4;v[m>>2]=q;l=(Fb(j)-1>>>0>l>>>0)+l|0;m=0}p=t[h|0];v[23296]=0;p=Q(1102,k|0,p|0)|0;n=v[23296];v[23296]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+4;v[n>>2]=p;h=h+1|0;m=m+1|0;continue}break}break a}g:{while(1){if(c>>>0>g>>>0){i=w[g|0];if((i|0)==46){v[23296]=0;i=T(1097,o|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break a}l=v[f>>2];h=l+4|0;v[f>>2]=h;v[l>>2]=i;g=g+1|0;break g}v[23296]=0;i=Q(1102,k|0,i<<24>>24)|0;h=v[23296];v[23296]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=i;g=g+1|0;continue}break}h=v[f>>2]}v[23296]=0;X(1096,k|0,g|0,c|0,h|0);i=v[23296];v[23296]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g<<2)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a<<2)+d|0;yb(j);jb=j+16|0;return}a=P()|0;O()|0;yb(j);S(a|0);L()}function Yr(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;if(!a){return Jd(b)}if(b>>>0>=4294967232){v[115772]=48;return 0}e=b>>>0<11?16:b+11&-8;h=a-4|0;i=v[h>>2];c=i&-8;a:{b:{if(!(i&3)){if(e>>>0<256|c>>>0<(e|4)>>>0){break b}if(c-e>>>0<=v[115924]<<1>>>0){break a}break b}g=a-8|0;f=c+g|0;if(c>>>0>=e>>>0){b=c-e|0;if(b>>>0<16){break a}v[h>>2]=i&1|e|2;c=e+g|0;v[c+4>>2]=b|3;v[f+4>>2]=v[f+4>>2]|1;wH(c,b);return a}if(v[115810]==(f|0)){c=c+v[115807]|0;if(c>>>0<=e>>>0){break b}v[h>>2]=i&1|e|2;b=e+g|0;c=c-e|0;v[b+4>>2]=c|1;v[115807]=c;v[115810]=b;return a}if(v[115809]==(f|0)){c=c+v[115806]|0;if(c>>>0<e>>>0){break b}b=c-e|0;c:{if(b>>>0>=16){v[h>>2]=i&1|e|2;d=e+g|0;v[d+4>>2]=b|1;c=c+g|0;v[c>>2]=b;v[c+4>>2]=v[c+4>>2]&-2;break c}v[h>>2]=c|i&1|2;b=c+g|0;v[b+4>>2]=v[b+4>>2]|1;b=0}v[115809]=d;v[115806]=b;return a}d=v[f+4>>2];if(d&2){break b}j=c+(d&-8)|0;if(j>>>0<e>>>0){break b}l=j-e|0;d:{if(d>>>0<=255){b=v[f+8>>2];d=d>>>3|0;c=v[f+12>>2];if((c|0)==(b|0)){n=463216,o=v[115804]&Wia(-2,d),v[n>>2]=o;break d}v[b+12>>2]=c;v[c+8>>2]=b;break d}k=v[f+24>>2];c=v[f+12>>2];e:{if((f|0)!=(c|0)){b=v[f+8>>2];v[b+12>>2]=c;v[c+8>>2]=b;break e}f:{b=f+20|0;d=v[b>>2];if(d){break f}b=f+16|0;d=v[b>>2];if(d){break f}c=0;break e}while(1){m=b;c=d;b=c+20|0;d=v[b>>2];if(d){continue}b=c+16|0;d=v[c+16>>2];if(d){continue}break}v[m>>2]=0}if(!k){break d}b=v[f+28>>2];d=(b<<2)+463520|0;g:{if(v[d>>2]==(f|0)){v[d>>2]=c;if(c){break g}n=463220,o=v[115805]&Wia(-2,b),v[n>>2]=o;break d}v[(v[k+16>>2]==(f|0)?16:20)+k>>2]=c;if(!c){break d}}v[c+24>>2]=k;b=v[f+16>>2];if(b){v[c+16>>2]=b;v[b+24>>2]=c}b=v[f+20>>2];if(!b){break d}v[c+20>>2]=b;v[b+24>>2]=c}if(l>>>0<=15){v[h>>2]=i&1|j|2;b=g+j|0;v[b+4>>2]=v[b+4>>2]|1;return a}v[h>>2]=i&1|e|2;b=e+g|0;v[b+4>>2]=l|3;c=g+j|0;v[c+4>>2]=v[c+4>>2]|1;wH(b,l);return a}c=Jd(b);if(!c){return 0}d=v[h>>2];d=(d&3?-4:-8)+(d&-8)|0;qc(c,a,b>>>0>d>>>0?d:b);Jb(a);a=c}return a}function jia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,z=0;d=jb-1104|0;jb=d;v[d+1100>>2]=c;i=nB(d+40|0,b);q=mq(i);e=Qb(a);v[23296]=0;a=T(190,b|0)|0;c=v[23296];v[23296]=0;a:{if((c|0)!=1){v[d+8>>2]=a;v[d+36>>2]=85899345;s=d,z=B(v[Ib(d+8|0,d+36|0)>>2],50),v[s+24>>2]=z;a=v[Ib(d+1100|0,d+24|0)>>2];v[23296]=0;R(308,e|0,a|0);a=v[23296];v[23296]=0;if((a|0)!=1){v[23296]=0;h=T(320,d+24|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){v[23296]=0;f=Q(321,d+8|0,8192)|0;a=v[23296];v[23296]=0;b:{if((a|0)!=1){a=v[h>>2];c=0;while(1){if((c|0)!=256){g=Db(a,c);t[g+2|0]=c;u[g>>1]=8192;c=c+1|0;continue}break}m=9;c:{d:while(1){g=0;n=257;while(1){r=m&255;e:{while(1){j=n&65535;while(1){v[23296]=0;o=Q(152,i|0,r|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}k=o&65535;if((k|0)==257|j>>>0<k>>>0){break e}if(ad(v[e>>2],v[e+4>>2])>>>0>=y[d+1100>>2]){break e}if((k|0)==256){m=9;continue d}c=j>>>0>k>>>0?o:g;a=v[h>>2];l=8192;while(1){c=c&65535;a=Db(a,c);l=l-1|0;p=l&65535;s=Lb(v[f>>2],p),z=w[a+2|0],t[s|0]=z;a=v[h>>2];c=x[Db(a,c)>>1];if(c>>>0<8192){continue}break}a=hc(d,Eb(v[e+4>>2]));c=$g(Eb(v[f>>2]),p);l=Eb(v[f+4>>2]);a=v[a>>2];v[23296]=0;X(309,e|0,a|0,c|0,l|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}f:{if((j|0)!=(k|0)){break f}a=v[f>>2];v[23296]=0;R(322,e|0,Lb(a,p)|0);a=v[23296];v[23296]=0;if((a|0)!=1){break f}break c}if(j>>>0>=8192){g=o;continue}if(ad(v[e>>2],v[e+4>>2])>>>0>=y[d+1100>>2]){continue}break}a=w[Lb(v[f>>2],p)|0];c=Db(v[h>>2],j);u[c>>1]=g;t[c+2|0]=a;a=n+1|0;n=8192;g=o;c=a&65535;if((c|0)==8192){continue}break}m=((c|0)==1<<r)+m|0;n=a;continue}break}break}a=mq(i);v[23296]=0;Q(143,b|0,((a-q|0)+3&-4)+q|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}fc(f);vc(h);Ab(i);jb=d+1104|0;return}c=P()|0;O()|0;fc(f);break b}c=P()|0;O()|0}vc(h);break a}c=P()|0;O()|0;break a}c=P()|0;O()|0;break a}c=P()|0;O()|0}fc(e);Ab(i);S(c|0);L()}function M3(a,b,c){a=a|0;b=C(b);c=c|0;var d=0,e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),k=C(0),m=0,n=0,o=0;d=jb-16|0;jb=d;a:{b:{c:{d:{switch(c-1|0){case 0:a=(p(b),j(2));e:{f:{g:{if((a|0)<=8388607){e=C(C(-1)/C(b*b));if(!(a&2147483647)){break e}e=C(C(b-b)/C(0));if((a|0)<0){break e}a=(p(C(b*C(33554432))),j(2));c=-152;break g}if(a>>>0>2139095039){break f}c=-127;b=C(0);if((a|0)==1065353216){break f}}a=a+4913933|0;k=C((a>>>23|0)+c|0);b=C((l(2,(a&8388607)+1060439283|0),q())+C(-1));f=C(b*C(b*C(.5)));g=C(b/C(b+C(2)));h=C(g*g);i=C(h*h);e=b;b=(l(2,(p(C(b-f)),j(2))&-4096),q());f=C(C(g*C(f+C(C(h*C(C(i*C(.2849878668785095))+C(.6666666269302368)))+C(i*C(C(i*C(.24279078841209412))+C(.40000972151756287))))))+C(C(e-b)-f));b=C(C(k*C(.3010292053222656))+C(C(b*C(.434326171875))+C(C(f*C(.434326171875))+C(C(k*C(7.903415166765626e-7))+C(C(f+b)*C(-3168997136526741e-20))))))}e=b}b=C(e*C(2e3));if(!(C(D(b))<C(2147483648))){break c}a=~~b;break b;case 1:a=(B(v[a+24604>>2],100)|0)/128|0;break b;case 2:c=jb-16|0;jb=c;h:{i:{j:{k:{a=w[a+24648|0];if(a>>>0>=6){a=ba(8)|0;v[23296]=0;c=Q(54,c|0,5084)|0;d=v[23296];v[23296]=0;if((d|0)==1){break k}a=sc(a,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break i}d=P()|0;O()|0;yb(c);break j}jb=c+16|0;a=v[(a<<24>>24<<2)+61336>>2];break h}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}break b;case 3:v[d>>2]=0;m=v[a+24640>>2];c=jb-80|0;jb=c;a=v[a+24636>>2];v[c+40>>2]=a;v[c>>2]=m;n=c+40|0;o=v[Ne(n,c)>>2];l:{if((a|0)==v[Np(n)+32>>2]){a=-1;if(v[Np(c)+36>>2]==(m|0)){break l}}a=0;if((o|0)<=0){break l}a=(o+500>>>0)/1e3|0}v[d>>2]=a;jb=c+80|0;a=v[d>>2];break b;default:break d}}c=ba(8)|0;v[23296]=0;d=Q(54,d|0,10277)|0;a=v[23296];v[23296]=0;m:{if((a|0)!=1){a=sc(c,d);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(d);break m}a=P()|0;O()|0;ca(c|0)}S(a|0);L()}a=-2147483648}jb=d+16|0;return a|0}L()}function _fa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb-48|0;jb=c;a:{b:{c:{d:{e:{f:{g:{if(xd(v[a+24>>2])){break g}h=a+4|0;k=Fb(h);e=jb-32|0;jb=e;d=e+24|0;b=d;v[b>>2]=-1;v[b+4>>2]=-1;v[23296]=0;f=XE(38);b=v[23296];v[23296]=0;if((b|0)==1){break a}v[e+8>>2]=f;v[e+12>>2]=mb;g=jb-16|0;jb=g;i=e+8|0;b=i;l=g,m=Sia(v[b>>2],v[b+4>>2],1e3,0),v[l>>2]=m;v[g+4>>2]=mb;f=qt(g+8|0,g);b=v[f+4>>2];jb=g+16|0;v[e+16>>2]=v[f>>2];v[e+20>>2]=b;b=e+16|0;l=e,m=Wz(v[b>>2],v[b+4>>2]),v[l+16>>2]=m;v[e+20>>2]=mb;g=fR(d,b,Gb(b));v[23296]=0;d=XE(39);f=v[23296];v[23296]=0;if((f|0)==1){break a}j=a+24|0;v[e+8>>2]=d;v[e+12>>2]=mb;d=jb-16|0;jb=d;a=v[i+4>>2];v[d>>2]=v[i>>2];v[d+4>>2]=a;f=qt(d+8|0,d);a=v[f+4>>2];jb=d+16|0;v[e+16>>2]=v[f>>2];v[e+20>>2]=a;l=e,m=Wz(v[b>>2],v[b+4>>2]),v[l+16>>2]=m;v[e+20>>2]=mb;a=fR(g,b,Gb(b));b=v[a>>2];a=v[a+4>>2];jb=e+32|0;if(k){d=Qb(c+32|0);v[23296]=0;v[c+16>>2]=a;R(32,d|0,c+16|0);a=v[23296];v[23296]=0;if((a|0)==1){break d}v[23296]=0;v[c+16>>2]=b;R(32,d|0,c+16|0);a=v[23296];v[23296]=0;if((a|0)==1){break e}a=0;h:{while(1){if(Fb(h)>>>0<=a>>>0){b=Eb(v[d>>2]);a=Eb(v[d+4>>2]);v[23296]=0;f=W(33,c+16|0,b|0,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break c}b=w[Oc(h,a)|0];v[23296]=0;v[c+16>>2]=b;R(32,d|0,c+16|0);b=v[23296];v[23296]=0;if((b|0)!=1){a=a+1|0;continue}break}a=P()|0;O()|0;break c}v[23296]=0;b=T(34,f|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){v[c+8>>2]=b;a=c+8|0;_z(j,a);jm(a);im(f);vc(d);break g}a=P()|0;O()|0;im(f);break c}mb=b;v[c+16>>2]=a;v[c+20>>2]=mb;b=Qb(c+32|0);v[23296]=0;U(37,b|0,c+16|0,c+24|0);a=v[23296];v[23296]=0;if((a|0)==1){a=P()|0;O()|0;vc(b);S(a|0);L()}v[23296]=0;f=T(34,b|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break f}v[c+8>>2]=f;a=c+8|0;_z(j,a);jm(a);im(b)}jb=c+48|0;return}a=P()|0;O()|0;im(b);break b}a=P()|0;O()|0;break c}a=P()|0;O()|0}vc(d)}S(a|0);L()}V(0)|0;O()|0;Ub();L()}function U_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=jb-16|0;jb=j;k=Xu(g);o=qw(g);Ng(j,o);v[f>>2]=d;a:{b:{c:{i=a;g=w[i|0];switch(g-43|0){case 0:case 2:break c;default:break b}}v[23296]=0;g=Q(19,k|0,g<<24>>24)|0;i=v[23296];v[23296]=0;if((i|0)==1){break a}i=v[f>>2];v[f>>2]=i+1;t[i|0]=g;i=a+1|0}d:{g=i;if(!((c-g|0)<2|w[g|0]!=48|(w[g+1|0]|32)!=120)){v[23296]=0;g=Q(19,k|0,48)|0;h=v[23296];v[23296]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;g=t[i+1|0];v[23296]=0;g=Q(19,k|0,g|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=g;i=i+2|0;g=i;while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Bd();if(!IG(h)){break d}g=g+1|0;continue}}while(1){if(c>>>0<=g>>>0){break d}h=t[g|0];Bd();if(!Mj(h)){break d}g=g+1|0;continue}}e:{if(De(j)){h=v[f>>2];v[23296]=0;X(1082,k|0,i|0,g|0,h|0);h=v[23296];v[23296]=0;if((h|0)==1){break a}v[f>>2]=v[f>>2]+(g-i|0);break e}Cl(i,g);v[23296]=0;q=T(1080,o|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break a}h=i;while(1){if(g>>>0<=h>>>0){Cl((i-a|0)+d|0,v[f>>2]);break e}f:{if(t[Oc(j,m)|0]<=0){break f}if(t[Oc(j,m)|0]!=(l|0)){break f}l=v[f>>2];v[f>>2]=l+1;t[l|0]=q;m=(Fb(j)-1>>>0>m>>>0)+m|0;l=0}p=t[h|0];v[23296]=0;p=Q(19,k|0,p|0)|0;n=v[23296];v[23296]=0;if((n|0)!=1){n=v[f>>2];v[f>>2]=n+1;t[n|0]=p;h=h+1|0;l=l+1|0;continue}break}break a}while(1){g:{if(c>>>0>g>>>0){i=w[g|0];if((i|0)!=46){break g}v[23296]=0;i=T(1083,o|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0}i=v[f>>2];v[23296]=0;X(1082,k|0,g|0,c|0,i|0);i=v[23296];v[23296]=0;if((i|0)==1){break a}i=f;f=v[f>>2]+(c-g|0)|0;v[i>>2]=f;v[e>>2]=(b|0)==(c|0)?f:(b-a|0)+d|0;yb(j);jb=j+16|0;return}v[23296]=0;i=Q(19,k|0,i<<24>>24)|0;h=v[23296];v[23296]=0;if((h|0)==1){break a}h=v[f>>2];v[f>>2]=h+1;t[h|0]=i;g=g+1|0;continue}}a=P()|0;O()|0;yb(j);S(a|0);L()}function tO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;c=jb-176|0;jb=c;e=v[a+12>>2];j=1<<e;a:{if(!(e&1)){h=j>>>2|0;l=1;break a}l=j>>>1|0;e=0;while(1){if((e|0)==(l|0)){h=j>>>3|0;l=2;e=v[a+12>>2]}else{i=v[b>>2];h=ed(i,e+l|0);d=ed(i,e);o=A[h>>3];p=A[h+8>>3];ej(c+160|0,d,o,p);i=v[c+172>>2];v[h+8>>2]=v[c+168>>2];v[h+12>>2]=i;i=v[c+164>>2];v[h>>2]=v[c+160>>2];v[h+4>>2]=i;Yx(ed(v[b>>2],e),o,p);e=e+1|0;continue}break}}i=e&-2;b:while(1){if(i){x=B(h,3);y=h<<1;j=0;c:while(1){if((j|0)==(l|0)){i=i-2|0;h=h>>>2|0;l=l<<2;continue b}d=v[a>>2];e=ed(d,j<<1);d=ed(d,j);o=A[d>>3];p=A[d+8>>3];r=A[e>>3];s=A[e+8>>3];oi(c+160|0,o,p,r,s);e=j<<i;d=h+e|0;z=d>>>0<e>>>0?e:d;while(1)if((e|0)==(z|0)){j=j+1|0;continue c}else{f=v[b>>2];d=ed(f,e);g=v[d+12>>2];v[c+152>>2]=v[d+8>>2];v[c+156>>2]=g;g=v[d+4>>2];v[c+144>>2]=v[d>>2];v[c+148>>2]=g;g=c+128|0;t=e+h|0;k=ed(f,t);oi(g,r,s,A[k>>3],A[k+8>>3]);u=e+y|0;k=ed(f,u);oi(c+112|0,o,p,A[k>>3],A[k+8>>3]);m=A[c+160>>3];n=A[c+168>>3];w=e+x|0;f=ed(f,w);oi(c+96|0,m,n,A[f>>3],A[f+8>>3]);k=c+80|0;f=c+144|0;m=A[c+112>>3];n=A[c+120>>3];Ok(k,f,m,n);q=c- -64|0;ej(q,f,m,n);m=A[c+96>>3];n=A[c+104>>3];Ok(c+48|0,g,m,n);f=c+16|0;Wk(f,-0,-1);ej(c,g,m,n);oi(c+32|0,A[c+16>>3],A[c+24>>3],A[c>>3],A[c+8>>3]);Ok(f,k,A[c+48>>3],A[c+56>>3]);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;ej(f,k,A[c+48>>3],A[c+56>>3]);d=ed(v[b>>2],t);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;Ok(f,q,A[c+32>>3],A[c+40>>3]);d=ed(v[b>>2],u);g=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=g;g=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=g;ej(f,q,A[c+32>>3],A[c+40>>3]);d=ed(v[b>>2],w);f=v[c+28>>2];v[d+8>>2]=v[c+24>>2];v[d+12>>2]=f;f=v[c+20>>2];v[d>>2]=v[c+16>>2];v[d+4>>2]=f;e=e+1|0;continue}}}break}jb=c+176|0}function u5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-80|0;jb=e;v[e+76>>2]=c;v[e+72>>2]=b;a:{if(!c){break a}f=w[Kk(b,c)|0];if((f|0)==33){d=1}else{if((f|0)!=63){break a}d=0}Tk(e+48|0,b,c,c-1|0);b=v[e+52>>2];v[e+72>>2]=v[e+48>>2];v[e+76>>2]=b}c=e+48|0;Qd(c);b=v[e+48>>2];Qd(e+32|0);b=Jk(b,v[e+36>>2],e+72|0);Qd(c);b:{c:{d:{e:{if((b|0)==v[e+52>>2]){b=v[e+72>>2];c=v[e+76>>2];a=rc(e- -64|0,21473);if(Mc(b,c,v[a>>2],v[a+4>>2])){a=ba(8)|0;v[23296]=0;b=Q(54,e+48|0,10374)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}b=0;c=0;if(!d){break e}b=ba(8)|0;v[23296]=0;d=Eh(e+32|0,v[e+72>>2],v[e+76>>2]);a=v[23296];v[23296]=0;f:{g:{h:{if((a|0)!=1){v[23296]=0;U(915,e+48|0,17488,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}a=0;c=sc(b,e+48|0);v[23296]=0;U(107,c|0,61592,904);c=v[23296];v[23296]=0;if((c|0)!=1){break b}c=P()|0;O()|0;yb(e+48|0);break g}c=P()|0;O()|0;break f}c=P()|0;a=1;O()|0}yb(d);if(!a){break c}}ca(b|0);break c}if(v[b+4>>2]!=1){a=ba(8)|0;v[23296]=0;b=Q(54,e+48|0,11442)|0;c=v[23296];v[23296]=0;if((c|0)!=1){a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;ca(a|0);break c}d=v[e+72>>2];f=v[e+76>>2];b=rc(e+24|0,21473);if(Mc(d,f,v[b>>2],v[b+4>>2])){a=ba(8)|0;v[23296]=0;b=Q(54,e+48|0,10374)|0;c=v[23296];v[23296]=0;if((c|0)!=1){a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}c=P()|0;O()|0;ca(a|0);break c}b=rc(e+16|0,10833);if(Mc(d,f,v[b>>2],v[b+4>>2])){a=v[a+8>>2];b=a;c=a>>31;break e}b=0;g=d;d=rc(e+8|0,8529);c=0;if(!Mc(g,f,v[d>>2],v[d+4>>2])){break e}b=Oj(w[v[a+32>>2]+140|0]);c=0}jb=e+80|0;mb=c;return b|0}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function e5(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=jb+-64|0;jb=k;a:{b:{c:{j=np(1,32);d:{e:{if(!j){a=Nl(ba(4)|0);v[23296]=0;U(107,a|0,91780,25);a=v[23296];v[23296]=0;if((a|0)!=1){break a}i=V(0)|0;O()|0;break e}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:881;c=hg(k+48|0);f:{g:{h:{if(!i){break h}while(1){d=v[i>>2];if(!d){break h}e=v[i+4>>2];i:{if(e){v[23296]=0;d=Q(54,k+32|0,d|0)|0;f=v[23296];v[23296]=0;j:{if((f|0)!=1){v[23296]=0;f=Q(892,c|0,d|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break j}v[23296]=0;R(257,f|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break j}break i}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0;yb(d);break f}v[23296]=0;d=Q(54,k+16|0,d|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break g}zs(c,d)}yb(d);i=i+8|0;continue}}v[23296]=0;d=T(765,96)|0;e=v[23296];v[23296]=0;k:{l:{m:{if((e|0)!=1){e=v[j+4>>2];f=v[j>>2];v[23296]=0;e=Q(893,f|0,e|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break m}v[k>>2]=e;e=v[Tf(k+8|0,k)>>2];v[23296]=0;a=ja(924,d|0,a|0,b|0,e|0,c|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break k}i=V(0)|0;O()|0;te(k);break l}i=V(0)|0;O()|0;break f}i=V(0)|0;O()|0}Jb(d);break f}v[j+28>>2]=a;te(k);a=v[j+28>>2];v[j+24>>2]=a?a+8|0:0;Uk(c);break d}i=V(0)|0;O()|0}Uk(c);_(i|0)|0;v[23296]=0;X(887,4934,j|0,g|0,h|0);a=v[23296];v[23296]=0;if((a|0)!=1){v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)!=1){a=v[j+28>>2];if(a){nb[v[v[a>>2]+4>>2]](a)}v[j+24>>2]=0;v[j+28>>2]=0;a=v[j+20>>2];if(a){Jb(a);v[j+20>>2]=0}Jb(j);j=0;break d}i=V(0)|0;O()|0;break e}i=V(0)|0;O()|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)==1){break b}}_(i|0)|0;j=0;v[23296]=0;X(887,4934,0,g|0,h|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}$()}jb=k- -64|0;return j|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ub()}L()}function rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0;g=jb-48|0;jb=g;p=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(g+24|0)|0;e=a+e|0;v[i+4>>2]=v[e+44>>2];v[i+8>>2]=v[e+48>>2];f=f+1|0;continue}break}i=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+32>>2];s=v[a+28>>2];t=v[a+72>>2];b=v[a+68>>2];w=b;x=b>>31;b=v[a+64>>2];y=b;z=b>>31;b=v[a+60>>2];A=b;C=b>>31;D=v[a+8>>2];E=v[a+12>>2];while(1){if(d){f=v[g+16>>2];l=((((v[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+p|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;j=u[b+14>>1];h=u[b+12>>1];m=u[b+10>>1];n=u[b+8>>1];o=u[b+6>>1];F=u[b+4>>1];G=u[b+2>>1];H=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=l+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((((B(u[b+8>>1],m)+B(u[b+4>>1],n)|0)+B(h,u[b+12>>1])|0)+B(j,u[b+16>>1])|0)/2|0)+((((B(u[b-8>>1],G)+B(u[b-12>>1],H)|0)+B(u[b-4>>1],F)|0)+B(u[b>>1],o)|0)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){l=(g+8|0)+(f<<2)|0;e=v[l>>2];b=(g+24|0)+(f<<3)|0;j=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;m=e<<8;e=m;e=Sia(A,C,e,e>>31);n=mb;o=b;b=Yb(h,-16777216,16776704);h=Sia(y,z,b,b>>31);e=h+e|0;b=mb+n|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Yb(j,-16777216,16776704);j=Sia(w,x,e,e>>31);e=h+j|0;b=mb+b|0;b=e>>>0<j>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Rc(e,b,24);v[o+4>>2]=b-(m&t);v[l>>2]=(b|0)/256;f=f+1|0;continue}break}k=k+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);i=i+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],i>>12);Sb(g+16|0,D,E);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}jb=g+48|0}function qh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{b:{c:{switch(b|0){case 1:b=0;a=Kb(a);d=Fb(c);v[23296]=0;R(47,a|0,d|0);d=v[23296];v[23296]=0;d:{if((d|0)!=1){e:{while(1){if(Fb(c)>>>0>b>>>0){d=t[Yf(c,b)|0];v[23296]=0;R(48,a|0,((d|0)<0?65533:d&255)|0);d=v[23296];v[23296]=0;if((d|0)==1){break e}b=b+1|0;continue}break}break d}}break a}return;case 2:b=0;a=Kb(a);d=Fb(c);v[23296]=0;R(47,a|0,d|0);d=v[23296];v[23296]=0;f:{if((d|0)!=1){while(1){if(Fb(c)>>>0<=b>>>0){break f}d=w[Yf(c,b)|0];v[23296]=0;R(48,a|0,d|0);d=v[23296];v[23296]=0;if((d|0)!=1){b=b+1|0;continue}break}}break a}return;case 3:Xl(a,c,49504);return;case 5:Xl(a,c,50528);return;case 4:Xl(a,c,51552);return;case 6:Xl(a,c,52576);return;case 7:Xl(a,c,53600);return;case 8:Xl(a,c,54624);return;case 9:Py(a,c,55648);return;case 10:Py(a,c,49504);return;case 11:Py(a,c,53600);return;default:a=ba(8)|0;v[23296]=0;b=Q(44,a|0,10965)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break b}b=P()|0;O()|0;ca(a|0);S(b|0);L();case 0:break c}}e=jb-16|0;jb=e;f=Kb(a);g=e,h=$s(c),v[g+8>>2]=h;g=e,h=Ys(c),v[g>>2]=h;a=0;g:{h:{while(1){i:{if(!Nh(e+8|0,e)){if(!a){break i}v[23296]=0;R(48,f|0,65533);a=v[23296];v[23296]=0;if((a|0)!=1){break i}break h}b=w[v[e+8>>2]];j:{k:{if(!a){if(!(b&128)){a=0;v[23296]=0;R(48,f|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break j}break h}if((b&224)==192){d=b&31;a=1;break j}if((b&240)==224){d=b&15;a=2;break j}d=65533;if((b&248)!=240){break k}d=b&7;a=3;break j}if((b&192)!=128){d=0;v[23296]=0;R(48,f|0,65533);c=v[23296];v[23296]=0;a=0;if((c|0)==1){break h}}d=b&63|d<<6;a=a-1|0;if(a){break j}}a=0;v[23296]=0;R(48,f|0,d|0);b=v[23296];v[23296]=0;d=0;if((b|0)==1){break h}}Be(e+8|0);continue}break}jb=e+16|0;break g}a=P()|0;O()|0;Kc(f);S(a|0);L()}return}ha(b|0,91912,24);L()}b=P()|0;O()|0;Kc(a);S(b|0);L()}function Rj(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;i=jb-16|0;jb=i;a:{if(!d){break a}g=v[c>>2];if(!g){break a}b:{c:{d:{e:{f=v[a+480180>>2];if((f|0)!=512){if((f|0)!=64){break e}f=B(d,20)+g|0;break d}f=((B(d,36318)|0)/1024|0)+g|0;break d}f:{g:{h:{if(w[a+480208|0]&16){if((f|0)==4){break h}f=d>>31;v[i+12>>2]=(f^d)-f;yc(i+12|0,1020);h=v[i+12>>2];i:{if((d|0)>0){if(h>>>0<=15){f=jb-16|0;jb=f;Bb(f+8|0,a+1074312|0,7);j=Cb(v[v[f+8>>2]>>2],v[f+12>>2]);jb=f+16|0;h=v[(h<<2)+(j?37008:37072)>>2];break i}f=jb-16|0;jb=f;Bb(f+8|0,a+1074312|0,7);j=Cb(v[v[f+8>>2]>>2],v[f+12>>2]);jb=f+16|0;h=v[(h>>>2<<2)+(j?37136:38160)>>2];break i}if(h>>>0<=15){f=jb-16|0;jb=f;Bb(f+8|0,a+1074312|0,7);j=Cb(v[v[f+8>>2]>>2],v[f+12>>2]);jb=f+16|0;h=v[(h<<2)+(j?37072:37008)>>2];break i}f=jb-16|0;jb=f;Bb(f+8|0,a+1074312|0,7);j=Cb(v[v[f+8>>2]>>2],v[f+12>>2]);jb=f+16|0;h=v[(h>>>2<<2)+(j?38160:37136)>>2]}h=Sia(h,h>>31,g,g>>31)+32768|0;f=mb;f=Ic(Tia(h,h>>>0<32768?f+1|0:f,65536,0),mb);v[c>>2]=f;if((f|0)!=(g|0)){break c}Bb(i,a+1074312|0,7);g=v[c>>2];if(!(Cb(v[v[i>>2]>>2],v[i+4>>2])^(d|0)>0)){f=2147483647;d=1;if((g|0)==2147483647){break c}break f}d=-1;if((g|0)>=2){break f}f=g;break c}Bb(i,a+1074312|0,7);if(Cb(v[v[i>>2]>>2],v[i+4>>2])){break g}g=v[c>>2]}f=g-d|0;break d}f=v[c>>2];if((d|0)<0){g=Sia(f,0,14317456,0);h=mb;f=Sia(f,0,0-d|0,0)+14317456|0;d=mb;f=cN(Via(g,h,f,f>>>0<14317456?d+1|0:d),mb);break d}d=Sia(f,f>>31,d,0);g=mb;if((g|0)>=0&d>>>0>=14317456|(g|0)>0){if(e){v[c>>2]=2147483647;break a}v[c>>2]=0;v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248;break a}d=cN(Via(Sia(f,0,14317456,0),mb,14317456-d|0,0-(g+(d>>>0>14317456)|0)|0),mb);v[c>>2]=d;if((d|0)>0){break a}break b}f=d+g|0}v[c>>2]=f}if((f|0)>0){break a}}v[c>>2]=1;if(v[a+480180>>2]!=2|e){break a}v[b+696>>2]=0;v[b+88>>2]=v[b+88>>2]|2101248}jb=i+16|0}function sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;g=jb-48|0;jb=g;p=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;i=e+(g+24|0)|0;e=a+e|0;v[i+4>>2]=v[e+44>>2];v[i+8>>2]=v[e+48>>2];f=f+1|0;continue}break}i=v[a+40>>2];k=v[a+36>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+32>>2];s=v[a+28>>2];w=v[a+72>>2];b=v[a+68>>2];x=b;y=b>>31;b=v[a+64>>2];z=b;A=b>>31;b=v[a+60>>2];C=b;D=b>>31;E=v[a+8>>2];F=v[a+12>>2];while(1){if(d){f=v[g+16>>2];l=(((v[g+20>>2]&2147483647)<<1|f>>>31)&-2)+p|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;j=u[b+14>>1];h=u[b+12>>1];m=u[b+10>>1];n=u[b+8>>1];o=u[b+6>>1];G=u[b+4>>1];H=u[b+2>>1];I=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=e+l|0;v[(g+8|0)+(e<<2)>>2]=(((((B(t[b+4|0],m)+B(t[b+2|0],n)|0)+B(h,t[b+6|0])|0)+B(j,t[b+8|0])<<8)/2|0)+((((B(t[b-4|0],H)+B(t[b-6|0],I)|0)+B(t[b-2|0],G)|0)+B(t[b|0],o)<<8)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){l=(g+8|0)+(f<<2)|0;e=v[l>>2];b=(g+24|0)+(f<<3)|0;j=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;m=e<<8;e=m;e=Sia(C,D,e,e>>31);n=mb;o=b;b=Yb(h,-16777216,16776704);h=Sia(z,A,b,b>>31);e=h+e|0;b=mb+n|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Yb(j,-16777216,16776704);j=Sia(x,y,e,e>>31);e=h+j|0;b=mb+b|0;b=e>>>0<j>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Rc(e,b,24);v[o+4>>2]=b-(m&w);v[l>>2]=(b|0)/256;f=f+1|0;continue}break}k=k+s|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);i=i+r|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],i>>12);Sb(g+16|0,E,F);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=i>>12;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}jb=g+48|0}function s5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-80|0;jb=f;v[f+76>>2]=d;v[f+72>>2]=c;a:{if(!d){break a}g=w[Kk(c,d)|0];if((g|0)==33){e=1}else{if((g|0)!=63){break a}e=0}Tk(f+48|0,c,d,d-1|0);c=v[f+52>>2];v[f+72>>2]=v[f+48>>2];v[f+76>>2]=c}c=f+48|0;Qd(c);d=v[f+48>>2];Qd(f+32|0);g=Jk(d,v[f+36>>2],f+72|0);Qd(c);c=v[f+76>>2];d=v[f+72>>2];b:{c:{d:{e:{if((g|0)==v[f+52>>2]){b=rc(f- -64|0,21473);if(Mc(d,c,v[b>>2],v[b+4>>2])){a=ba(8)|0;v[23296]=0;b=Q(54,f+48|0,10374)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}d=P()|0;O()|0;yb(b);break c}if(e){b=ba(8)|0;v[23296]=0;c=Eh(f+32|0,v[f+72>>2],v[f+76>>2]);a=v[23296];v[23296]=0;f:{g:{h:{if((a|0)!=1){v[23296]=0;U(915,f+48|0,17488,c|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}a=0;d=sc(b,f+48|0);v[23296]=0;U(107,d|0,61592,904);d=v[23296];v[23296]=0;if((d|0)!=1){break b}d=P()|0;O()|0;yb(f+48|0);break g}d=P()|0;O()|0;break f}d=P()|0;a=1;O()|0}yb(c);if(!a){break c}}ca(b|0);break c}Kb(a);break e}e=rc(f+24|0,21473);if(Mc(d,c,v[e>>2],v[e+4>>2])){a=ba(8)|0;v[23296]=0;b=Q(54,f+48|0,10374)|0;c=v[23296];v[23296]=0;if((c|0)!=1){a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}d=P()|0;O()|0;yb(b);break c}d=P()|0;O()|0;ca(a|0);break c}e=rc(f+16|0,12211);if(Mc(d,c,v[e>>2],v[e+4>>2])){i:{switch(v[b+52>>2]){case 0:Vb(a,5562);break e;case 1:Vb(a,11143);break e;case 2:Vb(a,9108);break e;default:break i}}Kb(a);break e}e=c;c=rc(f+8|0,11380);if(Mc(d,e,v[c>>2],v[c+4>>2])){j:{switch(v[b+56>>2]){case 0:Vb(a,15415);break e;case 1:Vb(a,15420);break e;case 2:Vb(a,12485);break e;case 3:Vb(a,9172);break e;default:break j}}Kb(a);break e}Kb(a)}jb=f+80|0;return}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function sR(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;t[a|0]=0;c=w[b|0];if(c){t[a|0]=c>>>0>96?-1:c+12|0}t[a+1|0]=w[b+1|0];c=w[b+2|0];d=c-16|0;a:{b:{if((d&255)>>>0<=128){t[a+2|0]=1;c=(d&254)>>>1|0;break b}c:{switch((c+96&240)>>>4|0){case 0:t[a+2|0]=4;c=c&15;break b;case 1:t[a+2|0]=3;c=c&15;break b;case 2:t[a+2|0]=6;c=c&15;break b;case 3:break c;default:break a}}t[a+2|0]=5;c=c&15}t[a+4|0]=c}e=w[b+4|0];d=w[b+5|0];c=w[b+6|0];d:{if(!(c?1:e|d)){break d}e:{f:{g:{h:{i:{j:{switch(e|0){default:k:{switch(e-29|0){case 7:break f;case 5:break g;case 3:break h;case 0:break i;case 1:case 2:case 4:case 6:break d;default:break k}}if((e|0)==128){break e}if((e|0)!=157){break d}t[a+2|0]=15;t[a+3|0]=20;t[a+4|0]=c>>>3;t[f+15|0]=15;h=a,i=w[Wb(b+5|0,f+15|0)|0]|208,t[h+5|0]=i;break d;case 0:t[a+5|0]=d;t[a+3|0]=c;Of(a);g=w[b+6|0]==15;break d;case 1:t[a+3|0]=2;h=a,i=xi(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 2:t[a+3|0]=3;h=a,i=xi(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 3:t[a+3|0]=4;h=a,i=xi(c<<4|(d&240)>>>4),t[h+5|0]=i;break d;case 4:t[a+3|0]=5;t[a+5|0]=c&240|(d&240)>>>4;break d;case 8:if(d){t[a+5|0]=d;t[a+3|0]=9;break d}if((c-1&255)>>>0>1){break d}t[a+5|0]=145;t[a+3|0]=20;break d;case 12:t[a+3|0]=13;t[a+5|0]=c>>>1;break d;case 15:if(c){t[a+5|0]=c;t[a+3|0]=17;break d}t[a+3|0]=16;t[a+5|0]=d&15;break d;case 16:break j;case 5:case 6:case 7:case 9:case 10:case 11:case 13:case 14:break d}}t[a+5|0]=d;t[a+3|0]=c;RA(a,1);g=(w[a+3|0]&254)==16;break d}t[a+5|0]=d;t[a+3|0]=18;break d}t[a+3|0]=31;t[a+5|0]=c>>>1;break d}t[a+3|0]=31;t[a+5|0]=c>>>1&120;break d}t[a+5|0]=159;t[a+3|0]=20;break d}t[a+3|0]=21;t[a+5|0]=c>>>2}b=w[b+3|0];l:{if(!b){break l}if(!w[a+3|0]){t[a+5|0]=b;t[a+3|0]=9;break l}if(w[a+2|0]){break l}t[a+2|0]=2;t[a+4|0]=b>>>2}jb=f+16|0;return g}function WJ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;k=jb+-64|0;jb=k;a:{b:{c:{d:{e:{f:{j=np(1,28);if(!j){a=Nl(ba(4)|0);v[23296]=0;U(107,a|0,91780,25);a=v[23296];v[23296]=0;if((a|0)!=1){break a}break f}v[j+12>>2]=f;v[j+8>>2]=e;v[j+4>>2]=d;v[j>>2]=c?c:881;c=hg(k+48|0);g:{h:{i:{if(!i){break i}while(1){d=v[i>>2];if(!d){break i}e=v[i+4>>2];j:{if(e){v[23296]=0;d=Q(54,k+32|0,d|0)|0;f=v[23296];v[23296]=0;k:{if((f|0)!=1){v[23296]=0;f=Q(892,c|0,d|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break k}v[23296]=0;R(257,f|0,e|0);e=v[23296];v[23296]=0;if((e|0)==1){break k}break j}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0;yb(d);break g}v[23296]=0;d=Q(54,k+16|0,d|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break h}zs(c,d)}yb(d);i=i+8|0;continue}}v[23296]=0;d=T(765,80)|0;e=v[23296];v[23296]=0;l:{m:{n:{if((e|0)!=1){e=v[j+4>>2];f=v[j>>2];v[23296]=0;e=Q(893,f|0,e|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break n}v[k>>2]=e;e=v[Tf(k+8|0,k)>>2];v[23296]=0;a=ja(898,d|0,a|0,b|0,e|0,c|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break l}i=V(0)|0;O()|0;te(k);break m}i=V(0)|0;O()|0;break g}i=V(0)|0;O()|0}Jb(d);break g}v[j+24>>2]=a;te(k);Uk(c);i=j;break d}i=V(0)|0;O()|0}Uk(c);_(i|0)|0;v[23296]=0;X(887,14919,j|0,g|0,h|0);a=v[23296];v[23296]=0;if((a|0)!=1){v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)==1){break f}a=v[j+24>>2];if(a){Jb(ys(a))}i=0;v[j+24>>2]=0;a=v[j+20>>2];if(a){Jb(a);v[j+20>>2]=0}Jb(j);break d}i=V(0)|0;O()|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)!=1){break e}break b}i=V(0)|0;O()|0}_(i|0)|0;i=0;v[23296]=0;X(887,14919,0,g|0,h|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}$()}jb=k- -64|0;return i|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)==1){break b}S(a|0);L()}V(0)|0;O()|0;Ub()}L()}function On(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[b+88>>2]=v[b+88>>2]|524288;a:{b:{if(!(v[a+480208>>2]&8)){Bb(e+8|0,a+1074312|0,15);if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break b}}if(v[a+480180>>2]!=268435456){break a}}c=c?c:w[b+811|0];t[b+812|0]=c;t[b+811|0]=c}if(c){u[b+768>>1]=c}d=v[b+656>>2];c:{if(oj(d)){c=x[b+768>>1];if(!c){break c}f=v[b+856>>2];g=v[a+1074392>>2];i=0-c|0;j=c;c=v[b+708>>2];h=(+(g>>>0)+1)*+(((c|0)<0?i:j)|0)/+y[a+1074416>>2];d:{if(D(h)<2147483648){a=~~h;break d}a=-2147483648}v[b+856>>2]=a;if(w[b+90|0]&16){a=B(v[v[d+44>>2]+36>>2]+1|0,a);v[b+856>>2]=a}a=a-(g?f:0)|0;d=a>>31;f=c>>31;if((f^c)-f>>>0<=(a^d)-d>>>0){if(!c){break c}v[b+708>>2]=0;v[b+852>>2]=c+v[b+852>>2];t[b+851|0]=w[b+851|0]|64;break c}v[b+708>>2]=c-a;v[b+852>>2]=a+v[b+852>>2];t[b+851|0]=w[b+851|0]|64;break c}c=1;e:{if(!(t[b+851|0]&1)){break e}d=v[a+480180>>2];if(d&524352){break e}if(v[a+1074416>>2]==1){Bb(e+8|0,a+1074312|0,6);if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break e}d=v[a+480180>>2]}c=0;if((d|0)!=8){break e}c=(w[a+480208|0]&2)>>>1|0}f:{if(!v[b+700>>2]|!v[b+708>>2]){break f}f=v[a+480180>>2];d=x[b+768>>1];g=(f|0)==268435456&d>>>0>239;if(!((g?w[b+851|0]:c)&1)){break f}c=b+700|0;d=B((f|0)==64?2:4,g?d-240|0:d);d=gj(a)?d:0-d|0;f=v[b+700>>2];g=v[b+708>>2];if(!(w[b+851|0]&16?0:(f|0)>=(g|0))){Rj(a,b,c,d,1);d=v[b+708>>2];if((d|0)>=v[b+700>>2]){break f}v[c>>2]=d;break f}if((f|0)<=(g|0)){break f}Rj(a,b,c,0-d|0,1);f=v[b+700>>2];d=v[b+708>>2];g:{if((f|0)<(d|0)){v[c>>2]=d;break g}if((d|0)!=(f|0)){break f}}Bb(e+8|0,a+1074312|0,112);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}t[b+851|0]=w[b+851|0]|16}if(v[b+700>>2]!=v[b+708>>2]){break c}Bb(e+8|0,a+1074312|0,25);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])&v[a+480180>>2]!=1){break c}v[b+708>>2]=0}jb=e+16|0}function b_(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=jb-1072|0;jb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+960|0;v[a+956>>2]=j;j=tw(j,100,11028,a+16|0);v[a+48>>2]=1071;k=a+48|0;o=le(a+536|0,0,k);v[a+48>>2]=1071;k=le(a+528|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+544|0;f=a+960|0;break d}j=Bd();v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;j=Si(a+956|0,j,11028,a);if((j|0)!=-1){f=v[a+956>>2];Oe(o,f);Oe(k,Jd(j<<2));h=v[k>>2];if(!Vj(h)){break d}}v[23296]=0;Z(1072);a=v[23296];v[23296]=0;if((a|0)!=1){break a}j=P()|0;O()|0;break c}g=a+520|0;bd(g,d);v[23296]=0;q=T(1084,g|0)|0;g=v[23296];v[23296]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}v[23296]=0;X(1096,q|0,f|0,f+j|0,h|0);g=v[23296];v[23296]=0;if((g|0)==1){break j}p=(j|0)>0?w[f|0]==45:p;i=Kb(a+488|0);f=Kb(a+472|0);g=Kb(a+456|0);v[23296]=0;la(1123,c|0,p|0,a+520|0,a+512|0,a+508|0,a+504|0,i|0,f|0,g|0,a+452|0);c=v[23296];v[23296]=0;if((c|0)==1){break i}v[a+36>>2]=1071;c=le(a+40|0,0,a+36|0);m=a+48|0;n=v[a+452>>2];k:{if((n|0)<(j|0)){l=((Fb(g)+(j-n<<1)|0)+Fb(f)|0)+1|0;break k}l=(Fb(g)+Fb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Oe(c,Jd(l<<2));m=v[c>>2];if(m){break h}v[23296]=0;Z(1072);b=v[23296];v[23296]=0;if((b|0)!=1){break a}break g}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[23296]=0;oa(1124,m|0,a+36|0,a+32|0,l|0,h|0,(j<<2)+h|0,q|0,p|0,a+512|0,v[a+508>>2],v[a+504>>2],i|0,f|0,g|0,n|0);h=v[23296];v[23296]=0;if((h|0)!=1){v[23296]=0;b=ka(1105,b|0,m|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break b}}}j=P()|0;O()|0;Qc(c)}Kc(g);Kc(f);yb(i)}_b(a+520|0)}Qc(k);Qc(o);S(j|0);L()}Qc(c);Kc(g);Kc(f);yb(i);_b(a+520|0);Qc(k);Qc(o);jb=a+1072|0;return b|0}L()}function _f(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=v[a+8>>2]+(B(x[a+14>>1],(w[a+80|0]?c:0)+b|0)>>>1|0)|0;v[a+8>>2]=j;i=w[a+79|0]?x[v[a>>2]+3836>>1]:i;c=x[a+20>>1];l=x[a+22>>1];m=x[a+70>>1];a:{b:{c:{d:{switch(v[a+16>>2]){case 1:b=x[v[a>>2]+3832>>1];f=x[a+26>>1]?x[a+48>>1]>>>x[v[a+52>>2]+((b>>>x[a+44>>1]&7)<<1)>>1]|0:0;g=b;b=x[a+46>>1];f=c+(b?g&b?0:f:f)|0;u[a+20>>1]=f;b=2;h=x[a+28>>1];if((h|0)<=f<<16>>16){break c}break b;case 2:if(w[a+78|0]){break b}case 3:b=0;f=x[v[a>>2]+3832>>1];h=x[a+30>>1]?x[a+60>>1]>>>x[v[a+64>>2]+((f>>>x[a+56>>1]&7)<<1)>>1]|0:0;g=f;f=x[a+58>>1];f=c+(f?g&f?0:h:h)|0;u[a+20>>1]=f;if(f<<16>>16<511){break b}v[a+16>>2]=-1;u[a+20>>1]=511;v[a+72>>2]=0;break a;default:b=0;v[a+72>>2]=0;break a;case 0:break d}}b=1;f=x[v[a>>2]+3832>>1];k=x[a+24>>1]?B((c^-1)<<16>>16,x[a+36>>1]>>>x[v[a+40>>2]+((f>>>x[a+32>>1]&7)<<1)>>1]|0)>>>3|0:0;g=f;f=x[a+34>>1];f=c+(f?g&f?0:k:k)|0;u[a+20>>1]=f;if(f<<16>>16>0){break b}}v[a+16>>2]=b;u[a+20>>1]=h}i=((c+l|0)+m|0)+i<<3;if(e){d=(u[a+74>>1]+u[a+72>>1]>>e)+d|0}d=(j>>>10|0)+d|0;c=d&255;b=d&65535;e:{f:{switch(x[a+12>>1]){case 0:d=(b&512)>>>9|0;b=x[((b&256?c^255:c)<<1)+28240>>1];break e;case 1:d=0;b=x[((b&512?0:b&256?c^255:c)<<1)+28240>>1];break e;case 2:d=0;b=x[((b&256?c^255:c)<<1)+28240>>1];break e;case 3:d=0;b=x[((b&256?0:c)<<1)+28240>>1];break e;case 4:e=0;d=0;if(!(b&512)){e=(c<<1^b<<24>>31)&254;d=(b&256)>>>8|0}b=x[(e<<1)+28240>>1];break e;case 5:d=0;if(b&512){b=0}else{c=c<<1&254;b=b&128?c^255:c}b=x[(b<<1)+28240>>1];break e;case 6:d=(d&512)>>>9|0;b=0;break e;default:break f}}c=d<<3&4088;d=(b&512)>>>9|0;b=d?c^4088:c}u[a+74>>1]=x[a+72>>1];c=a;a=b+i&65535;a=a>>>0<8191?a:8191;b=0-(d&1)^x[((a&255)<<1)+27728>>1]+1024>>>(a>>>8)<<1;u[c+72>>1]=b}return b<<16>>16}function Gp(a,b,c,d){var e=0,f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;v[e+12>>2]=u[b+780>>1]+w[b+837|0];v[e+8>>2]=u[b+782>>1]+(w[b+838|0]&127);he(e+12|0,0,127);he(e+8|0,0,127);k=a+1074312|0;Bb(e,k,1);j=v[e+12>>2];a:{if(Cb(v[v[e>>2]>>2],v[e+4>>2])){i=v[e+8>>2];break a}u[b+780>>1]=0;t[b+837|0]=j;i=v[e+8>>2];u[b+782>>1]=0;t[b+838|0]=i}Bb(e,k,36);l=B(j,d+256|0);m=(l|0)/256|0;b:{if(!(!Cb(v[v[e>>2]>>2],v[e+4>>2])|i|(l|0)<65024)){m=-1;if(!Uc(w[b+788|0])){break b}if(ct(w[b+790|0],w[b+791|0])|x[b+786>>1]|!(w[b+851|0]&2)){break b}v[b+88>>2]=v[b+88>>2]&-32769;break b}v[b+88>>2]=v[b+88>>2]|32768;f=me(C(10),C(C(0-i|0)*C(.00937500037252903)));i=jb-16|0;jb=i;g=C(B(j,d+256|0)>>>0);c:{if(v[a+480180>>2]!=33554432){h=C(110);g=C(C(g/(w[a+480209|0]&128?C(10240):C(12288)))+C(.25));break c}h=C(125);g=C(C(g*C(6))/C(65024))}n=i,o=Oh(C(me(C(2),g)*h)),v[n+12>>2]=o;he(i+12|0,120,2e4);d=v[i+12>>2];j=v[a+24620>>2];jb=i+16|0;Bb(e,k,36);g=C(C(((j|0)<d<<1?j>>>1|0:d)>>>0)*C(6.2831854820251465));d:{if(!(!Cb(v[v[e>>2]>>2],v[e+4>>2])|v[a+480208>>2]&32768)){h=C(C(y[a+24620>>2])/g);g=C(C(C(f*h)+f)+C(-1));z[e>>2]=g;f=C(h*h);break d}h=C(f+f);f=C(g/C(y[a+24620>>2]));z[e>>2]=C(C(1)-h)*f;LN(e,C(2));g=C(C(h-z[e>>2])/f);z[e>>2]=g;f=C(C(1)/C(f*f))}h=C(f+C(g+C(1)));g=C(C(f+C(f+g))/h);f=C(C(-f)/h);h=C(C(1)/h);e:{if(w[b+845|0]==1){n=b,o=Oh(C(C(C(1)-h)*C(16777216))),v[n+60>>2]=o;n=b,o=Oh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Oh(C(f*C(16777216))),v[n+68>>2]=o;a=-1;break e}d=Oh(C(h*C(16777216)));v[b+60>>2]=d;n=b,o=Oh(C(g*C(16777216))),v[n+64>>2]=o;n=b,o=Oh(C(f*C(16777216))),v[n+68>>2]=o;a=0;if(d){break e}v[b+60>>2]=1}v[b+72>>2]=a;if(!c){break b}v[b+44>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;v[b+56>>2]=0}jb=e+16|0;return m}function f_(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;a=jb-464|0;jb=a;v[a+16>>2]=f;v[a+20>>2]=g;v[a+24>>2]=h;v[a+28>>2]=i;j=a+352|0;v[a+348>>2]=j;j=tw(j,100,11028,a+16|0);v[a+48>>2]=1071;k=a+48|0;o=le(a+232|0,0,k);v[a+48>>2]=1071;k=le(a+224|0,0,k);a:{b:{c:{d:{if(j>>>0<100){h=a+240|0;f=a+352|0;break d}j=Bd();v[a>>2]=f;v[a+4>>2]=g;v[a+8>>2]=h;v[a+12>>2]=i;j=Si(a+348|0,j,11028,a);if((j|0)!=-1){f=v[a+348>>2];Oe(o,f);Oe(k,Jd(j));h=v[k>>2];if(!Vj(h)){break d}}v[23296]=0;Z(1072);a=v[23296];v[23296]=0;if((a|0)!=1){break a}j=P()|0;O()|0;break c}g=a+216|0;bd(g,d);v[23296]=0;q=T(18,g|0)|0;g=v[23296];v[23296]=0;e:{f:{g:{h:{i:{j:{if((g|0)==1){break j}v[23296]=0;X(1082,q|0,f|0,f+j|0,h|0);g=v[23296];v[23296]=0;if((g|0)==1){break j}p=(j|0)>0?w[f|0]==45:p;i=Kb(a+192|0);f=Kb(a+176|0);g=Kb(a+160|0);v[23296]=0;la(1121,c|0,p|0,a+216|0,a+208|0,a+207|0,a+206|0,i|0,f|0,g|0,a+156|0);c=v[23296];v[23296]=0;if((c|0)==1){break i}v[a+36>>2]=1071;c=le(a+40|0,0,a+36|0);m=a+48|0;n=v[a+156>>2];k:{if((n|0)<(j|0)){l=((Fb(g)+(j-n<<1)|0)+Fb(f)|0)+1|0;break k}l=(Fb(g)+Fb(f)|0)+2|0}l=l+n|0;if(l>>>0<101){break h}Oe(c,Jd(l));m=v[c>>2];if(m){break h}v[23296]=0;Z(1072);b=v[23296];v[23296]=0;if((b|0)!=1){break a}break g}j=P()|0;O()|0;break e}j=P()|0;O()|0;break f}l=v[d+4>>2];v[23296]=0;oa(1122,m|0,a+36|0,a+32|0,l|0,h|0,h+j|0,q|0,p|0,a+208|0,t[a+207|0],t[a+206|0],i|0,f|0,g|0,n|0);h=v[23296];v[23296]=0;if((h|0)!=1){v[23296]=0;b=ka(14,b|0,m|0,v[a+36>>2],v[a+32>>2],d|0,e|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break b}}}j=P()|0;O()|0;Qc(c)}yb(g);yb(f);yb(i)}_b(a+216|0)}Qc(k);Qc(o);S(j|0);L()}Qc(c);yb(g);yb(f);yb(i);_b(a+216|0);Qc(k);Qc(o);jb=a+464|0;return b|0}L()}function ZL(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=jb-16|0;jb=g;e=B(b,872)+a|0;j=e+1074992|0;a:{b:{i=v[e+1075080>>2];if(i&131072){h=a+480180|0;e=v[h>>2];i=1;c:{d:{e:{f=v[a+480208>>2];if(f&4096){if(!(e&16777248)){break e}i=!(f&4)}if((e|0)!=64){break d}break b}if((e|0)==64){break b}h=a+480180|0;i=0;break c}if(!i){break c}Bb(g+8|0,a+1074312|0,21);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break c}e=B(b,872)+a|0;f=e+1075811|0;t[f|0]=w[f|0]+(w[e+1075815|0]<<2)}f=B(b,872)+a|0;k=f+1075814|0;l=f+1075811|0;e=iy(a,w[k|0],w[l|0]);f:{if(oj(v[j+656>>2])){z[d>>2]=z[d>>2]+C(C(C(B(w[f+1075816|0],e)|0)*C(.05000000074505806))/C(7680));c=f+1075843|0;d=w[c|0];t[c|0]=d&159|64;if(v[a+1074416>>2]!=(v[a+1074392>>2]+1|0)){break f}t[c|0]=d|96;break f}d=v[a+480208>>2];if((d&2101248)==2101248){break a}f=v[h>>2];if(d&4096?f&67633152:0){break a}e=f&5?(w[k|0]&3)==1?0-e|0:e:e;k=a+1074312|0;Bb(g+8|0,k,21);f=v[a+480208>>2];g:{if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){d=f&4;e=d?e:0-e|0;d=d?5:6;break g}d=5;h:{if(f&131072){break h}h=v[h>>2];d=8;if((h|0)==1024){break h}d=7;if(h&524304){break h}d=h&16777248?f&4?6:7:6}Bb(g+8|0,k,80);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break g}d=w[(B(b,872)+a|0)+1075783|0]==26?d+2|0:d}d=(0-B(w[(B(b,872)+a|0)+1075816|0],e)|0)/(1<<d)|0;Rj(a,j,c,d,0);e=v[j+656>>2];c=Us(a,v[j+88>>2],e);if(!c){break f}nb[v[v[c>>2]+88>>2]](c,d,(e?t[e+33|0]:2)<<24>>24,b)}if(!i){break a}Bb(g+8|0,a+1074312|0,21);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break a}t[l|0]=w[l|0]+w[(B(b,872)+a|0)+1075815|0];break a}if(!(w[e+1075662|0]&2)){break a}a=Us(a,i,v[j+656>>2]);if(!a){break a}nb[v[v[a>>2]+88>>2]](a,0,0,b);break a}a=B(b,872)+a|0;b=a+1075811|0;d=w[b|0];if(d&1){v[c>>2]=v[c>>2]+B(w[a+1075816|0],167)}t[b|0]=d+1}jb=g+16|0}function DY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;r=jb-16|0;jb=r;j=c;while(1){a:{if((d|0)==(j|0)){j=d;break a}if(!w[j|0]){break a}j=j+1|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{d:{if((c|0)==(d|0)|(f|0)==(g|0)){break d}i=v[b+4>>2];v[r+8>>2]=v[b>>2];v[r+12>>2]=i;s=jb-16|0;jb=s;u=bi(s+8|0,v[a+8>>2]);m=j-c|0;k=0;o=0;n=jb-1040|0;jb=n;i=v[e>>2];v[n+12>>2]=i;p=f?f:n+16|0;l=f?g-f>>2:256;e:{f:{if(!(!i|!l)){while(1){g:{q=m>>>2|0;if(q>>>0<l>>>0&m>>>0<=131){break f}q=vG(p,n+12|0,l>>>0>q>>>0?q:l,b);if((q|0)==-1){k=-1;l=0;i=v[n+12>>2];break g}t=(n+16|0)==(p|0)?0:q;l=l-t|0;p=(t<<2)+p|0;m=i+m|0;i=v[n+12>>2];m=i?m-i|0:0;k=k+q|0;if(!i){break g}if(l){continue}}break}}if(!i){break e}}if(!(!l|!m)){o=i;i=k;while(1){h:{k=Jr(p,o,m,b);i:{if(k+2>>>0<=2){j:{switch(k+1|0){case 1:o=0;break i;case 0:break e;default:break j}}v[b>>2]=0;break i}i=i+1|0;o=k+o|0;l=l-1|0;if(l){break h}}k=i;break e}p=p+4|0;m=m-k|0;k=i;if(m){continue}break}break e}o=i}if(f){v[e>>2]=o}jb=n+1040|0;ai(u);jb=s+16|0;k:{l:{m:{n:{if((k|0)==-1){while(1){o:{v[h>>2]=f;if(v[e>>2]==(c|0)){break o}g=1;p:{q:{r:{b=oF(f,c,j-c|0,r+8|0,v[a+8>>2]);switch(b+2|0){case 0:break l;case 2:break p;case 1:break r;default:break q}}v[e>>2]=c;break n}g=b}c=c+g|0;f=v[h>>2]+4|0;continue}break}v[e>>2]=c;break d}f=v[h>>2]+(k<<2)|0;v[h>>2]=f;if((f|0)==(g|0)){break k}c=v[e>>2];if((d|0)==(j|0)){j=d;continue}if(!oF(f,c,1,b,v[a+8>>2])){break m}}a=2;break c}v[h>>2]=v[h>>2]+4;c=v[e>>2]+1|0;v[e>>2]=c;j=c;while(1){if((d|0)==(j|0)){j=d;break b}if(!w[j|0]){break b}j=j+1|0;continue}}v[e>>2]=c;a=1;break c}c=v[e>>2]}a=(c|0)!=(d|0)}jb=r+16|0;return a|0}f=v[h>>2];continue}}function SQ(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0;l=jb-16|0;jb=l;a:{if((c|0)==(g|0)){f=gc(l+8|0,f,c);i=jb-16|0;jb=i;g=_k(d,e,b,c);v[i+12>>2]=g;b:{if((g|0)<=0){g=v[f>>2];break b}c:{if(!c){c=v[f>>2];break c}h=32-c|0;v[i+8>>2]=h;d=v[td(i+8|0,i+12|0)>>2];v[i+12>>2]=g-d;e=v[f>>2];c=-1<<c&-1>>>h-d;v[e>>2]=v[e>>2]&(c^-1)|c&v[b>>2];c=d+v[f+4>>2]|0;v[f+4>>2]=c&31;c=e+(c>>>3&536870908)|0;v[f>>2]=c;b=b+4|0;g=v[i+12>>2]}e=c;d=(g|0)/32|0;c=d<<2;aj(e,b,c);d=g-(d<<5)|0;v[i+12>>2]=d;g=c+v[f>>2]|0;v[f>>2]=g;if((d|0)<=0){break b}d=-1>>>32-d|0;v[g>>2]=v[g>>2]&(d^-1)|d&v[b+c>>2];v[f+4>>2]=v[i+12>>2]}gc(a,g,v[f+4>>2]);jb=i+16|0;break a}i=a;h=gc(l,f,g);g=jb-16|0;jb=g;f=_k(d,e,b,c);v[g+12>>2]=f;d:{if((f|0)<=0){a=v[h+4>>2];break d}e:{if(!c){a=v[h+4>>2];break e}j=32-c|0;v[g+8>>2]=j;e=g+8|0;d=v[td(e,g+12|0)>>2];v[g+12>>2]=f-d;a=v[h+4>>2];k=v[b>>2];v[g+8>>2]=d;m=32-a|0;v[g+4>>2]=m;f=v[h>>2];n=v[f>>2];e=v[Ib(e,g+4|0)>>2];j=k&(-1<<c&-1>>>j-d);v[f>>2]=(-1<<a&-1>>>m-e^-1)&n|(a>>>0>c>>>0?j<<a-c:j>>>c-a|0);k=a+e|0;a=k&31;v[h+4>>2]=a;f=f+(k>>>3&536870908)|0;v[h>>2]=f;d=d-e|0;if((d|0)>0){v[f>>2]=v[f>>2]&(-1>>>32-d^-1)|j>>>c+e;v[h+4>>2]=d;a=d}b=b+4|0;f=v[g+12>>2]}d=32-a|0;e=-1<<a;j=e^-1;while(1){if((f|0)>=32){c=v[h>>2];f=v[b>>2];v[c>>2]=j&v[c>>2]|f<<a;v[h>>2]=c+4;v[c+4>>2]=e&v[c+4>>2]|f>>>d;f=v[g+12>>2]-32|0;v[g+12>>2]=f;b=b+4|0;continue}break}if((f|0)<=0){break d}j=v[b>>2];v[g+8>>2]=d;c=v[h>>2];b=v[c>>2];k=b;b=v[td(g+12|0,g+8|0)>>2];d=k&(e&-1>>>d-b^-1);e=j&-1>>>32-f;v[c>>2]=d|e<<a;d=a+b|0;a=d&31;v[h+4>>2]=a;c=c+(d>>>3&536870908)|0;v[h>>2]=c;d=v[g+12>>2]-b|0;v[g+12>>2]=d;if((d|0)<=0){break d}v[c>>2]=v[c>>2]&(-1>>>32-d^-1)|e>>>b;a=v[g+12>>2];v[h+4>>2]=a}gc(i,v[h>>2],a);jb=g+16|0}jb=l+16|0}function Gr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-128|0;jb=i;v[i+120>>2]=b;k=rG(c,d);v[i+4>>2]=1071;m=qG(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Jd(k);if(!j){v[23296]=0;Z(1072);a=v[23296];v[23296]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}Oe(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[23296]=0;h=Q(1073,a|0,i+120|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[23296]=0;b=Q(1074,a|0,i+120|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}b=v[a>>2];v[23296]=0;n=T(1075,b|0)|0;b=v[23296];v[23296]=0;g:{if((b|0)!=1){if(g){break g}v[23296]=0;n=Q(1076,e|0,n|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}q=o+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=q;if(!r){continue e}v[23296]=0;T(1077,a|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Fb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=t[Yf(b,o)|0];j:{if(g){break j}v[23296]=0;p=Q(1076,e|0,p<<24>>24)|0;s=v[23296];v[23296]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n&255)==(p&255)){r=1;if((Fb(b)|0)!=(q|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Qc(m);jb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!De(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Qc(m);S(b|0)}L()}function oi(a,b,c,d,e){var f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;q=c*d;r=b*e;m=q+r;s=b*d;t=c*e;p=s-t;a:{if(!si(p)){break a}if(!si(m)){break a}h=af(b);f=af(c);k=h|f;if((k|0)==1){o(+(f?1:0));f=j(1)|0;i=j(0)|0;o(+c);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);c=+n();o(0);f=j(1)|0;i=j(0)|0;o(+d);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);d=(u=+n(),v=d,w=si(d),w?u:v);o(0);f=j(1)|0;i=j(0)|0;o(+e);g=j(1)|0;j(0)|0;l(0,i|0);l(1,f&2147483647|g&-2147483648);e=(u=+n(),v=e,w=si(e),w?u:v);o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=+n()}h=af(d);f=af(e);b:{if(f?1:h){o(+(f?1:0));f=j(1)|0;g=j(0)|0;o(+e);k=j(1)|0;j(0)|0;l(0,g|0);l(1,f&2147483647|k&-2147483648);e=+n();o(+(h?1:0));h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=+n();o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=si(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=si(c),w?u:v);break b}if(k){break b}c:{if(af(s)){break c}if(af(t)){break c}if(af(r)){break c}if(!af(q)){break a}}o(0);h=j(1)|0;g=j(0)|0;o(+b);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);b=(u=+n(),v=b,w=si(b),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+c);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);c=(u=+n(),v=c,w=si(c),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+d);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);d=(u=+n(),v=d,w=si(d),w?u:v);o(0);h=j(1)|0;g=j(0)|0;o(+e);f=j(1)|0;j(0)|0;l(0,g|0);l(1,h&2147483647|f&-2147483648);e=(u=+n(),v=e,w=si(e),w?u:v)}m=(b*e+d*c)*N;p=(b*d-e*c)*N}Wk(a,p,m)}function Z8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;c=jb-208|0;jb=c;e=Dl(c+104|0,a);v[23296]=0;d=Q(396,c+88|0,43806)|0;a=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{if((a|0)!=1){v[23296]=0;v[c+72>>2]=19923969;v[c+76>>2]=0;U(397,e|0,d|0,c+72|0);a=v[23296];v[23296]=0;if((a|0)==1){break n}Tb(d);if(w[e+3|0]&64){break e}v[23296]=0;d=Q(396,c+72|0,13188)|0;a=v[23296];v[23296]=0;if((a|0)==1){break m}v[23296]=0;X(428,e|0,b|0,d|0,824);a=v[23296];v[23296]=0;if((a|0)==1){break l}Tb(d);v[c+68>>2]=0;v[c+64>>2]=0;v[23296]=0;d=Q(396,c+48|0,16569)|0;a=v[23296];v[23296]=0;if((a|0)==1){break k}v[23296]=0;U(825,e|0,c+68|0,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break j}Tb(d);v[23296]=0;d=Q(396,c+32|0,16541)|0;a=v[23296];v[23296]=0;if((a|0)==1){break i}v[23296]=0;U(825,e|0,c- -64|0,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}Tb(d);a=v[c+68>>2];d=v[c+64>>2];o:{if(!a|d>>>0<a>>>0){break o}f=v[v[v[v[b+48>>2]+12>>2]+8>>2]+40>>2];if(f>>>0<a>>>0|d>>>0>f>>>0){break o}v[b+20>>2]=d;v[b+16>>2]=a}d=Qb(c+16|0);v[23296]=0;f=Q(396,c|0,13965)|0;a=v[23296];v[23296]=0;if((a|0)==1){break d}v[23296]=0;U(826,e|0,d|0,f|0);a=v[23296];v[23296]=0;if((a|0)==1){break g}Tb(f);if(uc(v[d>>2],v[d+4>>2])){break f}a=v[b+16>>2];v[23296]=0;R(779,d|0,a|0);a=v[23296];v[23296]=0;if((a|0)!=1){break f}break c}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(d);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;Tb(d);break a}a=P()|0;O()|0;Tb(f);break b}v[23296]=0;R(827,b|0,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}vc(d)}_g(e);jb=c+208|0;return}a=P()|0;O()|0;break b}a=P()|0;O()|0}vc(d)}_g(e);S(a|0);L()}function wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0;g=jb-48|0;jb=g;o=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;j=e+(g+24|0)|0;e=a+e|0;v[j+4>>2]=v[e+44>>2];v[j+8>>2]=v[e+48>>2];f=f+1|0;continue}break}j=v[a+24>>2];p=v[a+20>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){f=v[g+16>>2];k=((((v[g+20>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;i=u[b+14>>1];h=u[b+12>>1];l=u[b+10>>1];m=u[b+8>>1];n=u[b+6>>1];D=u[b+4>>1];E=u[b+2>>1];F=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=k+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((((B(u[b+8>>1],l)+B(u[b+4>>1],m)|0)+B(h,u[b+12>>1])|0)+B(i,u[b+16>>1])|0)/2|0)+((((B(u[b-8>>1],E)+B(u[b-12>>1],F)|0)+B(u[b-4>>1],D)|0)+B(u[b>>1],n)|0)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){k=(g+8|0)+(f<<2)|0;e=v[k>>2];b=(g+24|0)+(f<<3)|0;i=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;l=e<<8;e=l;e=Sia(y,z,e,e>>31);m=mb;n=b;b=Yb(h,-16777216,16776704);h=Sia(w,x,b,b>>31);e=h+e|0;b=mb+m|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Yb(i,-16777216,16776704);i=Sia(s,t,e,e>>31);e=h+i|0;b=mb+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Rc(e,b,24);v[n+4>>2]=b-(l&r);v[k>>2]=(b|0)/256;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],p);v[c+4>>2]=v[c+4>>2]+B(j,v[g+12>>2]);Sb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}jb=g+48|0}function Dr(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;i=jb-128|0;jb=i;v[i+120>>2]=b;k=rG(c,d);v[i+4>>2]=1071;m=qG(i+8|0,i+4|0);j=i+16|0;a:{b:{if(k>>>0>=101){j=Jd(k);if(!j){v[23296]=0;Z(1072);a=v[23296];v[23296]=0;if((a|0)!=1){break a}b=P()|0;O()|0;break b}Oe(m,j)}h=j;b=c;while(1){if((b|0)==(d|0)){c:{d:{e:while(1){f:{v[23296]=0;h=Q(1089,a|0,i+120|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break f}if(!(h&(k|0)!=0)){v[23296]=0;b=Q(1090,a|0,i+120|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}if(!b){break d}v[f>>2]=v[f>>2]|2;break d}b=v[a>>2];v[23296]=0;n=T(1091,b|0)|0;b=v[23296];v[23296]=0;g:{if((b|0)!=1){if(g){break g}v[23296]=0;n=Q(1092,e|0,n|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break g}}b=P()|0;O()|0;break b}q=o+1|0;r=0;h=j;b=c;while(1){if((b|0)==(d|0)){o=q;if(!r){continue e}v[23296]=0;T(1093,a|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){h=j;b=c;if(k+l>>>0<2){continue e}while(1){if((b|0)==(d|0)){continue e}h:{if(w[h|0]!=2){break h}if((Fb(b)|0)==(o|0)){break h}t[h|0]=0;l=l-1|0}h=h+1|0;b=b+12|0;continue}}b=P()|0;O()|0;break b}i:{if(w[h|0]!=1){break i}p=v[ij(b,o)>>2];j:{if(g){break j}v[23296]=0;p=Q(1092,e|0,p|0)|0;s=v[23296];v[23296]=0;if((s|0)!=1){break j}b=P()|0;O()|0;break b}k:{if((n|0)==(p|0)){r=1;if((Fb(b)|0)!=(q|0)){break i}t[h|0]=2;l=l+1|0;break k}t[h|0]=0}k=k-1|0}h=h+1|0;b=b+12|0;continue}}break}b=P()|0;O()|0;break b}l:{m:{while(1){if((c|0)==(d|0)){break m}if(w[j|0]!=2){j=j+1|0;c=c+12|0;continue}break}d=c;break l}v[f>>2]=v[f>>2]|4}Qc(m);jb=i+128|0;return d|0}b=P()|0;O()|0}else{n:{if(!De(b)){t[h|0]=1;break n}t[h|0]=2;l=l+1|0;k=k-1|0}h=h+1|0;b=b+12|0;continue}break}}Qc(m);S(b|0)}L()}function z5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb+-64|0;jb=d;f=1;a:{if(De(c)){break a}e=w[yJ(c)|0];if((e|0)!=33){if((e|0)!=63){break a}f=0}e=d+48|0;Cv(e,c,0,Fb(c)-1|0);Bc(c,e);yb(e)}e=d+48|0;Qd(e);g=v[d+48>>2];Qd(d+40|0);g=xJ(g,v[d+44>>2],c);Qd(e);b:{c:{d:{e:{f:{if((g|0)==v[d+52>>2]){if(ne(c,21473)){a=ba(8)|0;v[23296]=0;b=Q(54,d+48|0,10374)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}if(!f){break f}a=ba(8)|0;v[23296]=0;U(906,d+48|0,17488,c|0);b=v[23296];v[23296]=0;if((b|0)!=1){a=sc(a,d+48|0);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(d+48|0);break c}c=P()|0;O()|0;ca(a|0);break c}e=Kb(d+48|0);g:{h:{i:{j:{switch(v[g+4>>2]){case 0:ve(d+32|0,c);v[23296]=0;b=fa(907,b|0,v[d+32>>2],v[d+36>>2],f|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){v[23296]=0;t[d+40|0]=b;R(908,a|0,d+40|0);a=v[23296];v[23296]=0;if((a|0)!=1){break g}}break i;case 1:ve(d+24|0,c);v[23296]=0;b=_E(b,v[d+24>>2],v[d+28>>2],f);c=mb;f=v[23296];v[23296]=0;if((f|0)!=1){v[23296]=0;v[d+40>>2]=b;v[d+44>>2]=c;R(910,a|0,d+40|0);a=v[23296];v[23296]=0;if((a|0)!=1){break g}}break i;case 2:ve(d+16|0,c);v[23296]=0;h=+za(911,b|0,v[d+16>>2],v[d+20>>2],f|0);b=v[23296];v[23296]=0;if((b|0)!=1){v[23296]=0;A[d+40>>3]=h;R(912,a|0,d+40|0);a=v[23296];v[23296]=0;if((a|0)!=1){break g}}break i;case 3:break j;default:break h}}ve(d+8|0,c);v[23296]=0;da(913,a|0,b|0,v[d+8>>2],v[d+12>>2],f|0);a=v[23296];v[23296]=0;if((a|0)!=1){break g}}c=P()|0;O()|0;yb(e);break c}Sc(a,e)}yb(e);break e}Kb(a)}jb=d- -64|0;return}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function xba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0,F=0,G=0;g=jb-48|0;jb=g;o=v[a+16>>2];while(1){if((f|0)!=2){e=f<<3;j=e+(g+24|0)|0;e=a+e|0;v[j+4>>2]=v[e+44>>2];v[j+8>>2]=v[e+48>>2];f=f+1|0;continue}break}j=v[a+24>>2];p=v[a+20>>2];f=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=f;q=b+24|0;r=v[a+72>>2];b=v[a+68>>2];s=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){if(d){f=v[g+16>>2];k=(((v[g+20>>2]&2147483647)<<1|f>>>31)&-2)+o|0;b=(((f>>>16|0)+4&131064)<<1)+q|0;i=u[b+14>>1];h=u[b+12>>1];l=u[b+10>>1];m=u[b+8>>1];n=u[b+6>>1];E=u[b+4>>1];F=u[b+2>>1];G=u[b>>1];f=0;e=0;while(1){if((e|0)!=2){b=e+k|0;v[(g+8|0)+(e<<2)>>2]=(((((B(t[b+4|0],l)+B(t[b+2|0],m)|0)+B(h,t[b+6|0])|0)+B(i,t[b+8|0])<<8)/2|0)+((((B(t[b-4|0],F)+B(t[b-6|0],G)|0)+B(t[b-2|0],E)|0)+B(t[b|0],n)<<8)/2|0)|0)/16384;e=e+1|0;continue}break}while(1){if((f|0)!=2){k=(g+8|0)+(f<<2)|0;e=v[k>>2];b=(g+24|0)+(f<<3)|0;i=v[b+8>>2];h=v[b+4>>2];v[b+8>>2]=h;l=e<<8;e=l;e=Sia(z,A,e,e>>31);m=mb;n=b;b=Yb(h,-16777216,16776704);h=Sia(x,y,b,b>>31);e=h+e|0;b=mb+m|0;b=e>>>0<h>>>0?b+1|0:b;h=e;e=Yb(i,-16777216,16776704);i=Sia(s,w,e,e>>31);e=h+i|0;b=mb+b|0;b=e>>>0<i>>>0?b+1|0:b;e=e+8388608|0;b=e>>>0<8388608?b+1|0:b;b=Rc(e,b,24);v[n+4>>2]=b-(l&r);v[k>>2]=(b|0)/256;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],p);v[c+4>>2]=v[c+4>>2]+B(j,v[g+12>>2]);Sb(g+16|0,C,D);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;f=0;while(1){if((f|0)!=2){b=f<<3;c=b+a|0;b=b+(g+24|0)|0;v[c+44>>2]=v[b+4>>2];v[c+48>>2]=v[b+8>>2];f=f+1|0;continue}break}jb=g+48|0}function Haa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0,x=0,y=0,z=0;h=jb-48|0;jb=h;f=vO(h+32|0,1<<v[b+12>>2]);g=v[f>>2];while(1){c=v[a>>2];if(Hg(c,v[a+4>>2])>>>0>d>>>0){c=Re(c,d);uO(ed(g,d),A[c>>3]);d=d+1|0;continue}break}tO(b,f);x=h,y=Eb(v[f>>2]),v[x+8>>2]=y;w=Eb(v[f+4>>2]);while(1){g=v[h+8>>2];if(Rb(g,w)){m=A[g+8>>3];k=jb-32|0;jb=k;o(+A[g>>3]);e=j(1)|0;r=j(0)|0;o(+m);c=j(1)|0;s=j(0)|0;q=e&2147483647;t=c&2147483647;d=t;c=(q|0)==(d|0)&r>>>0<s>>>0|d>>>0>q>>>0;e=c?r:s;c=c?q:d;d=c;l(0,e|0);l(1,c|0);p=+n();u=c>>>20|0;i=p;a:{if((u|0)==2047){break a}c=(q|0)==(t|0)&r>>>0>s>>>0|q>>>0>t>>>0;l(0,(c?r:s)|0);c=c?q:t;l(1,c|0);m=+n();b:{if(!(d|e)){break b}c=c>>>20|0;if((c|0)==2047){break b}i=m+p;if((c-u|0)>=65){break a}c:{if(c>>>0>=1534){p=p*190109156629516e-225;m=m*190109156629516e-225;i=5.260135901548374e210;break c}i=1;if(u>>>0>572){break c}p=p*5.260135901548374e210;m=m*5.260135901548374e210;i=190109156629516e-225}JH(k+24|0,k+16|0,m);JH(k+8|0,k,p);i=i*K(A[k>>3]+A[k+16>>3]+A[k+8>>3]+A[k+24>>3]);break a}i=m}p=i;jb=k+32|0;uO(g,lp(p));eo(h+8|0);continue}break}sO(b,f);rO(f);e=v[f>>2];g=hh(e,v[f+4>>2])>>>1|0;c=g>>>0>1?g:1;d=1;while(1){if((c|0)!=(d|0)){fz(ed(e,d),2);fz(ed(e,d+g|0),0);d=d+1|0;continue}break}tO(b,f);x=h,y=Eb(v[f>>2]),v[x+24>>2]=y;g=Eb(v[f+4>>2]);while(1){e=v[h+24>>2];if(Rb(e,g)){qO(h+8|0,A[e>>3],A[e+8>>3]);c=v[h+20>>2];v[e+8>>2]=v[h+16>>2];v[e+12>>2]=c;c=v[h+12>>2];v[e>>2]=v[h+8>>2];v[e+4>>2]=c;eo(h+24|0);continue}break}sO(b,f);rO(f);g=v[a>>2];c=Hg(g,v[a+4>>2]);b=v[f>>2];d=0;while(1){if((c|0)==(d|0)){dl(f);jb=h+48|0}else{a=ed(b,d);x=Re(g,d),z=A[a>>3],A[x>>3]=z;d=d+1|0;continue}break}}function $V(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=jb+-64|0;jb=f;Ac(b);No(a);a:{if(!Zh(b,f+56|0)){break a}if(!mD(f+56|0)){break a}if(!c){l=1;break a}if(!Ob(v[b>>2],v[b+8>>2],4)){break a}yv(a);p=f,q=xv(),v[p+32>>2]=q;c=f+32|0;wv(Cj(v[a+4>>2])+32|0,c);gr(c);k=v[Cj(v[a+4>>2])+32>>2];c=Ig(v[b>>2]);if(c&1){break a}d=c-4|0;$c(b,d);h=jb-16|0;jb=h;c=h+8|0;lv(c,b);e=w[Lb(c,0)|0];i=w[Lb(c,1)|0];c=w[Lb(c,2)|0];jb=h+16|0;h=c|(i<<8|e<<16);if(!h){break a}v[23296]=0;R(163,k|0,h|0);c=v[23296];v[23296]=0;l=1;if((c|0)==1){a=V(91780)|0;if((O()|0)==(ea(91780)|0)){_(a|0)|0;$();l=0;break a}S(a|0);L()}$c(b,4);m=f+32|0;lD(m,b);i=v[k>>2];e=jb-32|0;jb=e;b=v[f+32>>2];t[e+24|0]=w[b|0];t[e+25|0]=w[b+1|0];t[e+26|0]=w[b+2|0];t[e+27|0]=w[b+3|0];c=Zq(e+8|0);d=b+d|0;v[c+12>>2]=d-4;v[c+8>>2]=b;Bj(c,w[d-1|0]);b=h;b:while(1){c:{d:{e:{if(!b){break e}if(Bj(c,1)){break d}d=1;while(1){g=Bj(c,2);d=g+d|0;if((g|0)==3){continue}break}v[e+4>>2]=d;yc(e+4|0,b);d=0;g=v[e+4>>2];while(1)if((d|0)==(g|0)){if(!b){break e}break d}else{b=b-1|0;p=i+b|0,q=Bj(c,8),t[p|0]=q;d=d+1|0;continue}}jb=e+32|0;break c}g=Bj(c,2);d=g+2|0;v[e+4>>2]=d;f:{if((g|0)==3){if(Bj(c,1)){g=w[Lb(e+24|0,3)|0]}else{g=7}g=Bj(c,g);while(1){j=Bj(c,3);d=j+d|0;if((j|0)==7){continue}break}v[e+4>>2]=d;break f}g=Bj(c,w[Lb(e+24|0,g)|0])}yc(e+4|0,b);d=0;o=v[e+4>>2];while(1){if((d|0)==(o|0)){continue b}j=0;n=b+g|0;if(h>>>0>n>>>0){j=w[i+n|0]}b=b-1|0;t[i+b|0]=j;d=d+1|0;continue}}break}ke(f+16|0,v[k>>2],v[k+4>>2]);Og(f+24|0,v[f+16>>2],v[f+20>>2]);b=$d(f+8|0);b=er(m,v[f+24>>2],v[f+28>>2],v[b>>2],v[b+4>>2]);cd(Cj(v[a+4>>2])+12|0,b);Ab(b)}jb=f- -64|0;return l|0}function Yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=jb-48|0;jb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){e=v[g+16>>2];m=((((v[g+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+o|0;b=e>>>21&2040;j=u[b+39718>>1];i=u[b+39716>>1];n=u[b+39714>>1];l=u[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=m+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((B(u[f>>1],n)+B(u[f-4>>1],l)|0)+B(i,u[f+4>>1])|0)+B(j,u[f+8>>1])|0)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=v[m>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Sia(y,z,f,f>>31);l=mb;D=e;e=Yb(i,-16777216,16776704);i=Sia(w,x,e,e>>31);f=i+f|0;e=mb+l|0;e=f>>>0<i>>>0?e+1|0:e;l=f;f=Yb(j,-16777216,16776704);j=Sia(s,t,f,f>>31);f=l+j|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Rc(f,e,24);v[D+4>>2]=e-(n&r);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Sb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function Uga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=jb-16|0;jb=g;i=gf(a,c);ae(g,v[a+28>>2]);j=a;a:{if(!i){c=0;if(hd(a,5)){break a}}e=jb-192|0;jb=e;f=Dl(e+88|0,v[a+28>>2]);v[23296]=0;a=Q(396,e+72|0,27647)|0;c=v[23296];v[23296]=0;b:{c:{d:{e:{if((c|0)!=1){v[23296]=0;v[e+8>>2]=19923969;v[e+12>>2]=0;U(397,f|0,a|0,e+8|0);c=v[23296];v[23296]=0;if((c|0)==1){break e}Tb(a);if(!(w[f+3|0]&64)){break d}break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;Tb(a);break c}t[e+71|0]=0;t[e+70|0]=0;v[23296]=0;a=Q(396,e+56|0,9986)|0;c=v[23296];v[23296]=0;f:{g:{h:{i:{if((c|0)!=1){v[23296]=0;U(436,f|0,e+71|0,a|0);c=v[23296];v[23296]=0;if((c|0)==1){break i}Tb(a);if(!w[e+71|0]){break b}nf(e+71|0,50);v[23296]=0;a=Q(396,e+40|0,13078)|0;c=v[23296];v[23296]=0;if((c|0)==1){break f}v[23296]=0;U(436,f|0,e+70|0,a|0);c=v[23296];v[23296]=0;if((c|0)==1){break g}Tb(a);a=v[b>>2];c=kj(a,v[b+4>>2]);h=w[e+71|0];if(c>>>0<h>>>0){a=tz(e+8|0,v[b+12>>2]);v[23296]=0;U(437,b|0,h|0,a|0);c=v[23296];v[23296]=0;if((c|0)==1){break h}Yk(a);a=v[b>>2]}k=x[pj(a,0)+28>>1];c=0;j:{while(1){a=c&255;if(a>>>0>=h>>>0){a=w[e+70|0];n=b,o=kj(v[b>>2],v[b+4>>2])>>>0>a>>>0?a:0,t[n+16|0]=o;break b}_e(pj(v[b>>2],a),k);l=v[b>>2];v[23296]=0;R(438,e+8|0,c|0);m=v[23296];v[23296]=0;if((m|0)!=1){v[23296]=0;X(439,f|0,pj(l,a)|0,e+8|0,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break j}c=c+1|0;Tb(e+8|0);continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;Tb(e+8|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;Tb(a);break c}c=P()|0;O()|0;Yk(a);break c}c=P()|0;O()|0;Tb(a);break c}c=P()|0;O()|0}_g(f);S(c|0);L()}_g(f);jb=e+192|0;c=i}$e(j,c);jb=g+16|0}function Zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0,E=0;g=jb-48|0;jb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;w=b>>31;b=v[a+64>>2];x=b;y=b>>31;b=v[a+60>>2];z=b;A=b>>31;C=v[a+8>>2];D=v[a+12>>2];while(1){if(d){e=v[g+16>>2];m=(((v[g+20>>2]&2147483647)<<1|e>>>31)&-2)+o|0;b=e>>>21&2040;j=u[b+39718>>1];i=u[b+39716>>1];n=u[b+39714>>1];l=u[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=e+m|0;v[(g+8|0)+(e<<2)>>2]=(((B(t[f|0],n)+B(t[f-2|0],l)|0)+B(i,t[f+2|0])|0)+B(j,t[f+4|0])<<8)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=v[m>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Sia(z,A,f,f>>31);l=mb;E=e;e=Yb(i,-16777216,16776704);i=Sia(x,y,e,e>>31);f=i+f|0;e=mb+l|0;e=f>>>0<i>>>0?e+1|0:e;l=f;f=Yb(j,-16777216,16776704);j=Sia(s,w,f,f>>31);f=l+j|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Rc(f,e,24);v[E+4>>2]=e-(n&r);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Sb(g+16|0,C,D);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function gda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;h=jb-48|0;jb=h;j=c+484344|0;mg(j,w[b+70|0]|w[b+71|0]<<8);a:{b:{while(1){if((w[b+70|0]|w[b+71|0]<<8)>>>0<=i>>>0){break b}g=v[a+8>>2];e=qg(a);ac(a,1);c:{if((w[b+58|0]|w[b+59|0]<<8)==258){c=Ee(a)+1|0;break c}c=Fg(a)}d=Fg(a);$c(a,e+g|0);Yd(h,a,d);g=jc(h+24|0,h);Ab(h);v[23296]=0;c=W(214,j|0,i&65535,(c?c>>>0<1024?c:1024:64)|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){d:{if(!(c&(d|0)!=0)){break d}c=$b(v[j>>2],i);m=h,n=Eb(v[c>>2]),v[m>>2]=n;k=Eb(v[c+4>>2]);while(1){c=v[h>>2];if(!Rb(c,k)){break d}v[23296]=0;d=T(194,g|0)|0;e=v[23296];v[23296]=0;e:{f:{g:{if((e|0)!=1){if(!(d&128)){break g}if(d&1){v[23296]=0;e=T(194,g|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break a}t[c|0]=e}if(d&2){break f}break e}break a}t[c|0]=d;d=255}v[23296]=0;e=T(194,g|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break a}t[c+1|0]=e}e=0;if(d&4){v[23296]=0;e=T(194,g|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break a}}if(d&8){v[23296]=0;f=T(194,g|0)|0;l=v[23296];v[23296]=0;if((l|0)==1){break a}t[c+3|0]=f}if(d&16){v[23296]=0;d=T(194,g|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break a}t[c+5|0]=d}h:{i:{d=w[c|0];if(!d){break i}f=255;if((d|0)==97){break h}if(d>>>0>96){break i}f=d+12|0;break h}f=0}t[c|0]=f;j:{if(w[c+5|0]|w[c+3|0]){Of(c);break j}t[c+3|0]=0}if(w[c+1|0]==255){t[c+1|0]=0}d=e-16|0;k:{if((d&255)>>>0<=64){t[c+4|0]=d;t[c+2|0]=1;break k}if(e>>>0<96){break k}d=e&15;t[c+4|0]=d;e=e-96>>4;t[c+2|0]=w[e+26974|0];if((e|0)!=6){break k}t[c+4|0]=d<<2}kk(h);continue}}Ab(g);i=i+1|0;continue}break}break a}jb=h+48|0;return}a=P()|0;O()|0;Ab(g);S(a|0);L()}function Tg(a,b,c,d,e){var f=0,g=0,h=0;if(!b){c=jb-16|0;jb=c;a:{if((d|0)==189){t[a+3843|0]=e>>>7;t[a+3844|0]=e>>>6&1;break a}b=d&224;if(!b){if((d|0)!=8){if((d|0)!=260){break a}b=0;d=1;while(1){if((b|0)==6){break a}f=B(b>>>0<3?b:b+6|0,44)+a|0;g=f+148|0;f=f+16|0;h=d&e;b:{if(h){Zn(f,g);break b}Zn(f,0)}t[g+40|0]=!h;b=b+1|0;d=d<<1&510;continue}}t[a+3842|0]=e>>>6&1;b=0;while(1){if((b|0)==18){break a}mz((B(b,44)+a|0)+16|0);b=b+1|0;continue}}if(b-160>>>0<=32){b=d&15;if(b>>>0>8){break a}a=B(d&256?b+9|0:b,44)+a|0;v[c+8>>2]=a+16;b=v[a+52>>2];v[c+12>>2]=b;g=b?2:1;c:{b=d&240;if((b|0)!=160){if((b|0)==192){break c}if((b|0)!=176){break a}f=e&3;h=e>>>2&7;b=0;d=(e&32)!=0;while(1){if((b|0)==(g|0)){break a}a=v[(c+8|0)+(b<<2)>>2];GO(v[a>>2],d);GO(v[a+4>>2],d);u[a+22>>1]=h;lz(a);mz(a);t[a+21|0]=f;lz(a);mz(a);b=b+1|0;continue}}b=0;while(1){if((b|0)==(g|0)){break a}a=v[(c+8|0)+(b<<2)>>2];u[a+20>>1]=x[a+20>>1]&768|e&255;lz(a);b=b+1|0;continue}}t[a+58|0]=(e&32)>>>5;t[a+57|0]=(e&16)>>>4;b=e>>>1&7;u[a+46>>1]=b?9-b|0:0;u[a+48>>1]=e&1;break a}if((b|0)!=224&b>>>0>=129|-4144960>>>d&1){break a}f=a;a=t[(d&31)+28832|0];a=(f+B(d&256?a+18|0:a,84)|0)+808|0;d:{switch(b-32>>>5|0){case 0:t[a+79|0]=e>>>7;t[a+80|0]=(e&64)>>>6;t[a+78|0]=(e&32)>>>5;t[a+77|0]=(e&16)>>>4;_n(a);u[a+14>>1]=x[((e&15)<<1)+28864>>1];break a;case 1:u[a+68>>1]=w[(e>>>6|0)+21458|0];HO(a);u[a+22>>1]=(e&63)<<2;break a;case 2:u[a+24>>1]=e>>>4;_n(a);u[a+26>>1]=e&15;_n(a);break a;case 3:b=e>>>4|0;u[a+28>>1]=b>>>0<15?b<<4:496;u[a+30>>1]=e&15;_n(a);break a;case 6:break d;default:break a}}u[a+12>>1]=e&7}jb=c+16|0;return}nb[v[v[b>>2]>>2]](b,c,d,e)}function Dq(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{d=w[a|0];switch(d|0){case 1:case 6:case 7:case 8:case 10:case 12:case 14:case 15:case 16:case 17:case 18:case 19:break a;case 2:break j;case 13:break k;case 0:break l;case 5:break c;case 9:break e;case 11:break f;case 20:break g;case 4:break h;case 3:break i;default:break d}}t[a|0]=0;break b}e=1;t[a|0]=1;t[f+15|0]=64;h=b,i=w[Wb(b,f+15|0)|0],t[h|0]=i;break a}d=c;c=w[b|0];if(!(c&3|c>>>0>223?d:1)){break a}t[b|0]=(c&252)>>>2;t[a|0]=12;break b}d=c;c=w[b|0];if(!(c&3|c>>>0>223?d:1)){break a}t[b|0]=(c&252)>>>2;t[a|0]=13;break b}d=w[b|0];if(d>>>0<240){while(1){if((e|0)==10){e=0;break a}g=w[e+43744|0];m:{n:{if(c){if(d>>>0<=g>>>0){break n}break m}if((d|0)!=(g|0)){break m}}t[a|0]=11;t[b|0]=e;e=e>>>0<10;break a}e=e+1|0;continue}}t[a|0]=11;t[b|0]=9;break b}o:{p:{q:{d=w[b|0]>>>4|0;switch(d|0){case 3:case 4:case 5:case 6:case 7:break a;case 8:break o;case 0:case 1:case 2:break p;default:break q}}if((d|0)!=15){break a}}if(!c){break a}t[b|0]=0;t[a|0]=0;break b}t[a|0]=2;t[b|0]=w[b|0]<<2&60|2;break b}c=w[b|0];if(!c){break a}d=c&15;if(!d){t[b|0]=c>>>4;t[a|0]=3;break b}g=c&240;if(!g){t[a|0]=4;break b}if((d|0)==15){t[b|0]=c>>>4;t[a|0]=5;break b}if((g|0)!=240){break a}t[b|0]=d;t[a|0]=6;break b}c=b;b=w[b|0];t[c|0]=(b|0)==255?64:b>>>2|0;t[a|0]=2;break b}if((d|0)!=26){break a}r:{if(c){t[b|0]=0;break r}if(w[b|0]){break a}}t[a|0]=8;break b}s:{if(c){t[f+14|0]=w[b|0]&15;t[f+13|0]=9;c=w[Wb(f+14|0,f+13|0)|0];break s}c=w[b|0];if((c&14)>>>0>9|c&240){break a}}t[b|0]=c&15;t[a|0]=8}e=1}jb=f+16|0;return e}function qL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{b:{d=b;e=v[b>>2];if(e){if(!v[b+4>>2]){break b}g=v[b+4>>2];c:{if(!g){while(1){g=sh(d);d=v[d+8>>2];if(!g){continue}break}break c}d=eS(g)}e=v[d>>2];if(e){break b}}e=v[d+4>>2];if(e){break b}e=0;g=1;break a}v[e+8>>2]=v[d+8>>2];g=0}d:{e:{if(sh(d)){c=v[d+8>>2];v[c>>2]=e;if((a|0)==(d|0)){a=e;c=0;break d}c=c+4|0;break e}c=v[d+8>>2];v[c+4>>2]=e}c=v[c>>2]}h=!w[d+12|0];if((b|0)!=(d|0)){f=v[b+8>>2];v[d+8>>2]=f;i=f+(sh(b)?0:4)|0,j=d,v[i>>2]=j;f=v[b>>2];v[d>>2]=f;Ml(f,d);f=v[b+4>>2];v[d+4>>2]=f;if(f){Ml(f,d)}t[d+12|0]=w[b+12|0];a=(a|0)==(b|0)?d:a}if(!(h|!a)){if(g){while(1){b=w[c+12|0];f:{g:{if(!sh(c)){if(!b){t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;Zp(b);b=v[c>>2];a=(b|0)==(a|0)?c:a;c=v[b+4>>2]}b=v[c>>2];h:{if(!(w[b+12|0]?0:b)){d=v[c+4>>2];if(w[d+12|0]?0:d){break h}t[c+12|0]=0;i:{b=v[c+8>>2];if((b|0)!=(a|0)){if(w[b+12|0]){break i}a=b}t[a+12|0]=1;return}if(!sh(b)){break g}b=v[b+8>>2]+4|0;break f}d=v[c+4>>2];if(w[d+12|0]?0:d){break h}t[b+12|0]=1;t[c+12|0]=0;Yp(c);c=v[c+8>>2];d=v[c+4>>2]}a=v[c+8>>2];t[c+12|0]=w[a+12|0];t[a+12|0]=1;t[d+12|0]=1;Zp(a);return}if(!b){t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;Yp(b);b=v[c+4>>2];a=(b|0)==(a|0)?c:a;c=v[b>>2]}d=v[c>>2];j:{if(w[d+12|0]?0:d){break j}b=v[c+4>>2];if(!(w[b+12|0]?0:b)){t[c+12|0]=0;b=v[c+8>>2];if(!((a|0)!=(b|0)?w[b+12|0]:0)){t[b+12|0]=1;return}if(sh(b)){b=v[b+8>>2]+4|0;break f}b=v[b+8>>2];break f}if(w[d+12|0]?0:d){break j}t[b+12|0]=1;t[c+12|0]=0;Zp(c);c=v[c+8>>2];d=v[c>>2]}a=v[c+8>>2];t[c+12|0]=w[a+12|0];t[a+12|0]=1;t[d+12|0]=1;Yp(a);return}b=v[b+8>>2]}c=v[b>>2];continue}}t[e+12|0]=1}}function Eha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-32|0;jb=e;t[e+24|0]=44;v[e+16>>2]=-1;v[e+20>>2]=0;v[e+8>>2]=1042;v[e+12>>2]=2;d=jb+-64|0;jb=d;j=v[e+8>>2]&2?16:10;l=jb-32|0;jb=l;g=Je(l+16|0,1,0);a:{b:{c:{while(1){m=l+8|0;c=tc(g);n=c;o=Fb(g)+c|0;i=x[b>>1];h=0;d:{if((j|0)==10){px(m,n,o,i);break d}f=i;c=B(j,j);q=B(c,j);p=B(c,c);e:{while(1){f=f&65535;k=h|1;if(f>>>0<j>>>0){break e}k=h|2;if(c>>>0>f>>>0){break e}k=h|3;if(f>>>0<q>>>0){break e}if(f>>>0<p>>>0){k=h+4|0}else{h=h+4|0;f=(f>>>0)/(p>>>0)|0;continue}break}}c=k;if((c|0)>(o-n|0)){v[m+4>>2]=61;v[m>>2]=o;break d}f=c+n|0;c=f;while(1){h=i&65535;i=(h|0)/(j|0)|0;c=c-1|0;t[c|0]=w[(h-B(i,j)|0)+4856|0];if(i&65535){continue}break}v[m+4>>2]=0;v[m>>2]=f}if(!v[l+12>>2]){break c}c=Hf(Fb(g));v[23296]=0;R(58,g|0,c|0);c=v[23296];v[23296]=0;if((c|0)!=1){continue}break}break b}b=v[l+8>>2];c=tc(g);v[23296]=0;R(59,g|0,b-c|0);b=v[23296];v[23296]=0;f:{if((b|0)!=1){v[23296]=0;R(71,d|0,g|0);b=v[23296];v[23296]=0;if((b|0)!=1){break f}break b}break b}yb(g);jb=l+32|0;break a}a=P()|0;O()|0;yb(g);S(a|0);L()}b=d+16|0;fs(b,d,v[e+8>>2]);c=v[e+12>>2];i=v[e+8>>2];v[23296]=0;X(75,d+32|0,b|0,i|0,c|0);b=v[23296];v[23296]=0;g:{h:{i:{j:{k:{if((b|0)!=1){b=w[e+24|0];c=v[e+20>>2];v[23296]=0;X(76,d+48|0,d+32|0,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break k}v[23296]=0;R(70,a|0,d+48|0);a=v[23296];v[23296]=0;if((a|0)==1){break j}zb(d+48|0);zb(d+32|0);zb(d+16|0);zb(d);jb=d- -64|0;break g}a=P()|0;O()|0;break h}a=P()|0;O()|0;break i}a=P()|0;O()|0;zb(d+48|0)}zb(d+32|0)}zb(d+16|0);zb(d);S(a|0);L()}jb=e+32|0}function m_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=jb-624|0;jb=a;v[a+608>>2]=c;v[a+616>>2]=b;v[a+16>>2]=1106;h=le(a+200|0,a+208|0,a+16|0);b=a+192|0;bd(b,e);v[23296]=0;i=T(1084,b|0)|0;b=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){t[a+191|0]=0;b=v[e+4>>2];v[23296]=0;b=pa(1114,a+616|0,c|0,d|0,a+192|0,b|0,f|0,a+191|0,i|0,h|0,a+196|0,a+608|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}if(!b){break e}b=w[14498]|w[14499]<<8|(w[14500]<<16|w[14501]<<24);t[a+183|0]=b;t[a+184|0]=b>>>8;t[a+185|0]=b>>>16;t[a+186|0]=b>>>24;b=w[14495]|w[14496]<<8|(w[14497]<<16|w[14498]<<24);v[a+176>>2]=w[14491]|w[14492]<<8|(w[14493]<<16|w[14494]<<24);v[a+180>>2]=b;v[23296]=0;X(1096,i|0,a+176|0,a+186|0,a+128|0);b=v[23296];v[23296]=0;if((b|0)==1){break g}v[a+4>>2]=1071;d=le(a+8|0,0,a+4|0);e=a+16|0;b=v[a+196>>2];c=b-v[h>>2]|0;if((c|0)<393){break f}Oe(d,Jd((c>>2)+2|0));e=v[d>>2];if(e){break f}v[23296]=0;Z(1072);b=v[23296];v[23296]=0;if((b|0)==1){break c}break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}if(w[a+191|0]){t[e|0]=45;e=e+1|0}c=v[h>>2];while(1){if(b>>>0<=c>>>0){t[e|0]=0;v[a>>2]=g;if((BG(a+16|0,a)|0)!=1){v[23296]=0;Y(1108,7918);b=v[23296];v[23296]=0;if((b|0)!=1){break a}break c}Qc(d)}else{b=a+128|0;j=e,k=w[(a+176|0)+(jw(b,b+40|0,v[c>>2])-b>>2)|0],t[j|0]=k;e=e+1|0;c=c+4|0;b=v[a+196>>2];continue}break}}v[23296]=0;b=Q(1090,a+616|0,a+608|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}if(b){v[f>>2]=v[f>>2]|2}b=v[a+616>>2];_b(a+192|0);Qc(h);jb=a+624|0;return b|0}c=P()|0;O()|0;break b}c=P()|0;O()|0;Qc(d)}_b(a+192|0);Qc(h);S(c|0);L()}L()}function t_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;a=jb-288|0;jb=a;v[a+272>>2]=c;v[a+280>>2]=b;v[a+16>>2]=1106;h=le(a+152|0,a+160|0,a+16|0);b=a+144|0;bd(b,e);v[23296]=0;i=T(18,b|0)|0;b=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{if((b|0)!=1){t[a+143|0]=0;b=v[e+4>>2];v[23296]=0;b=pa(1107,a+280|0,c|0,d|0,a+144|0,b|0,f|0,a+143|0,i|0,h|0,a+148|0,a+260|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}if(!b){break e}b=w[14498]|w[14499]<<8|(w[14500]<<16|w[14501]<<24);t[a+135|0]=b;t[a+136|0]=b>>>8;t[a+137|0]=b>>>16;t[a+138|0]=b>>>24;b=w[14495]|w[14496]<<8|(w[14497]<<16|w[14498]<<24);v[a+128>>2]=w[14491]|w[14492]<<8|(w[14493]<<16|w[14494]<<24);v[a+132>>2]=b;v[23296]=0;X(1082,i|0,a+128|0,a+138|0,a+118|0);b=v[23296];v[23296]=0;if((b|0)==1){break g}v[a+4>>2]=1071;d=le(a+8|0,0,a+4|0);e=a+16|0;b=v[a+148>>2];c=b-v[h>>2]|0;if((c|0)<99){break f}Oe(d,Jd(c+2|0));e=v[d>>2];if(e){break f}v[23296]=0;Z(1072);b=v[23296];v[23296]=0;if((b|0)==1){break c}break a}c=P()|0;O()|0;break b}c=P()|0;O()|0;break b}if(w[a+143|0]){t[e|0]=45;e=e+1|0}c=v[h>>2];while(1){if(b>>>0<=c>>>0){t[e|0]=0;v[a>>2]=g;if((BG(a+16|0,a)|0)!=1){v[23296]=0;Y(1108,7918);b=v[23296];v[23296]=0;if((b|0)!=1){break a}break c}Qc(d)}else{b=a+118|0;j=e,k=w[((mi(b,b+10|0,c)-a|0)+a|0)+10|0],t[j|0]=k;e=e+1|0;c=c+1|0;b=v[a+148>>2];continue}break}}v[23296]=0;b=Q(1074,a+280|0,a+272|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}if(b){v[f>>2]=v[f>>2]|2}b=v[a+280>>2];_b(a+144|0);Qc(h);jb=a+288|0;return b|0}c=P()|0;O()|0;break b}c=P()|0;O()|0;Qc(d)}_b(a+144|0);Qc(h);S(c|0);L()}L()}function G3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-48|0;jb=c;g=Qb(a);a:{b:{c:{d=b+36|0;a=v[d>>2];f=v[b+40>>2];d:{if(Rb(a,f)){Cc(c+40|0);break d}v[23296]=0;R(975,c+24|0,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}v[23296]=0;a=T(959,c+24|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break c}v[c+40>>2]=a;Wf(c+24|0);f=v[b+40>>2];a=v[b+36>>2]}if(!Rb(a,f)){d=v[c+40>>2];a=v[d>>2]}f=v[d+4>>2];v[23296]=0;R(169,g|0,Bn(a,f)|0);a=v[23296];v[23296]=0;e:{if((a|0)!=1){i=c,j=Eb(v[d>>2]),v[i+16>>2]=j;f=Eb(v[d+4>>2]);f:{g:{h:{i:{j:{k:{while(1){a=v[c+16>>2];if(!Rb(a,f)){Ik(c+40|0);jb=c+48|0;return}d=w[a+16|0];e=v[v[b+24>>2]+484360>>2];v[23296]=0;d=pj(e,d);R(976,c|0,d|0);e=v[23296];v[23296]=0;if((e|0)!=1){v[23296]=0;R(962,c+24|0,c|0);e=v[23296];v[23296]=0;if((e|0)==1){break k}v[23296]=0;R(171,g|0,c+24|0);e=v[23296];v[23296]=0;if((e|0)==1){break j}yb(c+24|0);zb(c);l:{if(!De(dx(v[g+4>>2]))){break l}e=w[a+12|0];v[23296]=0;e=Q(297,d|0,e|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break f}if(!e){break l}e=v[b+24>>2];h=v[e+1298404>>2];a=x[dc(v[d>>2],v[a+12>>2])>>1];d=v[e+484344>>2];v[23296]=0;R(969,c|0,$b(d,a)|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}v[23296]=0;X(223,c+24|0,0,h|0,c|0);a=v[23296];v[23296]=0;if((a|0)==1){break g}a=c+24|0;Bc(dx(v[g+4>>2]),a);yb(a);yb(c)}JI(c+16|0);continue}break}a=P()|0;O()|0;break e}a=P()|0;O()|0;break i}a=P()|0;O()|0;yb(c+24|0)}zb(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0;yb(c);break e}a=P()|0;O()|0;break e}a=P()|0;O()|0}Ik(c+40|0);break a}a=P()|0;O()|0;Wf(c+24|0);break a}a=P()|0;O()|0}Me(g);S(a|0);L()}function hy(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=jb-16|0;jb=e;i=YL(b,c);a:{if(!v[b+656>>2]|!(t[i+6|0]&1)){break a}f=v[i>>2];j=a+1074312|0;Bb(e+8|0,j,31);g=Cb(v[v[e+8>>2]>>2],v[e+12>>2]);d=Vu(v[b+656>>2],c);if(uc(v[d>>2],v[d+4>>2])){break a}g=f+(g^1)|0;Bb(e+8|0,j,31);f=w[d+12|0];b:{c:{if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){d:{if(!(f&2)){break d}h=w[d+14|0];k=!(v[a+480180>>2]&1048580)+x[Db(v[d>>2],h)>>1]|0;if(!(w[b+89|0]&8)|(!(f&4)|(h|0)!=w[d+16|0])){f=l}else{Bb(e+8|0,j,70);f=Cb(v[v[e+8>>2]>>2],v[e+12>>2])}if(f|(g|0)!=(k|0)){break d}g=x[Db(v[d>>2],w[d+13|0])>>1]}if(!(!(w[d+12|0]&4)|w[b+89|0]&8)){a=v[d>>2];if((x[Db(a,w[d+16|0])>>1]+1|0)!=(g|0)){break b}g=x[Db(a,w[d+15|0])>>1];Bb(e+8|0,j,93);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])|(c|0)!=1|v[b+88>>2]&2048){break b}t[i+6|0]=w[i+6|0]&254;break b}k=1;f=x[Kn(v[d+4>>2])>>1];if(g>>>0>f>>>0){break c}break b}e:{f:{if(!(!(f&4)|w[b+669|0]&8)){if(x[i+4>>1]==65535){break f}Bb(e+8|0,j,97);if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}f=w[d+12|0]}if(f&2){h=v[d>>2];f=x[Db(h,w[d+13|0])>>1];h=x[Db(h,w[d+14|0])>>1]+1|0;break e}f=x[Kn(v[d+4>>2])>>1];k=g>>>0>f>>>0;h=f;break e}h=v[d>>2];f=x[Db(h,w[d+15|0])>>1];h=x[Db(h,w[d+16|0])>>1]+1|0}f=g>>>0<h>>>0?g:f}g:{if(!k|c){break g}g=v[a+480180>>2];c=v[b+88>>2];if(!(!(g&16777248)&(!(c&2048)|(g|0)==16384))){c=c|4096;v[b+88>>2]=c}if(w[Kn(v[d+4>>2])+2|0]|!(v[a+480180>>2]&16777248?1:x[b+786>>1])){break g}v[b+696>>2]=0;v[b+720>>2]=0;v[b+680>>2]=0;v[b+88>>2]=c|4096}g=f}Bb(e+8|0,j,31);m=i,n=Cb(v[v[e+8>>2]>>2],v[e+12>>2])+g|0,v[m>>2]=n}jb=e+16|0}function Os(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=jb-144|0;jb=g;a:{b:{c:{d:{e:{f:{g:{h:{if(!d){break h}e=v[d+4>>2];if(!e&c>>>0<=y[d>>2]|e){break h}a=ba(8)|0;v[23296]=0;b=Q(26,a|0,21473)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break g}b=P()|0;O()|0;ca(a|0);break a}if(!b){a=ba(8)|0;v[23296]=0;b=T(768,a|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break f}b=P()|0;O()|0;ca(a|0);break a}e=jb-16|0;jb=e;Og(e+8|0,b,c);h=g+120|0;JD(h,v[e+8>>2],v[e+12>>2]);v[h+12>>2]=0;jb=e+16|0;i:{j:{if(a&2){b=Jm(g+96|0,h);v[23296]=0;b=T(769,b|0)|0;f=v[23296];v[23296]=0;e=1;if((f|0)==1){break i}if((b|0)==1){break j}e=Jm(g+72|0,h);v[23296]=0;f=T(770,e|0)|0;i=v[23296];v[23296]=0;e=1;if((i|0)==1){break e}k=(f|0)==1;if(k){break j}e=Jm(g+48|0,h);v[23296]=0;i=Q(771,e|0,d|0)|0;j=v[23296];v[23296]=0;e=1;if((j|0)==1){break d}l=(i|0)==1;if(l){break j}e=Jm(g+24|0,h);v[23296]=0;j=Q(772,e|0,d|0)|0;m=v[23296];v[23296]=0;e=1;if((m|0)==1){break c}if((j|0)==1){break j}b=(b|0)==-1?-1:0;b=k?b:(f|0)==-1?-1:b;f=(j|0)==-1?-1:l?b:(i|0)==-1?-1:b}k:{if(!(a&1)){break k}b=31392;while(1){if((b|0)==31908){break k}a=v[b>>2];if(a){e=Jm(g,h);v[23296]=0;a=Q(a|0,e|0,d|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break b}e=1;if((a|0)==1){break j}f=(a|0)==-1?-1:f}b=b+12|0;continue}}if(d){e=0;if((f|0)!=-1){break j}e=Vc(v[d>>2],v[d+4>>2])>>>0>c>>>0?-1:0;break j}e=0;if((f|0)!=-1){break j}e=c>>>0>2047?1:-1}jb=g+144|0;return e}b=P()|0;O()|0;break a}ha(b|0,92072,24);L()}ha(b|0,91968,24);L()}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}S(b|0);L()}function mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=jb-48|0;jb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){b=v[g+16>>2];l=b>>>18|0;j=((((v[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+o|0;b=0;e=0;while(1){if((e|0)!=2){i=j+(e<<1)|0;f=u[i>>1];v[(g+8|0)+(e<<2)>>2]=f+((B(l,u[i+4>>1]-f|0)|0)/16384|0);e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Sia(y,z,f,f>>31);m=mb;D=e;e=Yb(i,-16777216,16776704);i=Sia(w,x,e,e>>31);f=i+f|0;e=mb+m|0;e=f>>>0<i>>>0?e+1|0:e;m=f;f=Yb(j,-16777216,16776704);j=Sia(s,t,f,f>>31);f=m+j|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Rc(f,e,24);v[D+4>>2]=e-(r&n);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Sb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function UM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=jb-16|0;jb=c;d=a+1074376|0;e=B(b,872);a:{if(v[(d+e|0)+704>>2]&134218752){break a}h=v[(a+e|0)+1075648>>2];if(!Sj(h)|w[h+15|0]&2){break a}d=sl(a,d,b,2,1);if((d-1&255)>>>0>249){break a}g=v[(B(d,160)+a|0)+906140>>2];if(!g){break a}f=B(b,872)+a|0;d=w[f+1075780|0];b:{if(w[f+1075782|0]==1){t[c+8|0]=64;e=w[Wb(f+1075784|0,c+8|0)|0];break b}e=255;if(w[f+1075783|0]!=13){break b}t[c+8|0]=64;e=w[Wb((B(b,872)+a|0)+1075785|0,c+8|0)|0]}i=a+1074312|0;Bb(c+8|0,i,2);if(Cb(v[v[c+8>>2]>>2],v[c+12>>2])){if(d){if(Uc(d)){d=w[Lb(h+108|0,d-1|0)|0]}Ul(a,b,d,x[(B(b,872)+a|0)+1075680>>1]);break a}if((e|0)==255){break a}nb[v[v[g>>2]+76>>2]](g,39,e,b);break a}j=v[h+4>>2];if(d){f=w[h+35|0]?j<<2:v[(B(b,872)+a|0)+1075680>>2];k=u[(B(b,872)+a|0)+1075768>>1];Bb(c+8|0,i,28);l=c,m=f+(Cb(v[v[c+8>>2]>>2],v[c+12>>2])?k<<2:k)|0,v[l+4>>2]=m;he(c+4|0,0,256);f=a;if(Uc(d)){a=w[Lb(h+108|0,d-1|0)|0]}else{a=d}Ul(f,b,a&255,x[c+4>>1])}f=w[h+35|0];Bb(c+8|0,i,101);if(Cb(v[v[c+8>>2]>>2],v[c+12>>2])){a=(d|0)!=0}else{a=Uc(d)}if(a^1|(f|0)!=1?(a|(e|0)==255)==1:0){break a}c:{switch(w[h+36|0]){case 1:if((e|0)!=255){Vs(v[g+20>>2],C(C(C(e<<1)/C(-127))+C(1)));break a}Vs(v[g+20>>2],C(C(C(j<<1>>>0)/C(-127))+C(1)));break a;case 0:break c;default:break a}}if((e|0)!=255){t[c+8|0]=127;t[c+4|0]=e<<1;m=g,n=7,o=w[Wb(c+8|0,c+4|0)|0],p=b,l=v[v[g>>2]+76>>2],nb[l](m|0,n|0,o|0,p|0);break a}v[c+8>>2]=127;v[c+4>>2]=j<<1;p=g,o=7,n=w[Ib(c+8|0,c+4|0)|0],m=b,l=v[v[g>>2]+76>>2],nb[l](p|0,o|0,n|0,m|0)}jb=c+16|0}function nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=jb-48|0;jb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];k=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){b=v[g+16>>2];l=b>>>10&4194048;j=(((v[g+20>>2]&2147483647)<<1|b>>>31)&-2)+o|0;b=0;e=0;while(1){if((e|0)!=2){i=e+j|0;f=t[i|0];v[(g+8|0)+(e<<2)>>2]=((B(l,t[i+2|0]-f|0)|0)/16384|0)+(f<<8);e=e+1|0;continue}break}while(1){if((b|0)!=2){l=(g+8|0)+(b<<2)|0;f=v[l>>2];e=(g+24|0)+(b<<3)|0;j=v[e+8>>2];i=v[e+4>>2];v[e+8>>2]=i;n=f<<8;f=n;f=Sia(y,z,f,f>>31);m=mb;D=e;e=Yb(i,-16777216,16776704);i=Sia(w,x,e,e>>31);f=i+f|0;e=mb+m|0;e=f>>>0<i>>>0?e+1|0:e;m=f;f=Yb(j,-16777216,16776704);j=Sia(s,u,f,f>>31);f=m+j|0;e=mb+e|0;e=f>>>0<j>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Rc(f,e,24);v[D+4>>2]=e-(r&n);v[l>>2]=(e|0)/256;b=b+1|0;continue}break}k=k+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],k>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Sb(g+16|0,A,C);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function $Z(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;v[c>>2]=a;y=d&512;z=h<<2;while(1){if((x|0)==4){if(Fb(n)>>>0>1){f=Zd(n);e=jb-16|0;jb=e;v[e+8>>2]=f;f=v[Ce(e+8|0)>>2];jb=e+16|0;B=c,C=Ji(f,zk(n),v[c>>2]),v[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}}else{a:{b:{switch(t[i+x|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];h=Mr(g,32);p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 3:if(De(n)){break a}h=v[ij(n,0)>>2];p=v[c>>2];v[c>>2]=p+4;v[p>>2]=h;break a;case 2:if(De(m)|!y){break a}B=c,C=Ji(Zd(m),zk(m),v[c>>2]),v[B>>2]=C;break a;case 4:break b;default:break a}}A=v[c>>2];e=e+z|0;h=e;while(1){c:{if(f>>>0<=h>>>0){break c}if(!Ck(g,64,v[h>>2])){break c}h=h+4|0;continue}break}if((o|0)>0){p=v[c>>2];q=o;while(1){if(!(!q|e>>>0>=h>>>0)){h=h-4|0;s=v[h>>2];r=p+4|0;v[c>>2]=r;v[p>>2]=s;q=q-1|0;p=r;continue}break}d:{if(!q){s=0;break d}s=Mr(g,48);p=v[c>>2]}while(1){r=p+4|0;if((q|0)>0){v[p>>2]=s;q=q-1|0;p=r;continue}break}v[c>>2]=r;v[p>>2]=j}e:{if((e|0)==(h|0)){p=Mr(g,48);q=v[c>>2];h=q+4|0;v[c>>2]=h;v[q>>2]=p;break e}if(De(l)){s=-1}else{s=t[Yf(l,0)|0]}q=0;u=0;while(1){if((e|0)!=(h|0)){r=v[c>>2];f:{if((q|0)!=(s|0)){p=r;r=q;break f}p=r+4|0;v[c>>2]=p;v[r>>2]=k;r=0;u=u+1|0;if(Fb(l)>>>0<=u>>>0){s=q;break f}s=-1;if(w[Yf(l,u)|0]==127){break f}s=t[Yf(l,u)|0]}h=h-4|0;q=v[h>>2];v[c>>2]=p+4;v[p>>2]=q;q=r+1|0;continue}break}h=v[c>>2]}Fr(A,h)}x=x+1|0;continue}break}}function aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=jb-48|0;jb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){e=v[g+16>>2];k=((((v[g+20>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+m|0;b=e>>>21&2040;i=u[b+39718>>1];h=u[b+39716>>1];l=u[b+39714>>1];j=u[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=k+(e<<1)|0;v[(g+8|0)+(e<<2)>>2]=(((B(u[f>>1],l)+B(u[f-4>>1],j)|0)+B(h,u[f+4>>1])|0)+B(i,u[f+8>>1])|0)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=v[k>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Sia(w,x,f,f>>31);j=mb;A=e;e=Yb(h,-16777216,16776704);h=Sia(s,t,e,e>>31);f=h+f|0;e=mb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Yb(i,-16777216,16776704);i=Sia(q,r,f,f>>31);f=j+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Rc(f,e,24);v[A+4>>2]=e-(l&p);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],n);Sb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function yK(a){var b=C(0),c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,k=0,l=C(0),m=0,n=C(0);c=jb-16|0;jb=c;e=a+4208|0;b=Ax(z[Db(e,2)>>2]);f=v[a+16>>2]+24620|0;z[c+12>>2]=b/C(y[f>>2]);v[c+8>>2]=1056964608;b=pp(C(z[Ol(c+12|0,c+8|0)>>2]*C(6.2831854820251465)));b=C(K(C(C(C(b+b)+C(3))/C(5))));z[a+4236>>2]=b;z[a+4240>>2]=K(C(C(1)-C(b*b)));b=C(C(z[Db(e,1)>>2]*C(29))+C(2));a:{if(b<C(4294967296)&b>=C(0)){i=~~b>>>0;break a}i=0}t[a+4272|0]=i;d=i;while(1){if(d&255){k=k+1|0;d=(d&254)>>>1|0;continue}break}t[a+4273|0]=k;l=me(C(10),C(C(C(z[e>>2]*C(60))+C(-60))/C(20)));m=c,n=C(Ax(z[Db(e,3)>>2])/C(y[f>>2])),z[m+12>>2]=n;v[c+8>>2]=1056964608;g=z[Ol(c+12|0,c+8|0)>>2];m=c,n=C(Ax(z[Db(e,4)>>2])/C(y[f>>2])),z[m+12>>2]=n;v[c+8>>2]=1056964608;b=C(C(z[Ol(c+12|0,c+8|0)>>2]*C(6.2831854820251465))*C(.5));f=jb-16|0;jb=f;e=(p(b),j(2));d=e&2147483647;b:{if(d>>>0<=1061752794){if(d>>>0<964689920){break b}b=un(+b,0);break b}if(d>>>0<=1081824209){h=+b;if(d>>>0<=1075235811){b=un(((e|0)<0?1.5707963267948966:-1.5707963267948966)+h,1);break b}b=un(((e|0)<0?3.141592653589793:-3.141592653589793)+h,0);break b}if(d>>>0<=1088565717){h=+b;if(d>>>0<=1085271519){b=un(((e|0)<0?4.71238898038469:-4.71238898038469)+h,1);break b}b=un(((e|0)<0?6.283185307179586:-6.283185307179586)+h,0);break b}if(d>>>0>=2139095040){b=C(b-b);break b}d=Pw(b,f+8|0);b=un(A[f+8>>3],d&1)}jb=f+16|0;b=C(C(C(1)-b)/C(b+C(1)));z[a+4268>>2]=b;g=pp(C(g*C(6.2831854820251465)));z[a+4264>>2]=-g;z[a+4260>>2]=C(C(l*C(K(C(C(1)-C(g*g)))))*C(K(C(C(1)-C(b*b)))))*z[(i<<2)+45568>>2];jb=c+16|0}function LJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=C(0);e=jb-48|0;jb=e;a:{b:{c:{d:{e:{switch(b-1|0){case 1:b=(c<<7)/100|0;d=v[a+24>>2];if((b|0)==v[d+24604>>2]){break d}a=e+8|0;qc(a,d+24604|0,40);v[e+8>>2]=b;ly(d,a);break d;case 2:f=v[a+24>>2];d=f+24664|0;b=v[d+4>>2];v[e+24>>2]=v[d>>2];v[e+28>>2]=b;d=f+24656|0;b=v[d+4>>2];v[e+16>>2]=v[d>>2];v[e+20>>2]=b;b=v[f+24652>>2];v[e+8>>2]=v[f+24648>>2];v[e+12>>2]=b;d=jb-16|0;jb=d;b=3;f:{g:{h:{if(!c|(c|0)>7){break h}b=2;if((c|0)>2){break h}b=1;if((c|0)==2){break h}b=0;if((c|0)>0){break h}c=ba(8)|0;v[23296]=0;b=Q(54,d|0,10689)|0;a=v[23296];v[23296]=0;i:{if((a|0)!=1){a=sc(c,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break g}a=P()|0;O()|0;yb(b);break i}a=P()|0;O()|0;ca(c|0)}S(a|0);L()}jb=d+16|0;break f}L()}t[e+8|0]=b;a=v[a+24>>2];if(!qx(e+8|0,a+24648|0)){break d}jy(a,e+8|0);break d;case 3:f=e+8|0;d=v[a+24>>2];qc(f,d+24604|0,40);b=jb-48|0;jb=b;j:{if((c|0)==-1){ps(f,v[Np(b+8|0)+32>>2]);Zn(f,v[Np(b+8|0)+36>>2]);break j}if((c|0)<=0){ps(f,0);Zn(f,0);break j}a=B(c,1e3);ps(f,a);Zn(f,a)}jb=b+48|0;if(v[d+24636>>2]==v[e+40>>2]&v[d+24640>>2]==v[e+44>>2]){break d}ly(d,e+8|0);break d;default:d=ba(8)|0;v[23296]=0;c=Q(54,e+8|0,10277)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}a=sc(d,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b;case 0:break e}}g=a,h=me(C(10),C(C(C(c|0)*C(.0010000000474974513))*C(.5))),z[g+48>>2]=h}jb=e+48|0;return}b=P()|0;O()|0;ca(d|0)}S(b|0)}L()}function v9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-112|0;jb=c;sj(c+88|0,b,1413829443);v[23296]=0;b=T(166,v[c+88>>2])|0;d=v[23296];v[23296]=0;a:{b:{c:{if((d|0)==1){break c}if(!b){v[23296]=0;U(724,c- -64|0,a+140|0,1413894985);a=v[23296];v[23296]=0;d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{if((a|0)!=1){v[23296]=0;a=Q(801,c- -64|0,13453)|0;b=v[23296];v[23296]=0;if((b|0)==1){break e}b=28591;if(a){b=Kb(c+48|0);v[23296]=0;a=T(190,c- -64|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break m}v[23296]=0;U(255,c- -64|0,b|0,a|0);a=v[23296];v[23296]=0;if((a|0)==1){break m}v[23296]=0;d=Q(53,c+16|0,b|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break l}v[23296]=0;Y(802,c|0);a=v[23296];v[23296]=0;if((a|0)==1){break k}v[23296]=0;U(803,c+32|0,d|0,c|0);a=v[23296];v[23296]=0;if((a|0)==1){break j}a=c+32|0;e=Bc(b,a);yb(a);yb(c);yb(d);v[23296]=0;U(11,a|0,2,e|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}v[23296]=0;a=T(694,c+32|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break g}zb(c+32|0);yb(e);b=a-1>>>0<19398657?1252:28591}Ab(c- -64|0);break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;break i}a=P()|0;O()|0;yb(c)}yb(d);break f}a=P()|0;O()|0;break f}a=P()|0;O()|0;zb(c+32|0)}yb(b);break d}a=P()|0;O()|0}Ab(c- -64|0);break b}v[23296]=0;a=W(144,v[c+88>>2],v[c+96>>2],2)|0;b=v[23296];v[23296]=0;if((b|0)==1){break c}b=28591;if(!a){break a}v[23296]=0;b=T(182,c+88|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0}Ab(c+88|0);S(a|0);L()}Ab(c+88|0);jb=c+112|0;return b|0}function Kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;h=jb-16|0;jb=h;a:{b:{c:{i=v[a+12>>2];j=v[a+8>>2];d:{if((i|0)<=1&j>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&j>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&j>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}p=b+196648|0;break a}p=b+131112|0;break a}p=b+262184|0}q=v[a+16>>2];f=v[a+48>>2];k=v[a+40>>2];l=v[a+36>>2];b=v[a+44>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;r=v[a+32>>2];s=v[a+28>>2];t=v[a+72>>2];e=v[a+68>>2];w=e;x=e>>31;e=v[a+64>>2];y=e;z=e>>31;e=v[a+60>>2];A=e;C=e>>31;while(1){e=b;if(d){b=Yb(e,-16777216,16776704);b=Sia(y,z,b,b>>31);m=mb;n=b;g=(v[h+12>>2]<<1)+q|0;b=(v[h+8>>2]>>>16&65520)+p|0;g=(((((((B(u[g-4>>1],u[b+2>>1])+B(u[g-6>>1],u[b>>1])|0)+B(u[g-2>>1],u[b+4>>1])|0)+B(u[g>>1],u[b+6>>1])|0)+B(u[g+2>>1],u[b+8>>1])|0)+B(u[g+4>>1],u[b+10>>1])|0)+B(u[g+6>>1],u[b+12>>1])|0)+B(u[g+8>>1],u[b+14>>1])|0)/32768<<8;b=g;b=Sia(b,b>>31,A,C);n=n+b|0;o=mb+m|0;o=b>>>0>n>>>0?o+1|0:o;b=Yb(f,-16777216,16776704);f=Sia(w,x,b,b>>31);m=f+n|0;b=mb+o|0;b=f>>>0>m>>>0?b+1|0:b;f=m+8388608|0;b=f>>>0<8388608?b+1|0:b;f=Rc(f,b,24);b=(f|0)/256|0;l=l+s|0;v[c>>2]=B(b,l>>12)+v[c>>2];k=k+r|0;v[c+4>>2]=v[c+4>>2]+B(b,k>>12);Sb(h+8|0,j,i);b=f-(g&t)|0;c=c+8|0;d=d-1|0;f=e;continue}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;v[a+40>>2]=k;v[a+20>>2]=l>>12;v[a+36>>2]=l;v[a+48>>2]=f;v[a+44>>2]=e;v[a+24>>2]=k>>12;jb=h+16|0}function Fda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;k=f,l=ak(b),v[k>>2]=l;e=jb-16|0;jb=e;h=a;c=Wd(a);a:{if(c){g=kc(h);while(1){a=c;c=a+14|0;if(tt(b,c)){g=a;c=v[a>>2];if(c){continue}break a}if(!tt(c,b)){break a}g=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=kc(h);g=a}v[e+12>>2]=a;b=v[g>>2];if(!b){i=jb-16|0;jb=i;a=kc(h);j=th(e,xc(48),uh(i+8|0,a));a=v[j>>2];b=v[f>>2];c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);d=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a+14|0]=d;t[a+15|0]=d>>>8;t[a+16|0]=d>>>16;t[a+17|0]=d>>>24;t[a+18|0]=c;t[a+19|0]=c>>>8;t[a+20|0]=c>>>16;t[a+21|0]=c>>>24;c=w[b+28|0]|w[b+29|0]<<8|(w[b+30|0]<<16|w[b+31|0]<<24);d=w[b+24|0]|w[b+25|0]<<8|(w[b+26|0]<<16|w[b+27|0]<<24);t[a+38|0]=d;t[a+39|0]=d>>>8;t[a+40|0]=d>>>16;t[a+41|0]=d>>>24;t[a+42|0]=c;t[a+43|0]=c>>>8;t[a+44|0]=c>>>16;t[a+45|0]=c>>>24;c=w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24);d=w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24);t[a+30|0]=d;t[a+31|0]=d>>>8;t[a+32|0]=d>>>16;t[a+33|0]=d>>>24;t[a+34|0]=c;t[a+35|0]=c>>>8;t[a+36|0]=c>>>16;t[a+37|0]=c>>>24;c=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);b=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[a+22|0]=b;t[a+23|0]=b>>>8;t[a+24|0]=b>>>16;t[a+25|0]=b>>>24;t[a+26|0]=c;t[a+27|0]=c>>>8;t[a+28|0]=c>>>16;t[a+29|0]=c>>>24;u[a+46>>1]=0;k=kc(j),l=1,t[k+4|0]=l;jb=i+16|0;Zg(h,v[e+12>>2],g,v[e>>2]);b=de(e);cl(e);d=1}Yg(f+8|0,v[hc(e,b)>>2],d);jb=e+16|0;a=Wp(v[f+8>>2]);jb=f+16|0;return a+32|0}function dba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=jb-16|0;jb=g;w=v[a+16>>2];x=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);p=v[a+128>>2];a:{if(!p){n=v[a+8>>2];s=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];o=0;break a}b=v[a+12>>2];s=b;n=v[a+8>>2];q=bg(n,b,p);r=mb;k=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Ff(i,e,ff(n,b,d),mb);o=k>>>0<mb>>>0?d:0}h=a+112|0;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{k=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;o=o-1|0;b=o;q=b?q:0;r=b?r:0;e=(e<<1)+w|0;b=p;while(1)if((b|0)<=0){Sb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Ld(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Kd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];y=v[a+32>>2];m=v[a+28>>2]+m|0;b=v[a+60>>2];e=b;j=b>>31;t=$f(h,x)<<8;b=t;b=Sia(e,j,b,b>>31);z=mb;e=b;b=v[a+64>>2];j=b;A=b>>31;b=Yb(k,-16777216,16776704);j=Sia(j,A,b,b>>31);e=e+j|0;b=mb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Yb(f,-16777216,16776704);e=Sia(e,e>>31,f,f>>31);f=j+e|0;b=mb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(m>>12,f)+v[c>>2];l=l+y|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,f);Sb(g,n,s);b=b-(i&t)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=k;continue b}else{Ld(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Kd(h,4);Sb(g+8|0,q,r);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=k;v[a+24>>2]=l>>12;jb=g+16|0}function bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0;g=jb-48|0;jb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){if(d){e=v[g+16>>2];k=(((v[g+20>>2]&2147483647)<<1|e>>>31)&-2)+m|0;b=e>>>21&2040;i=u[b+39718>>1];h=u[b+39716>>1];l=u[b+39714>>1];j=u[b+39712>>1];b=0;e=0;while(1){if((e|0)!=2){f=e+k|0;v[(g+8|0)+(e<<2)>>2]=(((B(t[f|0],l)+B(t[f-2|0],j)|0)+B(h,t[f+2|0])|0)+B(i,t[f+4|0])<<8)/16384;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=v[k>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Sia(x,y,f,f>>31);j=mb;C=e;e=Yb(h,-16777216,16776704);h=Sia(s,w,e,e>>31);f=h+f|0;e=mb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Yb(i,-16777216,16776704);i=Sia(q,r,f,f>>31);f=j+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Rc(f,e,24);v[C+4>>2]=e-(l&p);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],n);Sb(g+16|0,z,A);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function zaa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,x=0,y=0,z=0,A=0;f=jb+-64|0;jb=f;a:{b:{c:{d:{e:{f:{g:{if(!a){break g}l=e<<2;if(l>>>0>d>>>0){break g}s=l-4|0;o=B(b,e);x=o-8|0;h:while(1){b=v[c+8>>2];h=v[c>>2];v[23296]=0;b=W(144,h|0,b|0,l|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break b}if(!(b&n>>>0<o>>>0)){break g}v[23296]=0;U(178,f+16|0,c|0,d|0);b=v[23296];v[23296]=0;if((b|0)==1){break c}b=f+16|0;h=jc(f+40|0,b);Ab(b);v[23296]=0;R(512,b|0,h|0);b=v[23296];v[23296]=0;if((b|0)==1){break e}y=ye(f+16|0);p=v[f+16>>2];z=p-4|0;k=0;while(1){if((e|0)==(k|0)){Pc(f+16|0);Ab(h);n=(p-l<<1)+n|0;continue h}v[23296]=0;g=T(505,h|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){v[23296]=0;b=T(194,h|0)|0;j=v[23296];v[23296]=0;if((j|0)==1){break f}v[f+8>>2]=b;he(f+8|0,0,89);v[23296]=0;Q(176,h|0,1)|0;b=v[23296];v[23296]=0;if((b|0)==1){break f}j=k+n|0;b=e+k<<2;i:while(1){j:{if(j>>>0>x>>>0){break j}m=0;if(b>>>0>z>>>0){break j}while(1)if((m|0)==8){b=b+s|0;continue i}else{q=v[f+8>>2];i=w[b+y|0];r=m&1;i=r?i>>>4|0:i&15;v[f+8>>2]=q+t[(i&7)+30104|0];A=g;g=u[(q<<1)+30112>>1];g=(((0-(i&1)&g>>2)+(g>>3)|0)+(i<<30>>31&g>>1)|0)+(g&i<<29>>31)|0;v[f+12>>2]=A+(i&8?0-g|0:g);he(f+8|0,0,88);he(f+12|0,-32768,32767);g=v[f+12>>2];u[(j<<1)+a>>1]=g;m=m+1|0;j=e+j|0;b=b+r|0;continue}}break}k=k+1|0;continue}break}break}break f}Ab(c);jb=f- -64|0;return}b=P()|0;O()|0;Pc(f+16|0);break d}b=P()|0;O()|0}Ab(h);break a}b=P()|0;O()|0;break a}b=P()|0;O()|0}Ab(c);S(b|0);L()}function XV(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=jb-48|0;jb=f;g=ni(b)^-1;a:{if(wc(v[d>>2],v[d+4>>2])>>>0<=g>>>0){Ms(a);break a}ni(b);if((w[c+4|0]|w[c+5|0]<<8)>>>0>=60){ac(b,4)}j=f,k=ni(b),v[j+44>>2]=k;ac(b,4);h=ni(b);i=ni(b);if(!((h|0)>0&(i|0)>36)){Ms(a);break a}if(gq(Hd(v[e>>2],v[Db(v[d>>2],g)>>2]),12955)){Ms(a);break a}uv(f,b,i,h);d=jc(f+24|0,f);Ab(f);b=v[d>>2];v[23296]=0;b=T(166,b|0)|0;e=v[23296];v[23296]=0;b:{if((e|0)==1){break b}c:{d:{if(!b){v[23296]=0;T(175,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break d}break b}b=w[c+4|0]|w[c+5|0]<<8;if(b>>>0<=39){v[23296]=0;Q(176,d|0,8)|0;b=v[23296];v[23296]=0;if((b|0)==1){break b}b=w[c+4|0]|w[c+5|0]<<8}if((b&65535)>>>0<=59){v[23296]=0;Q(176,d|0,16)|0;b=v[23296];v[23296]=0;if((b|0)==1){break b}}v[23296]=0;T(177,d|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break b}e:{f:{b=w[c+4|0]|w[c+5|0]<<8;g:{if(b>>>0>=120){v[23296]=0;T(177,d|0)|0;c=v[23296];v[23296]=0;b=8;break g}h:{if(b>>>0>=100){v[23296]=0;Q(176,d|0,4)|0;b=v[23296];v[23296]=0;if((b|0)==1){break b}break h}if(b>>>0<62){break f}}v[23296]=0;T(177,d|0)|0;c=v[23296];v[23296]=0;b=4}if((c|0)==1){break b}v[23296]=0;Q(176,d|0,b|0)|0;break e}v[23296]=0;T(177,d|0)|0}b=v[23296];v[23296]=0;if((b|0)==1){break b}v[23296]=0;b=T(177,d|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}v[23296]=0;U(178,f|0,d|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break c}j=jc(a,f),k=v[f+44>>2],v[j+20>>2]=k;Ab(f)}Ab(d);break a}}a=P()|0;O()|0;Ab(d);S(a|0);L()}jb=f+48|0}function Lba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0;h=jb-16|0;jb=h;a:{b:{c:{i=v[a+12>>2];k=v[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=v[a+16>>2];b=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];e=v[a+44>>2];f=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=f;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];f=v[a+68>>2];s=f;w=f>>31;f=v[a+64>>2];x=f;y=f>>31;f=v[a+60>>2];z=f;A=f>>31;while(1){f=e;if(d){e=Yb(f,-16777216,16776704);e=Sia(x,y,e,e>>31);g=mb;j=e;b=Yb(b,-16777216,16776704);e=Sia(s,w,b,b>>31);j=j+e|0;b=mb+g|0;b=e>>>0>j>>>0?b+1|0:b;g=v[h+12>>2]+o|0;e=(v[h+8>>2]>>>16&65520)+n|0;g=(((((((B(t[g-2|0],u[e+2>>1])+B(t[g-3|0],u[e>>1])|0)+B(t[g-1|0],u[e+4>>1])|0)+B(t[g|0],u[e+6>>1])|0)+B(t[g+1|0],u[e+8>>1])|0)+B(t[g+2|0],u[e+10>>1])|0)+B(t[g+3|0],u[e+12>>1])|0)+B(t[g+4|0],u[e+14>>1])<<8)/32768<<8;e=g;e=Sia(e,e>>31,z,A);j=e+j|0;b=mb+b|0;b=e>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;m=m+q|0;v[c>>2]=B(b,m>>12)+v[c>>2];l=l+p|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,b);Sb(h+8|0,k,i);e=e-(g&r)|0;c=c+8|0;d=d-1|0;b=f;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=b;v[a+44>>2]=f;v[a+24>>2]=l>>12;jb=h+16|0}function Cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=jb-48|0;jb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;t=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){d=d-1|0;f=((((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&2147483646)<<1)+o|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=u[f+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=v[m>>2];e=(g+24|0)+(b<<3)|0;k=v[e+8>>2];j=v[e+4>>2];v[e+8>>2]=j;n=f<<8;f=n;f=Sia(y,z,f,f>>31);l=mb;D=e;e=Yb(j,-16777216,16776704);j=Sia(w,x,e,e>>31);f=j+f|0;e=mb+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Yb(k,-16777216,16776704);k=Sia(s,t,f,f>>31);f=l+k|0;e=mb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Rc(f,e,24);v[D+4>>2]=e-(r&n);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}i=i+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],i>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Sb(g+16|0,A,C);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+36>>2]=i;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function sV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;f=jb-32|0;jb=f;Ac(c);while(1){a:{if(!Ob(v[c>>2],v[c+8>>2],3)){break a}d=f+24|0;Mq(d,c);i=kd(d);h=Ue(d);d=w[f+24|0];if(d>>>0>=y[a+12>>2]){break a}g=fd(v[a>>2],v[v[a+48>>2]+12>>2],d,b);d=w[i|0];if(d>>>0<=126){if(!(d|w[h|0])){t[g|0]=254;continue}t[g|0]=d+1;if(w[h|0]==255){continue}t[g+2|0]=1;t[g+4|0]=w[h|0];continue}b:{switch(d-127|0){case 1:t[g+1|0]=w[h|0]+1;continue;case 0:continue;default:break b}}e=t[h|0];t[f+23|0]=e;h=0;d=d&127;if(d>>>0<=23){h=w[d+26048|0]}c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{j=w[i|0];switch((j&127)-2|0){case 21:break g;case 18:break h;case 17:break i;case 16:case 20:break j;case 15:break k;case 2:break l;case 1:break m;case 0:case 8:case 9:break n;default:break d}}if((e|0)>=0){break f}d=0-e&15;break e}t[f+16|0]=64;e=w[Wb(f+23|0,f+16|0)|0];if(w[g+2|0]>1){break d}t[g+4|0]=e;t[g+2|0]=1;continue}d=3;if((e|0)>=0){break c}d=0-e&127;break e}if(!e){continue}d=0-e|-16;if((e|0)<0){break e}d=e<<4|15;break e}if(!e){continue}d=(e|0)>=0;if(!d){e=0-e&15;t[f+23|0]=e;j=w[i|0]}d=d?3:2;e=((j|0)==22?-32:-16)|e;t[f+23|0]=e;break c}d=e&15|-48;break e}d=e&15|-64;break e}d=164;if((e|0)==100){break e}v[f+16>>2]=e- -64;v[f+12>>2]=0;v[f+8>>2]=128;e=v[wj(f+16|0,f+12|0,f+8|0)>>2];if(!w[g+3|0]){break d}o:{switch(w[g+2|0]){case 0:case 2:break o;default:continue}}t[g+2|0]=2;t[g+4|0]=(e&254)>>>1;continue}d=e<<4}e=d;t[f+23|0]=e}d=h;if(!d){continue}}t[g+5|0]=e;t[g+3|0]=d;continue}break}jb=f+32|0}function GU(){var a=0,b=0,c=0;if(!w[466832]){a=jb-16|0;jb=a;ss(466480);v[116632]=-1;v[116630]=466536;v[116628]=92880;v[116620]=77268;t[466532]=0;b=a+8|0;Or(b,466480);c=v[v[116620]+8>>2];v[23296]=0;R(c|0,466480,b|0);b=v[23296];v[23296]=0;a:{if((b|0)!=1){_b(a+8|0);jb=a+16|0;break a}b=P()|0;O()|0;_b(a+8|0);En(466480);S(b|0);L()}xs(465808);v[116452]=77400;v[116450]=77380;v[116451]=0;Dn(465808,466480);QG(466544,93024,466592);xw(465976,466544);QG(466600,92720,466648);xw(466144,466600);xw(466312,v[(v[v[116536]-12>>2]+466144|0)+24>>2]);PG(v[v[116450]-12>>2]+465800|0);qI(v[v[116536]-12>>2]+466144|0);PG(v[v[116536]-12>>2]+466144|0);a=jb-16|0;jb=a;dH(466656);v[116676]=-1;v[116674]=466712;v[116672]=92880;v[116664]=77660;t[466708]=0;b=a+8|0;Or(b,466656);c=v[v[116664]+8>>2];v[23296]=0;R(c|0,466656,b|0);b=v[23296];v[23296]=0;b:{if((b|0)!=1){_b(a+8|0);jb=a+16|0;break b}b=P()|0;O()|0;_b(a+8|0);Rr(466656);S(b|0);L()}MG(465896);v[116474]=77792;v[116472]=77772;v[116473]=0;Dn(465896,466656);OG(466720,93024,466768);ww(466060,466720);OG(466776,92720,466824);ww(466228,466776);ww(466396,v[(v[v[116557]-12>>2]+466228|0)+24>>2]);NG(v[v[116472]-12>>2]+465888|0);qI(v[v[116557]-12>>2]+466228|0);NG(v[v[116557]-12>>2]+466228|0);t[466832]=1}a=jb-16|0;jb=a;c:{if(eb(a+12|0,a+8|0)|0){break c}b=Jd((v[a+12>>2]<<2)+4|0);v[116710]=b;if(!b){break c}b=Jd(v[a+8>>2]);if(b){c=v[116710];v[c+(v[a+12>>2]<<2)>>2]=0;if(!(db(c|0,b|0)|0)){break c}}v[116710]=0}jb=a+16|0;v[115780]=42;v[115798]=466932}function d_(a,b,c,d,e,f,g,h,i,j,k,l,m,n,o){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;var p=0,q=0,r=0,s=0,u=0,x=0,y=0,z=0,A=0,B=0,C=0;v[c>>2]=a;z=d&512;while(1){if((x|0)==4){if(Fb(n)>>>0>1){f=$s(n);e=jb-16|0;jb=e;v[e+8>>2]=f;f=v[Be(e+8|0)>>2];jb=e+16|0;B=c,C=JF(f,Ys(n),v[c>>2]),v[B>>2]=C}d=d&176;if((d|0)!=16){if((d|0)==32){a=v[c>>2]}v[b>>2]=a}return}a:{b:{switch(t[i+x|0]){case 0:v[b>>2]=v[c>>2];break a;case 1:v[b>>2]=v[c>>2];p=ll(g,32);q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break a;case 3:if(De(n)){break a}p=w[Yf(n,0)|0];q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break a;case 2:if(De(m)|!z){break a}B=c,C=JF($s(m),Ys(m),v[c>>2]),v[B>>2]=C;break a;case 4:break b;default:break a}}p=v[g+8>>2];A=v[c>>2];e=e+h|0;r=e;while(1){c:{if(f>>>0<=r>>>0){break c}if(!lh(p,64,t[r|0])){break c}r=r+1|0;continue}break}p=o;if((p|0)>0){while(1){if(!(!p|e>>>0>=r>>>0)){r=r-1|0;q=w[r|0];s=v[c>>2];v[c>>2]=s+1;t[s|0]=q;p=p-1|0;continue}break}if(p){q=ll(g,48)}else{q=0}while(1){s=v[c>>2];v[c>>2]=s+1;if((p|0)>0){t[s|0]=q;p=p-1|0;continue}break}t[s|0]=j}d:{if((e|0)==(r|0)){p=ll(g,48);q=v[c>>2];v[c>>2]=q+1;t[q|0]=p;break d}if(De(l)){q=-1}else{q=t[Yf(l,0)|0]}p=0;u=0;while(1){if((e|0)==(r|0)){break d}e:{if((p|0)!=(q|0)){s=p;break e}q=v[c>>2];v[c>>2]=q+1;t[q|0]=k;s=0;u=u+1|0;if(Fb(l)>>>0<=u>>>0){q=p;break e}q=-1;if(w[Yf(l,u)|0]==127){break e}q=t[Yf(l,u)|0]}r=r-1|0;p=w[r|0];y=v[c>>2];v[c>>2]=y+1;t[y|0]=p;p=s+1|0;continue}}Cl(A,v[c>>2])}x=x+1|0;continue}}function eba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=jb-16|0;jb=g;w=v[a+16>>2];x=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);p=v[a+128>>2];a:{if(!p){n=v[a+8>>2];s=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];o=0;break a}b=v[a+12>>2];s=b;n=v[a+8>>2];q=bg(n,b,p);r=mb;k=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Ff(i,e,ff(n,b,d),mb);o=k>>>0<mb>>>0?d:0}h=a+112|0;f=v[a+48>>2];l=v[a+40>>2];m=v[a+36>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{k=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;o=o-1|0;b=o;q=b?q:0;r=b?r:0;e=e+w|0;b=p;while(1)if((b|0)<=0){Sb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Ld(h,t[e+v[g+12>>2]|0]<<6);Kd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];y=v[a+32>>2];m=v[a+28>>2]+m|0;b=v[a+60>>2];e=b;j=b>>31;u=$f(h,x)<<8;b=u;b=Sia(e,j,b,b>>31);z=mb;e=b;b=v[a+64>>2];j=b;A=b>>31;b=Yb(k,-16777216,16776704);j=Sia(j,A,b,b>>31);e=e+j|0;b=mb+z|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Yb(f,-16777216,16776704);e=Sia(e,e>>31,f,f>>31);f=j+e|0;b=mb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(m>>12,f)+v[c>>2];l=l+y|0;v[c+4>>2]=v[c+4>>2]+B(l>>12,f);Sb(g,n,s);b=b-(i&u)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=k;continue b}else{Ld(h,t[e+v[g+12>>2]|0]<<6);Kd(h,4);Sb(g+8|0,q,r);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+40>>2]=l;v[a+20>>2]=m>>12;v[a+36>>2]=m;v[a+48>>2]=f;v[a+44>>2]=k;v[a+24>>2]=l>>12;jb=g+16|0}function Dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0,C=0,D=0;g=jb-48|0;jb=g;o=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;h=e+(g+24|0)|0;e=a+e|0;v[h+4>>2]=v[e+44>>2];v[h+8>>2]=v[e+48>>2];b=b+1|0;continue}break}h=v[a+40>>2];i=v[a+36>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+32>>2];q=v[a+28>>2];r=v[a+72>>2];b=v[a+68>>2];s=b;u=b>>31;b=v[a+64>>2];w=b;x=b>>31;b=v[a+60>>2];y=b;z=b>>31;A=v[a+8>>2];C=v[a+12>>2];while(1){if(d){d=d-1|0;f=(((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&-2)+o|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=t[e+f|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){m=(g+8|0)+(b<<2)|0;f=v[m>>2];e=(g+24|0)+(b<<3)|0;k=v[e+8>>2];j=v[e+4>>2];v[e+8>>2]=j;n=f<<8;f=n;f=Sia(y,z,f,f>>31);l=mb;D=e;e=Yb(j,-16777216,16776704);j=Sia(w,x,e,e>>31);f=j+f|0;e=mb+l|0;e=f>>>0<j>>>0?e+1|0:e;l=f;f=Yb(k,-16777216,16776704);k=Sia(s,u,f,f>>31);f=l+k|0;e=mb+e|0;e=f>>>0<k>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Rc(f,e,24);v[D+4>>2]=e-(r&n);v[m>>2]=(e|0)/256;b=b+1|0;continue}break}i=i+q|0;v[c>>2]=v[c>>2]+B(v[g+8>>2],i>>12);h=h+p|0;v[c+4>>2]=v[c+4>>2]+B(v[g+12>>2],h>>12);Sb(g+16|0,A,C);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;v[a+40>>2]=h;v[a+20>>2]=i>>12;v[a+36>>2]=i;v[a+24>>2]=h>>12;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function U3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-80|0;jb=e;f=Qb(a);a=0;c=v[b+24>>2];g=lj(Zb(v[c+484360>>2],w[c+484376|0]));v[23296]=0;R(169,f|0,g|0);c=v[23296];v[23296]=0;a:{if((c|0)!=1){while(1){b:{if((a|0)!=(g|0)){c=v[b+24>>2];d=v[c+484344>>2];h=v[c+484348>>2];c=x[dc(v[Zb(v[c+484360>>2],w[c+484376|0])>>2],a)>>1];if(xm(d,h,c)){v[23296]=0;R(969,e+48|0,$b(d,c)|0);c=v[23296];v[23296]=0;c:{d:{e:{if((c|0)!=1){c=v[b+24>>2];v[23296]=0;U(956,e- -64|0,c|0,e+48|0);c=v[23296];v[23296]=0;if((c|0)==1){break e}v[23296]=0;R(171,f|0,e- -64|0);c=v[23296];v[23296]=0;if((c|0)==1){break d}yb(e- -64|0);yb(e+48|0);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(e- -64|0)}yb(e+48|0);break a}f:{switch(c-65534|0){case 0:v[23296]=0;c=Q(54,e+32|0,9142)|0;d=v[23296];v[23296]=0;g:{if((d|0)!=1){v[23296]=0;R(171,f|0,c|0);d=v[23296];v[23296]=0;if((d|0)==1){break g}yb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a;case 1:v[23296]=0;c=Q(54,e+16|0,9104)|0;d=v[23296];v[23296]=0;h:{if((d|0)!=1){v[23296]=0;R(171,f|0,c|0);d=v[23296];v[23296]=0;if((d|0)==1){break h}yb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a;default:break f}}v[23296]=0;c=Q(54,e|0,14460)|0;d=v[23296];v[23296]=0;i:{if((d|0)!=1){v[23296]=0;R(171,f|0,c|0);d=v[23296];v[23296]=0;if((d|0)==1){break i}yb(c);break b}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(c);break a}jb=e+80|0;return}a=a+1|0;continue}}a=P()|0;O()|0}Me(f);S(a|0);L()}function qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=jb-48|0;jb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){b=v[g+16>>2];j=b>>>18|0;i=((((v[g+20>>2]&2147483647)<<1|b>>>31)&2147483646)<<1)+m|0;b=0;e=0;while(1){if((e|0)!=2){h=i+(e<<1)|0;f=u[h>>1];v[(g+8|0)+(e<<2)>>2]=f+((B(j,u[h+4>>1]-f|0)|0)/16384|0);e=e+1|0;continue}break}while(1){if((b|0)!=2){j=(g+8|0)+(b<<2)|0;f=v[j>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Sia(w,x,f,f>>31);k=mb;A=e;e=Yb(h,-16777216,16776704);h=Sia(s,t,e,e>>31);f=h+f|0;e=mb+k|0;e=f>>>0<h>>>0?e+1|0:e;k=f;f=Yb(i,-16777216,16776704);i=Sia(q,r,f,f>>31);f=k+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Rc(f,e,24);v[A+4>>2]=e-(p&l);v[j>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+12>>2]);Sb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function J_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=jb-432|0;jb=i;v[i+424>>2]=37;v[i+428>>2]=0;l=Ar(i+424|1,13723,v[c+4>>2]);v[i+380>>2]=i+384;a=Bd();a:{if(l){b=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=b;j=Lg(i+384|0,30,a,i+424|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;j=Lg(i+384|0,30,a,i+424|0,i+80|0)}v[i+128>>2]=1071;k=le(i+368|0,0,i+128|0);b=i+384|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Bd();f:{if(l){j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i+8>>2]=e;v[i+12>>2]=f;v[i>>2]=j;j=Si(i+380|0,a,i+424|0,i);break f}v[i+32>>2]=e;v[i+36>>2]=f;v[i+40>>2]=g;v[i+44>>2]=h;j=Si(i+380|0,a,i+424|0,i+32|0)}if((j|0)==-1){v[23296]=0;Z(1072);a=v[23296];v[23296]=0;if((a|0)==1){break d}break e}a=v[i+380>>2];Oe(k,a)}f=a+j|0;g=Ti(a,f,c);v[i+116>>2]=1071;e=le(i+120|0,0,i+116|0);g:{h:{if((i+384|0)==(a|0)){j=i+128|0;break h}j=Jd(j<<3);if(!j){v[23296]=0;Z(1072);a=v[23296];v[23296]=0;if((a|0)!=1){break e}a=P()|0;O()|0;break g}Oe(e,j);b=a}a=i+104|0;bd(a,c);v[23296]=0;ia(1104,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=v[23296];v[23296]=0;i:{if((a|0)!=1){_b(i+104|0);v[23296]=0;a=ka(1105,m|0,j|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break i}Qc(e);Qc(k);jb=i+432|0;break b}a=P()|0;O()|0;_b(i+104|0);break g}a=P()|0;O()|0}Qc(e);break c}L()}a=P()|0;O()|0}Qc(k);S(a|0);L()}return a|0}function T_(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;m=b;i=jb-256|0;jb=i;v[i+248>>2]=37;v[i+252>>2]=0;l=Ar(i+248|1,13723,v[c+4>>2]);v[i+204>>2]=i+208;a=Bd();a:{if(l){b=v[c+8>>2];j=i- -64|0;v[j>>2]=g;v[j+4>>2]=h;v[i+56>>2]=e;v[i+60>>2]=f;v[i+48>>2]=b;j=Lg(i+208|0,30,a,i+248|0,i+48|0);break a}v[i+80>>2]=e;v[i+84>>2]=f;v[i+88>>2]=g;v[i+92>>2]=h;j=Lg(i+208|0,30,a,i+248|0,i+80|0)}v[i+128>>2]=1071;k=le(i+192|0,0,i+128|0);b=i+208|0;a=b;b:{c:{d:{e:{if((j|0)>=30){a=Bd();f:{if(l){j=v[c+8>>2];v[i+16>>2]=g;v[i+20>>2]=h;v[i+8>>2]=e;v[i+12>>2]=f;v[i>>2]=j;j=Si(i+204|0,a,i+248|0,i);break f}v[i+32>>2]=e;v[i+36>>2]=f;v[i+40>>2]=g;v[i+44>>2]=h;j=Si(i+204|0,a,i+248|0,i+32|0)}if((j|0)==-1){v[23296]=0;Z(1072);a=v[23296];v[23296]=0;if((a|0)==1){break d}break e}a=v[i+204>>2];Oe(k,a)}f=a+j|0;g=Ti(a,f,c);v[i+116>>2]=1071;e=le(i+120|0,0,i+116|0);g:{h:{if((i+208|0)==(a|0)){j=i+128|0;break h}j=Jd(j<<1);if(!j){v[23296]=0;Z(1072);a=v[23296];v[23296]=0;if((a|0)!=1){break e}a=P()|0;O()|0;break g}Oe(e,j);b=a}a=i+104|0;bd(a,c);v[23296]=0;ia(1099,b|0,g|0,f|0,j|0,i+116|0,i+112|0,a|0);a=v[23296];v[23296]=0;i:{if((a|0)!=1){_b(i+104|0);v[23296]=0;a=ka(14,m|0,j|0,v[i+116>>2],v[i+112>>2],c|0,d|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break i}Qc(e);Qc(k);jb=i+256|0;break b}a=P()|0;O()|0;_b(i+104|0);break g}a=P()|0;O()|0}Qc(e);break c}L()}a=P()|0;O()|0}Qc(k);S(a|0);L()}return a|0}function rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=jb-48|0;jb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;u=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){b=v[g+16>>2];j=b>>>10&4194048;i=(((v[g+20>>2]&2147483647)<<1|b>>>31)&-2)+m|0;b=0;e=0;while(1){if((e|0)!=2){h=e+i|0;f=t[h|0];v[(g+8|0)+(e<<2)>>2]=((B(j,t[h+2|0]-f|0)|0)/16384|0)+(f<<8);e=e+1|0;continue}break}while(1){if((b|0)!=2){j=(g+8|0)+(b<<2)|0;f=v[j>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Sia(w,x,f,f>>31);k=mb;A=e;e=Yb(h,-16777216,16776704);h=Sia(s,u,e,e>>31);f=h+f|0;e=mb+k|0;e=f>>>0<h>>>0?e+1|0:e;k=f;f=Yb(i,-16777216,16776704);i=Sia(q,r,f,f>>31);f=k+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Rc(f,e,24);v[A+4>>2]=e-(p&l);v[j>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+12>>2]);Sb(g+16|0,y,z);c=c+8|0;d=d-1|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function b$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-384|0;jb=a;v[a+368>>2]=c;v[a+376>>2]=b;iw(a+216|0,d,a+240|0,a+236|0,a+232|0);d=Kb(a+200|0);b=Tc(d);v[23296]=0;R(59,d|0,b|0);b=v[23296];v[23296]=0;a:{b:{c:{if((b|0)!=1){c=Oc(d,0);v[a+196>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;h=v[a+232>>2];i=v[a+236>>2];while(1){d:{v[23296]=0;b=Q(1089,a+376|0,a+368|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+196>>2];b=Fb(d);if((g|0)==(b+c|0)){v[23296]=0;R(59,d|0,b<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+196>>2]=b+c}v[23296]=0;b=T(1091,v[a+376>>2])|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}if(hw(b,a+23|0,a+22|0,c,a+196|0,i,h,a+216|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[23296]=0;T(1093,a+376|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+216|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}eG(a,c,v[a+196>>2],e);b=v[a>>2];c=v[a+4>>2];h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;v[f>>2]=b;v[f+4>>2]=c;rf(a+216|0,a+32|0,v[a+28>>2],e);v[23296]=0;b=Q(1090,a+376|0,a+368|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+376>>2];yb(d);yb(a+216|0);jb=a+384|0;break a}}b=P()|0;O()|0;yb(d);yb(a+216|0);S(b|0);L()}return b|0}function k$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;a=jb-288|0;jb=a;v[a+272>>2]=c;v[a+280>>2]=b;mw(a+224|0,d,a+240|0,a+239|0,a+238|0);d=Kb(a+208|0);b=Tc(d);v[23296]=0;R(59,d|0,b|0);b=v[23296];v[23296]=0;a:{b:{c:{if((b|0)!=1){c=Oc(d,0);v[a+204>>2]=c;v[a+28>>2]=a+32;v[a+24>>2]=0;t[a+23|0]=1;t[a+22|0]=69;h=t[a+238|0];i=t[a+239|0];while(1){d:{v[23296]=0;b=Q(1073,a+280|0,a+272|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+204>>2];b=Fb(d);if((g|0)==(b+c|0)){v[23296]=0;R(59,d|0,b<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+204>>2]=b+c}v[23296]=0;b=T(1075,v[a+280>>2])|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}if(lw(b,a+23|0,a+22|0,c,a+204|0,i,h,a+224|0,a+32|0,a+28|0,a+24|0,a+240|0)){break c}v[23296]=0;T(1077,a+280|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+224|0)|!w[a+23|0]){break e}b=v[a+28>>2];if((b-(a+32|0)|0)>159){break e}v[a+28>>2]=b+4;v[b>>2]=v[a+24>>2]}eG(a,c,v[a+204>>2],e);b=v[a>>2];c=v[a+4>>2];h=v[a+12>>2];v[f+8>>2]=v[a+8>>2];v[f+12>>2]=h;v[f>>2]=b;v[f+4>>2]=c;rf(a+224|0,a+32|0,v[a+28>>2],e);v[23296]=0;b=Q(1074,a+280|0,a+272|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+280>>2];yb(d);yb(a+224|0);jb=a+288|0;break a}}b=P()|0;O()|0;yb(d);yb(a+224|0);S(b|0);L()}return b|0}function k6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=jb-16|0;jb=j;i=jb-32|0;jb=i;h=Je(i+16|0,1,0);a:{b:{c:{while(1){g=tc(h);d=g+Fb(h)|0;c=v[b>>2];f=v[b+4>>2];if(!((f|0)>0|(f|0)>=0|(d|0)==(g|0))){t[g|0]=45;e=c;c=0-c|0;g=g+1|0;f=0-(f+((e|0)!=0)|0)|0}k=d-g|0;d:{if((k|0)<=19){e=E(f);e=B(64-((e|0)==32?E(c|1)+32|0:e)|0,1233)>>12;n=(e<<3)+25648|0;l=k;k=v[n+4>>2];m=61;if((l|0)<(((f|0)==(k|0)&c>>>0>=y[n>>2]|f>>>0>k>>>0)+e|0)){break d}}e:{if(!f&c>>>0<=99999999){d=Lw(g,c);break e}if((f|0)==2328306&c>>>0<=1874919423|f>>>0<2328306){d=Via(c,f,1e8,0);e=mb;l=Lw(g,d);d=Sia(d,e,-1e8,0)+c|0;c=d;d=(c>>>0)/1e4|0;d=Zi(Zi(l,d),c+B(d,-1e4)|0);break e}d=Via(c,f,1874919424,2328306);e=mb;g=Kw(g,d);d=Sia(d,e,-1874919424,-2328307)+c|0;e=f+mb|0;e=c>>>0>d>>>0?e+1|0:e;c=Via(d,e,1e8,0);e=mb;f=(c>>>0)/1e4|0;l=Zi(Zi(g,f),c+B(f,-1e4)|0);c=Sia(c,e,-1e8,0)+d|0;d=(c>>>0)/1e4|0;d=Zi(Zi(l,d),c+B(d,-1e4)|0)}m=0}v[i+12>>2]=m;v[i+8>>2]=d;if(!v[i+12>>2]){break c}c=Hf(Fb(h));v[23296]=0;R(58,h|0,c|0);c=v[23296];v[23296]=0;if((c|0)!=1){continue}break}break b}b=v[i+8>>2];c=tc(h);v[23296]=0;R(59,h|0,b-c|0);b=v[23296];v[23296]=0;f:{if((b|0)!=1){v[23296]=0;R(60,j|0,h|0);b=v[23296];v[23296]=0;if((b|0)!=1){break f}break b}break b}yb(h);jb=i+32|0;break a}a=P()|0;O()|0;yb(h);S(a|0);L()}v[23296]=0;R(57,a|0,j|0);a=v[23296];v[23296]=0;if((a|0)!=1){yb(j);jb=j+16|0;return}a=P()|0;O()|0;yb(j);S(a|0);L()}function mj(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{if(!Ud(v[a>>2],v[a+20>>2])){break a}lk(a);b:{switch(Hm(x[a+34>>1])-1|0){case 1:e=jb+-64|0;jb=e;h=v[a+20>>2];c=v[a>>2];d=Gd(x[a+34>>1]);f=h+(B(c,d)<<1)|0;while(1){c:{d:{if((g|0)!=16){i=B(d,g);j=B(d,g^-1);c=0;break d}g=f+(d<<5)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];Bb(e+32|0,b+1074312|0,33);aP(e+40|0,g,h+(B(d,f)<<1)|0,i-f|0,d,(c&4)>>>2|0,Cb(v[v[e+32>>2]>>2],v[e+36>>2]));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];Bb(e+32|0,b+1074312|0,33);aP(e+8|0,g+(d<<7)|0,h+(B(a,d)<<1)|0,f-a|0,d,(c&16)>>>4|0,Cb(v[v[e+32>>2]>>2],v[e+36>>2]))}jb=e- -64|0;break c}while(1){if((c|0)!=(d|0)){u[f+(c+i<<1)>>1]=x[f+(c-d<<1)>>1];u[h+(c+j<<1)>>1]=x[h+(c<<1)>>1];c=c+1|0;continue}break}g=g+1|0;continue}break};return;case 0:break b;default:break a}}e=jb+-64|0;jb=e;h=v[a+20>>2];c=v[a>>2];d=Gd(x[a+34>>1]);f=h+B(c,d)|0;while(1){e:{f:{if((g|0)!=16){i=B(d,g);j=B(d,g^-1);c=0;break f}g=f+(d<<4)|0;c=x[a+34>>1];if(c&2){i=v[a+8>>2];f=v[a+4>>2];Bb(e+32|0,b+1074312|0,33);$O(e+40|0,g,h+B(d,f)|0,i-f|0,d,(c&4)>>>2|0,Cb(v[v[e+32>>2]>>2],v[e+36>>2]));c=x[a+34>>1]}if(c&8){f=v[a+16>>2];a=v[a+12>>2];Bb(e+32|0,b+1074312|0,33);$O(e+8|0,g+(d<<6)|0,h+B(a,d)|0,f-a|0,d,(c&16)>>>4|0,Cb(v[v[e+32>>2]>>2],v[e+36>>2]))}jb=e- -64|0;break e}while(1){if((c|0)!=(d|0)){t[f+(c+i|0)|0]=w[f+(c-d|0)|0];t[h+(c+j|0)|0]=w[c+h|0];c=c+1|0;continue}break}g=g+1|0;continue}break}}}function iX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=Kb(a);a=w[b+11|0];g=v[b+4>>2];v[23296]=0;k=tl(g,a);R(103,i|0,k|0);a=v[23296];v[23296]=0;a:{b:{if((a|0)!=1){g=0;a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=t[rd(b)+a|0];h=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(h-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(h-123|0){case 2:m=1;e=g+1|0;f=0;if(d>>>0<=g>>>0){g=e;break d}v[23296]=0;Q(104,i|0,Hd(c,g)|0)|0;h=v[23296];v[23296]=0;g=e;if((h|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(h-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}v[23296]=0;Q(104,i|0,Hd(c,j)|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(B(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}h=(e|0)!=125;f=-1;e=125;if(h){break d}}f=0;v[23296]=0;Q(105,i|0,e|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b}f=-1}a=a+1|0;continue}break}b=ba(8)|0;v[23296]=0;a=T(106,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){v[23296]=0;U(107,a|0,41812,24);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ca(b|0);break b}a=P()|0;O()|0}zb(i);S(a|0)}L()}function hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;g=jb-16|0;jb=g;s=v[a+16>>2];t=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=bg(k,l,n);p=mb;b=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Ff(i,e,ff(k,l,d),mb);m=b>>>0<mb>>>0?d:0}h=a+112|0;f=v[a+48>>2];w=v[a+24>>2];x=v[a+20>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;m=m-1|0;b=m;o=b?o:0;p=b?p:0;e=(e<<1)+s|0;b=n;while(1)if((b|0)<=0){Sb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Ld(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Kd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];b=v[a+60>>2];e=b;j=b>>31;r=$f(h,t)<<8;b=r;b=Sia(e,j,b,b>>31);y=mb;e=b;b=v[a+64>>2];j=b;z=b>>31;b=Yb(q,-16777216,16776704);j=Sia(j,z,b,b>>31);e=e+j|0;b=mb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Yb(f,-16777216,16776704);e=Sia(e,e>>31,f,f>>31);f=j+e|0;b=mb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(f,x)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(f,w);Sb(g,k,l);b=b-(i&r)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=q;continue b}else{Ld(h,u[e+(v[g+12>>2]<<1)>>1]/4<<16>>16);Kd(h,4);Sb(g+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+48>>2]=f;v[a+44>>2]=q;jb=g+16|0}function a$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;h=Kb(a+208|0);b=a+16|0;bd(b,d);v[23296]=0;b=T(1084,b|0)|0;c=v[23296];v[23296]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23296]=0;X(1096,b|0,81808,81834,a+224|0);b=v[23296];v[23296]=0;if((b|0)==1){break d}_b(a+16|0);c=Kb(a+192|0);b=Tc(c);v[23296]=0;R(59,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break b}b=Oc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[23296]=0;d=Q(1089,a+344|0,a+336|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break e}if(!d){break c}g=v[a+188>>2];d=Fb(c);if((g|0)==(d+b|0)){v[23296]=0;R(59,c|0,d<<1);b=v[23296];v[23296]=0;if((b|0)==1){break b}b=Tc(c);v[23296]=0;R(59,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break b}b=Oc(c,0);v[a+188>>2]=d+b}v[23296]=0;d=T(1091,v[a+344>>2])|0;g=v[23296];v[23296]=0;if((g|0)==1){break e}if(hn(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[23296]=0;T(1093,a+344|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;_b(a+16|0);break a}v[23296]=0;R(59,c|0,v[a+188>>2]-b|0);b=v[23296];v[23296]=0;f:{if((b|0)==1){break f}b=Jc(c);d=Bd();v[a>>2]=f;if((dG(b,d,a)|0)!=1){v[e>>2]=4}v[23296]=0;b=Q(1090,a+344|0,a+336|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(c);yb(h);jb=a+352|0;return b|0}}b=P()|0;O()|0;yb(c)}yb(h);S(b|0);L()}function j$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;h=Kb(a+208|0);b=a+16|0;bd(b,d);v[23296]=0;b=T(18,b|0)|0;c=v[23296];v[23296]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23296]=0;X(1082,b|0,81808,81834,a+224|0);b=v[23296];v[23296]=0;if((b|0)==1){break d}_b(a+16|0);c=Kb(a+192|0);b=Tc(c);v[23296]=0;R(59,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break b}b=Oc(c,0);v[a+188>>2]=b;v[a+12>>2]=a+16;v[a+8>>2]=0;while(1){e:{v[23296]=0;d=Q(1073,a+264|0,a+256|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break e}if(!d){break c}g=v[a+188>>2];d=Fb(c);if((g|0)==(d+b|0)){v[23296]=0;R(59,c|0,d<<1);b=v[23296];v[23296]=0;if((b|0)==1){break b}b=Tc(c);v[23296]=0;R(59,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break b}b=Oc(c,0);v[a+188>>2]=d+b}v[23296]=0;d=T(1075,v[a+264>>2])|0;g=v[23296];v[23296]=0;if((g|0)==1){break e}if(kn(d,16,b,a+188|0,a+8|0,0,h,a+16|0,a+12|0,a+224|0)){break c}v[23296]=0;T(1077,a+264|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){continue}}break}break b}b=P()|0;O()|0;_b(a+16|0);break a}v[23296]=0;R(59,c|0,v[a+188>>2]-b|0);b=v[23296];v[23296]=0;f:{if((b|0)==1){break f}b=Jc(c);d=Bd();v[a>>2]=f;if((dG(b,d,a)|0)!=1){v[e>>2]=4}v[23296]=0;b=Q(1074,a+264|0,a+256|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break f}if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(c);yb(h);jb=a+272|0;return b|0}}b=P()|0;O()|0;yb(c)}yb(h);S(b|0);L()}function Oba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;h=jb-16|0;jb=h;a:{b:{c:{i=v[a+12>>2];j=v[a+8>>2];d:{if((i|0)<=1&j>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&j>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&j>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&j>>>0>2147483648|i>>>0>1){break b}}n=b+196648|0;break a}n=b+131112|0;break a}n=b+262184|0}o=v[a+16>>2];f=v[a+48>>2];p=v[a+24>>2];q=v[a+20>>2];b=v[a+44>>2];e=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=e;r=v[a+72>>2];e=v[a+68>>2];s=e;t=e>>31;e=v[a+64>>2];w=e;x=e>>31;e=v[a+60>>2];y=e;z=e>>31;while(1){e=b;if(d){b=Yb(e,-16777216,16776704);b=Sia(w,x,b,b>>31);k=mb;l=b;g=(v[h+12>>2]<<1)+o|0;b=(v[h+8>>2]>>>16&65520)+n|0;g=(((((((B(u[g-4>>1],u[b+2>>1])+B(u[g-6>>1],u[b>>1])|0)+B(u[g-2>>1],u[b+4>>1])|0)+B(u[g>>1],u[b+6>>1])|0)+B(u[g+2>>1],u[b+8>>1])|0)+B(u[g+4>>1],u[b+10>>1])|0)+B(u[g+6>>1],u[b+12>>1])|0)+B(u[g+8>>1],u[b+14>>1])|0)/32768<<8;b=g;b=Sia(b,b>>31,y,z);l=l+b|0;m=mb+k|0;m=b>>>0>l>>>0?m+1|0:m;b=Yb(f,-16777216,16776704);f=Sia(s,t,b,b>>31);k=f+l|0;b=mb+m|0;b=f>>>0>k>>>0?b+1|0:b;f=k+8388608|0;b=f>>>0<8388608?b+1|0:b;f=Rc(f,b,24);b=(f|0)/256|0;v[c>>2]=B(b,q)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(b,p);Sb(h+8|0,j,i);b=f-(g&r)|0;c=c+8|0;d=d-1|0;f=e;continue}break}b=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=b;v[a+48>>2]=f;v[a+44>>2]=e;jb=h+16|0}function Qy(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-16|0;jb=h;f=v[c+656>>2];a:{if(!oj(f)){i=v[c+704>>2];f=jb-16|0;jb=f;v[f+12>>2]=d;g=0;b:{if(!d){break b}j=v[b+480180>>2];if(j&20){e=b+1074312|0;Bb(f,e,73);d=Cb(v[v[f>>2]>>2],v[f+4>>2])?d&65535:d;if(w[b+480208|0]&16){Bb(f,e,73);e=Cb(v[v[f>>2]>>2],v[f+4>>2])?14-((9983-d>>>0)/768|0)&31:((d>>>0)/768|0)+2|0;g=v[((d>>>0)%768<<2)+33936>>2]<<6>>>e|0;break b}if(!d){v[f+12>>2]=1;d=1}g=229079296/(d>>>0)|0;break b}g=227001280/(d>>>0)|0;if(om(j)){break b}g=(d+i<<4)-133808|0;if((j|0)==64){break b}yc(f+12|0,16777215);if(j&17408){g=Vc(Via(Sia(i?i:8363,0,3506176,0),mb,(v[f+12>>2]<<8)+e|0,0),mb);break b}if(gj(b)){d=v[f+12>>2];i=d>>>24|0;j=d<<8;d=j+e|0;e=i+(e>>31)|0;g=((d>>>0<j>>>0?e+1|0:e)&15)<<28|d>>>4;break b}if(w[b+480208|0]&16){g=Vc(Via(Sia(i?i:8363,0,7012352,0),mb,(v[f+12>>2]<<8)+e|0,0),mb);break b}g=Vc(Via(-1485242368,13,(v[f+12>>2]<<8)+e|0,0),mb)}e=g;jb=f+16|0;f=v[c+656>>2];break a}e=v[c+700>>2]}v[h+12>>2]=e;c=u[c+774>>1];c:{if(!c){break c}c=f?B(t[f+33|0],c):c;if(!c){break c}e=Ie(Lj(+(c|0)/393216)*+(e>>>0));v[h+12>>2]=e}d:{if(!f){break d}c=v[f+40>>2];if(!c){break d}d=(c|0)/2|0;f=v[b+1074420>>2];e=Sia(f,f>>31,e,e>>31);f=d+e|0;d=mb+(d>>31)|0;k=h,l=Ic(Tia(f,e>>>0>f>>>0?d+1|0:d,c,c>>31),mb),v[k+12>>2]=l}yc(h+12|0,2147483647);c=v[h+12>>2];b=Tia(0,c,v[b+24620>>2]<<4,0);v[a+8>>2]=c;v[a>>2]=b;v[a+4>>2]=mb;jb=h+16|0}function cE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-96|0;jb=c;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{if(!b){Vb(a,9642);break j}if(!(b&65535)){d=jb-16|0;jb=d;e=Vb(d,4360);Sc(c+80|0,e);zb(e);jb=d+16|0;v[23296]=0;v[c+24>>2]=b>>>24;R(97,c- -64|0,c+24|0);d=v[23296];v[23296]=0;k:{l:{m:{n:{if((d|0)!=1){v[23296]=0;v[c+8>>2]=b>>>16&255;R(98,c+48|0,c+8|0);b=v[23296];v[23296]=0;if((b|0)==1){break n}v[23296]=0;X(99,a|0,c+80|0,c- -64|0,c+48|0);a=v[23296];v[23296]=0;if((a|0)==1){break m}zb(c+48|0);zb(c- -64|0);ec(c+80|0);break j}b=P()|0;O()|0;break k}b=P()|0;O()|0;break l}b=P()|0;O()|0;zb(c+48|0)}zb(c- -64|0)}break a}d=jb-16|0;jb=d;e=Vb(d,4084);Sc(c+80|0,e);zb(e);jb=d+16|0;v[23296]=0;v[c+44>>2]=b>>>24;R(97,c- -64|0,c+44|0);d=v[23296];v[23296]=0;if((d|0)==1){break i}v[23296]=0;v[c+40>>2]=b>>>16&255;R(98,c+48|0,c+40|0);d=v[23296];v[23296]=0;if((d|0)==1){break h}v[23296]=0;v[c+20>>2]=b>>>8&255;R(98,c+24|0,c+20|0);d=v[23296];v[23296]=0;if((d|0)==1){break g}v[23296]=0;v[c+4>>2]=b&255;R(98,c+8|0,c+4|0);b=v[23296];v[23296]=0;if((b|0)==1){break f}v[23296]=0;ma(100,a|0,c+80|0,c- -64|0,c+48|0,c+24|0,c+8|0);a=v[23296];v[23296]=0;if((a|0)==1){break e}zb(c+8|0);zb(c+24|0);zb(c+48|0);zb(c- -64|0);ec(c+80|0)}jb=c+96|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;break d}b=P()|0;O()|0;zb(c+8|0)}zb(c+24|0)}zb(c+48|0)}zb(c- -64|0)}ec(c+80|0);S(b|0);L()}function Xca(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-48|0;jb=e;u[e+46>>1]=254;c=lj(a);f=e+32|0;v[f>>2]=0;v[f+4>>2]=0;Cc(f+8|0);if(c){Sp(f,c);mC(f,c)}a:{b:{while(1){c:{if((b|0)==(c|0)){if(!(d&65535)){break a}c=Eb(v[a>>2]);d=Eb(v[a+4>>2]);b=jb-16|0;jb=b;c=aA(c,d,x[e+46>>1]);v[b+8>>2]=c;if(Rb(c,d)){v[b>>2]=c;while(1){c=v[Se(b)>>2];if(Rb(c,d)){c=x[c>>1];if((c|0)==x[e+46>>1]){continue}u[v[b+8>>2]>>1]=c;Se(b+8|0);continue}break}c=v[b+8>>2]}jb=b+16|0;b=hc(e+24|0,c);c=v[hc(e+16|0,Eb(v[a+4>>2]))>>2];d=v[b>>2];b=v[a>>2];b=(so(d,Eb(b))<<1)+b|0;if(Rb(d,c)){Nd(a,Ji(b+(so(c,d)<<1)|0,v[a+4>>2],b))}Eb(b);k=e,l=Eb(v[a>>2]),v[k+8>>2]=l;d=Eb(v[a+4>>2]);break c}k=dc(v[f>>2],b),l=b-d|0,u[k>>1]=l;g=v[a+4>>2];h=v[a>>2];v[23296]=0;g=W(700,h|0,g|0,b|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break b}b=b+1|0;d=(x[g>>1]==254)+d|0;continue}break}while(1){b=v[e+8>>2];if(!Rb(b,d)){b=v[f>>2];d=Nc(b,v[f+4>>2]);c=x[a+28>>1];if(d>>>0<=c>>>0){break a}k=a,l=x[dc(b,c)>>1],u[k+28>>1]=l;break a}d:{c=v[a+24>>2];g=v[c+484344>>2];b=x[b>>1];if(!oe(g,v[c+484348>>2],b)){break d}b=$b(g,b);k=e,l=Eb(v[b>>2]),v[k>>2]=l;g=Eb(v[b+4>>2]);h=v[f+4>>2];c=v[f>>2];while(1){b=v[e>>2];if(!Rb(b,g)){break d}e:{if(w[b+3|0]!=12){break e}j=Nc(c,h);i=w[b+5|0];if(j>>>0<=i>>>0){break e}k=b,l=w[dc(c,i)|0],t[k+5|0]=l}kk(e);continue}}Se(e+8|0);continue}}a=P()|0;O()|0;ud(f);S(a|0);L()}ud(f);jb=e+48|0}function vz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;if(b&5){if((b|0)==1){d=Sia(v[a+24>>2],0,8363,0)+4136|0;c=mb;h=a,i=Vc(Via(d,d>>>0<4136?c+1|0:c,8272,0),mb),v[h+24>>2]=i}d=jb-16|0;jb=d;f=d+8|0;c=jb-16|0;jb=c;g=v[a+24>>2];a:{if(!g){t[f|0]=0;t[f+1|0]=0;break a}pB(c+8|0,Yb(bm(lp(+(g>>>0)*.00011957431543704412)*2215.9795828054475),-16384,16383),128);g=v[c+8>>2];t[c+7|0]=v[c+12>>2];nt(f,g,c+7|0)}jb=c+16|0;hc(hc(d,a+36|0)+4|0,a+37|0);t[v[d>>2]]=w[f|0];t[v[d+4>>2]]=w[f+1|0];jb=d+16|0}if(b&3){u[a+38>>1]=0;u[a+40>>1]=0;t[a+36|0]=0;u[a+34>>1]=x[a+34>>1]&65499}if(b&7){u[a+32>>1]=64;c=x[a+34>>1];if(c&8){d=v[a+16>>2];v[a+4>>2]=v[a+12>>2];v[a+8>>2]=d;c=c&16?c|6:c&65529|2}v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=c&65511}b:{if(!(b&4)){break b}c=x[a+34>>1];if(!(c&32)){u[a+28>>1]=128;u[a+34>>1]=c|32}nf(a+40|0,15);nf(a+41|0,63);if(!w[a+41|0]){break b}d=w[a+40|0];if(!d){break b}c=w[a+39|0];if(c){c=Bm(Vc(((d<<8|c>>>1)>>>0)/(c>>>0)|0,0))}else{c=255}t[a+39|0]=c}c:{d:{if((b|0)!=4){if((b|0)==16777216){break c}if((b|0)!=32|w[a+38|0]!=2){break d}t[a+38|0]=3;break d}if(w[a+38|0]!=4){break d}t[a+38|0]=0}u[a+34>>1]=x[a+34>>1]&49151}e:{if(!(!(w[a+35|0]&2)|b&16777218)){v[e+24>>2]=0;v[e+8>>2]=0;v[e+16>>2]=0;v[e+20>>2]=0;v[e>>2]=0;v[e+4>>2]=0;hl(a,0,e);break e}if(!(w[a+35|0]&2)|(b|0)!=2){break e}a=a+68|0;b=Lb(a,8);t[b|0]=w[b|0]&3;a=Lb(a,9);t[a|0]=w[a|0]&3}jb=e+32|0}function tQ(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;j=jb-16|0;jb=j;a:{if((b|0)==(c|0)){break a}v[j+12>>2]=-1953789045;Pz(b,c,j+12|0);c=c-b|0;e=c>>2;v[j+8>>2]=e;f=wc(v[a>>2],v[a+4>>2]);g=11;b:{if(c>>>0>2488){break b}g=7;if(c>>>0>268){break b}g=5;if(c>>>0>152){break b}g=3;if(c>>>0>24){break b}g=e-1>>>1|0}c=f+1|0;v[j+4>>2]=c;n=v[Yc(j+4|0,j+8|0)>>2];k=e-g>>>1|0;d=(k<<2)+b|0;h=v[d>>2];i=B(Ct(v[((e<<2)+b|0)-4>>2]^(h^v[b>>2])),1664525);v[d>>2]=i+h;g=g+k|0;d=(g<<2)+b|0;f=f+i|0;v[d>>2]=f+v[d>>2];v[b>>2]=f;i=v[a>>2];a=1;while(1)if((a|0)==(c|0)){while(1)if(c>>>0>=n>>>0){c=n;while(1){if(e+n>>>0<=c>>>0){break a}d=((c+k>>>0)%(e>>>0)<<2)+b|0;h=v[d>>2];f=(c>>>0)%(e>>>0)|0;i=(f<<2)+b|0;a=B(Ct(v[((c-1>>>0)%(e>>>0)<<2)+b>>2]+(h+v[i>>2]|0)|0),1566083941);v[d>>2]=a^h;d=((c+g>>>0)%(e>>>0)<<2)+b|0;a=a-f|0;v[d>>2]=a^v[d>>2];v[i>>2]=a;c=c+1|0;continue}}else{d=((c+k>>>0)%(e>>>0)<<2)+b|0;h=v[d>>2];f=(c>>>0)%(e>>>0)|0;i=(f<<2)+b|0;a=B(Ct(v[((c-1>>>0)%(e>>>0)<<2)+b>>2]^(h^v[i>>2])),1664525);v[d>>2]=a+h;d=((c+g>>>0)%(e>>>0)<<2)+b|0;a=a+f|0;v[d>>2]=a+v[d>>2];v[i>>2]=a;c=c+1|0;continue}}else{d=a-1|0;l=((a+k>>>0)%(e>>>0)<<2)+b|0;m=v[l>>2];h=(a>>>0)%(e>>>0)|0;o=(h<<2)+b|0;f=B(Ct(v[((d>>>0)%(e>>>0)<<2)+b>>2]^(m^v[o>>2])),1664525);v[l>>2]=f+m;l=((a+g>>>0)%(e>>>0)<<2)+b|0;m=v[l>>2];f=v[Db(i,d)>>2]+(f+h|0)|0;v[l>>2]=f+m;v[o>>2]=f;a=a+1|0;continue}}jb=j+16|0}function Pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;h=jb-16|0;jb=h;a:{b:{c:{i=v[a+12>>2];k=v[a+8>>2];d:{if((i|0)<=1&k>>>0<=805306368|(i|0)<=0){if((i|0)>=-2&k>>>0>=3489660928|(i|0)>-2){break c}if((i|0)==-2&k>>>0>2147483647|i>>>0>4294967294){break d}break b}if((i|0)==1&k>>>0>2147483648|i>>>0>1){break b}}l=b+196648|0;break a}l=b+131112|0;break a}l=b+262184|0}m=v[a+16>>2];b=v[a+48>>2];n=v[a+24>>2];o=v[a+20>>2];e=v[a+44>>2];f=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=f;p=v[a+72>>2];f=v[a+68>>2];q=f;r=f>>31;f=v[a+64>>2];s=f;w=f>>31;f=v[a+60>>2];x=f;y=f>>31;while(1){f=e;if(d){e=Yb(f,-16777216,16776704);e=Sia(s,w,e,e>>31);g=mb;j=e;b=Yb(b,-16777216,16776704);e=Sia(q,r,b,b>>31);j=j+e|0;b=mb+g|0;b=e>>>0>j>>>0?b+1|0:b;g=v[h+12>>2]+m|0;e=(v[h+8>>2]>>>16&65520)+l|0;g=(((((((B(t[g-2|0],u[e+2>>1])+B(t[g-3|0],u[e>>1])|0)+B(t[g-1|0],u[e+4>>1])|0)+B(t[g|0],u[e+6>>1])|0)+B(t[g+1|0],u[e+8>>1])|0)+B(t[g+2|0],u[e+10>>1])|0)+B(t[g+3|0],u[e+12>>1])|0)+B(t[g+4|0],u[e+14>>1])<<8)/32768<<8;e=g;e=Sia(e,e>>31,x,y);j=e+j|0;b=mb+b|0;b=e>>>0>j>>>0?b+1|0:b;e=j+8388608|0;b=e>>>0<8388608?b+1|0:b;e=Rc(e,b,24);b=(e|0)/256|0;v[c>>2]=B(b,o)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(b,n);Sb(h+8|0,k,i);e=e-(g&p)|0;c=c+8|0;d=d-1|0;b=f;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=b;v[a+44>>2]=f;jb=h+16|0}function Gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=jb-48|0;jb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){d=d-1|0;f=((((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&2147483646)<<1)+m|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=u[f+(e<<1)>>1];e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=v[k>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Sia(w,x,f,f>>31);j=mb;A=e;e=Yb(h,-16777216,16776704);h=Sia(s,t,e,e>>31);f=h+f|0;e=mb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Yb(i,-16777216,16776704);i=Sia(q,r,f,f>>31);f=j+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Rc(f,e,24);v[A+4>>2]=e-(p&l);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+12>>2]);Sb(g+16|0,y,z);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function Lia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=Kb(a);k=Fb(b);v[23296]=0;R(283,h|0,k|0);a=v[23296];v[23296]=0;a:{b:{if((a|0)!=1){a=0;while(1){c:{if((a|0)==(k|0)){a=!f;if(!(l?a&(m^-1):a)){break c}return}e=t[Yf(b,a)|0];g=e&255;d:{e:{f:{g:{switch(f+1|0){case 1:f=1;h:{switch(g-123|0){case 2:break h;case 0:break d;default:break f}}f=3;break d;case 2:i:{switch(g-123|0){case 2:m=1;e=i+1|0;f=0;if(d>>>0<=i>>>0){i=e;break d}v[23296]=0;Q(284,h|0,Hd(c,i)|0)|0;g=v[23296];v[23296]=0;i=e;if((g|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break f;default:break i}}f=-1;e=e-48|0;if((e&255)>>>0>9){break d}l=1;f=2;j=e;break d;case 3:f=-1;j:{switch(g-123|0){case 2:f=0;if(d>>>0<=j>>>0){break d}v[23296]=0;Q(284,h|0,Hd(c,j)|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b;case 0:break d;default:break j}}if((e-48&255)>>>0>9){break d}j=(B(j,10)+e|0)-48|0;l=1;f=2;break d;case 4:break g;case 0:break e;default:break d}}g=(e|0)!=125;f=-1;e=125;if(g){break d}}f=0;v[23296]=0;Q(285,h|0,e|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break d}a=P()|0;O()|0;break b}f=-1}a=a+1|0;continue}break}b=ba(8)|0;v[23296]=0;a=T(106,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){v[23296]=0;U(107,a|0,41812,24);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;ca(b|0);break b}a=P()|0;O()|0}yb(h);S(a|0)}L()}function xN(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-32|0;jb=e;f=v[b+64>>2];a:{b:{h=v[b+60>>2];g=x[b+68>>1];if(!((h|0)==-1&(g|0)==65535)){c:{if((f|0)==-1){break c}f=a+1074312|0;Bb(e+24|0,f,68);if(Cb(v[v[e+24>>2]>>2],v[e+28>>2])){break c}Bb(e+16|0,f,103);if(i=Cb(v[v[e+16>>2]>>2],v[e+20>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}Bb(e+8|0,f,49);if(i=Cb(v[v[e+8>>2]>>2],v[e+12>>2]),j=0,k=(g|0)!=65535,k?i:j){break c}f=v[b+64>>2];break b}if((g|0)==65535){u[b+68>>1]=x[b+72>>1]+1}if((h|0)==-1){v[b+60>>2]=0}g=Nc(v[c>>2],v[c+4>>2]);f=x[b+68>>1];if(g>>>0<=f>>>0){f=x[c+28>>1];u[b+68>>1]=f}d:{if(x[b+72>>1]==(f&65535)){break d}c=a+1074312|0;Bb(e+24|0,c,26);if(Cb(v[v[e+24>>2]>>2],v[e+28>>2])){break d}Bb(e+16|0,c,68);if(Cb(v[v[e+16>>2]>>2],v[e+20>>2])|v[a+480180>>2]==1){break d}c=x[a+480188>>1];f=0;while(1){if((c|0)==(f|0)){break d}t[(B(f,872)+b|0)+1457|0]=0;f=f+1|0;continue}}v[b+52>>2]=v[b+60>>2];if(d){c=1;if(w[a+480208|0]&32){break a}}u[b+74>>1]=x[b+68>>1];c=1;break a}if((f|0)!=-1){break b}c=0;break a}v[b+52>>2]=f;u[b+74>>1]=x[b+72>>1];e:{if(!v[b+20>>2]){break e}c=v[a+480180>>2];if((c|0)==32){Bb(e+24|0,a+1074312|0,103);if(Cb(v[v[e+24>>2]>>2],v[e+28>>2])){break e}c=v[a+480180>>2]}if((c|0)==2){break e}v[b+52>>2]=v[b+52>>2]+1}c=0;if(y[b+64>>2]<y[$b(v[a+484344>>2],x[b+70>>1])+12>>2]){break a}v[b+52>>2]=0;u[b+74>>1]=x[b+74>>1]+1;c=0}jb=e+32|0;return c}function EY(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;n=jb-16|0;jb=n;b=c;while(1){a:{if((b|0)==(d|0)){b=d;break a}if(!v[b>>2]){break a}b=b+4|0;continue}break}v[h>>2]=f;v[e>>2]=c;while(1){b:{c:{if(!((c|0)==(d|0)|(f|0)==(g|0))){q=1;r=jb-16|0;jb=r;s=bi(r+8|0,v[a+8>>2]);i=f;j=g-f|0;m=0;o=jb-16|0;jb=o;k=v[e>>2];p=b-c>>2;d:{if(!k|!p){break d}j=i?j:0;while(1){l=Ow(j>>>0<4?o+12|0:i,v[k>>2]);if((l|0)==-1){m=-1;break d}if(i){if(j>>>0<=3){if(j>>>0<l>>>0){break d}qc(i,o+12|0,l)}j=j-l|0;i=i+l|0}else{i=0}if(!v[k>>2]){k=0;break d}m=m+l|0;k=k+4|0;p=p-1|0;if(p){continue}break}}if(i){v[e>>2]=k}jb=o+16|0;ai(s);jb=r+16|0;e:{f:{g:{h:{switch(m+1|0){case 0:v[h>>2]=f;while(1){i:{if(v[e>>2]==(c|0)){break i}b=ew(f,v[c>>2],v[a+8>>2]);if((b|0)==-1){break i}f=b+v[h>>2]|0;v[h>>2]=f;c=c+4|0;continue}break};v[e>>2]=c;break g;case 1:break c;default:break h}}f=m+v[h>>2]|0;v[h>>2]=f;if((f|0)==(g|0)){break e}if((b|0)==(d|0)){c=v[e>>2];b=d;continue}b=ew(n+12|0,0,v[a+8>>2]);if((b|0)!=-1){break f}}q=2;break c}c=n+12|0;if(g-v[h>>2]>>>0<b>>>0){break c}while(1){if(b){f=w[c|0];i=v[h>>2];v[h>>2]=i+1;t[i|0]=f;b=b-1|0;c=c+1|0;continue}break}c=v[e>>2]+4|0;v[e>>2]=c;b=c;while(1){if((b|0)==(d|0)){b=d;break b}if(!v[b>>2]){break b}b=b+4|0;continue}}c=v[e>>2]}q=(c|0)!=(d|0)}jb=n+16|0;return q|0}f=v[h>>2];continue}}function iba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0;g=jb-16|0;jb=g;s=v[a+16>>2];u=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];i=v[a>>2];e=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=bg(k,l,n);p=mb;b=v[a+76>>2];i=v[a>>2];e=v[a+4>>2];Ff(i,e,ff(k,l,d),mb);m=b>>>0<mb>>>0?d:0}h=a+112|0;f=v[a+48>>2];w=v[a+24>>2];x=v[a+20>>2];b=v[a+44>>2];v[g>>2]=i;v[g+4>>2]=e;b:while(1){c:{q=b;if(!d){break c}d=d-1|0;v[g+8>>2]=i;v[g+12>>2]=0;m=m-1|0;b=m;o=b?o:0;p=b?p:0;e=e+s|0;b=n;while(1)if((b|0)<=0){Sb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Ld(h,t[e+v[g+12>>2]|0]<<6);Kd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}i=v[a+72>>2];b=v[a+60>>2];e=b;j=b>>31;r=$f(h,u)<<8;b=r;b=Sia(e,j,b,b>>31);y=mb;e=b;b=v[a+64>>2];j=b;z=b>>31;b=Yb(q,-16777216,16776704);j=Sia(j,z,b,b>>31);e=e+j|0;b=mb+y|0;b=e>>>0<j>>>0?b+1|0:b;j=e;e=v[a+68>>2];f=Yb(f,-16777216,16776704);e=Sia(e,e>>31,f,f>>31);f=j+e|0;b=mb+b|0;b=e>>>0>f>>>0?b+1|0:b;f=f+8388608|0;b=f>>>0<8388608?b+1|0:b;b=Rc(f,b,24);f=(b|0)/256|0;v[c>>2]=B(f,x)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(f,w);Sb(g,k,l);b=b-(i&r)|0;c=c+8|0;i=v[g>>2];e=v[g+4>>2];f=q;continue b}else{Ld(h,t[e+v[g+12>>2]|0]<<6);Kd(h,4);Sb(g+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=i;v[a+4>>2]=e;v[a+48>>2]=f;v[a+44>>2]=q;jb=g+16|0}function py(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;h=89;i=88;j=92;k=91;l=85;m=84;n=83;o=5;p=113;q=111;r=107;s=106;t=96;u=82;v=80;w=78;x=79;y=77;z=57;A=47;d=10;e=8;f=7;c=Zq(a);a:{b:{c:{d:{switch(b-1|0){default:a=(b|0)==16777216;if(!a&(b|0)!=32){break c}Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(c,0,1),7,1),8,1),9,1),10,1),11,1),12,1),13,1),14,1),15,1),16,1),17,1),18,1),19,1),20,1),21,1),22,1),23,1),24,1),25,1),26,1),27,1),28,1),29,1),30,1),31,1),32,1),33,1),34,1),35,1),36,1),37,1),38,1),39,1),40,1),41,1),42,1),43,1),44,1),45,1),46,1),47,1),48,1),103,1),50,1),87,1),88,1),100,1),102,1),104,1),115,1);if(!a){break a}d=111;e=105;f=99;break b;case 3:Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(c,0,1),4,1),8,1),9,1),10,1),17,1),40,1),51,1),52,1),53,1),54,1),55,1),56,1),57,1),58,1),59,1),60,1),61,1),62,1),63,1),64,1),65,1),66,1),67,1);p=112;q=98;r=93;s=90;t=89;u=86;v=76;w=75;x=74;y=73;z=72;A=71;d=70;e=69;g=68;case 1:Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(c,g,1),e,1),d,1),A,1),z,1),y,1),x,1),w,1);m=88;o=v;n=u;l=t;k=s;j=r;i=q;h=p;break;case 2:break c;case 0:break d}}Nb(Nb(Nb(Nb(c,o,1),n,1),m,1),l,1);g=k;f=j;e=i;d=h}Nb(c,g,1)}Nb(Nb(Nb(c,f,1),e,1),d,1)}}function mI(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;h=jb-16|0;jb=h;g=v[a+32>>2];f=vs(g);if(!f){f=us(g)}a:{b:{c:{if(b>>>0>=f>>>0){b=ba(8)|0;v[23296]=0;c=Q(54,h|0,5961)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}a=sc(b,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}if(c>>>0>=120){b=ba(8)|0;v[23296]=0;c=Q(54,h|0,11176)|0;a=v[23296];v[23296]=0;if((a|0)!=1){a=sc(b,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=P()|0;O()|0;ca(b|0);break b}f=Cy(g,65535);j=(f|0)==65535?255:f;u[h>>1]=j;f=g+B(j,872)|0;i=f+1074992|0;$n(i,g,65535,1024);c=c+1|0;t[f+1075794|0]=c;t[f+1075791|0]=c;u[f+1075778>>1]=0;Vl(i);Dp(v[a+32>>2],i,b+1|0,0,1,1);v[f+1075688>>2]=65536;bt(v[a+32>>2],i,c,0,1,1,65535);l=f+1075684|0,m=bm(Sy(e*128,-128,128)+128),v[l>>2]=m;l=f+1075680|0,m=bm(Sy(d*256,0,256)),v[l>>2]=m;c=v[a+32>>2];i=c+1074478|0;b=i;c=b+(x[c+480212>>1]<<1)|0;g=x[h>>1];f=g;while(1){d:{e:{if((b|0)!=(c|0)){if((f|0)!=x[b>>1]){break e}}else{b=c}break d}b=b+2|0;continue}break}f:{if((b|0)==(c|0)){break f}f=b;while(1){f=f+2|0;if((f|0)==(c|0)){c=b;break f}k=x[f>>1];if((k|0)==(g|0)){continue}u[b>>1]=k;b=b+2|0;g=x[h>>1];continue}}l=v[a+32>>2],m=_y(i,c),u[l+480212>>1]=m;jb=h+16|0;return j|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function Gha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-80|0;jb=d;b=b&4095;u[d+78>>1]=b;a:{b:{c:{d:{if(b>>>0>=81){e=jb-16|0;jb=e;f=Vb(e,4412);Sc(d- -64|0,f);zb(f);jb=e+16|0;v[23296]=0;e=((b|0)==4095?c:b-80|0)+734016|0;c=Sia(e,e>>31,1e4,0)+14780|0;b=mb;b=Tia(c,c>>>0<14780?b+1|0:b,3652425,0);c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0;if((c|0)<0){b=b-1|0;c=(((e+((b|0)/-4|0)|0)+B(b,-365)|0)+((b|0)/100|0)|0)+((b|0)/-400|0)|0}g=b;b=(B(c,100)+52|0)/3060|0;e=b+2|0;f=(e|0)/12|0;v[d+44>>2]=g+f;R(86,d+48|0,d+44|0);g=v[23296];v[23296]=0;e:{f:{g:{h:{i:{j:{if((g|0)!=1){v[23296]=0;v[d+28>>2]=(e+B(f,-12)|0)+1;R(88,d+32|0,d+28|0);e=v[23296];v[23296]=0;if((e|0)==1){break j}v[23296]=0;v[d+12>>2]=(((B(b,306)+5|0)/-10|0)+c|0)+1;R(88,d+16|0,d+12|0);b=v[23296];v[23296]=0;if((b|0)==1){break i}v[23296]=0;da(349,a|0,d- -64|0,d+48|0,d+32|0,d+16|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}zb(d+16|0);zb(d+32|0);break d}b=P()|0;O()|0;break e}b=P()|0;O()|0;break f}b=P()|0;O()|0;break g}b=P()|0;O()|0;zb(d+16|0)}zb(d+32|0)}zb(d+48|0)}break a}sg(d- -64|0,4392);v[23296]=0;R(350,d+48|0,d+78|0);b=v[23296];v[23296]=0;if((b|0)==1){break c}v[23296]=0;U(133,a|0,d- -64|0,d+48|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}}zb(d+48|0);ec(d- -64|0);jb=d+80|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;zb(d+48|0)}ec(d- -64|0);S(b|0);L()}
function Ida(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,z=0,A=0,C=0;i=jb-16|0;jb=i;pd(d,32);g=i+8|0;TP(g,w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24),w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24),v[b>>2]);g=kc(g);TP(i,w[a+40|0]|w[a+41|0]<<8|(w[a+42|0]<<16|w[a+43|0]<<24),w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24),v[c>>2]);a=0;g=v[g>>2];if(g-838861>>>0>=4294128436){a=v[kc(i)>>2];v[d>>2]=B(g,320);u[d+34>>1]=1;a:{m=Bg(d);if(!m){break a}l=g<<2;e=+(l>>>0);q=+(a>>>0)/e;r=+(g>>>0)/e;s=1/+y[d>>2];t=+y[i>>2];z=+y[i+8>>2];g=0;b:while(1){if((g|0)==(l|0)){break a}n=+(g>>>0);o=0;p=0;a=v[b+20>>2];if(Ud(v[b>>2],a)){e=n*r+z;c:{if(e<4294967296&e>=0){f=~~e>>>0;break c}f=0}k=x[b+34>>1];j=Gd(k);h=B(f,j);e=e-+(f>>>0);d:{if(k&1){f=x[a+(h<<1)>>1];a=x[a+(h+j<<1)>>1];break d}f=w[a+h|0]<<8;a=w[a+(h+j|0)|0]<<8}p=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}a=v[c+20>>2];if(Ud(v[c>>2],a)){e=n*q+t;e:{if(e<4294967296&e>=0){f=~~e>>>0;break e}f=0}k=x[c+34>>1];j=Gd(k);h=B(f,j);e=e-+(f>>>0);f:{if(k&1){f=x[a+(h<<1)>>1];a=x[a+(h+j<<1)>>1];break f}f=w[a+h|0]<<8;a=w[a+(h+j|0)|0]<<8}o=+(f<<16>>16)*(1-e)+e*+(a<<16>>16)}f=0;a=g;while(1)if((f|0)==80){g=g+1|0;continue b}else{e=s*+(a>>>0);A=v[d+20>>2]+(a<<1)|0,C=Jz(p*(1-e)+o*e),u[A>>1]=C;a=a+l|0;f=f+1|0;continue}}}a=(m|0)!=0}jb=i+16|0;return a|0}function Hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=jb-48|0;jb=g;m=v[a+16>>2];b=0;while(1){if((b|0)!=2){e=b<<3;f=e+(g+24|0)|0;e=a+e|0;v[f+4>>2]=v[e+44>>2];v[f+8>>2]=v[e+48>>2];b=b+1|0;continue}break}n=v[a+24>>2];o=v[a+20>>2];b=v[a+4>>2];v[g+16>>2]=v[a>>2];v[g+20>>2]=b;p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;u=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){if(d){d=d-1|0;f=(((v[g+20>>2]&2147483647)<<1|v[g+16>>2]>>>31)&-2)+m|0;b=0;e=0;while(1){if((e|0)!=2){v[(g+8|0)+(e<<2)>>2]=t[e+f|0]<<8;e=e+1|0;continue}break}while(1){if((b|0)!=2){k=(g+8|0)+(b<<2)|0;f=v[k>>2];e=(g+24|0)+(b<<3)|0;i=v[e+8>>2];h=v[e+4>>2];v[e+8>>2]=h;l=f<<8;f=l;f=Sia(w,x,f,f>>31);j=mb;A=e;e=Yb(h,-16777216,16776704);h=Sia(s,u,e,e>>31);f=h+f|0;e=mb+j|0;e=f>>>0<h>>>0?e+1|0:e;j=f;f=Yb(i,-16777216,16776704);i=Sia(q,r,f,f>>31);f=j+i|0;e=mb+e|0;e=f>>>0<i>>>0?e+1|0:e;f=f+8388608|0;e=f>>>0<8388608?e+1|0:e;e=Rc(f,e,24);v[A+4>>2]=e-(p&l);v[k>>2]=(e|0)/256;b=b+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[g+8>>2],o);v[c+4>>2]=v[c+4>>2]+B(n,v[g+12>>2]);Sb(g+16|0,y,z);c=c+8|0;continue}break}b=v[g+20>>2];v[a>>2]=v[g+16>>2];v[a+4>>2]=b;b=0;while(1){if((b|0)!=2){c=b<<3;d=c+a|0;c=c+(g+24|0)|0;v[d+44>>2]=v[c+4>>2];v[d+48>>2]=v[c+8>>2];b=b+1|0;continue}break}jb=g+48|0}function VA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=jb-16|0;jb=j;a:{if(b&4){break a}c=w[a+14|0];b:{if(c>>>0>=w[a+15|0]){break b}d=w[a+12|0];if(!(d&2)){break b}t[a+12|0]=d&251}if(!(w[a+12|0]&2)|c>>>0<=w[a+13|0]){break a}e=v[a>>2];d=v[a+4>>2];if(re(e,d)>>>0<=c>>>0){break a}e=x[Lc(e,d,c)>>1];d=Lc(v[a>>2],v[a+4>>2],w[a+14|0]-1|0);c=w[a+14|0];if(x[d>>1]<(e-1|0)){c=x[Lc(v[a>>2],v[a+4>>2],c)>>1]-1&65535;e=Lp(a,c,64,64);d=hc(j+8|0,cm(Eb(v[a>>2]),w[a+14|0]));k=ko(j,c,e&255);m=jb-32|0;jb=m;c=v[d>>2];d=v[a>>2];c=(Qt(c,Eb(d))<<2)+d|0;h=v[a+4>>2];c:{d:{if(h>>>0<y[Gb(a)>>2]){if((c|0)!=(h|0)){break d}uS(a,k);break c}d=Gb(a);f=fg(m+8|0,Ug(a,wc(v[a>>2],h)+1|0),c-v[a>>2]>>2,d);v[23296]=0;R(702,f|0,k|0);d=v[23296];v[23296]=0;if((d|0)!=1){d=v[f+4>>2];i=f+4|0;Op(v[a>>2],c,i);e=v[a+4>>2];g=f+8|0;while(1){if((c|0)!=(e|0)){jo(v[g>>2],x[c>>1]|x[c+2>>1]<<16);v[g>>2]=v[g>>2]+4;c=c+4|0;continue}break}oc(a,i);oc(a+4|0,g);oc(Gb(a),zc(f));v[f>>2]=v[f+4>>2];c=d;eg(f);break c}a=P()|0;O()|0;eg(f);S(a|0);L()}f=jb-16|0;jb=f;i=v[a+4>>2];d=(i-(c+4|0)|0)+c|0;g=Ph(f,a,h-d>>2);l=v[g+4>>2];e=d;while(1){if(e>>>0>=h>>>0){lc(g);kq(c,d,i);jb=f+16|0}else{jo(l,x[e>>1]|x[e+2>>1]<<16);l=l+4|0;v[g+4>>2]=l;e=e+4|0;continue}break}t[c+2|0]=w[k+2|0];u[c>>1]=x[k>>1]}Eb(c);jb=m+32|0;break a}t[a+14|0]=c-1}if((b|0)!=16777216){t[a+17|0]=255}jb=j+16|0}function Ofa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;a:{if((c|0)!=4){g=b+236|0;h=b+108|0;while(1){if((d|0)==120){break a}f=(d<<2)+a|0;i=Lb(h,d),j=w[f+4|0]+1|0,t[i|0]=j;i=dc(g,d),j=(w[f+6|0]|w[f+7|0]<<8)+1|0,u[i>>1]=j;d=d+1|0;continue}}f=b+236|0;while(1){if((d|0)==96){break a}g=(d<<2)+a|0;i=dc(f,d+12|0),j=(w[g+6|0]|w[g+7|0]<<8)+1|0,u[i>>1]=j;d=d+1|0;continue}}mA(a+484|0,b+48|0,0);mA(a+590|0,b+68|0,0);mA(a+696|0,b+88|0,5);v[b>>2]=w[a+806|0]|w[a+807|0]<<8;d=t[a+808|0];b:{if((d|0)<0){t[b+34|0]=d-127;break b}if(d>>>0>16){break b}if(t[a|0]&1){t[b+31|0]=d+1;break b}if(!d){break b}t[b+31|0]=d+1}if(w[b+31|0]){c:{d:{if((c|0)==4){d=w[a+810|0];break d}d=t[a+809|0];if((d|0)>=0){u[b+28>>1]=(d&255)+1}d=t[a+810|0];if((d|0)<0){break c}}t[b+30|0]=d+1}t[b+33|0]=w[a+811|0]}if((c|0)==32){t[e+15|0]=w[a+812|0];t[e+14|0]=128;i=b,j=w[Wb(e+15|0,e+14|0)|0]>>>1|0,v[i+4>>2]=j}c=w[a+813|0]|w[a+814|0]<<8;if(c>>>0<=256){v[b+8>>2]=c;t[b+15|0]=w[b+15|0]|1}t[b+16|0]=w[a+815|0];t[b+26|0]=w[a+816|0];t[b+27|0]=w[a+817|0];t[b+17|0]=w[a+818|0];t[b+18|0]=w[a+819|0];u[e+12>>1]=w[a+820|0]|w[a+821|0]<<8;u[e+10>>1]=100;i=b,j=w[Zc(e+12|0,e+10|0)|0],t[i+20|0]=j;u[e+8>>1]=w[a+822|0]|w[a+823|0]<<8;u[e+6>>1]=256;i=b,j=x[Zc(e+8|0,e+6|0)>>1]>>>2|0,t[i+19|0]=j;c=w[a+824|0];Dm(b,c&127,c>>>7|0);a=w[a+825|0];Cm(b,a&127,a>>>7|0);jb=e+16|0}function rF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{c:{while(1){c=v[a+12>>2];if(!(c>>>0>=d>>>0|f>>>0>=g>>>0)){i=t[c|0];j=i&255;d:{if((i|0)>=0){u[f>>1]=j;b=c+1|0;break d}b=2;if(i>>>0<4294967234){break b}if(i>>>0<=4294967263){if((d-c|0)<2){break c}i=w[c+1|0];if((i&192)!=128){break a}u[f>>1]=i&63|j<<6&1984;b=c+2|0;break d}if(i>>>0<=4294967279){if((d-c|0)<3){break c}k=w[c+2|0];i=w[c+1|0];e:{f:{if((j|0)!=237){if((j|0)!=224){break f}if((i&224)==160){break e}break a}if((i&224)==128){break e}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}u[f>>1]=k&63|((i&63)<<6|j<<12);b=c+3|0;break d}if(i>>>0>4294967284){break b}b=1;if((d-c|0)<4){break a}k=w[c+3|0];i=w[c+2|0];c=w[c+1|0];g:{h:{switch(j-240|0){case 0:if((c+112&255)>>>0>=48){break b}break g;case 4:if((c&240)!=128){break b}break g;default:break h}}if((c&192)!=128){break b}}if((i&192)!=128|(k&192)!=128){break b}if((g-f|0)<4){break a}b=2;j=j&7;if((c<<12&196608|j<<18)>>>0>1114111){break a}b=c<<2;u[f>>1]=(i>>>4&3|(b&192|j<<8|b&60))+16320|55296;v[a+8>>2]=f+2;u[f+2>>1]=i<<6&960|k&63|56320;b=v[a+12>>2]+4|0}v[a+12>>2]=b;f=v[a+8>>2]+2|0;v[a+8>>2]=f;continue}break}b=c>>>0<d>>>0;break a}b=1;break a}b=2}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return b|0}function Vn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb-16|0;jb=d;h=a+1074312|0;Bb(d+8|0,h,96);i=b,j=(k=0,l=v[b+660>>2],m=Cb(v[v[d+8>>2]>>2],v[d+12>>2]),m?k:l)+c|0,v[i+660>>2]=j;g=v[a+480180>>2];e=v[b+84>>2];if(!(!(g&18)|e>>>0>c>>>0|(!(w[b+88|0]&2)|!e))){f=c;c=v[b+80>>2];c=((f-c>>>0)%(e-c>>>0)|0)+c|0}c=c>>>(v[b+88>>2]&1&(g|0)==16384)|0;a:{b:{if(!Uc(w[b+788|0])){Bb(d+8|0,h,114);if(!Cb(v[v[d+8>>2]>>2],v[d+12>>2])){break b}}e=v[b+656>>2];c:{if(!e){break c}g=w[b+788|0];if(!Uc(g)){break c}e=x[dc(e+236|0,g-1|0)>>1];if(!e|e>>>0>x[a+480190>>1]){break a}}d:{if(w[a+480210|0]&32){f=c;c=v[b+660>>2];v[b+660>>2]=f+c;f=0;break d}f=0}v[b>>2]=f;v[b+4>>2]=c;if((!(w[b+88|0]&2)|c>>>0<y[b+84>>2])&c>>>0<y[b+76>>2]){break a}Bb(d+8|0,h,57);e:{if(!Cb(v[v[d+8>>2]>>2],v[d+12>>2])){c=v[a+480180>>2];if((c|0)!=16){break e}}v[b+700>>2]=0;v[b+88>>2]=v[b+88>>2]|2097152;break a}if(!(c&1048581)){Bb(d+8|0,h,27);if(Cb(v[v[d+8>>2]>>2],v[d+12>>2])){if(w[a+480208|0]&4){c=v[b+76>>2];v[b>>2]=0;v[b+4>>2]=c;break a}v[b>>2]=0;v[b+4>>2]=0;break a}c=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=c;if(!(w[a+480208|0]&4)){break a}a=v[b+76>>2];if(a>>>0<5){break a}v[b>>2]=0;v[b+4>>2]=a-2;break a}if(!(w[b+88|0]&2)|(c|0)!=1){break a}c=v[b+80>>2];v[b>>2]=0;v[b+4>>2]=c;break a}if(!(v[a+480180>>2]&268582928)|c>>>0>=y[b+76>>2]){break a}v[b>>2]=0;v[b+4>>2]=c}jb=d+16|0}function iz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;a:{e=a;b:{c:{h=a+62|0;f=Lb(h,b);a=t[f|0];if((a|0)==-1){break c}if((a|0)>=0){break b}a=a&127;d=dc(e+26|0,a);g=x[d>>1];if((g|0)!=65535&(b|0)!=(g|0)){break c}u[d>>1]=b;t[f|0]=a;break b}l=e+8|0;i=e+26|0;d=255;a=0;g=255;while(1){if((a|0)!=18){j=dc(i,a);k=x[j>>1];if((k|0)==65535){u[j>>1]=b;t[f|0]=a;break b}else{if(!(w[Lb(l,a)|0]&32)){g=t[Lb(h,k)|0]<0?a:g;d=a}a=a+1|0;continue}}break}if((d&255)!=255){a=(g&255)==255?d:g;d=dc(i,a&255);m=Lb(h,x[d>>1]),n=255,t[m|0]=n;u[d>>1]=b;t[f|0]=a}a=Xk(e,b)}g=a&255;if((g|0)==255){break a}if(Vj(v[e>>2])){break a}d=Hd(e+318|0,g);a=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[d+8|0]=a;t[d+9|0]=a>>>8;t[d+10|0]=a>>>16;t[d+11|0]=a>>>24;a=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[d|0]=f;t[d+1|0]=f>>>8;t[d+2|0]=f>>>16;t[d+3|0]=f>>>24;t[d+4|0]=a;t[d+5|0]=a>>>8;t[d+6|0]=a>>>16;t[d+7|0]=a>>>24;f=CO(g);h=f+3|0;a=0;while(1){if((a|0)==2){Tg(v[e>>2],v[e+4>>2],b,lt(g)|192,w[Lb(c,10)|0])}else{d=a?h:f;Tg(v[e>>2],v[e+4>>2],b,d|32,w[Lb(c,a)|0]);Tg(v[e>>2],v[e+4>>2],b,d|64,w[Lb(c,a+2|0)|0]);Tg(v[e>>2],v[e+4>>2],b,d|96,w[Lb(c,a+4|0)|0]);Tg(v[e>>2],v[e+4>>2],b,d|128,w[Lb(c,a+6|0)|0]);Tg(v[e>>2],v[e+4>>2],b,d|224,w[Lb(c,a+8|0)|0]);a=a+1|0;continue}break}}}function d$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=C(0);a=jb-368|0;jb=a;v[a+352>>2]=c;v[a+360>>2]=b;iw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=Tc(d);v[23296]=0;R(59,d|0,b|0);b=v[23296];v[23296]=0;a:{b:{c:{if((b|0)!=1){c=Oc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[23296]=0;b=Q(1089,a+360|0,a+352|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+180>>2];b=Fb(d);if((g|0)==(b+c|0)){v[23296]=0;R(59,d|0,b<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+180>>2]=b+c}v[23296]=0;b=T(1091,v[a+360>>2])|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}if(hw(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23296]=0;T(1093,a+360|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=hG(c,v[a+180>>2],e),z[j>>2]=k;rf(a+200|0,a+16|0,v[a+12>>2],e);v[23296]=0;b=Q(1090,a+360|0,a+352|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];yb(d);yb(a+200|0);jb=a+368|0;break a}}b=P()|0;O()|0;yb(d);yb(a+200|0);S(b|0);L()}return b|0}function m$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=C(0);a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;mw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=Tc(d);v[23296]=0;R(59,d|0,b|0);b=v[23296];v[23296]=0;a:{b:{c:{if((b|0)!=1){c=Oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=t[a+222|0];i=t[a+223|0];while(1){d:{v[23296]=0;b=Q(1073,a+264|0,a+256|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+188>>2];b=Fb(d);if((g|0)==(b+c|0)){v[23296]=0;R(59,d|0,b<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+188>>2]=b+c}v[23296]=0;b=T(1075,v[a+264>>2])|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}if(lw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23296]=0;T(1077,a+264|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=hG(c,v[a+188>>2],e),z[j>>2]=k;rf(a+208|0,a+16|0,v[a+12>>2],e);v[23296]=0;b=Q(1074,a+264|0,a+256|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function fea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-48|0;jb=e;pd(b,2);f=e+16|0;ek(f,2,a+1|0);d=e+32|0;Gc(d,f);ze(b+43|0,d);yb(d);a:{b:{c:{d:{switch(w[a|0]){case 0:f=v[b+4>>2];d=v[b+8>>2];break c;case 2:break b;case 1:break d;default:break a}}d=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);v[b>>2]=d;v[e+32>>2]=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);v[e+16>>2]=d-1;d=e+32|0;f=v[Ib(d,e+16|0)>>2];v[b+4>>2]=f;v[e+32>>2]=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);d=v[Ib(d,b)>>2];v[b+8>>2]=d;u[b+34>>1]=x[b+34>>1]&65533|w[a+31|0]<<1&2}if(d>>>0>f>>>0&d>>>0>=2){break a}u[b+34>>1]=0;v[b+4>>2]=0;v[b+8>>2]=0;break a}f=e+16|0;Dh(f,a+16|0);d=v[e+16>>2];v[e+32>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);Dh(f,a+20|0);d=v[e+16>>2];v[e+36>>2]=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);Dh(f,a+24|0);d=v[e+16>>2];d=w[d|0]|w[d+1|0]<<8|(w[d+2|0]<<16|w[d+3|0]<<24);v[e+40>>2]=d;v[e+8>>2]=d;d=v[e+36>>2];v[e>>2]=v[e+32>>2];v[e+4>>2]=d;hl(b,1,e)}t[e+32|0]=w[a+28|0];t[e+16|0]=64;g=b,h=w[Wb(e+32|0,e+16|0)|0]<<2,u[g+30>>1]=h;d=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);v[b+24>>2]=d;b=b+24|0;e:{if(!c){break e}if(w[a|0]==2){d=d&65535;v[b>>2]=d;break e}if(y[b>>2]>=65536){v[b>>2]=65535}d=v[b>>2]}f:{g:{if(!d){a=8363;break g}a=1024;if(d>>>0>1023){break f}}v[b>>2]=a}jb=e+48|0}function c$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=jb-368|0;jb=a;v[a+352>>2]=c;v[a+360>>2]=b;iw(a+200|0,d,a+224|0,a+220|0,a+216|0);d=Kb(a+184|0);b=Tc(d);v[23296]=0;R(59,d|0,b|0);b=v[23296];v[23296]=0;a:{b:{c:{if((b|0)!=1){c=Oc(d,0);v[a+180>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=v[a+216>>2];i=v[a+220>>2];while(1){d:{v[23296]=0;b=Q(1089,a+360|0,a+352|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+180>>2];b=Fb(d);if((g|0)==(b+c|0)){v[23296]=0;R(59,d|0,b<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+180>>2]=b+c}v[23296]=0;b=T(1091,v[a+360>>2])|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}if(hw(b,a+7|0,a+6|0,c,a+180|0,i,h,a+200|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23296]=0;T(1093,a+360|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+200|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=fG(c,v[a+180>>2],e),A[j>>3]=k;rf(a+200|0,a+16|0,v[a+12>>2],e);v[23296]=0;b=Q(1090,a+360|0,a+352|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+360>>2];yb(d);yb(a+200|0);jb=a+368|0;break a}}b=P()|0;O()|0;yb(d);yb(a+200|0);S(b|0);L()}return b|0}function sga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=v[a>>2];b=Tt(c,v[a+4>>2]);if(b>>>0<=63){g=jb-32|0;jb=g;f=64-b|0;c=v[Gb(a)>>2];d=v[a+4>>2];a:{if(f>>>0<=(c-d|0)/33>>>0){b=jb-16|0;jb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+B(f,33);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){lc(b);jb=b+16|0}else{CA(a);a=a+33|0;v[b+4>>2]=a;continue}break}break a}i=Gb(a);c=g+8|0;h=Tt(v[a>>2],d)+f|0;d=jb-16|0;jb=d;v[d+12>>2]=h;e=jb-16|0;jb=e;v[e+12>>2]=130150524;v[e+8>>2]=2147483647;b=v[Ib(e+12|0,e+8|0)>>2];jb=e+16|0;b:{if(b>>>0>=h>>>0){e=yS(a);if(e>>>0<b>>>1>>>0){v[d+8>>2]=e<<1;b=v[Yc(d+8|0,d+12|0)>>2]}jb=d+16|0;break b}Wc();L()}e=Tt(v[a>>2],v[a+4>>2]);If(c+12|0,i);if(b){if(b>>>0>=130150525){jg();L()}d=xc(B(b,33))}else{d=0}v[c>>2]=d;e=d+B(e,33)|0;v[c+8>>2]=e;v[c+4>>2]=e;j=zc(c),k=d+B(b,33)|0,v[j>>2]=k;b=jb-16|0;jb=b;v[b>>2]=v[c+8>>2];d=v[c+8>>2];v[b+8>>2]=c+8;v[b+4>>2]=d+B(f,33);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){CA(d);d=v[b>>2]+33|0;v[b>>2]=d;continue}break}Id(b);jb=b+16|0;b=c+4|0;f=v[a>>2];d=v[a+4>>2]-f|0;e=v[b>>2]+B((d|0)/-33|0,33)|0;v[b>>2]=e;if((d|0)>0){qc(e,f,d)}oc(a,b);oc(a+4|0,c+8|0);oc(Gb(a),zc(c));v[c>>2]=v[c+4>>2];b=v[c+4>>2];a=v[c+8>>2];while(1){if((a|0)!=(b|0)){a=a-33|0;v[c+8>>2]=a;continue}break}a=v[c>>2];if(a){zc(c);Jb(a)}}jb=g+32|0;return}if((b|0)!=64){Nd(a,c+2112|0)}}function l$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=jb-272|0;jb=a;v[a+256>>2]=c;v[a+264>>2]=b;mw(a+208|0,d,a+224|0,a+223|0,a+222|0);d=Kb(a+192|0);b=Tc(d);v[23296]=0;R(59,d|0,b|0);b=v[23296];v[23296]=0;a:{b:{c:{if((b|0)!=1){c=Oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;t[a+7|0]=1;t[a+6|0]=69;h=t[a+222|0];i=t[a+223|0];while(1){d:{v[23296]=0;b=Q(1073,a+264|0,a+256|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}if(!b){break c}g=v[a+188>>2];b=Fb(d);if((g|0)==(b+c|0)){v[23296]=0;R(59,d|0,b<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+188>>2]=b+c}v[23296]=0;b=T(1075,v[a+264>>2])|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}if(lw(b,a+7|0,a+6|0,c,a+188|0,i,h,a+208|0,a+16|0,a+12|0,a+8|0,a+224|0)){break c}v[23296]=0;T(1077,a+264|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)|!w[a+7|0]){break e}b=v[a+12>>2];if((b-(a+16|0)|0)>159){break e}v[a+12>>2]=b+4;v[b>>2]=v[a+8>>2]}j=f,k=fG(c,v[a+188>>2],e),A[j>>3]=k;rf(a+208|0,a+16|0,v[a+12>>2],e);v[23296]=0;b=Q(1074,a+264|0,a+256|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+264>>2];yb(d);yb(a+208|0);jb=a+272|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function YH(a){var b=0,c=0,d=0,e=0;se(v[a+80>>2],v[a+20>>2]);while(1){c=v[a+28>>2];if((b|0)<v[a+24>>2]){se(v[a+80>>2],v[c+(b<<2)>>2]);b=b+1|0;continue}break}se(v[a+80>>2],c);a:{if(!v[a+396>>2]){break a}c=0;while(1){if(v[a+264>>2]<=(c|0)){break a}e=v[a+396>>2]+B(c,24)|0;d=v[e+16>>2];if(d){b=0;while(1){if((b|0)<v[(v[a+124>>2]+B(w[e+13|0],2096)|0)+4>>2]){se(v[a+80>>2],v[(b<<2)+d>>2]);b=b+1|0;d=v[e+16>>2];continue}break}se(v[a+80>>2],d)}se(v[a+80>>2],v[e+20>>2]);c=c+1|0;continue}}d=v[a+124>>2];if(d){c=0;while(1){if((c|0)<v[a+120>>2]){b=B(c,2096)+d|0;se(v[a+80>>2],v[b+8>>2]);se(v[a+80>>2],v[b+28>>2]);se(v[a+80>>2],v[b+32>>2]);se(v[a+80>>2],v[b+2084>>2]);b=v[b+2088>>2];se(v[a+80>>2],b?b-4|0:0);c=c+1|0;d=v[a+124>>2];continue}break}se(v[a+80>>2],d)}se(v[a+80>>2],v[a+260>>2]);se(v[a+80>>2],v[a+396>>2]);c=v[a+404>>2];if(c){b=0;while(1){if((b|0)<v[a+400>>2]){se(v[a+80>>2],v[(B(b,40)+c|0)+4>>2]);b=b+1|0;c=v[a+404>>2];continue}break}se(v[a+80>>2],c)}c=0;b=0;while(1){if(!(v[a+4>>2]<=(b|0)|b>>>0>15)){d=(b<<2)+a|0;se(v[a+80>>2],v[d+800>>2]);se(v[a+80>>2],v[d+928>>2]);se(v[a+80>>2],v[d+996>>2]);b=b+1|0;continue}break}while(1){if((c|0)!=2){b=(c<<2)+a|0;se(v[a+80>>2],v[b+1068>>2]);se(v[a+80>>2],v[b+1076>>2]);se(v[a+80>>2],v[b+1084>>2]);se(v[a+80>>2],v[b+1092>>2]);se(v[a+80>>2],v[b+1100>>2]);c=c+1|0;continue}break}}function FO(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;h=jb-16|0;jb=h;c=v[a>>2];a:{if(Vj(c)){i=jb-16|0;jb=i;e=xc(3848);d=e+808|0;c=e+16|0;while(1){v[c+16>>2]=0;v[c+20>>2]=0;v[c+36>>2]=0;t[c+42|0]=1;u[c+40>>1]=257;v[c+24>>2]=0;v[c+28>>2]=0;u[c+32>>1]=0;c=c+44|0;if((c|0)!=(d|0)){continue}break}c=e+3832|0;while(1){v[d>>2]=0;v[d+4>>2]=0;v[d+68>>2]=0;v[d+72>>2]=0;v[d+24>>2]=0;v[d+28>>2]=0;u[d+20>>1]=511;v[d+16>>2]=-1;u[d+14>>1]=1;u[d+6>>1]=0;u[d+8>>1]=0;u[d+10>>1]=0;u[d+12>>1]=0;t[d+73|0]=0;t[d+74|0]=0;t[d+75|0]=0;t[d+76|0]=0;t[d+77|0]=0;t[d+78|0]=0;t[d+79|0]=0;t[d+80|0]=0;d=d+84|0;if((c|0)!=(d|0)){continue}break}v[e+3832>>2]=0;v[e+3836>>2]=0;c=e+3837|0;t[c|0]=0;t[c+1|0]=0;t[c+2|0]=0;t[c+3|0]=0;t[c+4|0]=0;t[c+5|0]=0;t[c+6|0]=0;t[c+7|0]=0;while(1){if((g|0)==36){while(1){if((f|0)==18){b:{f=0;g=0;while(1)if((f|0)==18){while(1){if((g|0)==36){break b}_n((e+B(g,84)|0)+808|0);g=g+1|0;continue}}else{d=(e+B(f,44)|0)+16|0;c=v[(f<<2)+28752>>2];c:{if(!(!(1<<f&3591)|f>>>0>11)){c=e+B(c,84)|0;JO(d,c+808|0,c+1060|0,c+1312|0,c+1564|0);break c}c=e+B(c,84)|0;JO(d,c+808|0,c+1060|0,0,0)}f=f+1|0;continue}}}else{v[(e+B(f,44)|0)+32>>2]=e;f=f+1|0;continue}break}IO(e,b)}else{yd((e+B(g,84)|0)+808|0,e);g=g+1|0;continue}break}b=v[xf(i+8|0,e)>>2];jb=i+16|0;v[h+8>>2]=b;b=h+8|0;_z(a,b);jm(b);break a}IO(c,b)}EO(a);jb=h+16|0}function kba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;f=jb-16|0;jb=f;s=v[a+16>>2];u=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){k=v[a+8>>2];l=v[a+12>>2];e=v[a>>2];b=v[a+4>>2];m=0;break a}k=v[a+8>>2];l=v[a+12>>2];o=bg(k,l,n);p=mb;g=v[a+76>>2];e=v[a>>2];b=v[a+4>>2];Ff(e,b,ff(k,l,d),mb);m=g>>>0<mb>>>0?d:0}h=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[f>>2]=e;v[f+4>>2]=b;while(1){if(d){d=d-1|0;v[f+8>>2]=e;v[f+12>>2]=0;m=m-1|0;g=m;o=g?o:0;p=g?p:0;r=(((b&2147483647)<<1|e>>>31)&-2)+s|0;g=n;b:{c:while(1){d:{if((g|0)<=0){Sb(h,v[a+120>>2],v[a+124>>2]);g=v[a+116>>2];if(!g){break b}q=((v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31)&-2;e=0;b=0;break d}q=((v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31)&-2;b=0;e=0;while(1)if((b|0)==2){Ld(h,(e|0)/8<<16>>16);Kd(h,4);Sb(f+8|0,o,p);g=g-1|0;continue c}else{e=(t[(b+q|0)+r|0]<<8)+e|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){e=(t[(b+q|0)+r|0]<<8)+e|0;b=b+1|0;continue}break}Ld(h,(e|0)/8<<16>>16);Kd(h,g);v[h>>2]=v[h>>2];v[h+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;g=$f(h,u);v[c>>2]=B(j>>12,g)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(g,i>>12);Sb(f,k,l);c=c+8|0;e=v[f>>2];b=v[f+4>>2];continue}break}v[a>>2]=e;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;jb=f+16|0}function nP(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-240|0;jb=e;if(!w[93344]){if(!w[93220]){c=jb-16|0;jb=c;Kb(93196);v[23302]=0;t[93212]=0;v[23304]=0;v[23296]=0;b=ga(28)|0;a=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{if((a|0)!=1){v[c+8>>2]=b;b=c+8|0;Mt(93208,de(b));vA(b);t[93212]=0;break f}a=Da(91780,92364)|0;b=O()|0;if((ea(91780)|0)==(b|0)){_(a|0)|0;v[23296]=0;Z(29);c=v[23296];v[23296]=0;if((c|0)==1){break d}L()}if((ea(92364)|0)!=(b|0)){break c}_(a|0)|0;v[23296]=0;t[93212]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)==1){a=P()|0;O()|0;break c}if(w[93212]){break e}}v[23296]=0;Y(30,93192);b=v[23296];v[23296]=0;if((b|0)!=1){break e}a=P()|0;O()|0;break c}jb=c+16|0;break a}a=P()|0;O()|0;v[23296]=0;Z(17);c=v[23296];v[23296]=0;if((c|0)==1){break b}}jm(93216);vA(93208);yb(93196);S(a|0);L()}V(0)|0;O()|0;Ub();L()}t[93220]=1}c=jb+-64|0;jb=c;b=c+16|0;g=jb-16|0;jb=g;h=bP(g+8|0);j=e+120|0;while(1){if((i|0)==12){jb=g+16|0}else{f=jb-48|0;jb=f;a=v[h+4>>2];d=v[h>>2];g:{if((a|0)==(d|0)){break g}a=(a-d|0)+1|0;if(!a){a=PO(VO(f+8|0,32));break g}d=E(a);d=VO(f+8|0,(a<<d+1?32:31)-d|0);while(1){k=PO(d);if(a>>>0<=k>>>0){continue}break}a=v[h>>2]+k|0}jb=f+48|0;l=Db(b,i),m=a,v[l>>2]=m;i=i+1|0;continue}break}b=jP(c,b,mP(b));dP(j,b);im(b);jb=c- -64|0;qc(93224,qc(e,j,120),116);t[93344]=1}jb=e+240|0}function b4(a){a=a|0;var b=0,c=0,d=0,e=0;e=jb-160|0;jb=e;d=Vb(e,11458);v[23296]=0;b=d+12|0;Q(54,b|0,10864)|0;c=v[23296];v[23296]=0;a:{b:{if((c|0)==1){break a}v[23296]=0;b=d+24|0;Q(54,b|0,11288)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}v[23296]=0;b=d+36|0;Q(54,b|0,10856)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}v[23296]=0;b=d+48|0;Q(54,b|0,8161)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}v[23296]=0;b=d+60|0;Q(54,b|0,10841)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}v[23296]=0;b=d+72|0;Q(54,b|0,8227)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}v[23296]=0;b=d+84|0;Q(54,b|0,5581)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}v[23296]=0;b=d+96|0;Q(54,b|0,11862)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}v[23296]=0;b=d+108|0;Q(54,b|0,11231)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}v[23296]=0;b=d+120|0;Q(54,b|0,12063)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}v[23296]=0;b=d+132|0;Q(54,b|0,5433)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}v[23296]=0;b=d+144|0;Q(54,b|0,7253)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}v[23296]=0;W(966,a|0,d|0,13)|0;a=v[23296];v[23296]=0;if((a|0)==1){break b}b=d+156|0;while(1){b=yb(b-12|0);if((d|0)!=(b|0)){continue}break}jb=e+160|0;return}b=d+156|0}a=P()|0;O()|0;while(1){b=yb(b-12|0);if((d|0)!=(b|0)){continue}break}S(a|0);L()}function g$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Wi(d);i=bp(d,a+224|0);ap(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;a:{b:{c:{if((c|0)!=1){c=Oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23296]=0;g=Q(1089,a+344|0,a+336|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23296]=0;R(59,d|0,g<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+188>>2]=g+c}v[23296]=0;g=T(1091,v[a+344>>2])|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(hn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23296]=0;T(1093,a+344|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=mG(c,v[a+188>>2],e,b),v[k>>2]=l;v[f+4>>2]=mb;rf(a+208|0,a+16|0,v[a+12>>2],e);v[23296]=0;b=Q(1090,a+344|0,a+336|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function e$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Wi(d);i=bp(d,a+224|0);ap(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;a:{b:{c:{if((c|0)!=1){c=Oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23296]=0;g=Q(1089,a+344|0,a+336|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23296]=0;R(59,d|0,g<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+188>>2]=g+c}v[23296]=0;g=T(1091,v[a+344>>2])|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(hn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23296]=0;T(1093,a+344|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=iG(c,v[a+188>>2],e,b),v[k>>2]=l;v[f+4>>2]=mb;rf(a+208|0,a+16|0,v[a+12>>2],e);v[23296]=0;b=Q(1090,a+344|0,a+336|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function Vga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=jb-16|0;jb=g;h=gf(a,c);ae(g,v[a+28>>2]);i=a;a:{if(!h){c=0;if(hd(a,5)){break a}}d=jb-160|0;jb=d;e=Dl(d+56|0,v[a+28>>2]);v[23296]=0;a=Q(396,d+40|0,43811)|0;c=v[23296];v[23296]=0;b:{c:{d:{e:{if((c|0)!=1){v[23296]=0;v[d+24>>2]=19923969;v[d+28>>2]=0;U(397,e|0,a|0,d+24|0);c=v[23296];v[23296]=0;if((c|0)==1){break e}Tb(a);if(!(w[e+3|0]&64)){break d}break b}c=P()|0;O()|0;break c}c=P()|0;O()|0;Tb(a);break c}k=d,l=pf(v[b>>2],v[b+4>>2]),u[k+38>>1]=l;u[d+36>>1]=65535;v[23296]=0;a=Q(396,d+24|0,9997)|0;c=v[23296];v[23296]=0;f:{if((c|0)!=1){v[23296]=0;c=W(426,e|0,d+36|0,a|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break f}Tb(a);if((c|0)!=1){u[d+38>>1]=x[d+36>>1]}ug(d+38|0,4e3);a=x[d+38>>1];g:{if(pf(v[b>>2],v[b+4>>2])>>>0>=a>>>0){break g}v[23296]=0;R(213,b|0,a|0);c=v[23296];v[23296]=0;if((c|0)!=1){break g}c=P()|0;O()|0;break c}c=0;h:{while(1){if((a|0)==(c|0)){break b}f=v[b>>2];v[23296]=0;R(427,d+8|0,c|0);j=v[23296];v[23296]=0;if((j|0)!=1){v[23296]=0;X(428,e|0,$b(f,c)|0,d+8|0,429);f=v[23296];v[23296]=0;if((f|0)==1){break h}c=c+1|0;Tb(d+8|0);continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;Tb(d+8|0);break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;Tb(a)}_g(e);S(c|0);L()}_g(e);jb=d+160|0;c=h}$e(i,c);jb=g+16|0}function Wca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-48|0;jb=d;l=a+480190|0;c=x[l>>1];t[d+32|0]=0;iO(b,c+1|0,d+32|0);a:{j=a+480192|0;if(!x[j>>1]){break a}h=Qb(d+32|0);p=d,q=Eb(v[a+484344>>2]),v[p+24>>2]=q;o=Eb(v[a+484348>>2]);m=a+480188|0;while(1){i=v[d+24>>2];if(!Rb(i,o)){c=x[a+480190>>1];while(1)if(c){Bb(d+8|0,v[b>>2],c);if(!Cb(v[v[d+8>>2]>>2],v[d+12>>2])){e=f;f=B(c,104)+a|0;f=e+Ud(v[f+484380>>2],v[f+484400>>2])|0}c=c-1|0;continue}else{fc(h);break a}}b:{if(!Rb(v[i>>2],v[i+4>>2])){break b}c=x[m>>1];v[23296]=0;t[d+8|0]=0;U(701,h|0,c|0,d+8|0);c=v[23296];v[23296]=0;if((c|0)!=1){p=d,q=Eb(v[i>>2]),v[p+16>>2]=q;k=0;c:while(1){f=0;if(y[i+12>>2]<=k>>>0){break b}while(1){if(x[m>>1]<=f>>>0){k=k+1|0;continue c}d:{c=v[d+16>>2];if(!Uc(w[c|0])){break d}e:{f:{c=w[c+1|0];if(c){g=x[j>>1];break f}g=x[j>>1];c=w[Lb(v[h>>2],f)|0];if(c){break f}c=1;break e}p=Lb(v[h>>2],f),q=c,t[p|0]=q;g=g&65535;e=g>>>0<c>>>0;g=e?g:c;c=e?1:c}while(1){e=c&65535;if(e>>>0>(g&65535)>>>0){break d}e=v[((e<<2)+a|0)+900380>>2];g:{if(!e){break g}e=x[dc(e+236|0,w[v[d+16>>2]]-1|0)>>1];if(e>>>0>x[l>>1]){break g}n=d+8|0;Bb(n,v[b>>2],e);xg(n,1)}c=c+1|0;continue}}f=f+1|0;$z(d+16|0);continue}}}a=P()|0;O()|0;fc(h);S(a|0);L()}sM(d+24|0);continue}}jb=d+48|0;return f&65535}function yea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=jb-16|0;jb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+56;a=v[c+4>>2];v[23296]=0;R(607,a|0,b|0);a=v[23296];v[23296]=0;a:{if((a|0)!=1){v[c+4>>2]=v[c+4>>2]+56;lc(c);jb=c+16|0;break a}a=P()|0;O()|0;lc(c);S(a|0);L()}return}h=jb-32|0;jb=h;i=Gb(a);f=h+8|0;g=Rp(v[a>>2],v[a+4>>2])+1|0;d=jb-16|0;jb=d;v[d+12>>2]=g;e=jb-16|0;jb=e;v[e+12>>2]=76695844;v[e+8>>2]=2147483647;c=v[Ib(e+12|0,e+8|0)>>2];jb=e+16|0;b:{if(c>>>0>=g>>>0){e=VQ(a);if(e>>>0<c>>>1>>>0){v[d+8>>2]=e<<1;c=v[Yc(d+8|0,d+12|0)>>2]}jb=d+16|0;break b}Wc();L()}e=Rp(v[a>>2],v[a+4>>2]);If(f+12|0,i);if(c){if(c>>>0>=76695845){jg();L()}d=xc(B(c,56))}else{d=0}v[f>>2]=d;e=d+B(e,56)|0;v[f+8>>2]=e;v[f+4>>2]=e;j=zc(f),k=d+B(c,56)|0,v[j>>2]=k;c=v[f+8>>2];v[23296]=0;R(607,c|0,b|0);b=v[23296];v[23296]=0;c:{if((b|0)!=1){v[f+8>>2]=v[f+8>>2]+56;e=v[a>>2];b=v[a+4>>2];d=f+4|0;while(1){if((b|0)!=(e|0)){b=b-56|0;c=_j(v[d>>2]-56|0,b);_j(c+12|0,b+12|0);Sz(c+24|0,b+24|0);u[c+52>>1]=x[b+52>>1];g=v[b+48>>2];v[c+44>>2]=v[b+44>>2];v[c+48>>2]=g;g=v[b+40>>2];v[c+36>>2]=v[b+36>>2];v[c+40>>2]=g;v[d>>2]=v[d>>2]-56;continue}break}oc(a,d);oc(a+4|0,f+8|0);oc(Gb(a),zc(f));v[f>>2]=v[f+4>>2];UQ(f);jb=h+32|0;break c}a=P()|0;O()|0;UQ(f);S(a|0);L()}}function h$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Wi(d);i=bp(d,a+224|0);ap(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;a:{b:{c:{if((c|0)!=1){c=Oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23296]=0;g=Q(1089,a+344|0,a+336|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23296]=0;R(59,d|0,g<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+188>>2]=g+c}v[23296]=0;g=T(1091,v[a+344>>2])|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(hn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23296]=0;T(1093,a+344|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=oG(c,v[a+188>>2],e,b),v[k>>2]=l;rf(a+208|0,a+16|0,v[a+12>>2],e);v[23296]=0;b=Q(1090,a+344|0,a+336|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function f$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Wi(d);i=bp(d,a+224|0);ap(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;a:{b:{c:{if((c|0)!=1){c=Oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23296]=0;g=Q(1089,a+344|0,a+336|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23296]=0;R(59,d|0,g<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+188>>2]=g+c}v[23296]=0;g=T(1091,v[a+344>>2])|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(hn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23296]=0;T(1093,a+344|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=lG(c,v[a+188>>2],e,b),u[k>>1]=l;rf(a+208|0,a+16|0,v[a+12>>2],e);v[23296]=0;b=Q(1090,a+344|0,a+336|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function bG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;a=jb-352|0;jb=a;v[a+336>>2]=c;v[a+344>>2]=b;b=Wi(d);i=bp(d,a+224|0);ap(a+208|0,d,a+332|0);d=Kb(a+192|0);c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;a:{b:{c:{if((c|0)!=1){c=Oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;j=v[a+332>>2];while(1){d:{v[23296]=0;g=Q(1089,a+344|0,a+336|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23296]=0;R(59,d|0,g<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+188>>2]=g+c}v[23296]=0;g=T(1091,v[a+344>>2])|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(hn(g,b,c,a+188|0,a+8|0,j,a+208|0,a+16|0,a+12|0,i)){break c}v[23296]=0;T(1093,a+344|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}k=f,l=jG(c,v[a+188>>2],e,b),v[k>>2]=l;rf(a+208|0,a+16|0,v[a+12>>2],e);v[23296]=0;b=Q(1090,a+344|0,a+336|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+344>>2];yb(d);yb(a+208|0);jb=a+352|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function sF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;c=v[a+12>>2];a:{while(1){if(c>>>0>=d>>>0){f=0;break a}b:{b=x[c>>1];c:{if(b>>>0<=127){f=1;c=v[a+8>>2];if((g-c|0)<=0){break a}v[a+8>>2]=c+1;t[c|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if(b>>>0<=55295){c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}d:{e:{if(b>>>0<=56319){f=1;if((d-c|0)<4){break a}i=x[c+2>>1];if((i&64512)!=56320){break e}if((g-v[a+8>>2]|0)<4){break a}v[a+12>>2]=c+2;c=v[a+8>>2];v[a+8>>2]=c+1;f=c;c=(b>>>6&15)+1|0;t[f|0]=c>>>2|240;f=v[a+8>>2];v[a+8>>2]=f+1;t[f|0]=c<<4&48|b>>>2&15|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=i>>>6&15|b<<4&48|128;b=v[a+8>>2];v[a+8>>2]=b+1;t[b|0]=i&63|128;break c}if(b>>>0>=57344){break d}}f=2;break a}c=v[a+8>>2];if((g-c|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}c=v[a+12>>2]+2|0;v[a+12>>2]=c;continue}break}f=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return f|0}function p$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=jb-240|0;jb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Wi(d);dp(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;a:{b:{c:{if((c|0)!=1){c=Oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23296]=0;g=Q(1073,a+232|0,a+224|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23296]=0;R(59,d|0,g<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+188>>2]=g+c}v[23296]=0;g=T(1075,v[a+232>>2])|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(kn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,81808)){break c}v[23296]=0;T(1077,a+232|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=mG(c,v[a+188>>2],e,b),v[j>>2]=k;v[f+4>>2]=mb;rf(a+208|0,a+16|0,v[a+12>>2],e);v[23296]=0;b=Q(1074,a+232|0,a+224|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];yb(d);yb(a+208|0);jb=a+240|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function n$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=jb-240|0;jb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Wi(d);dp(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;a:{b:{c:{if((c|0)!=1){c=Oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23296]=0;g=Q(1073,a+232|0,a+224|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23296]=0;R(59,d|0,g<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+188>>2]=g+c}v[23296]=0;g=T(1075,v[a+232>>2])|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(kn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,81808)){break c}v[23296]=0;T(1077,a+232|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=iG(c,v[a+188>>2],e,b),v[j>>2]=k;v[f+4>>2]=mb;rf(a+208|0,a+16|0,v[a+12>>2],e);v[23296]=0;b=Q(1074,a+232|0,a+224|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];yb(d);yb(a+208|0);jb=a+240|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function RV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;g=jb-1088|0;jb=g;e=Bh(a);Xb(e+20|0,0,1040);v[e+1064>>2]=0;v[e+1068>>2]=0;v[e+1060>>2]=c;t[e+1084|0]=d;a=e+1072|0;v[a>>2]=0;v[a+4>>2]=0;v[e+1080>>2]=0;i=e+1064|0;a=c;d=0;a:{b:{c:while(1){if(Gd(x[a+34>>1])>>>0<=d>>>0){break a}v[e+1064>>2]=0;v[e+1068>>2]=0;a=0;while(1){d:{e:{f:{g:{h:{i:{j:{if(y[c>>2]<=a>>>0){break j}a=v[b+8>>2];f=v[b>>2];v[23296]=0;a=W(144,f|0,a|0,2)|0;f=v[23296];v[23296]=0;if((f|0)==1){break i}if(!a){break j}v[23296]=0;a=T(182,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break h}if(!a){break e}v[23296]=0;U(178,g|0,b|0,a|0);a=v[23296];v[23296]=0;if((a|0)==1){break g}a=fr(g+24|0,g);f=cd(e,a);qc(f+20|0,a+20|0,1040);Ab(a);Ab(g);v[e+1076>>2]=0;v[e+1080>>2]=0;h=v[e+1060>>2];a=v[h+20>>2];if(Hm(x[h+34>>1])>>>0>=2){v[23296]=0;R(183,f|0,a+(d<<1)|0);a=v[23296];v[23296]=0;if((a|0)!=1){break e}break f}v[23296]=0;R(184,f|0,a+d|0);a=v[23296];v[23296]=0;if((a|0)==1){break f}break e}d=d+1|0;a=v[e+1060>>2];continue c}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=V(30320)|0;if((O()|0)!=(ea(30320)|0)){break b}_(a|0)|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)==1){break d}}a=v[i>>2];continue}break}break}a=P()|0;O()|0}Ab(e);S(a|0);L()}jb=g+1088|0;return e|0}function tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;h=jb-16|0;jb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+32>>2];o=v[a+28>>2];p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;t=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Sia(s,t,e,e>>31);g=mb;f=Yb(f,-16777216,16776704);k=Sia(q,r,f,f>>31);e=k+e|0;f=mb+g|0;f=e>>>0<k>>>0?f+1|0:f;A=e;e=(v[h+12>>2]<<1)+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(u[e+4>>1],u[g+10>>1])+B(u[e+2>>1],u[g+8>>1])|0)+B(u[e+6>>1],u[g+12>>1])|0)+B(u[e+8>>1],u[g+14>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+2>>1])+B(u[e-6>>1],u[g>>1])|0)+B(u[e-2>>1],u[g+4>>1])|0)+B(u[e>>1],u[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;k=Sia(e,e>>31,w,x);e=A+k|0;f=mb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;j=j+o|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+n|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Sb(h+8|0,y,z);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;jb=h+16|0}function CK(a){var b=0,c=C(0),d=0,e=0,f=0,g=C(0),h=0,i=0,k=C(0),m=0,n=0,o=C(0);d=jb-16|0;jb=d;b=v[v[a+16>>2]+24620>>2];e=a+4208|0;n=a,o=me(C(10),C(C(C(z[Db(e,0)>>2]*C(120))+C(-60))/C(20))),z[n+4232>>2]=o;k=C(C(b>>>0)/C(1e3));n=a,o=me(C(10),C(C(-1)/C(k*C(C(z[Db(e,1)>>2]*C(499.989990234375))+C(.009999999776482582))))),z[n+4236>>2]=o;n=a,o=me(C(10),C(C(-1)/C(k*C(C(z[Db(e,2)>>2]*C(2950))+C(50))))),z[n+4240>>2]=o;v[d+12>>2]=1325400064;c=C(me(C(10),C(C(C(z[Db(e,3)>>2]*C(60))+C(-60))/C(20)))*C(2147483648));b=(p(c),j(2));g=C(0);a:{if((b|0)==1065353216){break a}b:{if(b-2139095040>>>0<=2164260863){f=b<<1;if(!f){b=jb-16|0;z[b+12>>2]=-1;g=C(z[b+12>>2]/C(0));break a}if((b|0)==2139095040){break b}if(!(f>>>0<4278190080&(b|0)>=0)){g=sJ(c);break a}b=(p(C(c*C(8388608))),j(2))-192937984|0}f=b-1060306944|0;h=f>>>15&240;i=+(l(2,b-(f&-8388608)|0),q())*A[h+3568>>3]+-1;m=i*i;c=C((A[479]*m+(A[480]*i+A[481]))*m+(+(f>>23)*A[478]+A[h+3576>>3]+i))}g=c}z[d+8>>2]=C(C(g*C(67108864))/C(.6931471824645996))+C(67108864);n=a,o=C(z[Ol(d+12|0,d+8|0)>>2]*C(4.656612873077393e-10)),z[n+4244>>2]=o;n=a,o=C(C(C(-1)/C(C(z[Db(e,4)>>2]*C(99))+C(1)))+C(1)),z[n+4248>>2]=o;c=C(C(C(z[Db(e,5)>>2]*C(4))*k)+C(2));c:{if(C(D(c))<C(2147483648)){h=~~c;break c}h=-2147483648}v[a+4252>>2]=h;jb=d+16|0}function me(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=C(0),k=0;f=(p(b),j(2));d=cF(f);a:{b:{c:{d:{c=(p(a),j(2));e:{if(c-2139095040>>>0>=2164260864){if(d){break e}break c}if(!d){break d}}i=C(1);if((c|0)==1065353216){break b}e=f<<1;if(!e){break b}d=e>>>0<4278190081;e=c<<1;a=C(a+b);if(!(d&e>>>0<=4278190080)){break a}if((e|0)==2130706432){break b}a=e>>>0>2130706431^(f|0)>=0?C(0):C(b*b);break a}if(cF(c)){i=C(a*a);if((c|0)<0){i=(bF(f)|0)==1?C(-i):i}if((f|0)>=0){break b}a=EH(C(C(1)/i));break a}if((c|0)<0){e=bF(f);if(!e){a=sJ(a);break a}c=c&2147483647;e=((e|0)==1)<<16}if(c>>>0>8388607){break c}c=((p(C(a*C(8388608))),j(2))&2147483647)-192937984|0}f=c-1060306944|0;d=f>>>15&240;g=+(l(2,c-(f&-8388608)|0),q())*A[d+92408>>3]+-1;h=g*g;h=((g*.288457581109214+-.36092606229713164)*(h*h)+((g*.480898481472577+-.7213474675006291)*h+(g*1.4426950408774342+(A[d+92416>>3]+ +(f>>23)))))*+b;o(+h);d=j(1)|0;j(0)|0;f:{d=d&2147450880;if((d|0)==1079967744|d>>>0<1079967744){break f}if(h>127.99999995700433){a=tD(e);break a}if(!(h<=-150)){break f}a=VC(e);break a}k=h;g=A[160];h=g+h;g=k-(h-g);k=(A[161]*g+A[162])*(g*g)+(A[163]*g+1);o(+h);j(1)|0;c=j(0)|0;f=e+c|0;f=f<<15;d=((c&31)<<3)+1024|0;e=v[d>>2];c=e;d=v[d+4>>2]+f|0;l(0,c|0);l(1,(c>>>0<c>>>0?d+1|0:d)|0);i=C(k*+n())}a=i}return a}function q$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=jb-240|0;jb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Wi(d);dp(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;a:{b:{c:{if((c|0)!=1){c=Oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23296]=0;g=Q(1073,a+232|0,a+224|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23296]=0;R(59,d|0,g<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+188>>2]=g+c}v[23296]=0;g=T(1075,v[a+232>>2])|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(kn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,81808)){break c}v[23296]=0;T(1077,a+232|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=oG(c,v[a+188>>2],e,b),v[j>>2]=k;rf(a+208|0,a+16|0,v[a+12>>2],e);v[23296]=0;b=Q(1074,a+232|0,a+224|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];yb(d);yb(a+208|0);jb=a+240|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function o$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=jb-240|0;jb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Wi(d);dp(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;a:{b:{c:{if((c|0)!=1){c=Oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23296]=0;g=Q(1073,a+232|0,a+224|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23296]=0;R(59,d|0,g<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+188>>2]=g+c}v[23296]=0;g=T(1075,v[a+232>>2])|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(kn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,81808)){break c}v[23296]=0;T(1077,a+232|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=lG(c,v[a+188>>2],e,b),u[j>>1]=k;rf(a+208|0,a+16|0,v[a+12>>2],e);v[23296]=0;b=Q(1074,a+232|0,a+224|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];yb(d);yb(a+208|0);jb=a+240|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function kG(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;a=jb-240|0;jb=a;v[a+224>>2]=c;v[a+232>>2]=b;b=Wi(d);dp(a+208|0,d,a+223|0);d=Kb(a+192|0);c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;a:{b:{c:{if((c|0)!=1){c=Oc(d,0);v[a+188>>2]=c;v[a+12>>2]=a+16;v[a+8>>2]=0;i=t[a+223|0];while(1){d:{v[23296]=0;g=Q(1073,a+232|0,a+224|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(!g){break c}h=v[a+188>>2];g=Fb(d);if((h|0)==(g+c|0)){v[23296]=0;R(59,d|0,g<<1);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Tc(d);v[23296]=0;R(59,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}c=Oc(d,0);v[a+188>>2]=g+c}v[23296]=0;g=T(1075,v[a+232>>2])|0;h=v[23296];v[23296]=0;if((h|0)==1){break d}if(kn(g,b,c,a+188|0,a+8|0,i,a+208|0,a+16|0,a+12|0,81808)){break c}v[23296]=0;T(1077,a+232|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){continue}}break}break b}break b}e:{if(!Fb(a+208|0)){break e}g=v[a+12>>2];if((g-(a+16|0)|0)>159){break e}v[a+12>>2]=g+4;v[g>>2]=v[a+8>>2]}j=f,k=jG(c,v[a+188>>2],e,b),v[j>>2]=k;rf(a+208|0,a+16|0,v[a+12>>2],e);v[23296]=0;b=Q(1074,a+232|0,a+224|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if(b){v[e>>2]=v[e>>2]|2}b=v[a+232>>2];yb(d);yb(a+208|0);jb=a+240|0;break a}}b=P()|0;O()|0;yb(d);yb(a+208|0);S(b|0);L()}return b|0}function P_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-16|0;jb=k;l=Cw(g);g=kw(g);Ng(k,g);a:{b:{if(De(k)){v[23296]=0;X(1096,l|0,a|0,c|0,d|0);g=v[23296];v[23296]=0;if((g|0)==1){break b}g=(c-a<<2)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[23296]=0;j=Q(1102,l|0,h<<24>>24)|0;h=v[23296];v[23296]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+4;v[h>>2]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[23296]=0;h=Q(1102,l|0,48)|0;i=v[23296];v[23296]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;h=t[j+1|0];v[23296]=0;h=Q(1102,l|0,h|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=h;j=j+2|0}Cl(j,c);i=0;v[23296]=0;o=T(1094,g|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Fr((j-a<<2)+d|0,v[f>>2]);g=v[f>>2];break a}e:{if(!w[Oc(k,h)|0]){break e}if(t[Oc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+4;v[i>>2]=o;h=(Fb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[23296]=0;n=Q(1102,l|0,n|0)|0;m=v[23296];v[23296]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+4;v[m>>2]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;O()|0;yb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a<<2)+d|0;yb(k);jb=k+16|0}function OH(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=C(0);d=(b<<2)+a|0;h=d+1068|0;k=c<<1&-4;p=h,q=be(a,k),v[p>>2]=q;g=d+1076|0;p=g,q=be(a,k),v[p>>2]=q;i=be(a,c&-4);v[d+1084>>2]=i;a:{h=v[h>>2];if(!h){break a}g=v[g>>2];if(!g|!i){break a}d=c>>2;o=(d|0)>0?d:0;j=C(c|0);d=0;while(1){if((e|0)==(o|0)){d=0;e=c>>3;h=(e|0)>0?e:0;e=0;while(1){if((d|0)!=(h|0)){g=e|1;f=+C(C(C(g<<1)*C(3.1415927410125732))/j);p=i+(e<<2)|0,r=C(Qe(f)),z[p>>2]=r;p=i+(g<<2)|0,r=C(-C(ti(f))),z[p>>2]=r;e=e+2|0;d=d+1|0;continue}break}}else{l=d<<2;f=+C(C(C(e<<2)*C(3.1415927410125732))/j);p=h+l|0,r=C(Qe(f)),z[p>>2]=r;m=d|1;n=m<<2;p=h+n|0,r=C(-C(ti(f))),z[p>>2]=r;f=+C(C(C(C(m|0)*C(3.1415927410125732))/j)*C(.5));p=g+l|0,r=C(C(Qe(f))*C(.5)),z[p>>2]=r;p=g+n|0,r=C(C(ti(f))*C(.5)),z[p>>2]=r;d=d+2|0;e=e+1|0;continue}break}i=(b<<2)+a|0;d=be(a,k);v[i+1092>>2]=d;if(!d){break a}b=0;e=c>>1;k=(e|0)>0?e:0;f=+(e|0);while(1){if((b|0)!=(k|0)){j=C(ti((+(b|0)+.5)/f*.5*3.1415927410125732));p=d+(b<<2)|0,r=C(ti(+C(j*j)*1.5707963705062866)),z[p>>2]=r;b=b+1|0;continue}break}b=be(a,c>>2&-2);v[i+1100>>2]=b;if(!b){break a}a=0;d=c>>3;d=(d|0)>0?d:0;c=36-Kl(c)|0;while(1){if((a|0)!=(d|0)){p=b+(a<<1)|0,q=Il(a)>>>c<<2,u[p>>1]=q;a=a+1|0;continue}break}return 1}bc(a,3);return 0}function uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0,C=0;h=jb-16|0;jb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+32>>2];o=v[a+28>>2];p=v[a+72>>2];b=v[a+68>>2];q=b;r=b>>31;b=v[a+64>>2];s=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Sia(s,w,e,e>>31);g=mb;f=Yb(f,-16777216,16776704);k=Sia(q,r,f,f>>31);e=k+e|0;f=mb+g|0;f=e>>>0<k>>>0?f+1|0:f;C=e;e=v[h+12>>2]+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(t[e+2|0],u[g+10>>1])+B(t[e+1|0],u[g+8>>1])|0)+B(t[e+3|0],u[g+12>>1])|0)+B(t[e+4|0],u[g+14>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+2>>1])+B(t[e-3|0],u[g>>1])|0)+B(t[e-1|0],u[g+4>>1])|0)+B(t[e|0],u[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;k=Sia(e,e>>31,x,y);e=C+k|0;f=mb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;j=j+o|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+n|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Sb(h+8|0,z,A);e=f-(g&p)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;jb=h+16|0}function Rg(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;v[f+12>>2]=d;e=0;a:{if(b-251>>>0<4294967046){break a}e=b-1|0;g=v[a+480180>>2];if(!om(g)){if(g&17408){a=((e&255)>>>0)/12|0;e=x[((B(a,-12)+e&255)<<1)+33248>>1]<<4>>>a|0;break a}if(!d){v[f+12>>2]=8363;d=8363}if(gj(a)){a=((e&255)>>>0)/12|0;b=Sia(v[(B(a,-12)+e<<6&960)+37136>>2]<<a,0,d,0);a=mb;c=a>>>21|0;h=f,i=Vc((a&2097151)<<11|b>>>21,c),v[h>>2]=i;yc(f,2147483647);e=v[f>>2];break a}if(w[a+480208|0]&16){a=e&255;e=x[((a>>>0)%12<<1)+33248>>1]<<5>>>(a>>>0)/12|0;break a}a=((e&255)>>>0)/12|0;yc(f+12|0,-1>>>a|0);e=Vc(Via(Sia(x[((B(a,-12)+e&255)<<1)+33248>>1],0,267616,0),mb,v[f+12>>2]<<a,0),mb);break a}if(g&20){d=e>>>0>12;if((g|0)==16){b=c<<4}else{Bb(f,a+1074312|0,76);b=Cb(v[v[f>>2]>>2],v[f+4>>2])?c&-8:c}c=d?e:12;if(w[a+480208|0]&16){a=(((b|0)/-2|0)-(c<<6)|0)+8448|0;e=(a|0)>1?a:1;break a}a=c-12|0;c=((a&255)>>>0)/12|0;d=((b|0)/16|0)+(B(c,-12)+a<<3&248)|0;v[f>>2]=d+8;he(f,0,103);a=b>>31;b=(a^b)-a&15;a=d+(a|1)|0;a=(a|0)>-8?a:-8;e=B(b,x[(((a|0)<95?a:95)<<1)+33744>>1])+B(x[(v[f>>2]<<1)+33728>>1],16-b|0)<<1>>>c|0;break a}if(!((c&255)>>>0<16&b-25>>>0<=83)){a=((e&255)>>>0)/12|0;e=x[(B((c&240)>>>4|0,12)+(B(a,-12)+e&255)<<1)+32848>>1]<<5>>>a|0;break a}e=x[(b<<1)+32622>>1]<<2}jb=f+16|0;return e}function b3(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-80|0;jb=e;a:{b:{c:{d:{f=a+36|0;d=v[f>>2];c=v[a+40>>2];e:{if(Rb(d,c)){Cc(e+72|0);break e}c=e+32|0;Cn(c,a);v[23296]=0;c=T(959,c|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break d}v[e+72>>2]=c;Wf(e+32|0);c=v[a+40>>2];d=v[a+36>>2]}c=(k=f,l=v[e+72>>2],m=Rb(d,c),m?k:l);f=v[a+8>>2];if((f|0)==-1){d=v[c+4>>2];f=d-24|0;g=v[c>>2];i=Bn(g,d);j=A[f>>3];d=0;while(1){if((d|0)==(i|0)){c=f;break c}c=bl(g,d);if(h+A[c>>3]>b){break c}d=d+1|0;h=h+j;continue}}c=bl(v[c>>2],f);break b}d=P()|0;O()|0;Wf(e+32|0);break a}b=b-h}f=x[c+12>>1];d=v[a+24>>2];v[23296]=0;R(992,d|0,f|0);f=v[23296];v[23296]=0;if((f|0)!=1){f:{f=v[a+24>>2];d=w[a+64|0];c=bM(FR(e+32|0,b),w[c+16|0],x[c+12>>1],v[c+8>>2]);v[23296]=0;g=v[c+12>>2];v[e+16>>2]=v[c+8>>2];v[e+20>>2]=g;g=v[c+20>>2];v[e+24>>2]=v[c+16>>2];v[e+28>>2]=g;g=v[c+4>>2];v[e+8>>2]=v[c>>2];v[e+12>>2]=g;X(993,e+56|0,f|0,(d?7:1)|0,e+8|0);c=v[23296];v[23296]=0;if((c|0)==1){break f}c=cM(v[e+60>>2]);f=t[c+26|0]&1;d=v[(f?c+8|0:c+12|0)>>2];f=x[(f?c+20|0:c+22|0)>>1];b=A[c>>3];vi(e+56|0);c=v[a+24>>2];u[c+1074450>>1]=f;u[c+1074448>>1]=f;v[c+1074428>>2]=d;v[c+1074392>>2]=-2;b=h+b;A[a+16>>3]=b;Ik(e+72|0);jb=e+80|0;return+b}}d=P()|0;O()|0;Ik(e+72|0)}S(d|0);L()}function xS(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=w[a|0];a:{if(d>>>0>21){break a}t[a|0]=w[d+26512|0];b:{switch(d-8|0){case 0:t[b|0]=w[b|0]<<1;break a;case 4:t[b|0]=w[b|0]+1>>>1;break a;case 5:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);break a;case 6:c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{d=w[b|0];switch((d>>>4|0)-1|0){case 11:case 12:case 13:break a;case 9:break e;case 8:break f;case 6:break g;case 5:break h;case 4:break i;case 3:break j;case 1:break k;case 0:break l;case 14:break c;case 10:break d;default:break m}}t[a|0]=0;break a}t[a|0]=29;t[c+15|0]=w[b|0]&15;t[c+14|0]=14;e=b,f=w[Wb(c+15|0,c+14|0)|0]<<4|15,t[e|0]=f;break a}t[a|0]=29;t[c+13|0]=w[b|0]&15;t[c+12|0]=14;e=b,f=w[Wb(c+13|0,c+12|0)|0]|240,t[e|0]=f;break a}t[b|0]=d&15|48;break a}t[a|0]=35;t[b|0]=w[b|0]<<4^128;break a}t[b|0]=d&15|176;break a}t[b|0]=d&15|64;break a}t[a|0]=15;t[b|0]=w[b|0]&15;break a}t[a|0]=24;t[b|0]=(w[b|0]<<3&120)+8&240;break a}t[a|0]=24;t[b|0]=(w[b|0]&15)+1>>>1;break a}t[a|0]=10;break a;case 8:a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?-16:a<<2&240;break a}if(a>>>0<=239){t[b|0]=a<<2&48|15;break a}t[b|0]=a<<4|15;break a;case 9:break b;default:break a}}a=w[b|0];if(a>>>0<=223){t[b|0]=a>>>0>63?15:a>>>2|0;break a}if(a>>>0>239){break a}t[b|0]=a>>>2&3|240}jb=c+16|0}function jM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;f=a+484376|0;while(1){a:{c=Zb(v[a+484360>>2],w[f|0]);e=b&65535;if(Nc(v[c>>2],v[c+4>>2])>>>0>e>>>0){if(!rq(c,e)){break a}c=Zb(v[a+484360>>2],w[a+484376|0])}if(Nc(v[c>>2],v[c+4>>2])>>>0>e>>>0){e=a+1074312|0;f=a+1298224|0;c=a+1074992|0;b:{while(1){c:{if((c|0)==(f|0)){iM(a);if(b&65535){break c}b=0;while(1){if((b|0)==256){Xn(a+1298264|0,1);v[a+1074456>>2]=v[a+480200>>2];v[a+1074416>>2]=v[a+480196>>2];v[a+1074420>>2]=v[a+480204>>2];v[a+480208>>2]=v[a+480208>>2]&-769;Ky(a+1074376|0);u[a+1074450>>1]=0;v[a+1074392>>2]=-2;b=a+1074428|0;v[b>>2]=0;v[b+4>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074376>>2]=0;v[a+1074380>>2]=0}else{$n((B(b,872)+a|0)+1074992|0,a,b&65535,134217728);b=b+1|0;continue}break}break b}t[c+797|0]=0;v[c+700>>2]=0;t[c+841|0]=0;t[c+805|0]=0;v[c+708>>2]=0;t[c+821|0]=0;v[c+764>>2]=0;t[c+819|0]=0;t[c+820|0]=0;Bb(d+8|0,e,23);if(Cb(v[v[d+8>>2]>>2],v[d+12>>2])){t[c+807|0]=1;t[c+808|0]=0}t[c+839|0]=0;c=c+872|0;continue}break}u[a+1074450>>1]=b;u[a+1074446>>1]=0;b=a+1074424|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074392>>2]=-2;v[a+1074432>>2]=0;b=a+1074396|0;v[b>>2]=0;v[b+4>>2]=0;v[a+1074380>>2]=0}v[a+480208>>2]=v[a+480208>>2]&-769}jb=d+16|0;return}b=b+1|0;continue}}function _Z(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=jb-496|0;jb=a;g=a+488|0;bd(g,d);v[23296]=0;m=T(1084,g|0)|0;g=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Fb(f)){g=v[ij(f,0)>>2];v[23296]=0;h=Q(1102,m|0,45)|0;k=v[23296];v[23296]=0;if((k|0)==1){break g}n=(g|0)==(h|0)}k=Kb(a+456|0);g=Kb(a+440|0);h=Kb(a+424|0);v[23296]=0;la(1123,c|0,n|0,a+488|0,a+480|0,a+476|0,a+472|0,k|0,g|0,h|0,a+420|0);c=v[23296];v[23296]=0;if((c|0)==1){break f}v[a+4>>2]=1071;c=le(a+8|0,0,a+4|0);j=Fb(f);l=v[a+420>>2];h:{if((j|0)>(l|0)){i=((Fb(h)+(j-l<<1)|0)+Fb(g)|0)+1|0;break h}i=(Fb(h)+Fb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}Oe(c,Jd(i<<2));j=v[c>>2];if(j){break e}v[23296]=0;Z(1072);b=v[23296];v[23296]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}o=v[d+4>>2];i=tc(f);f=Fb(f);v[23296]=0;oa(1124,j|0,a+4|0,a|0,o|0,i|0,i+(f<<2)|0,m|0,n|0,a+480|0,v[a+476>>2],v[a+472>>2],k|0,g|0,h|0,l|0);f=v[23296];v[23296]=0;if((f|0)!=1){v[23296]=0;b=ka(1105,b|0,j|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Qc(c)}Kc(h);Kc(g);yb(k)}_b(a+488|0);S(f|0);L()}Qc(c);Kc(h);Kc(g);yb(k);_b(a+488|0);jb=a+496|0;return b|0}function NR(a,b){var c=0;a:{b:{c:{d:{if(fe(a,16546)){break d}if(fe(a,17315)){break d}if(fe(a,13428)){break d}if(fe(a,13538)){break d}if(!fe(a,14103)){break c}}u[b+10>>1]=4;v[b>>2]=11894;break b}e:{f:{if(fe(a,17310)){break f}if(fe(a,13438)){break f}if(!fe(a,16531)){break e}}t[b+12|0]=1;v[b>>2]=8309;u[b+10>>1]=4;return 1}g:{if(!fe(a,14149)){if(!fe(a,14154)){break g}}u[b+10>>1]=8;v[b>>2]=8087;break b}h:{if(!fe(a,15140)){if(!fe(a,15145)){break h}}v[b>>2]=16918;u[b+10>>1]=t[a+2|0]-48;break b}i:{if(!fe(a,26714)){if(!fe(a,26719)){break i}}v[b+4>>2]=1;v[b>>2]=16724;u[b+10>>1]=w[a|0]==56?8:4;return 1}if(!(Pb(a,15246,3)|(w[a+3|0]-52&255)>>>0>4)){v[b>>2]=8427;a=t[a+3|0];u[b+8>>1]=1088;u[b+10>>1]=a-48;break b}j:{if(Pb(a,13466,3)){if(Pb(a,13600,3)){break j}}if((w[a+3|0]-52&255)>>>0>5){break j}t[b+15|0]=1;t[b+13|0]=1;v[b>>2]=8186;u[b+10>>1]=t[a+3|0]-48;return 1}k:{if((w[a|0]-49&255)>>>0>8){break k}if(!Pb(a+1|0,13624,3)){t[b+14|0]=1;v[b>>2]=8475;u[b+10>>1]=t[a|0]-48;return 1}if((w[a+1|0]-48&255)>>>0>9){break k}c=a+2|0;if(Pb(c,13952,2)){if(Pb(c,13628,2)){break k}}t[b+14|0]=1;v[b>>2]=8475;u[b+10>>1]=(t[a+1|0]+B(t[a|0],10)|0)-528;return 1}c=0;if(Pb(a,13294,3)|(w[a+3|0]-49&255)>>>0>8){break a}v[b>>2]=8336;u[b+10>>1]=t[a+3|0]-48}c=1}return c}function Z_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-16|0;jb=k;l=Xu(g);g=qw(g);Ng(k,g);a:{b:{if(De(k)){v[23296]=0;X(1082,l|0,a|0,c|0,d|0);g=v[23296];v[23296]=0;if((g|0)==1){break b}g=(c-a|0)+d|0;v[f>>2]=g;break a}v[f>>2]=d;c:{d:{j=a;h=w[j|0];switch(h-43|0){case 0:case 2:break d;default:break c}}v[23296]=0;j=Q(19,l|0,h<<24>>24)|0;h=v[23296];v[23296]=0;if((h|0)==1){break b}h=v[f>>2];v[f>>2]=h+1;t[h|0]=j;j=a+1|0}if(!(w[j|0]!=48|(c-j|0)<2|(w[j+1|0]|32)!=120)){v[23296]=0;h=Q(19,l|0,48)|0;i=v[23296];v[23296]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;h=t[j+1|0];v[23296]=0;h=Q(19,l|0,h|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break b}i=v[f>>2];v[f>>2]=i+1;t[i|0]=h;j=j+2|0}Cl(j,c);i=0;v[23296]=0;o=T(1080,g|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break b}h=0;g=j;while(1){if(c>>>0<=g>>>0){Cl((j-a|0)+d|0,v[f>>2]);g=v[f>>2];break a}e:{if(!w[Oc(k,h)|0]){break e}if(t[Oc(k,h)|0]!=(i|0)){break e}i=v[f>>2];v[f>>2]=i+1;t[i|0]=o;h=(Fb(k)-1>>>0>h>>>0)+h|0;i=0}n=t[g|0];v[23296]=0;n=Q(19,l|0,n|0)|0;m=v[23296];v[23296]=0;if((m|0)!=1){m=v[f>>2];v[f>>2]=m+1;t[m|0]=n;g=g+1|0;i=i+1|0;continue}break}}a=P()|0;O()|0;yb(k);S(a|0);L()}v[e>>2]=(b|0)==(c|0)?g:(b-a|0)+d|0;yb(k);jb=k+16|0}function EG(a,b){var c=0,d=0,e=0,f=0,g=0;a:{b:{c:{d:{e:{f:{g:{c=v[a+4>>2];h:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break h}c=od(a)}switch(c-43|0){case 0:case 2:break g;default:break f}}f=(c|0)==45;g=!b;c=v[a+4>>2];i:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break i}c=od(a)}b=c-58|0;if(g|b>>>0>4294967285){break e}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){break d}break a}b=c-58|0}if(b>>>0<4294967286){break c}b=c-48|0;if(b>>>0<10){while(1){e=(B(e,10)+c|0)-48|0;d=(e|0)<214748364;c=v[a+4>>2];j:{if((c|0)!=v[a+104>>2]){v[a+4>>2]=c+1;c=w[c|0];break j}c=od(a)}b=c-48|0;if(d&b>>>0<=9){continue}break}d=e>>31}k:{if(b>>>0>=10){break k}while(1){b=Sia(e,d,10,0);c=b+c|0;d=mb;d=b>>>0>c>>>0?d+1|0:d;b=c;e=b-48|0;d=d-(b>>>0<48)|0;b=v[a+4>>2];l:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;c=w[b|0];break l}c=od(a)}b=c-48|0;if(b>>>0>9){break k}if(e>>>0<2061584302&(d|0)<=21474836|(d|0)<21474836){continue}break}}if(b>>>0<10){while(1){b=v[a+4>>2];m:{if((b|0)!=v[a+104>>2]){v[a+4>>2]=b+1;b=w[b|0];break m}b=od(a)}if(b-48>>>0<10){continue}break}}b=v[a+116>>2];if((b|0)>0|(b|0)>=0){v[a+4>>2]=v[a+4>>2]-1}mb=f?0-(((e|0)!=0)+d|0)|0:d;return f?0-e|0:e}v[a+4>>2]=v[a+4>>2]-1;break b}if(v[a+116>>2]<0){break a}}v[a+4>>2]=v[a+4>>2]-1}mb=-2147483648;return 0}function c_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=jb-192|0;jb=a;g=a+184|0;bd(g,d);v[23296]=0;m=T(18,g|0)|0;g=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{if((g|0)!=1){if(Fb(f)){g=w[Yf(f,0)|0];v[23296]=0;h=Q(19,m|0,45)|0;k=v[23296];v[23296]=0;if((k|0)==1){break g}n=(g|0)==(h&255)}k=Kb(a+160|0);g=Kb(a+144|0);h=Kb(a+128|0);v[23296]=0;la(1121,c|0,n|0,a+184|0,a+176|0,a+175|0,a+174|0,k|0,g|0,h|0,a+124|0);c=v[23296];v[23296]=0;if((c|0)==1){break f}v[a+4>>2]=1071;c=le(a+8|0,0,a+4|0);j=Fb(f);l=v[a+124>>2];h:{if((j|0)>(l|0)){i=((Fb(h)+(j-l<<1)|0)+Fb(g)|0)+1|0;break h}i=(Fb(h)+Fb(g)|0)+2|0}j=a+16|0;i=i+l|0;if(i>>>0<101){break e}Oe(c,Jd(i));j=v[c>>2];if(j){break e}v[23296]=0;Z(1072);b=v[23296];v[23296]=0;if((b|0)==1){break d}L()}f=P()|0;O()|0;break b}f=P()|0;O()|0;break b}f=P()|0;O()|0;break c}o=v[d+4>>2];i=Jc(f);f=Fb(f);v[23296]=0;oa(1122,j|0,a+4|0,a|0,o|0,i|0,f+i|0,m|0,n|0,a+176|0,t[a+175|0],t[a+174|0],k|0,g|0,h|0,l|0);f=v[23296];v[23296]=0;if((f|0)!=1){v[23296]=0;b=ka(14,b|0,j|0,v[a+4>>2],v[a>>2],d|0,e|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break a}}}f=P()|0;O()|0;Qc(c)}yb(h);yb(g);yb(k)}_b(a+184|0);S(f|0);L()}Qc(c);yb(h);yb(g);yb(k);_b(a+184|0);jb=a+192|0;return b|0}function Qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){h=v[f+8>>2];o=((((v[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+l|0;e=(h>>>16&65520)+b|0;p=u[e+14>>1];q=u[e+12>>1];r=u[e+10>>1];s=u[e+8>>1];t=u[e+6>>1];w=u[e+4>>1];x=u[e+2>>1];y=u[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+o|0;v[(h<<2)+f>>2]=(((((((B(u[e-8>>1],x)+B(u[e-12>>1],y)|0)+B(u[e-4>>1],w)|0)+B(u[e>>1],t)|0)+B(u[e+4>>1],s)|0)+B(u[e+8>>1],r)|0)+B(u[e+12>>1],q)|0)+B(u[e+16>>1],p)|0)/32768;h=h+1|0;continue}break}k=k+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],j>>12);Sb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;jb=f+16|0}function Daa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;l=jb-16|0;jb=l;k=jb-32|0;jb=k;h=k+28|0;f=k+24|0;g=jb-16|0;jb=g;a:{b:{if(!uc(b,v[hc(g+8|0,Jf(a))>>2])){e=x[c>>1];i=v[c+4>>2];j=vd(b);m=x[j>>1];j=v[j+4>>2];if(!Vk(e,i,m,j)){break b}}v[g+8>>2]=b;e=hc(g,Eb(v[a>>2]));c:{f=v[g+8>>2];if(!uc(f,v[e>>2])){f=v[cz(g+8|0)>>2];e=vd(f);j=x[e>>1];m=v[e+4>>2];e=x[c>>1];i=v[c+4>>2];if(!Vk(j,m,e,i)){break c}}if(!v[b>>2]){v[h>>2]=b;break a}v[h>>2]=f;b=f+4|0;break a}b=bz(a,h,e,i);break a}if(Vk(m,j,e,i)){d:{f=az(b);if(!uc(f,v[hc(g+8|0,Jf(a))>>2])){e=x[c>>1];i=v[c+4>>2];j=vd(f);if(!Vk(e,i,x[j>>1],v[j+4>>2])){break d}}if(!v[b+4>>2]){v[h>>2]=b;b=b+4|0;break a}v[h>>2]=f;b=f;break a}b=bz(a,h,e,i);break a}v[h>>2]=b;v[f>>2]=b;b=f}jb=g+16|0;f=b;b=v[b>>2];if(!b){b=jb-16|0;jb=b;g=kc(a);h=k+8|0;e=th(h,xc(36),uh(b+8|0,g));g=v[e>>2]+16|0;i=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=i;_j(g+8|0,d);o=kc(e),p=1,t[o+4|0]=p;jb=b+16|0;Zg(a,v[k+28>>2],f,v[k+8>>2]);b=de(h);cO(h);n=1}Yg(l,v[hc(k+8|0,b)>>2],n);jb=k+32|0;if(!w[kc(l)|0]){a=vd(v[l>>2])+8|0;bO(a);v[a>>2]=v[d>>2];v[a+4>>2]=v[d+4>>2];b=Gb(d);o=Gb(a),p=v[b>>2],v[o>>2]=p;v[b>>2]=0;v[d>>2]=0;v[d+4>>2]=0}a=v[hc(l+8|0,v[l>>2])>>2];jb=l+16|0;return a|0}function Qia(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{e=b;if(e){if(!c){break j}f=d;if(!f){break i}e=E(f)-E(e)|0;if(e>>>0<=31){break h}break b}if((d|0)==1|d>>>0>1){break b}b=(a>>>0)/(c>>>0)|0;kb=a-B(b,c)|0;lb=0;mb=0;return b}f=d;if(!a){break g}if(!f){break f}g=f-1|0;if(g&f){break f}kb=a;lb=e&g;a=e>>>Ria(f)|0;mb=0;return a}f=c-1|0;if(!(f&c)){break e}h=(E(c)+33|0)-E(e)|0;g=0-h|0;break c}h=e+1|0;g=63-e|0;break c}kb=0;a=(e>>>0)/(f>>>0)|0;lb=e-B(a,f)|0;mb=0;return a}e=E(f)-E(e)|0;if(e>>>0<31){break d}break b}kb=a&f;lb=0;if((c|0)==1){break a}d=a;c=Ria(c);a=c&31;if((c&63)>>>0>=32){e=0;a=b>>>a|0}else{e=b>>>a|0;a=((1<<a)-1&b)<<32-a|d>>>a}mb=e;return a}h=e+1|0;g=63-e|0}i=a;e=h&63;f=e&31;if((e&63)>>>0>=32){e=0;k=b>>>f|0}else{e=b>>>f|0;k=((1<<f)-1&b)<<32-f|i>>>f}f=e;e=g&63;a=e&31;if((e&63)>>>0>=32){e=i<<a;a=0}else{e=(1<<a)-1&i>>>32-a|b<<a;a=i<<a}b=e;if(h){e=d-1|0;g=c-1|0;e=(g|0)!=-1?e+1|0:e;i=e;while(1){j=k;e=f<<1|j>>>31;f=j<<1;j=e;f=b>>>31|f;e=i-((f>>>0>g>>>0)+e|0)>>31;l=e;m=c&e;k=f-m|0;f=j-((d&e)+(f>>>0<m>>>0)|0)|0;e=b<<1|a>>>31;a=n|a<<1;b=e|o;j=0;l=l&1;n=l;h=h-1|0;if(h){continue}break}}kb=k;lb=f;e=b<<1|a>>>31;a=l|a<<1;mb=e|j;return a}kb=a;lb=b;a=0;b=0}mb=b;return a}function L_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=jb-384|0;jb=f;v[f+376>>2]=37;v[f+380>>2]=0;h=Ar(f+376|1,21473,v[c+4>>2]);v[f+332>>2]=f+336;a=Bd();a:{if(h){b=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=b;g=Lg(f+336|0,30,a,f+376|0,f+32|0);break a}A[f+48>>3]=e;g=Lg(f+336|0,30,a,f+376|0,f+48|0)}v[f+80>>2]=1071;i=le(f+320|0,0,f+80|0);b=f+336|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Bd();f:{if(h){g=v[c+8>>2];A[f+8>>3]=e;v[f>>2]=g;g=Si(f+332|0,a,f+376|0,f);break f}A[f+16>>3]=e;g=Si(f+332|0,a,f+376|0,f+16|0)}if((g|0)==-1){v[23296]=0;Z(1072);a=v[23296];v[23296]=0;if((a|0)==1){break d}break e}a=v[f+332>>2];Oe(i,a)}j=a+g|0;l=Ti(a,j,c);v[f+68>>2]=1071;h=le(f+72|0,0,f+68|0);g:{h:{if((f+336|0)==(a|0)){g=f+80|0;break h}g=Jd(g<<3);if(!g){v[23296]=0;Z(1072);a=v[23296];v[23296]=0;if((a|0)!=1){break e}a=P()|0;O()|0;break g}Oe(h,g);b=a}a=f+56|0;bd(a,c);v[23296]=0;ia(1104,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=v[23296];v[23296]=0;i:{if((a|0)!=1){_b(f+56|0);v[23296]=0;a=ka(1105,k|0,g|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break i}Qc(h);Qc(i);jb=f+384|0;break b}a=P()|0;O()|0;_b(f+56|0);break g}a=P()|0;O()|0}Qc(h);break c}L()}a=P()|0;O()|0}Qc(i);S(a|0);L()}return a|0}function oba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0;e=jb-16|0;jb=e;q=v[a+16>>2];r=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){j=v[a+8>>2];k=v[a+12>>2];f=v[a>>2];g=v[a+4>>2];i=0;break a}j=v[a+8>>2];k=v[a+12>>2];m=bg(j,k,l);n=mb;b=v[a+76>>2];f=v[a>>2];g=v[a+4>>2];Ff(f,g,ff(j,k,d),mb);i=b>>>0<mb>>>0?d:0}h=a+112|0;s=v[a+24>>2];u=v[a+20>>2];v[e>>2]=f;v[e+4>>2]=g;while(1){if(d){b=v[e+4>>2];f=v[e>>2];v[e+8>>2]=f;v[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;p=(((b&2147483647)<<1|f>>>31)&-2)+q|0;f=l;b:{c:while(1){d:{if((f|0)<=0){Sb(h,v[a+120>>2],v[a+124>>2]);f=v[a+116>>2];if(!f){break b}o=((v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31)&-2;g=0;b=0;break d}o=((v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31)&-2;b=0;g=0;while(1)if((b|0)==2){Ld(h,(g|0)/8<<16>>16);Kd(h,4);Sb(e+8|0,m,n);f=f-1|0;continue c}else{g=(t[(b+o|0)+p|0]<<8)+g|0;b=b+1|0;continue}}break}while(1){if((b|0)!=2){g=(t[(b+o|0)+p|0]<<8)+g|0;b=b+1|0;continue}break}Ld(h,(g|0)/8<<16>>16);Kd(h,f);v[h>>2]=v[h>>2];v[h+4>>2]=0}f=v[c>>2];b=$f(h,r);v[c>>2]=f+B(b,u);v[c+4>>2]=v[c+4>>2]+B(b,s);Sb(e,j,k);c=c+8|0;continue}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;jb=e+16|0}function V_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0;k=b;f=jb-208|0;jb=f;v[f+200>>2]=37;v[f+204>>2]=0;h=Ar(f+200|1,21473,v[c+4>>2]);v[f+156>>2]=f+160;a=Bd();a:{if(h){b=v[c+8>>2];A[f+40>>3]=e;v[f+32>>2]=b;g=Lg(f+160|0,30,a,f+200|0,f+32|0);break a}A[f+48>>3]=e;g=Lg(f+160|0,30,a,f+200|0,f+48|0)}v[f+80>>2]=1071;i=le(f+144|0,0,f+80|0);b=f+160|0;a=b;b:{c:{d:{e:{if((g|0)>=30){a=Bd();f:{if(h){g=v[c+8>>2];A[f+8>>3]=e;v[f>>2]=g;g=Si(f+156|0,a,f+200|0,f);break f}A[f+16>>3]=e;g=Si(f+156|0,a,f+200|0,f+16|0)}if((g|0)==-1){v[23296]=0;Z(1072);a=v[23296];v[23296]=0;if((a|0)==1){break d}break e}a=v[f+156>>2];Oe(i,a)}j=a+g|0;l=Ti(a,j,c);v[f+68>>2]=1071;h=le(f+72|0,0,f+68|0);g:{h:{if((f+160|0)==(a|0)){g=f+80|0;break h}g=Jd(g<<1);if(!g){v[23296]=0;Z(1072);a=v[23296];v[23296]=0;if((a|0)!=1){break e}a=P()|0;O()|0;break g}Oe(h,g);b=a}a=f+56|0;bd(a,c);v[23296]=0;ia(1099,b|0,l|0,j|0,g|0,f+68|0,f- -64|0,a|0);a=v[23296];v[23296]=0;i:{if((a|0)!=1){_b(f+56|0);v[23296]=0;a=ka(14,k|0,g|0,v[f+68>>2],v[f+64>>2],c|0,d|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break i}Qc(h);Qc(i);jb=f+208|0;break b}a=P()|0;O()|0;_b(f+56|0);break g}a=P()|0;O()|0}Qc(h);break c}L()}a=P()|0;O()|0}Qc(i);S(a|0);L()}return a|0}function cJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c=jb+-64|0;jb=c;d=v[a>>2];a=v[d>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];g=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=g;tf(c+48|0,c+32|0,f);a=v[d+4>>2];f=v[a+8>>2];g=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a=jb-32|0;jb=a;a:{b:{c:{d:{k=v[c+4>>2];if(k>>>0>=g>>>0){if(y[c+20>>2]<g>>>0){break d}if(f>>>0>y[c+8>>2]){break c}l=v[c+28>>2];if(Xe(v[c+24>>2],l)>>>0<f>>>0){break b}m=b+12|0;n=v[c+16>>2];o=v[c>>2];e:while(1){d=0;if((f|0)==(h|0)){break a}while(1)if((d|0)==(g|0)){h=h+1|0;continue e}else{j=Pg(o,k,d,h);e=Db(v[b>>2],d);i=ge(cg(A[j>>3])*134217728);j=e;e=(v[e>>2]>>1)+am(i)|0;p=e;e=js(m)+e&-4096;v[j>>2]=p-e;A[a+24>>3]=+(e|0)*7.450580596923828e-9;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;i=ge(A[zg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(i)<2147483648){e=~~i;break f}e=-2147483648}e=Xc(e);q=xn(n,l,d,h),r=e,u[q>>1]=r;d=d+1|0;continue}}}aa(7150,8947,77,8627);L()}aa(7115,8947,78,8627);L()}aa(5858,8947,79,8627);L()}aa(5828,8947,80,8627);L()}jb=a+32|0;jb=c- -64|0}function NX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;if(Jg(a,v[b+8>>2],e)){bw(b,c,d);return}a:{if(Jg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;if(v[b+44>>2]!=4){f=a+16|0;h=f+(v[a+12>>2]<<3)|0;d=0;b:{c:{while(1){d:{if(f>>>0>=h>>>0){break d}u[b+52>>1]=0;Zv(v[f>>2],v[f+4>>2],b,c,c,1,e);if(w[b+54|0]){break d}e:{if(!w[b+53|0]){break e}if(w[b+52|0]){d=1;if(v[b+24>>2]==1){break c}g=1;if(w[a+8|0]&2){break e}break c}g=1;if(!(t[a+8|0]&1)){break c}}f=f+8|0;continue}break}a=4;if(!g){break b}}a=3}v[b+44>>2]=a;if(d&1){break a}}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}g=v[a+12>>2];h=a+16|0;ur(v[h>>2],v[a+20>>2],b,c,d,e);f=a+24|0;g=h+(g<<3)|0;if(f>>>0>=g>>>0){break a}a=v[a+8>>2];if(!(!(a&2)&v[b+36>>2]!=1)){while(1){if(w[b+54|0]){break a}ur(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}break a}if(!(a&1)){while(1){if(w[b+54|0]|v[b+36>>2]==1){break a}ur(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break a}}while(1){if(w[b+54|0]|v[b+36>>2]==1&v[b+24>>2]==1){break a}ur(v[f>>2],v[f+4>>2],b,c,d,e);f=f+8|0;if(g>>>0>f>>>0){continue}break}}}function jba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=jb-16|0;jb=f;q=v[a+16>>2];r=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);n=v[a+128>>2];a:{if(!n){l=v[a+8>>2];m=v[a+12>>2];e=v[a>>2];b=v[a+4>>2];h=0;break a}l=v[a+8>>2];m=v[a+12>>2];o=bg(l,m,n);p=mb;h=v[a+76>>2];e=v[a>>2];b=v[a+4>>2];Ff(e,b,ff(l,m,d),mb);h=h>>>0<mb>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[f>>2]=e;v[f+4>>2]=b;b:while(1){if(d){d=d-1|0;v[f+8>>2]=e;v[f+12>>2]=0;h=h-1|0;o=h?o:0;p=h?p:0;e=((((b&2147483647)<<1|e>>>31)&2147483646)<<1)+q|0;b=n;while(1)if((b|0)<=0){Sb(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){k=(v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31;Ld(g,(u[(k<<1|2)+e>>1]+u[e+((k&2147483646)<<1)>>1]|0)/8<<16>>16);Kd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;e=$f(g,r);v[c>>2]=B(j>>12,e)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(e,i>>12);Sb(f,l,m);c=c+8|0;e=v[f>>2];b=v[f+4>>2];continue b}else{k=(v[f+12>>2]&2147483647)<<1|v[f+8>>2]>>>31;Ld(g,(u[(k<<1|2)+e>>1]+u[e+((k&2147483646)<<1)>>1]|0)/8<<16>>16);Kd(g,4);Sb(f+8|0,o,p);b=b-1|0;continue}}break}v[a>>2]=e;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;jb=f+16|0}function XI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c=jb+-64|0;jb=c;d=v[a>>2];a=v[d>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];g=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=g;tf(c+48|0,c+32|0,f);a=v[d+4>>2];g=v[a+8>>2];j=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;f=c+16|0;a=jb-32|0;jb=a;a:{b:{c:{d:{l=v[c+4>>2];if(l>>>0>=j>>>0){if(y[f+4>>2]<j>>>0){break d}if(y[c+8>>2]<g>>>0){break c}if(Xe(v[f+8>>2],v[f+12>>2])>>>0<g>>>0){break b}m=b+12|0;n=v[c>>2];e:while(1){d=0;if((g|0)==(h|0)){break a}while(1)if((d|0)==(j|0)){h=h+1|0;continue e}else{k=Pg(n,l,d,h);e=Db(v[b>>2],d);i=ge(cg(A[k>>3])*134217728);k=e;e=(v[e>>2]>>1)+am(i)|0;o=e;e=js(m)+e&-4096;v[k>>2]=o-e;A[a+24>>3]=+(e|0)*7.450580596923828e-9;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;i=ge(A[zg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(i)<2147483648){e=~~i;break f}e=-2147483648}e=Xc(e);p=wn(f,d,h),q=e,u[p>>1]=q;d=d+1|0;continue}}}aa(7150,8947,77,8627);L()}aa(7115,8947,78,8627);L()}aa(5858,8947,79,8627);L()}aa(5828,8947,80,8627);L()}jb=a+32|0;jb=c- -64|0}function Rba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){h=v[f+8>>2];o=(((v[f+12>>2]&2147483647)<<1|h>>>31)&-2)+l|0;e=(h>>>16&65520)+b|0;p=u[e+14>>1];q=u[e+12>>1];r=u[e+10>>1];s=u[e+8>>1];w=u[e+6>>1];x=u[e+4>>1];y=u[e+2>>1];z=u[e>>1];h=0;while(1){if((h|0)!=2){e=h+o|0;v[(h<<2)+f>>2]=(((((((B(t[e-4|0],y)+B(t[e-6|0],z)|0)+B(t[e-2|0],x)|0)+B(t[e|0],w)|0)+B(t[e+2|0],s)|0)+B(t[e+4|0],r)|0)+B(t[e+6|0],q)|0)+B(t[e+8|0],p)<<8)/32768;h=h+1|0;continue}break}k=k+n|0;v[c>>2]=v[c>>2]+B(v[f>>2],k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],j>>12);Sb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;jb=f+16|0}function Wha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=jb-288|0;jb=f;Nf(b);a:{if(!Ob(v[a>>2],v[a+8>>2],1)){break a}while(1){d=f+32|0;jn(f+8|0,d,hq(d));k=v[a>>2];g=v[a+8>>2];d=jb-32|0;jb=d;Og(d+16|0,v[f+8>>2],v[f+12>>2]);e=v[v[k>>2]+28>>2];l=v[d+20>>2];v[d+8>>2]=v[d+16>>2];v[d+12>>2]=l;nb[e|0](d+24|0,k,g,d+8|0);Og(f+16|0,v[d+24>>2],v[d+28>>2]);jb=d+32|0;v[f+28>>2]=v[f+20>>2];o=f,p=c-Fb(b)|0,v[o+4>>2]=p;d=v[Ib(f+28|0,f+4|0)>>2];if(!d){break a}t[f+16|0]=0;k=f+32|0;m=k+d|0;d=f+16|0;l=mi(k,m,d);o=f,p=oh(b),v[o+16>>2]=p;e=v[Gf(f,d)>>2];g=jb-32|0;jb=g;v[g+24>>2]=e;o=g,p=Zd(b),v[o+8>>2]=p;h=dk(g+24|0,g+8|0);b:{c:{d=k;i=pi(d,l);if(!i){break c}if(!Is(b,d)){e=Fb(b);j=Tc(b);d:{if(i>>>0<=j-e>>>0){j=tc(b);if((e|0)==(h|0)){break d}n=h+j|0;rj(i+n|0,n,e-h|0);break d}Ql(b,j,(e+i|0)-j|0,e,h,0,i);j=v[b>>2]}e=e+i|0;Mh(b,e);t[g+8|0]=0;sd(e+j|0,g+8|0);e=h+j|0;while(1){if((d|0)==(l|0)){break c}sd(e,d);d=d+1|0;e=e+1|0;continue}}d=Zf(g+8|0,d,l);h=Jc(d);i=Fb(d);v[23296]=0;fa(342,b|0,e|0,h|0,h+i|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){yb(d);break b}a=P()|0;O()|0;yb(d);S(a|0);L()}Zd(b)}jb=g+32|0;ac(a,l-k|0);if(l>>>0>=m>>>0){continue}break}ac(a,1)}jb=f+288|0}function uF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;a:{b:{while(1){j=v[a+12>>2];if(!(j>>>0>=d>>>0|f>>>0>=g>>>0)){i=t[j|0];c=i&255;c:{if((i|0)>=0){i=1;break c}b=2;if(i>>>0<4294967234){break a}if(i>>>0<=4294967263){if((d-j|0)<2){break b}i=w[j+1|0];if((i&192)!=128){break a}c=i&63|c<<6&1984;i=2;break c}if(i>>>0<=4294967279){if((d-j|0)<3){break b}k=w[j+2|0];i=w[j+1|0];d:{e:{if((c|0)!=237){if((c|0)!=224){break e}if((i&224)==160){break d}break a}if((i&224)==128){break d}break a}if((i&192)!=128){break a}}if((k&192)!=128){break a}c=k&63|(c<<12&61440|(i&63)<<6);i=3;break c}if(i>>>0>4294967284){break a}if((d-j|0)<4){break b}l=w[j+3|0];m=w[j+2|0];k=w[j+1|0];f:{g:{switch(c-240|0){case 0:if((k+112&255)>>>0<48){break f}break a;case 4:if((k&240)==128){break f}break a;default:break g}}if((k&192)!=128){break a}}if((m&192)!=128|(l&192)!=128){break a}i=4;c=l&63|(m<<6&4032|(c<<18&1835008|(k&63)<<12));if(c>>>0>1114111){break a}}v[f>>2]=c;v[a+12>>2]=i+j;f=v[a+8>>2]+4|0;v[a+8>>2]=f;continue}break}b=d>>>0>j>>>0;break a}b=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return b|0}function y6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=C(0),q=C(0),r=0,s=0,t=0,u=C(0),w=0;i=jb-16|0;jb=i;a:{if(!Vh(a+44|0)){break a}n=v[a+44>>2];j=Fc(n,0);k=Fc(n,1);n=v[a+56>>2];t=Fc(n,0);n=Fc(n,1);u=z[Db(a+4208|0,1)>>2];v[i+12>>2]=d;s=v[a+4220>>2];q=C(C(1)/C(s>>>0));w=v[a+4216>>2];o=d;f=n;g=t;while(1){if(!o){ji(a,b,c,t,n,d);break a}h=v[a+4224>>2];b:{if(s>>>0>h>>>0){v[i+8>>2]=s-h;r=v[Ib(i+12|0,i+8|0)>>2];m=0;c:{if(u<C(1)){l=h+r|0;e=h>>>0>l>>>0?h:l;while(1){if((h|0)==(e|0)){break c}p=C(h>>>0);z[g>>2]=q*C(z[j>>2]*p);z[f>>2]=q*C(z[k>>2]*p);h=h+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((m|0)!=(r|0)){z[g>>2]=z[j>>2];z[f>>2]=z[k>>2];m=m+1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}break}l=h+r|0}o=o-r|0;v[i+12>>2]=o;break b}m=w-h|0;v[i+4>>2]=m;l=v[Ib(i+12|0,i+4|0)>>2];e=0;d:{if(u<C(1)){e=m-l|0;while(1){if(e>>>0>=m>>>0){break d}p=C(m>>>0);z[g>>2]=q*C(z[j>>2]*p);z[f>>2]=q*C(z[k>>2]*p);m=m-1|0;f=f+4|0;k=k+4|0;g=g+4|0;j=j+4|0;continue}}while(1){if((e|0)!=(l|0)){v[g>>2]=0;v[f>>2]=0;e=e+1|0;f=f+4|0;g=g+4|0;continue}break}e=l<<2;k=e+k|0;j=j+e|0}o=o-l|0;v[i+12>>2]=o;e=h+l|0;l=e>>>0<w>>>0?e:0}v[a+4224>>2]=l;continue}}jb=i+16|0}function X9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=jb-16|0;jb=l;v[l+8>>2]=b;q=yf(a);while(1){if(Ag(b,c)){b=v[hc(l,q)>>2];k=vd(v[l+8>>2]);o=jb-16|0;jb=o;p=0;m=jb-16|0;jb=m;i=jb-32|0;jb=i;g=i+28|0;d=i+24|0;e=jb-16|0;jb=e;a:{b:{if(!uc(b,v[hc(e+8|0,Jf(a))>>2])){f=w[k|0];j=v[k+4>>2];h=vd(b);n=w[h|0];h=v[h+4>>2];if(!Ln(f,j,n,h)){break b}}v[e+8>>2]=b;f=hc(e,Eb(v[a>>2]));c:{d=v[e+8>>2];if(!uc(d,v[f>>2])){d=v[cz(e+8|0)>>2];f=vd(d);h=w[f|0];n=v[f+4>>2];f=w[k|0];j=v[k+4>>2];if(!Ln(h,n,f,j)){break c}}if(!v[b>>2]){v[g>>2]=b;break a}v[g>>2]=d;b=d+4|0;break a}b=Dy(a,g,f,j);break a}if(Ln(n,h,f,j)){d:{d=az(b);if(!uc(d,v[hc(e+8|0,Jf(a))>>2])){f=w[k|0];j=v[k+4>>2];h=vd(d);if(!Ln(f,j,w[h|0],v[h+4>>2])){break d}}if(!v[b+4>>2]){v[g>>2]=b;b=b+4|0;break a}v[g>>2]=d;b=d;break a}b=Dy(a,g,f,j);break a}v[g>>2]=b;v[d>>2]=b;b=d}jb=e+16|0;d=b;b=v[b>>2];if(!b){b=jb-16|0;jb=b;e=kc(a);g=i+8|0;e=th(g,xc(28),uh(b+8|0,e));Nz(v[e>>2]+16|0,k);r=kc(e),s=1,t[r+4|0]=s;jb=b+16|0;Zg(a,v[i+28>>2],d,v[i+8>>2]);b=de(g);cl(g);p=1}Yg(m+8|0,v[hc(i+8|0,b)>>2],p);jb=i+32|0;jb=m+16|0;hc(o+8|0,v[m+8>>2]);jb=o+16|0;b=v[Xg(l+8|0)>>2];continue}else{jb=l+16|0}break}}function Mfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;pd(b,0);Bo(b);f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);a:{if(c&34){if(d){v[b+24>>2]=f;break a}g=b,h=Ie(Lj(+(f+1408|0)/1536)*8363),v[g+24>>2]=h;break a}t[b+37|0]=(c|0)==16?f:f^128;t[b+36|0]=w[a+4|0]}t[e+15|0]=w[a+5|0];t[e+14|0]=64;g=b,h=w[Wb(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;d=w[a+6|0]|w[a+7|0]<<8;if(d>>>0<=256){u[b+28>>1]=d;u[b+34>>1]=x[b+34>>1]|32}v[b>>2]=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);v[b+4>>2]=w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24);v[b+8>>2]=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);d=w[a+20|0]|w[a+21|0]<<8;if(d&16){u[b+34>>1]=x[b+34>>1]|2;d=w[a+20|0]|w[a+21|0]<<8}if(d&32){u[b+34>>1]=x[b+34>>1]|4;d=w[a+20|0]|w[a+21|0]<<8}if(d&256){u[b+34>>1]=x[b+34>>1]|8;d=w[a+20|0]|w[a+21|0]<<8}if(d&512){u[b+34>>1]=x[b+34>>1]|16}t[b+38|0]=w[(w[a+22|0]&7)+39696|0];t[b+39|0]=w[a+23|0];t[b+40|0]=w[a+24|0];t[b+41|0]=w[a+25|0];if((c|0)==32){t[e+13|0]=w[a+26|0];t[e+12|0]=64;g=b,h=w[Wb(e+13|0,e+12|0)|0],u[g+32>>1]=h}v[b+12>>2]=w[a+27|0]|w[a+28|0]<<8|(w[a+29|0]<<16|w[a+30|0]<<24);v[b+16>>2]=w[a+31|0]|w[a+32|0]<<8|(w[a+33|0]<<16|w[a+34|0]<<24);jb=e+16|0}function _P(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=v[a>>2];e=rh(c,v[a+4>>2]);if(e>>>0<b>>>0){g=jb-32|0;jb=g;f=b-e|0;b=v[Gb(a)>>2];c=v[a+4>>2];a:{if(f>>>0<=b-c>>8>>>0){b=jb-16|0;jb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(f<<8);a=v[b+4>>2];e=v[b+8>>2];while(1){if((a|0)==(e|0)){lc(b);jb=b+16|0}else{Ez(a);a=a+256|0;v[b+4>>2]=a;continue}break}break a}i=Gb(a);b=g+8|0;e=a;h=rh(v[a>>2],c)+f|0;c=jb-16|0;jb=c;v[c+12>>2]=h;d=jb-16|0;jb=d;v[d+12>>2]=16777215;v[d+8>>2]=2147483647;a=v[Ib(d+12|0,d+8|0)>>2];jb=d+16|0;b:{if(a>>>0>=h>>>0){d=Lz(e);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;break b}Wc();L()}d=rh(v[e>>2],v[e+4>>2]);If(b+12|0,i);if(a){if(a>>>0>=16777216){jg();L()}c=xc(a<<8)}else{c=0}v[b>>2]=c;d=c+(d<<8)|0;v[b+8>>2]=d;v[b+4>>2]=d;j=zc(b),k=c+(a<<8)|0,v[j>>2]=k;a=jb-16|0;jb=a;v[a>>2]=v[b+8>>2];c=v[b+8>>2];v[a+8>>2]=b+8;v[a+4>>2]=c+(f<<8);c=v[a>>2];while(1){if(v[a+4>>2]!=(c|0)){Ez(c);c=v[a>>2]+256|0;v[a>>2]=c;continue}break}Id(a);jb=a+16|0;Ad(e,b);e=v[b+4>>2];a=v[b+8>>2];while(1){if((a|0)!=(e|0)){a=a-256|0;v[b+8>>2]=a;continue}break}a=v[b>>2];if(a){zc(b);Jb(a)}}jb=g+32|0;return}if(b>>>0<e>>>0){Nd(a,c+(b<<8)|0)}}function M9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;i=jb-16|0;jb=i;e=v[b+1298304>>2];if(!xd(e)){d=jb-16|0;jb=d;c=xc(12);v[23296]=0;e=T(861,c|0)|0;f=v[23296];v[23296]=0;a:{if((f|0)!=1){c=v[xf(d+8|0,e)>>2];jb=d+16|0;break a}a=P()|0;O()|0;Jb(c);S(a|0);L()}v[i+8>>2]=c;c=b+1298304|0;d=i+8|0;zM(c,de(d));vy(d);e=v[c>>2]}f=jb-48|0;jb=f;c=f+16|0;nM(c,a);v[23296]=0;U(8,f+32|0,0,c|0);c=v[23296];v[23296]=0;b:{c:{if((c|0)!=1){zb(f+16|0);m=f,n=Eb(v[e>>2]),v[m+8>>2]=n;l=Eb(v[e+4>>2]);c=0;e=0;d:{while(1){e:{h=v[f+8>>2];if(!Rb(h,l)){if(!e){break e}c=v[e+4>>2];if(!c){break e}v[23296]=0;W(c|0,e|0,b|0,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break e}break d}j=0;d=v[h>>2];if(v[d+32>>2]==v[a+16>>2]){j=v[d+36>>2]==v[a+20>>2]}v[23296]=0;R(862,f+16|0,d+8|0);d=v[23296];v[23296]=0;if((d|0)==1){break d}g=jb-16|0;jb=g;k=f+16|0;ve(g+8|0,k);ve(g,f+32|0);d=VL(v[g+8>>2],v[g+12>>2],v[g>>2],v[g+4>>2]);jb=g+16|0;yb(k);f:{if(!(!j|(d|0)!=0)){e=v[h>>2];c=3;break f}if((c|0)<2&j){e=v[h>>2];c=2;break f}d=!d&(c|0)<=0;e=d?v[h>>2]:e;c=d?1:c}Ce(f+8|0);continue}break}yb(f+32|0);jb=f+48|0;break b}e=P()|0;O()|0;yb(f+32|0);break c}e=P()|0;O()|0;zb(f+16|0)}S(e|0);L()}jb=i+16|0}function MV(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-32|0;jb=d;if(!Pb(a,13496,4)){pd(b,32);Bo(b);Uh(d,1,a+4|0);c=d+16|0;Gc(c,d);ze(b+43|0,c);yb(c);u[b+30>>1]=w[a+19|0]<<2;ug(b+30|0,256);u[b+32>>1]=w[a+17|0];ug(b+32|0,64);u[b+28>>1]=(w[a+47|0]&127)<<2;ug(b+28|0,256);if(t[a+47|0]<0){u[b+34>>1]=x[b+34>>1]|32}c=w[a+18|0];if(c&16){u[b+34>>1]=x[b+34>>1]|2;c=w[a+18|0]}if(c&32){u[b+34>>1]=x[b+34>>1]|8;c=w[a+18|0]}if(c&64){u[b+34>>1]=x[b+34>>1]|4;c=w[a+18|0]}if(c<<24>>24<0){u[b+34>>1]=x[b+34>>1]|16}c=w[a+60|0]|w[a+61|0]<<8|(w[a+62|0]<<16|w[a+63|0]<<24);v[b+24>>2]=c?c>>>0>256?c:256:8363;v[b>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[b+4>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[b+8>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);v[b+12>>2]=w[a+64|0]|w[a+65|0]<<8|(w[a+66|0]<<16|w[a+67|0]<<24);v[b+16>>2]=w[a+68|0]|w[a+69|0]<<8|(w[a+70|0]<<16|w[a+71|0]<<24);lk(b);t[b+38|0]=w[(w[a+79|0]&7)+39696|0];t[b+41|0]=w[a+76|0];t[b+40|0]=w[a+77|0]&127;t[b+39|0]=w[a+78|0];c=w[a+46|0];a:{if((c|0)==64){c=512}else{if((c|0)!=128){break a}c=16384}u[b+34>>1]=c|x[b+34>>1]}c=w[a+72|0]|w[a+73|0]<<8|(w[a+74|0]<<16|w[a+75|0]<<24)}jb=d+32|0;return c|0}function uG(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;l=jb-16|0;jb=l;f=w[a|0];a:{if(!f){g=a;break a}g=a;b:{while(1){if(!Ak(f<<24>>24)){break b}f=w[g+1|0];g=g+1|0;if(f){continue}break}break a}c:{f=f&255;switch(f-43|0){case 0:case 2:break c;default:break a}}m=(f|0)==45?-1:0;g=g+1|0}d:{if(!((c|16)!=16|w[g|0]!=48)){o=1;if((w[g+1|0]&223)==88){g=g+2|0;j=16;break d}g=g+1|0;j=c?c:8;break d}j=c?c:10}p=j>>31;c=0;while(1){e:{f=-48;i=t[g|0];f:{if((i-48&255)>>>0<10){break f}f=-87;if((i-97&255)>>>0<26){break f}f=-55;if((i-65&255)>>>0>25){break e}}i=f+i|0;if((i|0)>=(j|0)){break e}mf(l,j,p,0,0,k,h,0,0);f=1;g:{if(v[l+8>>2]|v[l+12>>2]){break g}q=Sia(k,h,j,p);n=mb;r=i>>31;s=r^-1;if((n|0)==(s|0)&(i^-1)>>>0<q>>>0|n>>>0>s>>>0){break g}h=n+r|0;f=i+q|0;h=f>>>0<i>>>0?h+1|0:h;k=f;o=1;f=c}g=g+1|0;c=f;continue}break}if(b){v[b>>2]=o?g:a}h:{i:{j:{if(c){v[115772]=68;a=d&1;m=a?0:m;k=d;h=e;break j}if((e|0)==(h|0)&d>>>0>k>>>0|e>>>0>h>>>0){break i}a=d&1}if(!(a|m)){v[115772]=68;a=d;d=a-1|0;e=e-!a|0;break h}if((e|0)==(h|0)&d>>>0>=k>>>0|e>>>0>h>>>0){break i}v[115772]=68;break h}a=m;b=a^k;d=b-a|0;c=a>>31;e=(c^h)-((a>>>0>b>>>0)+c|0)|0}jb=l+16|0;mb=e;return d}function mda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;k=jb-48|0;jb=k;if(pf(v[b>>2],v[b+4>>2])>>>0>c>>>0){while(1){i=m&65535;if(i>>>0<=c>>>0){g=Pf(v[b>>2],i);e=v[g>>2];if(Rb(e,v[g+4>>2])){n=k+24|0;e=Eb(e);o=Eb(v[Pf(v[b>>2],i)+4>>2]);f=FP(k,d);l=jb-16|0;jb=l;v[l+8>>2]=e;while(1){if(Rb(e,o)){j=jb-16|0;jb=j;if(!(w[e+5|0]|w[e+3|0]!=4)){g=j+8|0;Bb(g,v[f>>2],x[f+14>>1]);xg(g,0);t[e+3|0]=0}h=w[e+2|0];if(!(w[e+4|0]|(h|0)!=11)){g=j+8|0;Bb(g,v[f>>2],x[f+14>>1]);xg(g,0);t[e+2|0]=0;h=0}a:{b:{if(!w[e|0]){Bb(j+8|0,v[f>>2],x[f+14>>1]);if(Cb(v[v[j+8>>2]>>2],v[j+12>>2])){break b}h=w[e+2|0]}i=w[e+3|0];g=j+8|0;Bb(g,v[f>>2],x[f+14>>1]);xg(g,(i|0)==4|(h|0)==11);h=w[e+3|0];break a}h=w[e+3|0];g=w[e+2|0];if(!(h|(g|0)==11)){t[e+5|0]=0;h=4;t[e+3|0]=4;break a}if(g|(h|0)==4){break a}t[e+4|0]=0;t[e+2|0]=11}c:{d:{e:{if(!(!w[f+16|0]|h)){t[e+3|0]=17;i=0;h=125;break e}i=0;f:{switch(h-16|0){case 1:break d;case 0:break f;default:break c}}if(w[e+5|0]){break c}i=1;h=6}t[e+5|0]=h}t[f+16|0]=i}u[f+14>>1]=(x[f+14>>1]+1>>>0)%x[f+12>>1];jb=j+16|0;e=v[kk(l+8|0)>>2];continue}break}DP(n,f);jb=l+16|0;Le(n);Le(f)}m=m+1|0;continue}break}}DP(a,d);jb=k+48|0}function Z2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;b=jb-2144|0;jb=b;Nx(b+96|0);a:{b:{c:{f=v[c+4>>2];if(!f){a=ba(8)|0;v[23296]=0;b=Q(54,b+80|0,10345)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}g=v[c>>2];d=v[c+12>>2];c=v[c+8>>2];v[b+72>>2]=c;v[b+76>>2]=d;e=v[b+76>>2];v[b+24>>2]=v[b+72>>2];v[b+28>>2]=e;v[b+68>>2]=f;v[b+64>>2]=g;e=v[b+68>>2];v[b+16>>2]=v[b+64>>2];v[b+20>>2]=e;h=RI(b+16|0);if(h){v[b+48>>2]=c;v[b+52>>2]=d;c=v[b+52>>2];v[b+8>>2]=v[b+48>>2];v[b+12>>2]=c;v[b+44>>2]=f;v[b+40>>2]=g;c=v[b+44>>2];v[b>>2]=v[b+40>>2];v[b+4>>2]=c;c=LI(b)}else{c=0}v[b+56>>2]=c;v[b+60>>2]=0;d=0;c=2048;while(1){if(c){e=nb[f|0](g,(b+96|0)+d|0,c)|0;c=c-e|0;d=d+e|0;if(e){continue}}break}c=a;a=gc(b+32|0,b+96|0,d);a=Os(c,v[a>>2],v[a+4>>2],h?b+56|0:0);if(a+1>>>0>=3){a=ba(8)|0;v[23296]=0;b=Q(54,b+80|0,7975)|0;c=v[23296];v[23296]=0;if((c|0)!=1){a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}c=P()|0;O()|0;ca(a|0);break b}jb=b+2144|0;return a|0}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}function m2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=jb+-64|0;jb=c;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[c+40>>2]=v[a+20>>2];f=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=f;tf(c+48|0,c+32|0,e);a=v[d+4>>2];e=v[a+8>>2];f=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a=jb-32|0;jb=a;a:{b:{c:{d:{h=v[c+4>>2];if(h>>>0>=f>>>0){if(y[c+20>>2]<f>>>0){break d}if(e>>>0>y[c+8>>2]){break c}i=v[c+28>>2];if(Xe(v[c+24>>2],i)>>>0<e>>>0){break b}k=b+12|0;l=v[c+16>>2];m=v[c>>2];b=0;e:while(1){d=0;if((b|0)==(e|0)){break a}while(1)if((d|0)==(f|0)){b=b+1|0;continue e}else{n=a,o=+(am(ge(cg(A[Pg(m,h,d,b)>>3])*134217728))+id(is(k),21)|0)*7.450580596923828e-9,A[n+24>>3]=o;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;j=ge(A[zg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(j)<2147483648){g=~~j;break f}g=-2147483648}g=Xc(g);n=xn(l,i,d,b),p=g,u[n>>1]=p;d=d+1|0;continue}}}aa(7150,8947,77,8627);L()}aa(7115,8947,78,8627);L()}aa(5858,8947,79,8627);L()}aa(5828,8947,80,8627);L()}jb=a+32|0;jb=c- -64|0}function Ed(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb+-64|0;jb=d;v[a+480180>>2]=b;b=fq(a);Mz(d,b);e=v[d+12>>2];c=a+1074320|0;v[c>>2]=v[d+8>>2];v[c+4>>2]=e;c=v[d+4>>2];v[a+1074312>>2]=v[d>>2];v[a+1074316>>2]=c;Ps(a+8|0,b);b=1;while(1){c=b&65535;if(c>>>0>x[a+480192>>1]){v[a+480184>>2]=0;v[a+480188>>2]=0;v[a+480236>>2]=65536;v[a+480228>>2]=48;v[a+480232>>2]=48;t[a+480268|0]=5;v[a+480260>>2]=16;v[a+480264>>2]=32767;v[a+480204>>2]=125e4;v[a+480208>>2]=0;v[a+480196>>2]=6;v[a+480200>>2]=256;v[a+1074304>>2]=0;v[a+1074308>>2]=0;u[a+480192>>1]=0;qy(a,4);e=jb+-64|0;jb=e;b=a+484344|0;Rs(b);f=ik(v[b>>2],v[b+4>>2]);c=Ux(e+8|0,b);v[23296]=0;U(767,b|0,f|0,c|0);b=v[23296];v[23296]=0;a:{if((b|0)!=1){Pk(c);jb=e- -64|0;break a}a=P()|0;O()|0;Pk(c);S(a|0);L()}SO(a+484360|0);Nf(a+1298308|0);lA(a+1298320|0);Nf(a+1298332|0);c=Xb(d,0,64);b=GM(c);d=Hb(a+1298344|0,b);Hb(d+12|0,b+12|0);Hb(d+24|0,b+24|0);Hb(d+36|0,b+36|0);Hb(d+48|0,b+48|0);v[d+60>>2]=v[b+60>>2];wy(b);Hc(a+1298408|0);Hc(a+480248|0);if(v[a+480180>>2]&738230281){v[a+480208>>2]=v[a+480208>>2]|8388608}jb=c- -64|0;return}c=((c<<2)+a|0)+900380|0;e=v[c>>2];if(e){Jb(Rt(e))}v[c>>2]=0;b=b+1|0;continue}}function yba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;h=jb-16|0;jb=h;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+72>>2];b=v[a+68>>2];o=b;p=b>>31;b=v[a+64>>2];q=b;r=b>>31;b=v[a+60>>2];s=b;t=b>>31;w=v[a+8>>2];x=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Sia(q,r,e,e>>31);g=mb;f=Yb(f,-16777216,16776704);i=Sia(o,p,f,f>>31);e=i+e|0;f=mb+g|0;f=e>>>0<i>>>0?f+1|0:f;y=e;e=(v[h+12>>2]<<1)+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(u[e+4>>1],u[g+10>>1])+B(u[e+2>>1],u[g+8>>1])|0)+B(u[e+6>>1],u[g+12>>1])|0)+B(u[e+8>>1],u[g+14>>1])|0)/2|0)+((((B(u[e-4>>1],u[g+2>>1])+B(u[e-6>>1],u[g>>1])|0)+B(u[e-2>>1],u[g+4>>1])|0)+B(u[e>>1],u[g+6>>1])|0)/2|0)|0)/16384<<8;e=g;i=Sia(e,e>>31,s,t);e=y+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(h+8|0,w,x);e=f-(g&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;jb=h+16|0}function d2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=jb+-64|0;jb=c;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[c+40>>2]=v[a+20>>2];f=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=f;tf(c+48|0,c+32|0,e);a=v[d+4>>2];f=v[a+8>>2];h=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;e=c+16|0;a=jb-32|0;jb=a;a:{b:{c:{d:{i=v[c+4>>2];if(i>>>0>=h>>>0){if(y[e+4>>2]<h>>>0){break d}if(y[c+8>>2]<f>>>0){break c}if(Xe(v[e+8>>2],v[e+12>>2])>>>0<f>>>0){break b}k=b+12|0;l=v[c>>2];b=0;e:while(1){d=0;if((b|0)==(f|0)){break a}while(1)if((d|0)==(h|0)){b=b+1|0;continue e}else{m=a,n=+(am(ge(cg(A[Pg(l,i,d,b)>>3])*134217728))+id(is(k),21)|0)*7.450580596923828e-9,A[m+24>>3]=n;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;j=ge(A[zg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(j)<2147483648){g=~~j;break f}g=-2147483648}g=Xc(g);m=wn(e,d,b),o=g,u[m>>1]=o;d=d+1|0;continue}}}aa(7150,8947,77,8627);L()}aa(7115,8947,78,8627);L()}aa(5858,8947,79,8627);L()}aa(5828,8947,80,8627);L()}jb=a+32|0;jb=c- -64|0}function zba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;h=jb-16|0;jb=h;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];g=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=g;m=b+24|0;n=v[a+72>>2];b=v[a+68>>2];o=b;p=b>>31;b=v[a+64>>2];q=b;r=b>>31;b=v[a+60>>2];s=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Sia(q,r,e,e>>31);g=mb;f=Yb(f,-16777216,16776704);i=Sia(o,p,f,f>>31);e=i+e|0;f=mb+g|0;f=e>>>0<i>>>0?f+1|0:f;z=e;e=v[h+12>>2]+l|0;g=(((v[h+8>>2]>>>16|0)+4&131064)<<1)+m|0;g=(((((B(t[e+2|0],u[g+10>>1])+B(t[e+1|0],u[g+8>>1])|0)+B(t[e+3|0],u[g+12>>1])|0)+B(t[e+4|0],u[g+14>>1])<<8)/2|0)+((((B(t[e-2|0],u[g+2>>1])+B(t[e-3|0],u[g>>1])|0)+B(t[e-1|0],u[g+4>>1])|0)+B(t[e|0],u[g+6>>1])<<8)/2|0)|0)/16384<<8;e=g;i=Sia(e,e>>31,s,w);e=z+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(h+8|0,x,y);e=f-(g&n)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;jb=h+16|0}function _ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0,C=0;h=jb-16|0;jb=h;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;o=v[a+32>>2];p=v[a+28>>2];q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];t=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Sia(t,w,e,e>>31);k=mb;C=e;e=(v[h+12>>2]<<1)+n|0;g=v[h+8>>2]>>>21&2040;l=(((B(u[e>>1],u[g+39714>>1])+B(u[e-2>>1],u[g+39712>>1])|0)+B(u[e+2>>1],u[g+39716>>1])|0)+B(u[e+4>>1],u[g+39718>>1])|0)/16384<<8;e=l;m=Sia(e,e>>31,x,y);g=C+m|0;e=mb+k|0;e=g>>>0<m>>>0?e+1|0:e;f=Yb(f,-16777216,16776704);k=Sia(r,s,f,f>>31);g=k+g|0;f=mb+e|0;f=g>>>0<k>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;j=j+p|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+o|0;v[c+4>>2]=v[c+4>>2]+B(e,i>>12);Sb(h+8|0,z,A);e=f-(q&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;jb=h+16|0}function Cda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=jb-16|0;jb=f;u[f+12>>1]=c;u[f+14>>1]=b;u[f+10>>1]=d;h=x[v[v[a+24>>2]+8>>2]+12>>1];a:{if(h>>>0<=b>>>0){break a}if(!c|lj(a)>>>0>=h>>>0){break a}ug(f+12|0,h-b&65535);p=f,q=fl(v[a>>2],v[a+4>>2]),u[p+8>>1]=q;g=x[f+12>>1];iS(a,g+x[We(f+14|0,f+8|0)>>1]|0);c=v[a>>2];e=a;if(Nc(c,v[a+4>>2])>>>0<b>>>0){kg(e,b);c=v[e>>2]}a=Eb(c);c=jb-16|0;jb=c;v[c+8>>2]=a;a=v[WO(c+8|0,b)>>2];jb=c+16|0;a=v[hc(f,a)>>2];i=f+10|0;l=jb-32|0;jb=l;b=a;a=v[e>>2];d=(so(b,Eb(a))<<1)+a|0;a=g;b:{if(!a){break b}b=v[Gb(e)>>2];g=v[e+4>>2];if(a>>>0<=b-g>>1>>>0){b=a;c=g-d>>1;if(c>>>0<a>>>0){xo(e,a-c|0,i);b=c;if((d|0)==(g|0)){break b}}m=jb-16|0;jb=m;c=g;o=v[e+4>>2];g=(o-((a<<1)+d|0)|0)+d|0;n=Fi(m,e,c-g>>1);j=v[n+4>>2];k=g;while(1){if(c>>>0<=k>>>0){lc(n);kq(d,g,o);jb=m+16|0}else{Di(j,x[k>>1]);j=j+2|0;v[n+4>>2]=j;k=k+2|0;continue}break}Ot(d,b,((d>>>0<=i>>>0?y[e+4>>2]>i>>>0?a:0:0)<<1)+i|0);break b}b=Gb(e);b=xj(l+8|0,yj(e,Nc(v[e>>2],g)+a|0),d-v[e>>2]>>1,b);DC(b,a,i);d=TO(e,b,d);Gi(b)}Eb(d);jb=l+32|0;if(Nc(v[e>>2],v[e+4>>2])>>>0<=h>>>0){break a}kg(e,h)}jb=f+16|0}function U7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-16|0;jb=h;if(!w[a+4242|0]){Jx(a);a:{if(!w[a+4240|0]){break a}e=kM(v[a+16>>2]);if(e==A[a+4288>>3]){break a}A[a+4288>>3]=e;Es(a)}f=a+4256|0;b:{if(w[a+4244|0]){if(A[f>>3]>1){v[f>>2]=0;v[f+4>>2]=1072693248}break b}i=(v[a+4232>>2]&-2)!=4;e=A[f>>3];c:{if(D(e)<2147483648){g=~~e;break c}g=-2147483648}if(!(i|(g|0)<=0)){Hx(a);e=A[a+4256>>3]}A[f>>3]=e-+(g|0)}e=0;d:{e:{switch(v[a+4232>>2]){case 0:e=ti(A[f>>3]*6.283185307179586);break d;case 1:e=D(A[f>>3]+-.5)*-4+1;break d;case 2:e=A[f>>3];e=e+e+-1;break d;case 3:e=A[f>>3]<.5?-1:1;break d;case 4:e=A[a+4272>>3];break d;case 5:break e;default:break d}}e=A[a+4256>>3];e=e*(e*e)*(e*(e*6+-15)+10);e=A[a+4280>>3]*e+A[a+4272>>3]*(1-e)}A[h+8>>3]=(w[a+4241|0]?-e:e)*+z[a+4220>>2]+ +z[a+4224>>2];MN(h+8|0,1);g=Pj(a);f:{if(!g){break f}f=v[a+4236>>2];if(w[a+4243|0]){k=g,l=(f>>>8&15|176)&191|(f&127)<<8|io(A[h+8>>3]*127)<<16,j=v[v[g>>2]+68>>2],nb[j](k|0,l|0)|0;break f}nb[v[v[g>>2]+44>>2]](g,f,C(A[h+8>>3]))}A[a+4256>>3]=A[a+4264>>3]*+(d>>>0)+A[a+4256>>3]}g=a;a=v[a+44>>2];ji(g,b,c,Fc(a,0),Fc(a,1),d);jb=h+16|0}function $ba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0,A=0;g=jb-16|0;jb=g;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];w=b;x=b>>31;y=v[a+8>>2];z=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Sia(r,s,e,e>>31);h=mb;f=Yb(f,-16777216,16776704);k=Sia(p,q,f,f>>31);e=k+e|0;f=mb+h|0;f=e>>>0<k>>>0?f+1|0:f;A=e;e=v[g+12>>2]+l|0;h=v[g+8>>2]>>>21&2040;h=(((B(t[e|0],u[h+39714>>1])+B(t[e-1|0],u[h+39712>>1])|0)+B(t[e+1|0],u[h+39716>>1])|0)+B(t[e+2|0],u[h+39718>>1])<<8)/16384<<8;e=h;k=Sia(e,e>>31,w,x);e=A+k|0;f=mb+f|0;f=e>>>0<k>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;j=j+n|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+m|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Sb(g+8|0,y,z);e=f-(h&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;jb=g+16|0}function nba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=jb-16|0;jb=e;o=v[a+16>>2];p=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){j=v[a+8>>2];k=v[a+12>>2];f=v[a>>2];g=v[a+4>>2];i=0;break a}j=v[a+8>>2];k=v[a+12>>2];m=bg(j,k,l);n=mb;b=v[a+76>>2];f=v[a>>2];g=v[a+4>>2];Ff(f,g,ff(j,k,d),mb);i=b>>>0<mb>>>0?d:0}h=a+112|0;q=v[a+24>>2];r=v[a+20>>2];v[e>>2]=f;v[e+4>>2]=g;b:while(1){if(d){b=v[e+4>>2];f=v[e>>2];v[e+8>>2]=f;v[e+12>>2]=0;i=i-1|0;m=i?m:0;n=i?n:0;d=d-1|0;f=((((b&2147483647)<<1|f>>>31)&2147483646)<<1)+o|0;b=l;while(1)if((b|0)<=0){Sb(h,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){g=(v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31;Ld(h,(u[(g<<1|2)+f>>1]+u[((g&2147483646)<<1)+f>>1]|0)/8<<16>>16);Kd(h,b);v[h>>2]=v[h>>2];v[h+4>>2]=0}f=v[c>>2];b=$f(h,p);v[c>>2]=f+B(b,r);v[c+4>>2]=v[c+4>>2]+B(b,q);Sb(e,j,k);c=c+8|0;continue b}else{g=(v[e+12>>2]&2147483647)<<1|v[e+8>>2]>>>31;Ld(h,(u[(g<<1|2)+f>>1]+u[((g&2147483646)<<1)+f>>1]|0)/8<<16>>16);Kd(h,4);Sb(e+8|0,m,n);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;jb=e+16|0}function Uba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=((((v[f+12>>2]&2147483647)<<1|h>>>31)&2147483646)<<1)+j|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];t=u[e+2>>1];w=u[e>>1];h=0;while(1){if((h|0)!=2){e=(h<<1)+m|0;v[(h<<2)+f>>2]=(((((((B(u[e-8>>1],t)+B(u[e-12>>1],w)|0)+B(u[e-4>>1],s)|0)+B(u[e>>1],r)|0)+B(u[e+4>>1],q)|0)+B(u[e+8>>1],p)|0)+B(u[e+12>>1],o)|0)+B(u[e+16>>1],n)|0)/32768;h=h+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],k);Sb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;jb=f+16|0}function Pia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;t[d+24|0]=44;v[d+16>>2]=-1;v[d+20>>2]=0;v[d+8>>2]=1058;v[d+12>>2]=2;c=jb+-64|0;jb=c;h=v[d+8>>2]&2?16:10;f=jb-32|0;jb=f;e=Je(f+16|0,1,0);a:{b:{c:{while(1){g=tc(e);OI(f+8|0,g,Fb(e)+g|0,v[b>>2],h);if(!v[f+12>>2]){break c}g=Hf(Fb(e));v[23296]=0;R(58,e|0,g|0);g=v[23296];v[23296]=0;if((g|0)!=1){continue}break}break b}b=v[f+8>>2];h=tc(e);v[23296]=0;R(59,e|0,b-h|0);b=v[23296];v[23296]=0;d:{if((b|0)!=1){v[23296]=0;R(60,c|0,e|0);b=v[23296];v[23296]=0;if((b|0)!=1){break d}break b}break b}yb(e);jb=f+32|0;break a}a=P()|0;O()|0;yb(e);S(a|0);L()}b=c+16|0;ms(b,c,v[d+8>>2]);e=v[d+12>>2];f=v[d+8>>2];v[23296]=0;X(73,c+32|0,b|0,f|0,e|0);b=v[23296];v[23296]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=w[d+24|0];e=v[d+20>>2];v[23296]=0;X(74,c+48|0,c+32|0,e|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break i}v[23296]=0;R(57,a|0,c+48|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}yb(c+48|0);yb(c+32|0);yb(c+16|0);yb(c);jb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(c+48|0)}yb(c+32|0)}yb(c+16|0);yb(c);S(a|0);L()}jb=d+32|0}function Nt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;t[d+24|0]=44;v[d+16>>2]=-1;v[d+20>>2]=0;v[d+8>>2]=1058;v[d+12>>2]=2;c=jb+-64|0;jb=c;h=v[d+8>>2]&2?16:10;f=jb-32|0;jb=f;e=Je(f+16|0,1,0);a:{b:{c:{while(1){g=tc(e);SI(f+8|0,g,Fb(e)+g|0,w[b|0],h);if(!v[f+12>>2]){break c}g=Hf(Fb(e));v[23296]=0;R(58,e|0,g|0);g=v[23296];v[23296]=0;if((g|0)!=1){continue}break}break b}b=v[f+8>>2];h=tc(e);v[23296]=0;R(59,e|0,b-h|0);b=v[23296];v[23296]=0;d:{if((b|0)!=1){v[23296]=0;R(60,c|0,e|0);b=v[23296];v[23296]=0;if((b|0)!=1){break d}break b}break b}yb(e);jb=f+32|0;break a}a=P()|0;O()|0;yb(e);S(a|0);L()}b=c+16|0;ms(b,c,v[d+8>>2]);e=v[d+12>>2];f=v[d+8>>2];v[23296]=0;X(73,c+32|0,b|0,f|0,e|0);b=v[23296];v[23296]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=w[d+24|0];e=v[d+20>>2];v[23296]=0;X(74,c+48|0,c+32|0,e|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break i}v[23296]=0;R(57,a|0,c+48|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}yb(c+48|0);yb(c+32|0);yb(c+16|0);yb(c);jb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(c+48|0)}yb(c+32|0)}yb(c+16|0);yb(c);S(a|0);L()}jb=d+32|0}function D7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0;b=jb+-64|0;jb=b;g=Qb(a);v[23296]=0;Y(863,g|0);a=v[23296];v[23296]=0;a:{if((a|0)!=1){a=44560;b:{c:{d:{e:{f:{g:{h:{i:{j:{while(1){if((a|0)==44872){jb=b- -64|0;return g|0}k:{h=Ns(44);if(h){d=v[a>>2];e=v[a+4>>2];v[23296]=0;e=Q(54,b+32|0,e|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break k}v[23296]=0;R(864,b+48|0,e|0);c=v[23296];v[23296]=0;if((c|0)==1){break j}c=v[a+8>>2];v[23296]=0;c=Q(54,b|0,c|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break i}v[23296]=0;R(864,b+16|0,c|0);f=v[23296];v[23296]=0;if((f|0)==1){break h}v[23296]=0;d=fa(865,h|0,d|0,b+48|0,b+16|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break g}Tb(b+16|0);yb(c);Tb(b+48|0);yb(e);v[b+60>>2]=d;v[23296]=0;R(866,g|0,b+60|0);e=v[23296];v[23296]=0;if((e|0)==1){break b}v[d+32>>2]=v[a+12>>2];v[d+36>>2]=v[a+16>>2];t[d+40|0]=w[a+20|0];t[d+41|0]=w[d+41|0]&253|w[a+21|0]<<1}a=a+24|0;continue}break}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;Tb(b+16|0)}yb(c)}Tb(b+48|0)}yb(e)}Jb(h);break a}a=P()|0;O()|0;break a}a=P()|0;O()|0}vc(g);S(a|0);L()}function hia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=jb-1072|0;jb=d;v[d+1068>>2]=c;o=d,p=Ee(b),t[o+8|0]=p;t[d+4|0]=1;c=d+8|0;g=w[ef(c,d+4|0)|0];f=nB(c,b);l=mq(f);v[23296]=0;c=T(190,b|0)|0;e=v[23296];v[23296]=0;a:{if((e|0)!=1){v[d+4>>2]=c;v[d>>2]=536870911;yc(d+1068|0,v[Ib(d+4|0,d)>>2]<<3);v[23296]=0;m=v[d+1068>>2];k=Q(321,a|0,m|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){v[23296]=0;c=8;h=Q(152,f|0,8)|0;a=v[23296];v[23296]=0;b:{if((a|0)!=1){c:{o=Lb(v[k>>2],0),p=h,t[o|0]=p;i=1;a=g;while(1){c=c&255;n=c>>>0>9?c:9;e=a;d:{e:{while(1){if(i>>>0>=m>>>0){break d}v[23296]=0;j=Q(152,f|0,c|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){if(j){break e}if((c|0)==(n|0)){break d}c=c+1|0;e=g;continue}break}break c}a=j>>>1|0;h=(j&1?0-a|0:a)+h|0;o=Lb(v[k>>2],i),p=h,t[o|0]=p;i=i+1|0;a=g;if(j>>>c-1|0){continue}a=e-1|0;e=a&255;a=e?a:g;c=c-(!e&(c&255)>>>0>1)|0;continue}break}a=mq(f);v[23296]=0;Q(143,b|0,((a-l|0)+3&-4)+l|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break b}}}c=P()|0;O()|0;fc(k);break a}Ab(f);jb=d+1072|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0}Ab(f);S(c|0);L()}function i_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=jb-448|0;jb=a;v[a+432>>2]=c;v[a+440>>2]=b;v[a+20>>2]=1106;b=le(a+24|0,a+32|0,a+20|0);h=a+16|0;bd(h,e);v[23296]=0;h=T(1084,h|0)|0;i=v[23296];v[23296]=0;if((i|0)!=1){a:{t[a+15|0]=0;e=v[e+4>>2];v[23296]=0;c=pa(1114,a+440|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+432|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}d:{if(Ve(g)){yd(v[g>>2],0);Td(g,0);break d}yd(g,0);xe(g,0)}if(w[a+15|0]){v[23296]=0;c=Q(1102,h|0,45)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}v[23296]=0;R(48,g|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break a}}v[23296]=0;d=Q(1102,h|0,48)|0;c=v[23296];v[23296]=0;if((c|0)==1){break b}e=v[a+20>>2];h=e-4|0;c=v[b>>2];while(1){if(!((d|0)!=v[c>>2]|c>>>0>=h>>>0)){c=c+4|0;continue}break}v[23296]=0;W(1119,g|0,c|0,e|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break c}break a}v[23296]=0;c=Q(1090,a+440|0,a+432|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}if(c){v[f>>2]=v[f>>2]|2}c=v[a+440>>2];_b(a+16|0);Qc(b);jb=a+448|0;return c|0}}}c=P()|0;O()|0;_b(a+16|0);Qc(b);S(c|0);L()}function Cn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-80|0;jb=c;g=Qb(a);a=v[b+24>>2];a:{b:{if(kj(v[a+484360>>2],v[a+484364>>2])){c:{d:{e:while(1){if(kj(v[a+484360>>2],v[a+484364>>2])>>>0<=f>>>0){break d}d=bM(GR(c+40|0,1),f&255,0,0);v[23296]=0;e=v[d+12>>2];v[c+16>>2]=v[d+8>>2];v[c+20>>2]=e;e=v[d+20>>2];v[c+24>>2]=v[d+16>>2];v[c+28>>2]=e;e=v[d+4>>2];v[c+8>>2]=v[d>>2];v[c+12>>2]=e;X(993,c- -64|0,a|0,0,c+8|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}j=c,k=Eb(v[c+64>>2]),v[j+32>>2]=k;d=Eb(v[c+68>>2]);while(1){a=v[c+32>>2];if(!Rb(a,d)){f=f+1|0;vi(c- -64|0);a=v[b+24>>2];continue e}h=A[a>>3];e=v[a+16>>2];i=x[a+24>>1];a=c+40|0;v[a+16>>2]=f;v[a+12>>2]=i;v[a+8>>2]=e;A[a>>3]=h;v[23296]=0;R(1010,g|0,a|0);a=v[23296];v[23296]=0;if((a|0)!=1){sz(c+32|0);continue}break}break}a=P()|0;O()|0;vi(c- -64|0);break b}jb=c+80|0;return}a=P()|0;O()|0;break b}b=ba(8)|0;v[23296]=0;d=Q(54,c+40|0,7228)|0;a=v[23296];v[23296]=0;if((a|0)!=1){a=sc(b,d);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(d);break b}a=P()|0;O()|0;ca(b|0)}Wf(g);S(a|0)}L()}function rE(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;t[e+24|0]=44;v[e+16>>2]=-1;v[e+20>>2]=0;v[e+8>>2]=1058;v[e+12>>2]=c;c=jb+-64|0;jb=c;g=e+8|0;i=v[g>>2]&2?16:10;f=jb-32|0;jb=f;d=Je(f+16|0,1,0);a:{b:{c:{while(1){h=tc(d);lx(f+8|0,h,Fb(d)+h|0,v[b>>2],i);if(!v[f+12>>2]){break c}h=Hf(Fb(d));v[23296]=0;R(58,d|0,h|0);h=v[23296];v[23296]=0;if((h|0)!=1){continue}break}break b}b=v[f+8>>2];i=tc(d);v[23296]=0;R(59,d|0,b-i|0);b=v[23296];v[23296]=0;d:{if((b|0)!=1){v[23296]=0;R(60,c|0,d|0);b=v[23296];v[23296]=0;if((b|0)!=1){break d}break b}break b}yb(d);jb=f+32|0;break a}a=P()|0;O()|0;yb(d);S(a|0);L()}b=c+16|0;ms(b,c,v[g>>2]);d=v[g+4>>2];f=v[g>>2];v[23296]=0;X(73,c+32|0,b|0,f|0,d|0);b=v[23296];v[23296]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=w[g+16|0];d=v[g+12>>2];v[23296]=0;X(74,c+48|0,c+32|0,d|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break i}v[23296]=0;R(57,a|0,c+48|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}yb(c+48|0);yb(c+32|0);yb(c+16|0);yb(c);jb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;yb(c+48|0)}yb(c+32|0)}yb(c+16|0);yb(c);S(a|0);L()}jb=e+32|0}function Y9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;i=jb-16|0;jb=i;v[i+8>>2]=b;o=yf(a);while(1){if(Ag(b,c)){b=v[hc(i,o)>>2];j=vd(v[i+8>>2]);m=jb-16|0;jb=m;n=0;k=jb-16|0;jb=k;h=jb-32|0;jb=h;f=h+28|0;d=h+24|0;e=jb-16|0;jb=e;a:{b:{if(!uc(b,v[hc(e+8|0,Jf(a))>>2])){g=w[j|0];l=w[vd(b)|0];if(!Mn(g,l)){break b}}v[e+8>>2]=b;g=hc(e,Eb(v[a>>2]));c:{d=v[e+8>>2];if(!uc(d,v[g>>2])){d=v[cz(e+8|0)>>2];l=w[vd(d)|0];g=w[j|0];if(!Mn(l,g)){break c}}if(!v[b>>2]){v[f>>2]=b;break a}v[f>>2]=d;b=d+4|0;break a}b=Ey(a,f,g);break a}if(Mn(l,g)){d:{d=az(b);if(!uc(d,v[hc(e+8|0,Jf(a))>>2])){g=w[j|0];if(!Mn(g,w[vd(d)|0])){break d}}if(!v[b+4>>2]){v[f>>2]=b;b=b+4|0;break a}v[f>>2]=d;b=d;break a}b=Ey(a,f,g);break a}v[f>>2]=b;v[d>>2]=b;b=d}jb=e+16|0;d=b;b=v[b>>2];if(!b){b=jb-16|0;jb=b;e=kc(a);f=h+8|0;e=th(f,xc(24),uh(b+8|0,e));ZM(v[e>>2]+16|0,v[j>>2],v[j+4>>2]);p=kc(e),q=1,t[p+4|0]=q;jb=b+16|0;Zg(a,v[h+28>>2],d,v[h+8>>2]);b=de(f);cl(f);n=1}Yg(k+8|0,v[hc(h+8|0,b)>>2],n);jb=h+32|0;jb=k+16|0;hc(m+8|0,v[k+8>>2]);jb=m+16|0;b=v[Xg(i+8|0)>>2];continue}else{jb=i+16|0}break}}function UR(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;a:{if((d&255)>>>0<=4){while(1){d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!bf(a,f+15|0)){break a}d=w[f+15|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!bf(a,f+14|0)){break a}d=w[f+14|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){d=bf(a,f+13|0);if(d){g=w[f+13|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!d){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}break a}}while(1){d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){if(!bf(a,f+12|0)){break a}d=w[f+12|0];u[c>>1]=d<<1|1;t[b|0]=d>>>7;u[c>>1]=w[c|0]}u[e>>1]=t[b|0]+(x[e>>1]<<1);d=x[c>>1]<<1;u[c>>1]=d;t[b|0]=(d&65534)>>>0>255;d=w[c|0];u[c>>1]=d;if(!d){d=bf(a,f+11|0);if(d){g=w[f+11|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!d){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}break}}jb=f+16|0}function WU(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=jb-32|0;jb=g;t[g+12|0]=0;m=um(g+16|0,d,g+12|0);f=v[m>>2];v[g+12>>2]=d;h=d;while(1){if(!(!b|!h)){a:{i=b-1|0;k=w[a|0];if(!(!i|(k|0)!=(e&255))){v[g+8>>2]=w[a+1|0];i=a+2|0;j=Ib(g+8|0,g+12|0);b:{k=b-2|0;if(!k){break b}j=v[j>>2];if(!(j&255)){break b}i=w[i|0];while(1){if(!(j&255)){break a}t[f|0]=i;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;j=j-1|0;continue}}t[f|0]=e;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;b=k;a=i;continue}a=a+1|0;t[f|0]=k;h=v[g+12>>2]-1|0;v[g+12>>2]=h;f=f+1|0;b=i;continue}b=b-3|0;a=a+3|0;continue}break}e=d-h|0;a=v[m>>2];k=0;f=128;b=0;i=0;c:while(1){if((e|0)==(i|0)){while(1){if(e){d=k<<24>>24;b=t[c|0];a=128;d:{if((b|0)==-128){break d}a=b;if((b|0)>=0){break d}a=0-(b&127)|0}k=d-(a&255)|0;t[c|0]=k;e=e-1|0;c=c+1|0;continue}break}fc(m);jb=g+32|0;return}n=w[a|0];h=0;j=0;while(1)if((j&65535)>>>0>=8){f=f&65535;f=(f<<8|f)>>>h&255;i=i+1|0;a=a+1|0;continue c}else{l=b+c|0;t[l|0]=w[l|0]|B(f&n,257)>>>(h-j&7);l=b+1|0;b=d>>>0>l>>>0?l:0;j=j+1|0;h=(d>>>0<=l>>>0)+h|0;f=(f<<8|f)>>>1&255;continue}}}function qr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;t[e+24|0]=44;v[e+16>>2]=-1;v[e+20>>2]=0;v[e+8>>2]=c;v[e+12>>2]=d;c=jb+-64|0;jb=c;g=e+8|0;i=v[g>>2]&2?16:10;f=jb-32|0;jb=f;d=Je(f+16|0,1,0);a:{b:{c:{while(1){h=tc(d);lx(f+8|0,h,Fb(d)+h|0,v[b>>2],i);if(!v[f+12>>2]){break c}h=Hf(Fb(d));v[23296]=0;R(58,d|0,h|0);h=v[23296];v[23296]=0;if((h|0)!=1){continue}break}break b}b=v[f+8>>2];i=tc(d);v[23296]=0;R(59,d|0,b-i|0);b=v[23296];v[23296]=0;d:{if((b|0)!=1){v[23296]=0;R(71,c|0,d|0);b=v[23296];v[23296]=0;if((b|0)!=1){break d}break b}break b}yb(d);jb=f+32|0;break a}a=P()|0;O()|0;yb(d);S(a|0);L()}b=c+16|0;fs(b,c,v[g>>2]);d=v[g+4>>2];f=v[g>>2];v[23296]=0;X(75,c+32|0,b|0,f|0,d|0);b=v[23296];v[23296]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=w[g+16|0];d=v[g+12>>2];v[23296]=0;X(76,c+48|0,c+32|0,d|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break i}v[23296]=0;R(70,a|0,c+48|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}zb(c+48|0);zb(c+32|0);zb(c+16|0);zb(c);jb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;zb(c+48|0)}zb(c+32|0)}zb(c+16|0);zb(c);S(a|0);L()}jb=e+32|0}function SM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-16|0;jb=g;f=B(b,872)+a|0;a:{if(c){Bb(g+8|0,a+1074312|0,90);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){t[(B(b,872)+a|0)+1075803|0]=c}t[(B(b,872)+a|0)+1075804|0]=c;break a}c=w[f+1075804|0]}f=f+1074992|0;h=c&255;i=0-h|0;e=a+480180|0;j=!(v[e>>2]&204473357)&(d^-1);NM(a,b,i,j);e=v[e>>2];b:{c:{if((e|0)!=268435456){if((e|0)!=16777216){break c}k=v[(B(b,872)+a|0)+1075648>>2];if(!k|!v[k+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){MM(v[a+1074392>>2],v[a+1074416>>2],f,240-h|0);break b}if(!(b>>>0<224|d)){LM(f,224-h|0);break b}JM(f,i);break b}v[(B(b,872)+a|0)+1075700>>2]=65535}d:{if(!((c&255)>>>0>223&j)){break d}e:{d=h&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}xy(a,f,d);break b}if((e|0)==524288){break d}PM(a,f,d);break b}if((e|0)!=524288){break b}}f:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break f}if(v[a+1074416>>2]==1){Bb(g+8|0,a+1074312|0,6);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break f}e=v[a+480180>>2]}if(e&32832){break f}if(!(v[a+480208>>2]&2)|(e|0)!=8){break b}}Rj(a,f,(B(b,872)+a|0)+1075692|0,0-(h<<2)|0,0)}jb=g+16|0}function Nv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;t[e+24|0]=44;v[e+16>>2]=-1;v[e+20>>2]=0;v[e+8>>2]=c;v[e+12>>2]=d;c=jb+-64|0;jb=c;g=e+8|0;i=v[g>>2]&2?16:10;f=jb-32|0;jb=f;d=Je(f+16|0,1,0);a:{b:{c:{while(1){h=tc(d);OI(f+8|0,h,Fb(d)+h|0,v[b>>2],i);if(!v[f+12>>2]){break c}h=Hf(Fb(d));v[23296]=0;R(58,d|0,h|0);h=v[23296];v[23296]=0;if((h|0)!=1){continue}break}break b}b=v[f+8>>2];i=tc(d);v[23296]=0;R(59,d|0,b-i|0);b=v[23296];v[23296]=0;d:{if((b|0)!=1){v[23296]=0;R(71,c|0,d|0);b=v[23296];v[23296]=0;if((b|0)!=1){break d}break b}break b}yb(d);jb=f+32|0;break a}a=P()|0;O()|0;yb(d);S(a|0);L()}b=c+16|0;fs(b,c,v[g>>2]);d=v[g+4>>2];f=v[g>>2];v[23296]=0;X(75,c+32|0,b|0,f|0,d|0);b=v[23296];v[23296]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=w[g+16|0];d=v[g+12>>2];v[23296]=0;X(76,c+48|0,c+32|0,d|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break i}v[23296]=0;R(70,a|0,c+48|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}zb(c+48|0);zb(c+32|0);zb(c+16|0);zb(c);jb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;zb(c+48|0)}zb(c+32|0)}zb(c+16|0);zb(c);S(a|0);L()}jb=e+32|0}function Rv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;t[e+24|0]=44;v[e+16>>2]=-1;v[e+20>>2]=0;v[e+8>>2]=c;v[e+12>>2]=d;c=jb+-64|0;jb=c;g=e+8|0;i=v[g>>2]&2?16:10;f=jb-32|0;jb=f;d=Je(f+16|0,1,0);a:{b:{c:{while(1){h=tc(d);SI(f+8|0,h,Fb(d)+h|0,w[b|0],i);if(!v[f+12>>2]){break c}h=Hf(Fb(d));v[23296]=0;R(58,d|0,h|0);h=v[23296];v[23296]=0;if((h|0)!=1){continue}break}break b}b=v[f+8>>2];i=tc(d);v[23296]=0;R(59,d|0,b-i|0);b=v[23296];v[23296]=0;d:{if((b|0)!=1){v[23296]=0;R(71,c|0,d|0);b=v[23296];v[23296]=0;if((b|0)!=1){break d}break b}break b}yb(d);jb=f+32|0;break a}a=P()|0;O()|0;yb(d);S(a|0);L()}b=c+16|0;fs(b,c,v[g>>2]);d=v[g+4>>2];f=v[g>>2];v[23296]=0;X(75,c+32|0,b|0,f|0,d|0);b=v[23296];v[23296]=0;e:{f:{g:{h:{i:{if((b|0)!=1){b=w[g+16|0];d=v[g+12>>2];v[23296]=0;X(76,c+48|0,c+32|0,d|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break i}v[23296]=0;R(70,a|0,c+48|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}zb(c+48|0);zb(c+32|0);zb(c+16|0);zb(c);jb=c- -64|0;break e}a=P()|0;O()|0;break f}a=P()|0;O()|0;break g}a=P()|0;O()|0;zb(c+48|0)}zb(c+32|0)}zb(c+16|0);zb(c);S(a|0);L()}jb=e+32|0}function $8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;j=jb-32|0;jb=j;e=b;b=v[a>>2];f=B(Ls(e,Eb(b)),6)+b|0;a:{if(!c){break a}b=v[Gb(a)>>2];g=v[a+4>>2];if((b-g|0)/6>>>0>=c>>>0){b=c;e=(g-f|0)/6|0;if(e>>>0<c>>>0){MA(a,c-e|0,d);b=e;if((f|0)==(g|0)){break a}}k=jb-16|0;jb=k;m=v[a+4>>2];h=B((m-(B(c,6)+f|0)|0)/6|0,6)+f|0;l=oq(k,a,(g-h|0)/6|0);i=v[l+4>>2];e=h;while(1){if(e>>>0>=g>>>0){lc(l);if((f|0)!=(h|0)){e=h-f|0;aj(m+B((e|0)/-6|0,6)|0,f,e)}jb=k+16|0}else{Xt(i,e);i=i+6|0;v[l+4>>2]=i;e=e+6|0;continue}break}e=f;a=B(e>>>0<=d>>>0?y[a+4>>2]>d>>>0?c:0:0,6)+d|0;while(1){if(b){c=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[e|0]=c;t[e+1|0]=c>>>8;t[e+2|0]=c>>>16;t[e+3|0]=c>>>24;c=w[a+4|0]|w[a+5|0]<<8;t[e+4|0]=c;t[e+5|0]=c>>>8;b=b-1|0;e=e+6|0;continue}break}break a}b=Gb(a);e=QS(j+8|0,IA(a,ck(v[a>>2],g)+c|0),(f-v[a>>2]|0)/6|0,b);PS(e,c,d);b=v[e+4>>2];d=e+4|0;NS(v[a>>2],f,d);h=v[a+4>>2];c=e+8|0;while(1){if((f|0)!=(h|0)){Xt(v[c>>2],f);v[c>>2]=v[c>>2]+6;f=f+6|0;continue}break}oc(a,d);oc(a+4|0,c);oc(Gb(a),zc(e));v[e>>2]=v[e+4>>2];f=b;OS(e)}Eb(f);jb=j+32|0}function RA(a,b){a:{b:{switch((w[a+3|0]|64)+-64|0){case 0:t[a+3|0]=w[a+5|0]?37:0;return;case 1:t[a+3|0]=16;return;case 2:t[a+3|0]=12;return;case 3:t[a+3|0]=14;if(b){break a}b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 4:t[a+3|0]=11;return;case 5:t[a+3|0]=3;return;case 6:t[a+3|0]=2;return;case 7:t[a+3|0]=4;return;case 8:t[a+3|0]=5;return;case 9:t[a+3|0]=18;return;case 10:t[a+3|0]=1;return;case 11:t[a+3|0]=7;return;case 12:t[a+3|0]=6;return;case 13:t[a+3|0]=21;return;case 14:t[a+3|0]=22;return;case 15:t[a+3|0]=10;return;case 16:t[a+3|0]=29;return;case 17:t[a+3|0]=15;return;case 18:t[a+3|0]=8;return;case 19:t[a+3|0]=20;return;case 20:t[a+3|0]=17;return;case 21:t[a+3|0]=26;return;case 22:t[a+3|0]=23;return;case 23:t[a+3|0]=24;return;case 24:t[a+3|0]=9;return;case 25:t[a+3|0]=27;return;case 26:t[a+3|0]=31;return;case 28:t[a+3|0]=b?32:31;return;case 29:t[a+3|0]=b?33:0;return;case 27:t[a+3|0]=b?34:0;return;case 30:t[a+3|0]=b?35:0;return;case 31:t[a+3|0]=b?36:0;return;case 50:t[a+3|0]=b?25:0;return;case 51:t[a+3|0]=b?30:0;return;default:break b}}t[a+3|0]=0}}function Vba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){h=v[f+8>>2];m=(((v[f+12>>2]&2147483647)<<1|h>>>31)&-2)+j|0;e=(h>>>16&65520)+b|0;n=u[e+14>>1];o=u[e+12>>1];p=u[e+10>>1];q=u[e+8>>1];r=u[e+6>>1];s=u[e+4>>1];w=u[e+2>>1];x=u[e>>1];h=0;while(1){if((h|0)!=2){e=h+m|0;v[(h<<2)+f>>2]=(((((((B(t[e-4|0],w)+B(t[e-6|0],x)|0)+B(t[e-2|0],s)|0)+B(t[e|0],r)|0)+B(t[e+2|0],q)|0)+B(t[e+4|0],p)|0)+B(t[e+6|0],o)|0)+B(t[e+8|0],n)<<8)/32768;h=h+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[f>>2],l);v[c+4>>2]=v[c+4>>2]+B(v[f+4>>2],k);Sb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;jb=f+16|0}function n2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;b=jb+-64|0;jb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;tf(b+48|0,b+32|0,d);a=v[c+4>>2];d=v[a+8>>2];e=v[a+4>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;a=jb-32|0;jb=a;a:{b:{c:{d:{h=v[b+4>>2];if(h>>>0>=e>>>0){if(y[b+20>>2]<e>>>0){break d}if(d>>>0>y[b+8>>2]){break c}i=v[b+28>>2];if(Xe(v[b+24>>2],i)>>>0<d>>>0){break b}k=v[b+16>>2];l=v[b>>2];e:while(1){c=0;if((d|0)==(f|0)){break a}while(1)if((c|0)==(e|0)){f=f+1|0;continue e}else{m=a,n=A[Pg(l,h,c,f)>>3],A[m+24>>3]=n;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;j=ge(A[zg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(j)<2147483648){g=~~j;break f}g=-2147483648}g=Xc(g);m=xn(k,i,c,f),o=g,u[m>>1]=o;c=c+1|0;continue}}}aa(7150,8947,77,8627);L()}aa(7115,8947,78,8627);L()}aa(5858,8947,79,8627);L()}aa(5828,8947,80,8627);L()}jb=a+32|0;jb=b- -64|0}function t7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=0,p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=0,x=0,y=0,A=C(0);i=v[a+44>>2];h=Fc(i,0);i=Fc(i,1);j=v[a+56>>2];n=Fc(j,0);j=Fc(j,1);k=a+4208|0;g=wc(v[k>>2],v[a+4212>>2]);o=B(v[v[a+16>>2]+1074404>>2],w[a+4233|0]);e=o<<1;if(g>>>0<e>>>0){Qj(k,e)}l=w[a+4232|0];a:{if(l){e=v[a+4220>>2];k=v[a+4208>>2];u=l-1|0;l=0;while(1){if((d|0)==(l|0)){break a}r=z[i>>2];e=e>>>0<o>>>0?e:0;g=e-o|0;g=((g|0)<0?e:g)<<1;x=Db(k,g);f=z[Db(k,g|1)>>2];s=z[h>>2];t=z[x>>2];p=C(s+t);z[n>>2]=p;q=C(r+f);z[j>>2]=q;f=C(0);m=C(0);b:{c:{switch(u|0){case 0:f=z[a+4224>>2];m=C(q*f);f=C(p*f);break b;case 1:case 2:f=z[a+4224>>2];m=C(p*f);f=C(q*f);break b;case 3:break c;default:break b}}f=C(C(C(C(s+r)*C(.5))+t)*z[a+4224>>2]);m=f}j=j+4|0;n=n+4|0;i=i+4|0;h=h+4|0;g=e<<1;y=Db(k,g),A=C(D(f))<C(10000000195414814e-40)?C(0):f,z[y>>2]=A;y=Db(k,g|1),A=C(D(m))<C(10000000195414814e-40)?C(0):m,z[y>>2]=A;e=e+1|0;v[a+4220>>2]=e;l=l+1|0;continue}}e=h;h=d<<2;ch(e,e+h|0,n);ch(i,i+h|0,j)}h=a;a=v[a+56>>2];ji(h,b,c,Fc(a,0),Fc(a,1),d)}function TM(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=jb-16|0;jb=g;f=B(b,872)+a|0;a:{if(c){Bb(g+8|0,a+1074312|0,90);if(!Cb(v[v[g+8>>2]>>2],v[g+12>>2])){t[(B(b,872)+a|0)+1075804|0]=c}t[(B(b,872)+a|0)+1075803|0]=c;break a}c=w[f+1075803|0]}f=f+1074992|0;h=c&255;e=a+480180|0;i=!(v[e>>2]&204473357)&(d^-1);NM(a,b,h,i);e=v[e>>2];b:{c:{if((e|0)!=268435456){if((e|0)!=16777216){break c}j=v[(B(b,872)+a|0)+1075648>>2];if(!j|!v[j+44>>2]){break c}b=c&255;if(!(b>>>0<240|d)){MM(v[a+1074392>>2],v[a+1074416>>2],f,h-240|0);break b}if(!(b>>>0<224|d)){LM(f,h-224|0);break b}JM(f,h);break b}v[(B(b,872)+a|0)+1075700>>2]=1}d:{if(!((c&255)>>>0>223&i)){break d}e:{d=h&15;if(!d){break e}c=c&240;if((c|0)!=224){if((c|0)!=240){break e}yy(a,f,d);break b}if((e|0)==524288){break d}OM(a,f,d);break b}if((e|0)!=524288){break b}}f:{if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break f}if(v[a+1074416>>2]==1){Bb(g+8|0,a+1074312|0,6);if(Cb(v[v[g+8>>2]>>2],v[g+12>>2])){break f}e=v[a+480180>>2]}if(e&32832){break f}if(!(v[a+480208>>2]&2)|(e|0)!=8){break b}}Rj(a,f,(B(b,872)+a|0)+1075692|0,h<<2,0)}jb=g+16|0}function dX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;f=Qb(a);a=0;a:{b:{c:{d:{e:{while(1){if((Fv(b,c,a)|0)==-1){break b}e=Fv(b,c,a);v[23296]=0;X(110,d|0,b|0,a|0,e-a|0);e=v[23296];v[23296]=0;if((e|0)!=1){v[23296]=0;R(111,d+16|0,d|0);e=v[23296];v[23296]=0;if((e|0)==1){break e}v[23296]=0;R(112,f|0,d+16|0);e=v[23296];v[23296]=0;if((e|0)==1){break d}zb(d+16|0);zb(d);a=Fv(b,c,a)+tl(v[c+4>>2],w[c+11|0])|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;zb(d+16|0)}zb(d);break a}f:{g:{h:{i:{j:{k:{if(uc(v[f>>2],v[f+4>>2])){v[23296]=0;X(110,d+16|0,b|0,a|0,-1);c=v[23296];v[23296]=0;if((c|0)==1){break j}c=tl(v[d+20>>2],w[d+27|0]);zb(d+16|0);if(!c){break k}}v[23296]=0;X(110,d|0,b|0,a|0,-1);a=v[23296];v[23296]=0;if((a|0)==1){break i}v[23296]=0;R(111,d+16|0,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}v[23296]=0;R(112,f|0,d+16|0);a=v[23296];v[23296]=0;if((a|0)==1){break g}zb(d+16|0);zb(d)}jb=d+32|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break a}a=P()|0;O()|0;break f}a=P()|0;O()|0;zb(d+16|0)}zb(d)}xl(f);S(a|0);L()}function $6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=C(0),f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=C(0),t=0,u=0,w=0,x=0,y=0,A=C(0);a:{j=v[a+4272>>2];if(!j){break a}if(!Vh(a+44|0)){break a}f=v[a+44>>2];l=Fc(f,0);m=Fc(f,1);u=v[a+4252>>2]-1|0;i=v[a+4268>>2];k=v[a+4256>>2];n=d;f=v[a+56>>2];q=Fc(f,0);o=q;r=Fc(f,1);p=r;while(1){if(n){e=z[m>>2];f=i<<1;h=Db(k,f);g=z[l>>2];z[h>>2]=g;y=Db(k,f|1),A=e,z[y>>2]=A;s=z[a+4276>>2];e=C(C(D(BK(C(C(C(D(g))+C(D(e)))*C(536870912)),31,5)))*C(4.656612873077393e-10));e=C(C(C(s-e)*z[(e>=s?4236:4240)+a>>2])+e);z[a+4276>>2]=e;g=z[a+4244>>2];e=C(C(C(C(g-(e<g?g:e))*z[a+4248>>2])+C(.9999998807907104))*C(2147483648));b:{if(e<C(4294967296)&e>=C(0)){f=~~e>>>0;break b}f=0}t=((((i<<12)+u|0)+j|0)/4096|0)%(j|0)<<1;g=z[Db(k,t)>>2];h=f<<5;w=h;x=h|-2147483648;h=f>>>0<67108864;e=C(z[a+4232>>2]*C(C((h?w:x)>>>(h?31:32-(f>>>26|0)|0)>>>0)*C(4.656612873077393e-10)));z[o>>2]=g*e;y=p,A=C(z[Db(k,t|1)>>2]*e),z[y>>2]=A;i=((i?0:j)+i|0)-1|0;v[a+4268>>2]=i;n=n-1|0;p=p+4|0;o=o+4|0;m=m+4|0;l=l+4|0;continue}else{ji(a,b,c,q,r,d)}break}}}function e2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=jb+-64|0;jb=b;c=v[a>>2];a=v[c>>2];d=v[a+4>>2];v[b+40>>2]=v[a+20>>2];e=v[a+16>>2];v[b+32>>2]=v[a+12>>2];v[b+36>>2]=e;tf(b+48|0,b+32|0,d);a=v[c+4>>2];e=v[a+8>>2];h=v[a+4>>2];c=v[b+60>>2];v[b+24>>2]=v[b+56>>2];v[b+28>>2]=c;c=v[b+52>>2];v[b+16>>2]=v[b+48>>2];v[b+20>>2]=c;v[b+8>>2]=v[a+8>>2];c=v[a+4>>2];v[b>>2]=v[a>>2];v[b+4>>2]=c;d=b+16|0;a=jb-32|0;jb=a;a:{b:{c:{d:{i=v[b+4>>2];if(i>>>0>=h>>>0){if(y[d+4>>2]<h>>>0){break d}if(y[b+8>>2]<e>>>0){break c}if(Xe(v[d+8>>2],v[d+12>>2])>>>0<e>>>0){break b}k=v[b>>2];e:while(1){c=0;if((e|0)==(f|0)){break a}while(1)if((c|0)==(h|0)){f=f+1|0;continue e}else{l=a,m=A[Pg(k,i,c,f)>>3],A[l+24>>3]=m;v[a+16>>2]=0;v[a+20>>2]=-1074790400;v[a+8>>2]=0;v[a+12>>2]=1072693248;j=ge(A[zg(a+24|0,a+16|0,a+8|0)>>3]*32768);f:{if(D(j)<2147483648){g=~~j;break f}g=-2147483648}g=Xc(g);l=wn(d,c,f),n=g,u[l>>1]=n;c=c+1|0;continue}}}aa(7150,8947,77,8627);L()}aa(7115,8947,78,8627);L()}aa(5858,8947,79,8627);L()}aa(5828,8947,80,8627);L()}jb=a+32|0;jb=b- -64|0}function tha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-48|0;jb=d;i=a+484344|0;j=a+480280|0;while(1){a:{if(Ob(v[b>>2],v[b+8>>2],9)){e=d+44|0;no(b,e);c=qg(b);b:{if(!Pb(e,13840,4)){break b}if(!Pb(d+44|0,13496,4)){break b}if(!Pb(d+44|0,13672,4)){break b}if(!Pb(d+44|0,13677,4)){break b}if(Ob(v[b>>2],v[b+8>>2],c)){break a}}ng(b,8)}jb=d+48|0;return k|0}Yd(d,b,c);e=jc(d+24|0,d);Ab(d);c=j;c:{d:{e:{if(!Pb(d+44|0,13407,4)){while(1){if((c|0)==(i|0)){break c}v[23296]=0;f=T(145,e|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break e}t[c+8|0]=f;c=c+32|0;continue}}if(w[d+44|0]!=70){break d}f=w[d+45|0];h=(f|0)==88;f:{if(!h){if((f-48&255)>>>0>9){break d}c=t[d+46|0];if((c|0)>47){break f}break d}c=t[d+46|0];if((c|0)<48){break d}}if(c>>>0>57){break d}g=t[d+47|0];if((g|0)<48|(g|0)>57){break d}c=(g+(h?-16:B(f,100)+48|0)|0)+B(c,10)&255;if(c>>>0>249){break c}v[23296]=0;R(386,e|0,(B(c,160)+a|0)+906300|0);c=v[23296];v[23296]=0;if((c|0)!=1){break c}}a=P()|0;O()|0;Ab(e);S(a|0);L()}if(Pb(d+44|0,13423,4)){break c}v[a+1074308>>2]=0;k=1}Ab(e);continue}}function BM(a){var b=0,c=0,d=0,e=0,f=0,g=0;while(1){if((f|0)!=4e3){g=jb-32|0;jb=g;b=ot(g);d=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);c=(f<<5)+a|0;e=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[c|0]=e;t[c+1|0]=e>>>8;t[c+2|0]=e>>>16;t[c+3|0]=e>>>24;t[c+4|0]=d;t[c+5|0]=d>>>8;t[c+6|0]=d>>>16;t[c+7|0]=d>>>24;d=w[b+28|0]|w[b+29|0]<<8|(w[b+30|0]<<16|w[b+31|0]<<24);e=w[b+24|0]|w[b+25|0]<<8|(w[b+26|0]<<16|w[b+27|0]<<24);t[c+24|0]=e;t[c+25|0]=e>>>8;t[c+26|0]=e>>>16;t[c+27|0]=e>>>24;t[c+28|0]=d;t[c+29|0]=d>>>8;t[c+30|0]=d>>>16;t[c+31|0]=d>>>24;d=w[b+20|0]|w[b+21|0]<<8|(w[b+22|0]<<16|w[b+23|0]<<24);e=w[b+16|0]|w[b+17|0]<<8|(w[b+18|0]<<16|w[b+19|0]<<24);t[c+16|0]=e;t[c+17|0]=e>>>8;t[c+18|0]=e>>>16;t[c+19|0]=e>>>24;t[c+20|0]=d;t[c+21|0]=d>>>8;t[c+22|0]=d>>>16;t[c+23|0]=d>>>24;d=w[b+12|0]|w[b+13|0]<<8|(w[b+14|0]<<16|w[b+15|0]<<24);b=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[c+8|0]=b;t[c+9|0]=b>>>8;t[c+10|0]=b>>>16;t[c+11|0]=b>>>24;t[c+12|0]=d;t[c+13|0]=d>>>8;t[c+14|0]=d>>>16;t[c+15|0]=d>>>24;jb=g+32|0;f=f+1|0;continue}break}}function pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0;g=jb-16|0;jb=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];u=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Sia(r,s,e,e>>31);i=mb;f=Yb(f,-16777216,16776704);h=Sia(p,q,f,f>>31);e=h+e|0;f=mb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=v[g+12>>2]+l|0;e=t[h|0];z=i;i=((B(t[h+1|0]-e|0,v[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=Sia(e,e>>31,u,w);e=z+h|0;f=mb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;k=k+n|0;v[c>>2]=B(e,k>>12)+v[c>>2];j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Sb(g+8|0,x,y);e=f-(i&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=j>>12;jb=g+16|0}function UH(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=C(0),p=0;a:{if(w[b+21|0]){p=B(d,g);j=v[e>>2];l=v[f>>2];m=v[b>>2];b:{while(1){if((h|0)>0){if(v[a+1396>>2]<=9){Gk(a)}g=v[a+1392>>2];k=u[(((g&1023)<<1)+b|0)+36>>1];c:{if((k|0)>=0){i=g;k=k&65535;g=w[k+v[b+8>>2]|0];v[a+1392>>2]=i>>>g;g=v[a+1396>>2]-g|0;v[a+1396>>2]=(g|0)>0?g:0;k=(g|0)>=0?k:-1;break c}k=Jl(a,b)}if((k|0)>=v[b+2092>>2]?w[b+23|0]:0){break a}if((k|0)<0){if(!w[a+1376|0]){b=0;if(v[a+1384>>2]){break b}}bc(a,21);return 0}g=0;n=B(d,l);m=((m+n|0)+j|0)>(p|0)?(p-n|0)+j|0:m;n=(m|0)>0?m:0;k=B(k,v[b>>2]);o=C(0);d:{if(w[b+22|0]){while(1){if((g|0)==(n|0)){break d}o=C(o+z[v[b+28>>2]+(g+k<<2)>>2]);i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=o+z[i>>2]}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}while(1){if((g|0)==(n|0)){break d}i=v[(j<<2)+c>>2];if(i){i=i+(l<<2)|0;z[i>>2]=z[i>>2]+C(z[v[b+28>>2]+(g+k<<2)>>2]+C(0))}j=j+1|0;i=(j|0)==(d|0);j=i?0:j;g=g+1|0;l=i+l|0;continue}}h=h-m|0;continue}break}v[e>>2]=j;v[f>>2]=l;b=1}return b}bc(a,21);return 0}aa(7470,13048,1887,6512);L()}function DN(a,b){var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{b:{switch(w[a+480224|0]-1|0){default:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2]<<1;c=Sia(c,c>>31,5e4,0);e=mb;b=v[Yc(d+12|0,d+8|0)>>2];c=Ic(Tia(c,e,b,b>>31),mb);break a;case 0:c=v[a+24620>>2];v[d+12>>2]=1;v[d+8>>2]=v[b+44>>2];c=Sia(c,c>>31,1e4,0);e=mb;b=v[Yc(d+12|0,d+8|0)>>2];c=Ic(Tia(c,e,b,b>>31),mb);break a;case 1:break b}}f=60/(+y[b+44>>2]/1e4*(+(Sia(v[b+32>>2],0,v[b+40>>2],0)>>>0)+ +(mb>>>0)*4294967296))*+y[a+24620>>2];c:{d:{c=v[a+484344>>2];e=x[b+70>>1];if(!oe(c,v[a+484348>>2],e)){break d}c=$b(c,e);if(!Rb(v[c+24>>2],v[c+28>>2])){break d}c=c+24|0;break c}c=a+480248|0}e=v[c>>2];c=v[c+4>>2];if(!uc(e,c)){f=f*+y[Db(e,y[b+48>>2]%(wc(e,c)>>>0)|0)>>2]*5.960464477539063e-8}e:{if(D(f)<2147483648){c=~~f;break e}c=-2147483648}f=A[b+8>>3]+(f-+(c>>>0));A[b+8>>3]=f;if(f>=1){A[b+8>>3]=f+-1;c=c+1|0;break a}if(!(A[a+1074384>>3]<=-1)){break a}A[b+8>>3]=f+1;c=c-1|0}b=Sia(v[a+480244>>2],0,c,0)+32768|0;a=mb;a=b>>>0<32768?a+1|0:a;a=Vc((a&65535)<<16|b>>>16,a>>>16|0);jb=d+16|0;return a?a:1}function K8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=C(0);h=u[d>>1];j=u[d+2>>1];a:{if((h|0)>(j|0)){break a}k=v[b>>2];g=wc(k,v[b+4>>2]);if(!g){break a}i=u[e>>1];if((i|0)<(h|0)|(i|0)>(j|0)|(g-1&65535)>>>0>(j-i&65535)>>>0|y[a+36>>2]>65535){break a}b:{while(1){if((f|0)==(g|0)){break b}i=Db(k,f);f=f+1|0;if(!(z[i>>2]<C(0))){continue}break}return 0}i=(f|0)!=(g|0);f=0;if(i){break a}l=z[c>>2];if(l<=C(0)){break a}u[a+28>>1]=h;u[a>>1]=1;m=a,n=tL(g),u[m+30>>1]=n;z[a+32>>2]=D(l);Qj(a+4|0,(j-h|0)+1|0);ch(Eb(v[b>>2]),Eb(v[b+4>>2]),cm(Eb(v[a+4>>2]),u[e>>1]-u[d>>1]|0));c=v[a+4>>2];g=u[a+30>>1];h=u[a+28>>1];b=u[e>>1];f=b;while(1){if((b&65535)!=32768&(f|0)>(h|0)){f=f-1|0;b=f-h|0;j=Db(c,b+g|0);m=Db(c,b),o=C(z[j>>2]/z[a+32>>2]),z[m>>2]=o;b=u[e>>1];continue}else{c=u[a+30>>1];e=u[a+28>>1];h=c+e|0;f=g;g=b<<16>>16;f=f+g|0;b=v[a+4>>2];d=u[d+2>>1];c=(g|0)<=(32767-c|0);while(1){if(c&(d|0)>=(f|0)){g=Db(b,f-h|0);m=Db(b,f-e|0),o=C(z[a+32>>2]*z[g>>2]),z[m>>2]=o;f=f+1|0;continue}else{rp(a)}break}}break}f=1}return f|0}function o_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;a=jb-160|0;jb=a;v[a+144>>2]=c;v[a+152>>2]=b;v[a+20>>2]=1106;b=le(a+24|0,a+32|0,a+20|0);h=a+16|0;bd(h,e);v[23296]=0;h=T(18,h|0)|0;i=v[23296];v[23296]=0;if((i|0)!=1){a:{t[a+15|0]=0;e=v[e+4>>2];v[23296]=0;c=pa(1107,a+152|0,c|0,d|0,a+16|0,e|0,f|0,a+15|0,h|0,b|0,a+20|0,a+132|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}b:{c:{if(!c){break c}Nf(g);if(w[a+15|0]){v[23296]=0;c=Q(19,h|0,45)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}v[23296]=0;R(46,g|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break a}}v[23296]=0;d=Q(19,h|0,48)|0;c=v[23296];v[23296]=0;if((c|0)==1){break b}e=v[a+20>>2];h=e-1|0;c=v[b>>2];d=d&255;while(1){if(!((d|0)!=w[c|0]|c>>>0>=h>>>0)){c=c+1|0;continue}break}v[23296]=0;W(1113,g|0,c|0,e|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break c}break a}v[23296]=0;c=Q(1074,a+152|0,a+144|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}if(c){v[f>>2]=v[f>>2]|2}c=v[a+152>>2];_b(a+16|0);Qc(b);jb=a+160|0;return c|0}}}c=P()|0;O()|0;_b(a+16|0);Qc(b);S(c|0);L()}function oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;g=jb-16|0;jb=g;f=v[a+48>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+32>>2];n=v[a+28>>2];o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];t=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Sia(r,s,e,e>>31);i=mb;f=Yb(f,-16777216,16776704);h=Sia(p,q,f,f>>31);e=h+e|0;f=mb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=(v[g+12>>2]<<1)+l|0;e=u[h>>1];z=i;i=e+((B(u[h+2>>1]-e|0,v[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=Sia(e,e>>31,t,w);e=z+h|0;f=mb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;k=k+n|0;v[c>>2]=B(e,k>>12)+v[c>>2];j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(j>>12,e);Sb(g+8|0,x,y);e=f-(i&o)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=j>>12;jb=g+16|0}function My(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-16|0;jb=e;f=a+1074312|0;Bb(e+8|0,f,77);a:{if(j=Cb(v[v[e+8>>2]>>2],v[e+12>>2]),k=0,l=v[c+88>>2]&134218752,l?j:k){break a}b:{c:{if(d){g=w[c+841|0];if(!g){break c}d=g-1|0;t[c+841|0]=d;if(d&255){break b}Bb(e+8|0,f,16);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])&v[a+480180>>2]!=2){break a}a=v[b+48>>2]+1|0}else{a=v[b+48>>2]}v[c+764>>2]=a;break a}Bb(e+8|0,f,17);d:{if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])|v[a+480180>>2]&3){break d}g=b+616|0;i=x[a+480188>>1];while(1){if((h&65535)>>>0>=i>>>0){break d}if(w[g+841|0]?(c|0)!=(g|0):0){break a}g=g+872|0;h=h+1|0;continue}}t[c+841|0]=d}d=v[c+764>>2];v[b+56>>2]=d;e:{if((d|0)==-1){break e}f:{if(v[b+60>>2]==-1){break f}Bb(e+8|0,f,68);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break f}v[b+60>>2]=d}v[b+64>>2]=d;Bb(e+8|0,f,103);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break e}u[b+68>>1]=65535}if(v[a+480180>>2]!=2){break a}d=x[a+480188>>1];a=0;while(1){if((a|0)==(d|0)){break a}f=B(a,872)+b|0;v[f+1380>>2]=v[c+764>>2];t[f+1457|0]=w[c+841|0];a=a+1|0;continue}}jb=e+16|0}function FQ(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-80|0;jb=c;v[c+72>>2]=0;v[c+76>>2]=0;b=c- -64|0;v[b>>2]=0;v[b+4>>2]=0;v[c+56>>2]=0;v[c+60>>2]=0;v[c+48>>2]=0;v[c+52>>2]=0;zz(a,Az(a),c+48|0);b=rc(c+40|0,14033);Ye(pe(a,0),v[b>>2],v[b+4>>2]);b=rc(c+32|0,14137);Ye(pe(a,1),v[b>>2],v[b+4>>2]);b=rc(c+24|0,5457);Ye(pe(a,3),v[b>>2],v[b+4>>2]);b=rc(c+16|0,15525);Ye(pe(a,4),v[b>>2],v[b+4>>2]);b=rc(c+8|0,9167);Ye(pe(a,8),v[b>>2],v[b+4>>2]);e=pe(a+288|0,0);b=jb-16|0;jb=b;d=e;e=rc(b+8|0,4893);Ye(d,v[e>>2],v[e+4>>2]);jb=b+16|0;e=a+800|0;b=0;a=jb-80|0;jb=a;a:{b:{while(1){if((b|0)==128){break a}v[a+76>>2]=b<<3;c:{d:{if(b>>>0<=15){tu(a+32|0,4045);v[23296]=0;R(274,a+16|0,a+76|0);d=v[23296];v[23296]=0;if((d|0)==1){break c}v[23296]=0;U(275,a+48|0,a+32|0,a+16|0);d=v[23296];v[23296]=0;if((d|0)!=1){d=a+48|0;ve(a- -64|0,d);Ye(pe(e,b),v[a+64>>2],v[a+68>>2]);yb(d);yb(a+16|0);Tb(a+32|0);break d}b=P()|0;O()|0;yb(a+16|0);break b}d=rc(a+8|0,21473);Ye(pe(e,b),v[d>>2],v[a+12>>2])}b=b+1|0;continue}break}b=P()|0;O()|0}Tb(a+32|0);S(b|0);L()}jb=a+80|0;jb=c+80|0}function PH(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-208|0;jb=d;v[d+8>>2]=1;v[d+12>>2]=0;h=b<<2;a:{if(!h){break a}v[d+16>>2]=4;v[d+20>>2]=4;b=4;g=4;e=2;while(1){f=b;b=(b+g|0)+4|0;v[(d+16|0)+(e<<2)>>2]=b;e=e+1|0;g=f;if(b>>>0<h>>>0){continue}break}f=(a+h|0)-4|0;b:{if(f>>>0<=a>>>0){e=1;b=1;f=0;break b}e=1;b=1;while(1){c:{if((e&3)==3){Sw(a,c,b,d+16|0);$r(d+8|0,2);b=b+2|0;break c}g=b-1|0;d:{if(y[(d+16|0)+(g<<2)>>2]>=f-a>>>0){_r(a,c,e,v[d+12>>2],b,0,d+16|0);break d}Sw(a,c,b,d+16|0)}if((b|0)==1){Zr(d+8|0,1);b=0;break c}Zr(d+8|0,g);b=1}e=v[d+8>>2]|1;v[d+8>>2]=e;a=a+4|0;if(f>>>0>a>>>0){continue}break}f=v[d+12>>2]}_r(a,c,e,f,b,0,d+16|0);e=v[d+8>>2];g=v[d+12>>2];if(!(g?1:(b|0)!=1|(e|0)!=1)){break a}while(1){e:{if((b|0)<=1){f=IH(e,g);$r(d+8|0,f);b=b+f|0;break e}g=d+8|0;Zr(g,2);v[d+8>>2]=v[d+8>>2]^7;$r(g,1);h=a-4|0;e=d+16|0;f=b-2|0;_r(h-v[e+(f<<2)>>2]|0,c,v[d+8>>2],v[d+12>>2],b-1|0,1,e);Zr(g,1);b=v[d+8>>2]|1;v[d+8>>2]=b;_r(h,c,b,v[d+12>>2],f,1,e);b=f}a=a-4|0;g=v[d+12>>2];e=v[d+8>>2];if(g|((b|0)!=1|(e|0)!=1)){continue}break}}jb=d+208|0}function $n(a,b,c,d){var e=0;e=jb-16|0;jb=e;t[a+841|0]=0;v[a+708>>2]=0;t[a+797|0]=0;v[a+764>>2]=0;u[a+802>>1]=0;u[a+804>>1]=0;v[a+696>>2]=0;v[a+668>>2]=0;v[a+88>>2]=v[a+88>>2]|6144;Bb(e+8|0,b+1074312|0,23);if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){t[a+807|0]=1;t[a+808|0]=0}t[a+846|0]=0;t[a+839|0]=0;u[a+774>>1]=0;t[a+850|0]=255;v[a+660>>2]=0;t[a+851|0]=w[a+851|0]&224;fo(a+788|0);v[a+84>>2]=0;v[a+76>>2]=0;v[a+80>>2]=0;v[a+700>>2]=0;v[a+656>>2]=0;v[a+104>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;t[a+845|0]=0;t[a+838|0]=0;t[a+821|0]=0;v[a+688>>2]=0;v[a+672>>2]=0;v[a+676>>2]=0;u[a+836>>1]=32512;t[a+819|0]=0;t[a+820|0]=0;u[a+842>>1]=0;v[a+28>>2]=0;v[a+32>>2]=0;v[a+20>>2]=0;v[a+24>>2]=0;v[a+852>>2]=0;v[a+856>>2]=0;t[a+851|0]=w[a+851|0]&159;a:{if(c>>>0<=126){b=(c<<5)+b|0;c=v[b+480280>>2];v[a+88>>2]=c;v[a+692>>2]=x[b+480284>>1];v[a+748>>2]=x[b+480286>>1];if(!(c&1024)){break a}v[a+88>>2]=c&-1025|d;break a}v[a+748>>2]=64;v[a+692>>2]=128;v[a+88>>2]=0}u[a+784>>1]=0;t[a+795|0]=0;t[a+796|0]=0;jb=e+16|0}function WN(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=jb-32|0;jb=f;n=dz(v[a+24>>2],w[a+32|0]);o=lj(n);a:{while(1){b:{u[b>>1]=m;d=m&65535;if(d>>>0>=o>>>0){break b}c:{if(!rq(n,d)){break c}d=v[a>>2];h=wd(d,v[a+4>>2]);e=x[b>>1];if(h>>>0<=e>>>0){v[c>>2]=0;break a}k=Hd(d,e);$k(f+16|0,v[k>>2]);gm(f+8|0,v[k>>2],v[k+4>>2]);i=f+24|0;d=v[f+16>>2];g=v[f+20>>2];e=_k(v[f+8>>2],v[f+12>>2],d,g);j=jb-16|0;jb=j;v[j+12>>2]=e;d:{if(g){h=32-g|0;v[j+8>>2]=h;l=h;h=v[Ib(j+8|0,j+12|0)>>2];l=-1<<g&-1>>>l-h&v[d>>2];if(l){gc(i,d,Ria(l));break d}if((e|0)==(h|0)){v[i>>2]=d;v[i+4>>2]=g;tP(i,e);break d}e=e-h|0;d=d+4|0}while(1){if(e>>>0>=32){g=v[d>>2];if(g){gc(i,d,Ria(g));break d}else{e=e-32|0;v[j+12>>2]=e;d=d+4|0;continue}}break}if(!e){gc(i,d,0);break d}g=v[d>>2]&-1>>>32-e;if(!g){gc(i,d,e);break d}gc(i,d,Ria(g))}jb=j+16|0;gm(f,v[k>>2],v[k+4>>2]);if(!(v[f+24>>2]==v[f>>2]&v[f+28>>2]==v[f+4>>2])){break c}v[c>>2]=0;break a}m=x[b>>1]+1|0;continue}break}u[b>>1]=65535;v[c>>2]=-1}jb=f+32|0;return(m&65535)>>>0<o>>>0|0}function H7(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=C(0),h=0,i=0;c=jb-32|0;jb=c;a:{d=v[a+20>>2];b:{if(!d){break b}v[d+148>>2]=-1;h=c,i=nb[v[v[a>>2]+40>>2]](a)|0,v[h+16>>2]=i;v[c+8>>2]=1073741822;f=v[Ib(c+16|0,c+8|0)>>2];b=f<<2;if(!b){break b}e=v[a+20>>2];d=0;v[23296]=0;R(272,e+4|0,b+4|0);b=v[23296];v[23296]=0;c:{d:{if((b|0)!=1){b=v[a+20>>2];ke(c+8|0,v[b+4>>2],v[b+8>>2]);v[c>>2]=0;v[c+4>>2]=0;e=v[c+12>>2];b=c+16|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=e;e=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=e;e=jb-16|0;jb=e;v[e+8>>2]=0;TK(b,e+8|0);jb=e+16|0;b=v[v[a>>2]+180>>2];v[23296]=0;R(b|0,a|0,-1);b=v[23296];v[23296]=0;if((b|0)==1){break d}while(1){if((d|0)==(f|0)){d=v[v[a>>2]+184>>2];v[23296]=0;Y(d|0,a|0);d=v[23296];v[23296]=0;if((d|0)!=1){break b}break d}b=v[v[a>>2]+48>>2];v[23296]=0;g=C($a(b|0,a|0,d|0));b=v[23296];v[23296]=0;if((b|0)!=1){z[c+8>>2]=g;d=d+1|0;TK(c+16|0,c+8|0);continue}break}d=V(91780)|0;break c}d=V(91780)|0;break c}d=V(91780)|0}if((O()|0)!=(ea(91780)|0)){break a}_(d|0)|0;Hc(v[a+20>>2]+4|0);$()}jb=c+32|0;return}S(d|0);L()}function HU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=jb-32|0;jb=h;e=b;b=v[a>>2];b=(so(e,Eb(b))<<1)+b|0;a:{b:{f=v[a+4>>2];if(f>>>0<y[Gb(a)>>2]){if((b|0)!=(f|0)){break b}d=jb-16|0;jb=d;a=Fi(d,a,1);uq(v[a+4>>2],w[c|0]|w[c+1|0]<<8);v[a+4>>2]=v[a+4>>2]+2;lc(a);jb=d+16|0;break a}d=Gb(a);d=xj(h+8|0,yj(a,Nc(v[a>>2],f)+1|0),b-v[a>>2]>>1,d);v[23296]=0;R(279,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)!=1){c=v[d+4>>2];f=d+4|0;Op(v[a>>2],b,f);g=v[a+4>>2];e=d+8|0;while(1){if((b|0)!=(g|0)){uq(v[e>>2],w[b|0]|w[b+1|0]<<8);v[e>>2]=v[e>>2]+2;b=b+2|0;continue}break}oc(a,f);oc(a+4|0,e);oc(Gb(a),zc(d));v[d>>2]=v[d+4>>2];b=c;Gi(d);break a}a=P()|0;O()|0;Gi(d);S(a|0);L()}i=jb-16|0;jb=i;j=v[a+4>>2];e=(j-(b+2|0)|0)+b|0;k=Fi(i,a,f-e>>1);g=v[k+4>>2];d=e;while(1){if(d>>>0>=f>>>0){lc(k);while(1){if((b|0)!=(e|0)){e=e-2|0;j=wU(j-2|0,e);continue}break}jb=i+16|0}else{uq(g,w[d|0]|w[d+1|0]<<8);g=g+2|0;v[k+4>>2]=g;d=d+2|0;continue}break}a=((b>>>0<=c>>>0&y[a+4>>2]>c>>>0)<<1)+c|0;c=w[a|0];t[b+1|0]=w[a+1|0];t[b|0]=c}Eb(b);jb=h+32|0}function lba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-16|0;jb=e;p=v[a+16>>2];q=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){k=v[a+8>>2];m=v[a+12>>2];f=v[a>>2];b=v[a+4>>2];h=0;break a}b=v[a+12>>2];m=b;k=v[a+8>>2];n=bg(k,b,l);o=mb;h=v[a+76>>2];f=v[a>>2];b=v[a+4>>2];Ff(f,b,ff(k,m,d),mb);h=h>>>0<mb>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[e>>2]=f;v[e+4>>2]=b;b:while(1){if(d){d=d-1|0;v[e+8>>2]=f;v[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;f=(b<<1)+p|0;b=l;while(1)if((b|0)<=0){Sb(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Ld(g,u[f+(v[e+12>>2]<<1)>>1]/4<<16>>16);Kd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;f=$f(g,q);v[c>>2]=B(j>>12,f)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(f,i>>12);Sb(e,k,m);c=c+8|0;f=v[e>>2];b=v[e+4>>2];continue b}else{Ld(g,u[f+(v[e+12>>2]<<1)>>1]/4<<16>>16);Kd(g,4);Sb(e+8|0,n,o);b=b-1|0;continue}}break}v[a>>2]=f;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;jb=e+16|0}function Sba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){e=(v[f+12>>2]<<1)+l|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(u[e-4>>1],u[h+2>>1])+B(u[e-6>>1],u[h>>1])|0)+B(u[e-2>>1],u[h+4>>1])|0)+B(u[e>>1],u[h+6>>1])|0)+B(u[e+2>>1],u[h+8>>1])|0)+B(u[e+4>>1],u[h+10>>1])|0)+B(u[e+6>>1],u[h+12>>1])|0)+B(u[e+8>>1],u[h+14>>1])|0)/32768|0;k=k+n|0;v[c>>2]=v[c>>2]+B(e,k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(e,j>>12);Sb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;jb=f+16|0}function hP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0;i=jb-16|0;jb=i;if(oj(v[a+656>>2])){e=w[a+797|0];g=Uc(e);f=w[a+799|0];Bb(i+8|0,d+1074312|0,34);d=g?e:f;a:{if(!Cb(v[v[i+8>>2]>>2],v[i+12>>2])){break a}e=d&255;if(!e|e>>>0>120){break a}d=w[Lb(v[a+656>>2]+108|0,e-1|0)|0]}l=C(C(v[a+704>>2])*b);e=v[v[a+656>>2]+44>>2];f=((d&255)+c<<16)-3997696>>16;b:{c:{c=v[a+852>>2]+u[a+772>>1]|0;if(c){h=v[e+36>>2];if(h){break c}}b=Sl(e,c+f<<16>>16);break b}k=h+1|0;j=Qx(c,k);d=In(c,k);b=C(1);g=u[e+28>>1];c=f+j<<16>>16;d:{if((g|0)>(c|0)){break d}f=v[e+4>>2];if((c|0)>(wc(f,v[e+8>>2])+g<<16)-65536>>16){break d}if(!d){b=z[Db(f,c-g|0)>>2];break b}e:{f:{g:{switch(x[e>>1]-1|0){case 2:h=v[e+16>>2];if(!wc(h,v[e+20>>2])){break f}b=z[Db(h,d-1|0)>>2];break e;case 0:break g;default:break f}}j=v[e+16>>2];if(!wc(j,v[e+20>>2])){break f}b=z[Db(j,(d+B(h,In(c,x[e+30>>1])<<16>>16)|0)-1|0)>>2];break e}b=me(C(Sl(e,(c<<16)+65536>>16)/Sl(e,c)),C(C(d|0)/C(k|0)))}b=C(b*z[Db(f,c-g|0)>>2])}}m=a,n=Wj(C(C(l*b)*C(16))),v[m+700>>2]=n}jb=i+16|0}function d9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;pd(c,0);u[d+14>>1]=w[a+36|0]|w[a+37|0]<<8;u[d+12>>1]=32767;g=c,h=(x[Zc(d+14|0,d+12|0)>>1]<<8>>>0)/32767|0,u[g+28>>1]=h;u[d+10>>1]=w[a+38|0]|w[a+39|0]<<8;u[d+8>>1]=32767;g=c,h=(x[Zc(d+10|0,d+8|0)>>1]<<8>>>0)/32767|0,u[g+30>>1]=h;u[c+32>>1]=64;v[c>>2]=w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24);v[c+4>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[c+8>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[c+24>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);e=w[b+166|0];if(e>>>0<=4){t[c+38|0]=w[e+42714|0]}e=w[b+167|0]|w[b+168|0]<<8;t[c+39|0]=e;f=(w[b+171|0]|w[b+172|0]<<8)>>>4|0;t[c+41|0]=f;b=(w[b+169|0]|w[b+170|0]<<8)>>>2|0;t[c+40|0]=b;if((b|f)&255){t[c+39|0]=e^-1}b=w[a+40|0]|w[a+41|0]<<8;if(b&4){u[c+34>>1]=x[c+34>>1]|1;b=w[a+40|0]|w[a+41|0]<<8}if(b&8){u[c+34>>1]=x[c+34>>1]|2;b=w[a+40|0]|w[a+41|0]<<8}if(b&16){u[c+34>>1]=x[c+34>>1]|4;b=w[a+40|0]|w[a+41|0]<<8}if(b&32){u[c+34>>1]=x[c+34>>1]|32}jb=d+16|0}function TH(a,b,c,d,e){var f=C(0),g=0,h=C(0),i=0,j=C(0),k=C(0);if(!(a&3)){c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;while(1){if((a|0)>0){b=d-4|0;h=z[b>>2];j=z[c>>2];k=z[d>>2];z[c>>2]=j+k;g=c-4|0;f=z[g>>2];z[g>>2]=f+z[b>>2];j=C(j-k);f=C(f-h);z[d>>2]=C(j*z[e>>2])-C(z[e+4>>2]*f);z[b>>2]=C(f*z[e>>2])+C(j*z[e+4>>2]);b=d-12|0;j=z[b>>2];g=c-8|0;f=z[g>>2];i=g;g=d-8|0;k=z[g>>2];z[i>>2]=f+k;i=c-12|0;h=z[i>>2];z[i>>2]=h+z[b>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+32>>2])-C(z[e+36>>2]*h);z[b>>2]=C(h*z[e+32>>2])+C(f*z[e+36>>2]);b=d-20|0;j=z[b>>2];g=c-16|0;f=z[g>>2];i=g;g=d-16|0;k=z[g>>2];z[i>>2]=f+k;i=c-20|0;h=z[i>>2];z[i>>2]=h+z[b>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+64>>2])-C(z[e+68>>2]*h);z[b>>2]=C(h*z[e+64>>2])+C(f*z[e+68>>2]);b=d-28|0;j=z[b>>2];g=c-24|0;f=z[g>>2];i=g;g=d-24|0;k=z[g>>2];z[i>>2]=f+k;i=c-28|0;h=z[i>>2];z[i>>2]=h+z[b>>2];f=C(f-k);h=C(h-j);z[g>>2]=C(f*z[e+96>>2])-C(z[e+100>>2]*h);z[b>>2]=C(h*z[e+96>>2])+C(f*z[e+100>>2]);a=a-1|0;d=d-32|0;c=c-32|0;e=e+128|0;continue}break}return}aa(15614,13048,2423,9113);L()}function cca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0;h=jb-16|0;jb=h;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[h+8>>2]=v[a>>2];v[h+12>>2]=b;o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];t=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Sia(r,s,e,e>>31);i=mb;z=e;e=(v[h+12>>2]<<1)+n|0;g=v[h+8>>2]>>>21&2040;j=(((B(u[e>>1],u[g+39714>>1])+B(u[e-2>>1],u[g+39712>>1])|0)+B(u[e+2>>1],u[g+39716>>1])|0)+B(u[e+4>>1],u[g+39718>>1])|0)/16384<<8;e=j;k=Sia(e,e>>31,t,w);g=z+k|0;e=mb+i|0;e=g>>>0<k>>>0?e+1|0:e;f=Yb(f,-16777216,16776704);i=Sia(p,q,f,f>>31);g=i+g|0;f=mb+e|0;f=g>>>0<i>>>0?f+1|0:f;e=g+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Sb(h+8|0,x,y);e=f-(o&j)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[h+12>>2];v[a>>2]=v[h+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;jb=h+16|0}function b6(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;e=jb-160|0;jb=e;d=e+24|0;f=d+56|0;c=xs(f);v[d>>2]=76788;v[c>>2]=76808;v[d+56>>2]=76848;v[d>>2]=76828;h=f;f=d+4|0;Dn(h,f);v[d>>2]=76788;v[c>>2]=76808;c=ss(f);v[c>>2]=76272;Kb(c+32|0);v[c+44>>2]=0;v[c+48>>2]=16;c=v[v[d>>2]-12>>2];v[23296]=0;f=ga(61)|0;h=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{if((h|0)==1){break f}v[23296]=0;U(62,e+16|0,c+d|0,f|0);c=v[23296];v[23296]=0;if((c|0)==1){break f}_b(e+16|0);c=jb-16|0;jb=c;v[c+8>>2]=17;jb=c+16|0;Ml(v[v[d>>2]-12>>2]+d|0,v[c+8>>2]);i=A[b>>3];v[23296]=0;b=ab(63,d|0,+i)|0;c=v[23296];v[23296]=0;if((c|0)==1){break e}v[23296]=0;R(64,e|0,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break d}v[23296]=0;R(60,g|0,e|0);c=v[23296];v[23296]=0;if((c|0)==1){break c}yb(e);mp(b);jb=e+160|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(e)}mp(d);S(a|0);L()}v[23296]=0;R(57,a|0,g|0);a=v[23296];v[23296]=0;if((a|0)!=1){yb(g);jb=g+16|0;return}a=P()|0;O()|0;yb(g);S(a|0);L()}function Tba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}l=v[a+16>>2];j=v[a+40>>2];k=v[a+36>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;m=v[a+32>>2];n=v[a+28>>2];while(1){if(d){e=v[f+12>>2]+l|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(t[e-2|0],u[h+2>>1])+B(t[e-3|0],u[h>>1])|0)+B(t[e-1|0],u[h+4>>1])|0)+B(t[e|0],u[h+6>>1])|0)+B(t[e+1|0],u[h+8>>1])|0)+B(t[e+2|0],u[h+10>>1])|0)+B(t[e+3|0],u[h+12>>1])|0)+B(t[e+4|0],u[h+14>>1])<<8)/32768|0;k=k+n|0;v[c>>2]=v[c>>2]+B(e,k>>12);j=j+m|0;v[c+4>>2]=v[c+4>>2]+B(e,j>>12);Sb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=j;v[a+20>>2]=k>>12;v[a+36>>2]=k;v[a+24>>2]=j>>12;jb=f+16|0}function MJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;a:{b:{c:{d:{e:{f:{g:{f=a+36|0;e=v[f>>2];c=v[a+40>>2];h:{if(Rb(e,c)){Cc(d+24|0);break h}c=d+8|0;Cn(c,a);v[23296]=0;c=T(959,c|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break g}v[d+24>>2]=c;Wf(d+8|0);c=v[a+40>>2];e=v[a+36>>2]}e=(h=f,i=v[d+24>>2],j=Rb(e,c),j?h:i);if((b|0)==-1){f=v[e>>2];g=4194304;c=0;break e}if((b|0)>=0){c=b;f=v[e>>2];if((Bn(f,v[e+4>>2])|0)>(b|0)){break e}}b=ba(8)|0;v[23296]=0;c=Q(54,d+8|0,10825)|0;a=v[23296];v[23296]=0;if((a|0)==1){break f}a=sc(b,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}a=P()|0;O()|0;yb(c);break d}a=P()|0;O()|0;Wf(d+8|0);break c}a=P()|0;O()|0;ca(b|0);break d}v[a+8>>2]=b;b=v[a+24>>2];v[b+480208>>2]=v[b+480208>>2]&-4194305|g;Ai(b+484360|0,w[bl(f,c)+16|0]);b=bl(v[e>>2],c);c=v[b+8>>2];b=v[b+12>>2];v[23296]=0;+ya(990,a|0,b|0,c|0);b=v[23296];v[23296]=0;if((b|0)!=1){break a}a=P()|0;O()|0}Ik(d+24|0)}S(a|0)}L()}v[a+16>>2]=0;v[a+20>>2]=0;Ik(d+24|0);jb=d+32|0}function zz(a,b,c){var d=0,e=0;b=b-a>>5;while(1){if((b|0)>0){d=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);e=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a|0]=e;t[a+1|0]=e>>>8;t[a+2|0]=e>>>16;t[a+3|0]=e>>>24;t[a+4|0]=d;t[a+5|0]=d>>>8;t[a+6|0]=d>>>16;t[a+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[a+24|0]=e;t[a+25|0]=e>>>8;t[a+26|0]=e>>>16;t[a+27|0]=e>>>24;t[a+28|0]=d;t[a+29|0]=d>>>8;t[a+30|0]=d>>>16;t[a+31|0]=d>>>24;d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[a+16|0]=e;t[a+17|0]=e>>>8;t[a+18|0]=e>>>16;t[a+19|0]=e>>>24;t[a+20|0]=d;t[a+21|0]=d>>>8;t[a+22|0]=d>>>16;t[a+23|0]=d>>>24;d=w[c+12|0]|w[c+13|0]<<8|(w[c+14|0]<<16|w[c+15|0]<<24);e=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+8|0]=e;t[a+9|0]=e>>>8;t[a+10|0]=e>>>16;t[a+11|0]=e>>>24;t[a+12|0]=d;t[a+13|0]=d>>>8;t[a+14|0]=d>>>16;t[a+15|0]=d>>>24;b=b-1|0;a=a+32|0;continue}break}}function Gc(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{c=v[b>>2];e=jb-48|0;jb=e;f=v[b+4>>2];b=w[b+8|0];d=f-(((b|0)==1|(b|0)==4)&(f|0)!=0)|0;f=Kb(a);b:{c:{d:{e:{f:{g:{h:{if((b-1&255)>>>0<=1){t[e+32|0]=0;a=mi(c,c+d|0,e+32|0);v[23296]=0;W(52,f|0,c|0,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break h}a=P()|0;O()|0;break b}if((b-3&255)>>>0>1){break h}v[23296]=0;b=W(52,f|0,c|0,c+d|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break g}c=Zd(b);d=oh(b);g=Zd(b);a=jb-32|0;jb=a;v[a+16>>2]=d;v[a+24>>2]=c;v[a+8>>2]=g;while(1){if(Nh(a+24|0,a+16|0)){c=a+8|0;d=a+24|0;g=t[v[d>>2]];t[v[c>>2]]=g?g:32;Be(d);Be(c);continue}break}jb=a+32|0;v[23296]=0;c=Q(53,e+16|0,b|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break f}v[23296]=0;d=Q(54,e|0,17644)|0;a=v[23296];v[23296]=0;if((a|0)==1){break e}v[23296]=0;U(55,e+32|0,c|0,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break d}a=e+32|0;Bc(b,a);yb(a);yb(d);yb(c)}jb=e+48|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d)}yb(c)}yb(f);S(a|0);L()}}function i$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=nb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}bd(g,d);v[23296]=0;b=T(1084,g|0)|0;a=v[23296];v[23296]=0;d:{e:{f:{g:{if((a|0)!=1){_b(g);bd(g,d);v[23296]=0;a=T(1085,g|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break g}_b(g);v[23296]=0;R(1086,g|0,a|0);d=v[23296];v[23296]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[23296]=0;R(1087,g|12,a|0);a=v[23296];v[23296]=0;if((a|0)==1){break f}v[23296]=0;d=g+24|0;a=ua(1088,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[23296];v[23296]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=Kc(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;_b(g);break d}b=P()|0;O()|0;_b(g);break d}b=P()|0;O()|0;Kc(g);break d}b=P()|0;O()|0;while(1){d=Kc(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}jb=g+32|0;return b|0}function t$(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-32|0;jb=g;v[g+24>>2]=b;a:{b:{if(!(v[d+4>>2]&1)){v[g>>2]=-1;b=nb[v[v[a>>2]+16>>2]](a,b,c,d,e,g)|0;v[g+24>>2]=b;c:{switch(v[g>>2]){case 1:t[f|0]=1;break a;case 0:break b;default:break c}}t[f|0]=1;v[e>>2]=4;break a}bd(g,d);v[23296]=0;b=T(18,g|0)|0;a=v[23296];v[23296]=0;d:{e:{f:{g:{if((a|0)!=1){_b(g);bd(g,d);v[23296]=0;a=T(1067,g|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break g}_b(g);v[23296]=0;R(1068,g|0,a|0);d=v[23296];v[23296]=0;if((d|0)==1){b=P()|0;O()|0;break d}v[23296]=0;R(1069,g|12,a|0);a=v[23296];v[23296]=0;if((a|0)==1){break f}v[23296]=0;d=g+24|0;a=ua(1070,d|0,c|0,g|0,d|0,b|0,e|0,1)|0;b=v[23296];v[23296]=0;if((b|0)==1){break e}t[f|0]=(a|0)==(g|0);b=v[g+24>>2];while(1){d=yb(d-12|0);if((g|0)!=(d|0)){continue}break}break a}b=P()|0;O()|0;_b(g);break d}b=P()|0;O()|0;_b(g);break d}b=P()|0;O()|0;yb(g);break d}b=P()|0;O()|0;while(1){d=yb(d-12|0);if((g|0)!=(d|0)){continue}break}}S(b|0);L()}t[f|0]=0}jb=g+32|0;return b|0}function dca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0;g=jb-16|0;jb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;w=v[a+8>>2];x=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Sia(p,q,e,e>>31);h=mb;f=Yb(f,-16777216,16776704);i=Sia(n,o,f,f>>31);e=i+e|0;f=mb+h|0;f=e>>>0<i>>>0?f+1|0:f;y=e;e=v[g+12>>2]+l|0;h=v[g+8>>2]>>>21&2040;h=(((B(t[e|0],u[h+39714>>1])+B(t[e-1|0],u[h+39712>>1])|0)+B(t[e+1|0],u[h+39716>>1])|0)+B(t[e+2|0],u[h+39718>>1])<<8)/16384<<8;e=h;i=Sia(e,e>>31,r,s);e=y+i|0;f=mb+f|0;f=e>>>0<i>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(g+8|0,w,x);e=f-(h&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;jb=g+16|0}function KU(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-144|0;jb=f;v[23296]=0;l=T(258,a|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){m=c+480192|0;while(1){a:{if((j&65535)>>>0>=l>>>0){Ab(a);jb=f+144|0;return}v[23296]=0;R(277,a|0,f+8|0);e=v[23296];v[23296]=0;if((e|0)!=1){b:{e=Mb(x[f+8>>1]);if(!e|e>>>0>x[m>>1]){break b}e=v[((e<<2)+c|0)+900380>>2];if(!e){break b}e=Ei(e,b);g=w[f+11|0];c:{if(!g){break c}h=w[f+10|0];if(h&1){t[e+12|0]=w[e+12|0]|1}if(h&2){t[e+12|0]=w[e+12|0]|4}if(!(h&4)){break c}t[e+12|0]=w[e+12|0]|2}t[f+4|0]=g;t[f+7|0]=31;h=w[Wb(f+4|0,f+7|0)|0];v[23296]=0;h=h+1&255;R(278,e|0,h|0);g=v[23296];v[23296]=0;if((g|0)==1){break a}t[e+13|0]=w[f+13|0];t[e+14|0]=w[f+14|0];g=w[f+12|0];t[e+15|0]=g;t[e+16|0]=g;g=v[e>>2];e=0;while(1){if((e|0)==(h|0)){break b}i=(f+8|0)+(e<<2)|0;n=Mb(x[i+8>>1]);k=Db(g,e);u[k>>1]=n;i=Mb(x[i+10>>1]);u[f+4>>1]=d?i+128>>>2|0:i;ug(f+4|0,64);t[k+2|0]=w[f+4|0];e=e+1|0;continue}}j=j+1|0;continue}}break}}b=P()|0;O()|0;Ab(a);S(b|0);L()}function bJ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;c=jb+-64|0;jb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;tf(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+8>>2];f=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a:{b:{c:{d:{h=v[c+4>>2];if(f>>>0<=h>>>0){if(f>>>0>y[c+20>>2]){break d}if(e>>>0>y[c+8>>2]){break c}i=v[c+28>>2];if(Xe(v[c+24>>2],i)>>>0<e>>>0){break b}k=b+12|0;l=v[c+16>>2];m=v[c>>2];e:while(1){a=0;if((e|0)==(g|0)){break a}while(1)if((a|0)==(f|0)){g=g+1|0;continue e}else{d=Kh(m,h,a,g);j=Db(v[b>>2],a);d=v[d>>2]+(v[j>>2]>>1)|0;n=d;d=js(k)+d&-4096;v[j>>2]=n-d;d=id(d|2048,12);d=(d|0)<32767?d:32767;o=xn(l,i,a,g),p=(d|0)>-32768?d:-32768,u[o>>1]=p;a=a+1|0;continue}}}aa(7150,8947,33,8660);L()}aa(7115,8947,34,8660);L()}aa(5858,8947,35,8660);L()}aa(5828,8947,36,8660);L()}jb=c- -64|0}function Lj(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;o(+a);b=j(1)|0;e=j(0)|0;f=b>>>20&2047;a:{if(f-969>>>0>=63){if(f>>>0<=968){return a+1}b:{if(f>>>0<1033){break b}c=0;if(!e&(b|0)==-1048576){break a}if((f|0)==2047){return a+1}if((b|0)>0|(b|0)>=0){return tr(3105036184601418e216)}if(b>>>0<3230714880){break b}return tr(12882297539194267e-247)}b=b<<1|e>>>31;e=e<<1;f=(b|0)==-2129002496&(e|0)!=0|b>>>0>2165964800?0:f}c=A[177];g=c+a;a=a-(g-c);c=a*a;h=c*c*(a*A[182]+A[181]);c=c*(a*A[180]+A[179]);a=a*A[178];o(+g);j(1)|0;e=j(0)|0;d=e<<4&2032;a=h+(c+(a+A[d+1464>>3]));d=d+1472|0;i=v[d>>2];b=v[d+4>>2];d=i;i=0;d=d+i|0;b=(e<<13)+b|0;b=d>>>0<i>>>0?b+1|0:b;if(!f){c:{if(!(e&-2147483648)){l(0,d|0);l(1,b+-1048576|0);c=+n();a=c*a+c;a=a+a;break c}e=jb-16|0;l(0,d|0);l(1,b+1071644672|0);c=+n();g=c*a;a=g+c;if(a<1){b=e;v[b+8>>2]=0;v[b+12>>2]=1048576;A[b+8>>3]=A[b+8>>3]*22250738585072014e-324;h=a+1;a=h+(g+(c-a)+(a+(1-h)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,b|0);c=+n();c=c*a+c}return c}function Jj(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=jb-32|0;jb=i;v[i+16>>2]=c;v[i+24>>2]=b;b=i+8|0;bd(b,d);c=0;v[23296]=0;j=T(18,b|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){_b(i+8|0);v[e>>2]=0;a:{while(1){if((g|0)==(h|0)|c){break a}b:{if(Yi(i+24|0,i+16|0)){break b}c:{if((en(j,t[g|0])|0)==37){c=g+1|0;if((h|0)==(c|0)){break b}d:{e:{b=en(j,t[c|0]);if((b|0)==69){break e}k=0;if((b&255)==48){break e}c=g;break d}if((g+2|0)==(h|0)){break b}k=b;b=en(j,t[g+2|0])}l=i,m=nb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,b,k)|0,v[l+24>>2]=m;g=c+2|0;break c}b=v[j+8>>2];if(lh(b,1,t[g|0])){while(1){f:{g=g+1|0;if((h|0)==(g|0)){g=h;break f}if(lh(b,1,t[g|0])){continue}}break}while(1){if(!ep(i+24|0,i+16|0)){break c}b=Ek(v[i+24>>2]);if(!lh(v[j+8>>2],1,b)){break c}Hl(i+24|0);continue}}if((ow(j,Ek(v[i+24>>2]))|0)==(ow(j,t[g|0])|0)){g=g+1|0;Hl(i+24|0);break c}v[e>>2]=4}c=v[e>>2];continue}break}v[e>>2]=4}if(Yi(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}jb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;_b(i+8|0);S(a|0);L()}function TG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;p=a;i=jb-1040|0;jb=i;q=v[115772];a:{b:{a=i+16|0;l=x[((b>>>0>149?0:b)<<1)+90672>>1]+88848|0;c=v[v[115798]+20>>2];if(c){j=v[c+4>>2];c=v[c>>2];e=v[c>>2]+1794895138|0;h=Fl(v[c+8>>2],e);f=Fl(v[c+12>>2],e);d=Fl(v[c+16>>2],e);c:{if(j>>>2>>>0<=h>>>0){break c}k=j-(h<<2)|0;if((d|f)&3|(k>>>0<=f>>>0|d>>>0>=k>>>0)){break c}r=d>>>2|0;s=f>>>2|0;f=0;while(1){k=h>>>1|0;m=k+f|0;n=m<<1;d=c+(n+s<<2)|0;o=Fl(v[d>>2],e);d=Fl(v[d+4>>2],e);if(d>>>0>=j>>>0|j-d>>>0<=o>>>0|w[c+(d+o|0)|0]){break c}d=fj(l,c+d|0);if(!d){f=c+(r+n<<2)|0;h=Fl(v[f>>2],e);e=Fl(v[f+4>>2],e);if(e>>>0>=j>>>0|h>>>0>=j-e>>>0){break c}g=w[c+(e+h|0)|0]?0:c+e|0;break c}if((h|0)==1){break c}d=(d|0)<0;h=d?k:h-k|0;f=d?f:m;continue}}}g=g?g:l;c=Ef(g);d:{if(c>>>0>=1024){qc(a,g,1023);t[a+1023|0]=0;g=68;break d}qc(a,g,c+1|0);g=0}if(g){if((g|0)!=28){break b}a=21473}break a}wa();L()}if(!w[a|0]){v[i>>2]=b;a=i+16|0;tw(a,1024,12865,i)}v[115772]=q;Vb(p,a);jb=i+1040|0}function mba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-16|0;jb=e;p=v[a+16>>2];q=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);l=v[a+128>>2];a:{if(!l){k=v[a+8>>2];m=v[a+12>>2];f=v[a>>2];b=v[a+4>>2];h=0;break a}b=v[a+12>>2];m=b;k=v[a+8>>2];n=bg(k,b,l);o=mb;h=v[a+76>>2];f=v[a>>2];b=v[a+4>>2];Ff(f,b,ff(k,m,d),mb);h=h>>>0<mb>>>0?d:0}g=a+112|0;i=v[a+40>>2];j=v[a+36>>2];v[e>>2]=f;v[e+4>>2]=b;b:while(1){if(d){d=d-1|0;v[e+8>>2]=f;v[e+12>>2]=0;h=h-1|0;n=h?n:0;o=h?o:0;f=b+p|0;b=l;while(1)if((b|0)<=0){Sb(g,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Ld(g,t[f+v[e+12>>2]|0]<<6);Kd(g,b);v[g>>2]=v[g>>2];v[g+4>>2]=0}b=v[a+32>>2];j=v[a+28>>2]+j|0;f=$f(g,q);v[c>>2]=B(j>>12,f)+v[c>>2];i=b+i|0;v[c+4>>2]=v[c+4>>2]+B(f,i>>12);Sb(e,k,m);c=c+8|0;f=v[e>>2];b=v[e+4>>2];continue b}else{Ld(g,t[f+v[e+12>>2]|0]<<6);Kd(g,4);Sb(e+8|0,n,o);b=b-1|0;continue}}break}v[a>>2]=f;v[a+4>>2]=b;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+24>>2]=i>>12;jb=e+16|0}function uw(a,b,c,d){var e=0,f=0,g=0,h=0;g=jb-32|0;jb=g;e=d&2147483647;h=e;f=e-1006698496|0;e=e-1140785152|0;a:{if((f|0)==(e|0)&0|e>>>0>f>>>0){e=d<<4|c>>>28;f=c<<4|b>>>28;c=e;b=b&268435455;if((b|0)==134217728&(a|0)!=0|b>>>0>134217728){e=c+1073741824|0;a=f+1|0;e=a?e:e+1|0;f=a;break a}e=c+1073741824|0;if(a|(b|0)!=134217728){break a}b=f&1;a=b+f|0;e=a>>>0<b>>>0?e+1|0:e;f=a;break a}if(!(!c&(h|0)==2147418112?!(a|b):h>>>0<2147418112)){e=c;c=d<<4|e>>>28;f=e<<4|b>>>28;e=c&524287|2146959360;break a}f=0;e=2146435072;if(h>>>0>1140785151){break a}e=0;h=h>>>16|0;if(h>>>0<15249){break a}e=d&65535|65536;vf(g+16|0,a,b,c,e,h-15233|0);fm(g,a,b,c,e,15361-h|0);e=v[g+4>>2];h=e;a=v[g+8>>2];c=v[g+12>>2]<<4|a>>>28;f=a<<4|e>>>28;e=c;a=h&268435455;b=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;if((a|0)==134217728&(b|0)!=0|a>>>0>134217728){a=f+1|0;e=a?e:e+1|0;f=a;break a}if(b|(a|0)!=134217728){break a}a=f+(f&1)|0;e=a>>>0<f>>>0?e+1|0:e;f=a}jb=g+32|0;l(0,f|0);l(1,d&-2147483648|e);return+n()}function gf(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-80|0;jb=d;c=v[a+28>>2];Wm(v[v[c>>2]-12>>2]+c|0,0);if(!hd(a,4)){Xv(a)}a:{if(!v[a+4>>2]){break a}if(hd(a,6)){break a}if(hd(a,7)){break a}f=v[a+28>>2];c=v[a+84>>2];g=B(v[a+20>>2],v[a+4>>2]);e=g+v[a+80>>2]|0;c=jh(d- -64|0,e,e>>>0<g>>>0?c+1|0:c);e=v[c+12>>2];v[d+24>>2]=v[c+8>>2];v[d+28>>2]=e;e=v[c+4>>2];v[d+16>>2]=v[c>>2];v[d+20>>2]=e;Gj(f,d+16|0)}e=0;b:{if(!hd(a,5)){break b}f=hh(v[a+44>>2],v[a+48>>2]);c=0;while(1){if((c|0)==(f|0)){break b}g=(v[a+96>>2]+c>>>0)%(f>>>0)|0;i=ed(v[a+44>>2],g);h=v[i>>2];c:{j=v[a+32>>2];if(ad(j,v[a+36>>2])>>>0<=h>>>0){break c}h=$m(d+48|0,Lb(j,h),x[i+12>>1]);i=aw(b,h);Tb(h);if(!i){break c}v[a+96>>2]=(g+1>>>0)%(f>>>0);e=ed(v[a+44>>2],g);b=v[e+4>>2];if(!b){break b}f=v[a+28>>2];c=v[a+12>>2];e=b+v[a+8>>2]|0;c=e>>>0<b>>>0?c+1|0:c;b=jh(d+32|0,e,c);c=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=c;c=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=c;Gj(f,d);e=ed(v[a+44>>2],g);break b}c=c+1|0;continue}}jb=d+80|0;return e}function Aba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;e=jb-16|0;jb=e;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){f=v[e+8>>2];o=((((v[e+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;p=u[b+14>>1];q=u[b+12>>1];r=u[b+10>>1];s=u[b+8>>1];t=u[b+6>>1];w=u[b+4>>1];x=u[b+2>>1];y=u[b>>1];f=0;while(1){if((f|0)!=2){b=(f<<1)+o|0;v[(f<<2)+e>>2]=(((((B(u[b+8>>1],r)+B(u[b+4>>1],s)|0)+B(u[b+12>>1],q)|0)+B(u[b+16>>1],p)|0)/2|0)+((((B(u[b-8>>1],x)+B(u[b-12>>1],y)|0)+B(u[b-4>>1],w)|0)+B(u[b>>1],t)|0)/2|0)|0)/16384;f=f+1|0;continue}break}h=h+l|0;v[c>>2]=v[c>>2]+B(v[e>>2],h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g>>12);Sb(e+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;jb=e+16|0}function EP(a,b,c){var d=0,e=0;d=w[a|0]&15;t[a|0]=w[d+26912|0];a:{b:{c:{switch(d|0){case 0:if(w[b|0]?c>>>0>=51:0){break b}t[a|0]=0;return;case 5:d:{e:{d=w[b|0];e=d&15;f:{if(!((e|0)!=2&(d&240)!=32)){t[a|0]=20;d=159;t[b|0]=159;break f}if((e|0)==12){break e}}if(c>>>0<51){break b}if((d&240)==192){break d}break b}if(c>>>0<51){break b}}t[a|0]=25;t[b|0]=0;return;case 7:if(c>>>0>51){break b}t[a|0]=0;return;case 10:a=w[b|0]&240;if(!a){break b}t[b|0]=a;return;case 11:t[b|0]=B(w[b|0]&15,17);return;case 12:t[b|0]=w[b|0]>>>2;return;case 13:a=w[b|0];t[b|0]=B(a>>>4|0,10)+(a&15);return;case 14:g:{switch((w[b|0]>>>4|0)-1|0){case 0:t[a|0]=2;break a;case 1:t[a|0]=3;break a;case 7:if(c>>>0<52){break b}t[a|0]=20;t[b|0]=w[b|0]&15|96;return;case 8:t[a|0]=15;t[b|0]=w[b|0]&15;return;case 9:t[a|0]=11;t[b|0]=w[b|0]<<4|15;return;case 10:t[a|0]=11;break a;case 11:case 12:break g;default:break b}}t[a|0]=20;return;case 15:break c;default:break b}}if(w[b|0]<48){break b}t[a|0]=17}return}t[b|0]=w[b|0]|240}function a5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23296]=0;Y(925,a|0);e=v[23296];v[23296]=0;a:{b:{c:{d:{e:{if((e|0)==1){break e}v[23296]=0;Y(901,b|0);e=v[23296];v[23296]=0;if((e|0)==1){break e}e=0;v[23296]=0;Y(926,c|0);f=v[23296];v[23296]=0;if((f|0)==1){break e}a=Xb(c,0,d);if(!w[b|0]){break b}if(fj(b,7184)|(d|0)!=8){break d}v[a+4>>2]=927;v[a>>2]=928;break c}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,12134,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();return 0}if(!(fj(b,11099)|(d|0)!=64)){v[a+60>>2]=929;v[a+56>>2]=930;v[a+52>>2]=931;v[a+48>>2]=932;v[a+44>>2]=933;v[a+40>>2]=934;v[a+36>>2]=935;v[a+32>>2]=936;v[a+28>>2]=937;v[a+24>>2]=938;v[a+20>>2]=939;v[a+16>>2]=940;v[a+12>>2]=941;v[a+8>>2]=942;v[a+4>>2]=943;v[a>>2]=944;break c}if(fj(b,14963)|(d|0)!=24){break b}v[a+20>>2]=945;v[a+16>>2]=946;v[a+12>>2]=947;v[a+8>>2]=948;v[a+4>>2]=949;v[a>>2]=950}e=1}return e|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0,z=0,A=0;g=jb-16|0;jb=g;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+32>>2];p=v[a+28>>2];q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];t=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){l=u[(v[g+12>>2]<<1)+n>>1]<<8;e=l;e=Sia(e,e>>31,x,y);k=mb;h=e;e=Yb(b,-16777216,16776704);m=Sia(t,w,e,e>>31);h=h+m|0;e=mb+k|0;e=h>>>0<m>>>0?e+1|0:e;f=Yb(f,-16777216,16776704);k=Sia(r,s,f,f>>31);h=k+h|0;f=mb+e|0;f=h>>>0<k>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;j=j+p|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+o|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Sb(g+8|0,z,A);e=f-(q&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;jb=g+16|0}function $ha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;pd(b,32);g=b,h=cc(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24)),v[g>>2]=h;f=cc(w[a+10|0]|w[a+11|0]<<8|(w[a+12|0]<<16|w[a+13|0]<<24));v[b+4>>2]=f;g=b,h=cc(w[a+14|0]|w[a+15|0]<<8|(w[a+16|0]<<16|w[a+17|0]<<24))+f|0,v[g+8>>2]=h;if(!(d?0:c)){c=cc(w[a+46|0]|w[a+47|0]<<8|(w[a+48|0]<<16|w[a+49|0]<<24))}v[b+24>>2]=c;c=w[a+8|0]<<28>>24;a:{if((d|0)!=841887798){break a}d=Mb(w[a+42|0]|w[a+43|0]<<8);if(!d|(d|0)==48){break a}c=(c-(d<<7)|0)+6144|0}iq(b,+(c|0)*.0006510416666666666);t[e+15|0]=w[a+9|0];t[e+14|0]=64;g=b,h=w[Wb(e+15|0,e+14|0)|0]<<2,u[g+30>>1]=h;if(t[a+40|0]&1){u[b+34>>1]=x[b+34>>1]|64;v[b>>2]=v[b>>2]>>>1;v[b+4>>2]=v[b+4>>2]>>>1;v[b+8>>2]=v[b+8>>2]>>>1}b:{if(w[a+41|0]<=8){a=v[b+4>>2];c=v[b+8>>2];break b}u[b+34>>1]=x[b+34>>1]|1;v[b>>2]=v[b>>2]>>>1;a=v[b+4>>2]>>>1|0;v[b+4>>2]=a;c=v[b+8>>2]>>>1|0;v[b+8>>2]=c}c:{if(a+1>>>0<c>>>0){u[b+34>>1]=x[b+34>>1]|2;break c}v[b+4>>2]=0;v[b+8>>2]=0}jb=e+16|0}function WI(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=jb+-64|0;jb=c;d=v[a>>2];a=v[d>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];g=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=g;tf(c+48|0,c+32|0,f);a=v[d+4>>2];f=v[a+8>>2];g=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;d=c+16|0;a:{b:{c:{d:{i=v[c+4>>2];if(i>>>0>=g>>>0){if(y[d+4>>2]<g>>>0){break d}if(f>>>0>y[c+8>>2]){break c}if(Xe(v[d+8>>2],v[d+12>>2])>>>0<f>>>0){break b}k=b+12|0;l=v[c>>2];e:while(1){a=0;if((f|0)==(h|0)){break a}while(1)if((a|0)==(g|0)){h=h+1|0;continue e}else{e=Kh(l,i,a,h);j=Db(v[b>>2],a);e=v[e>>2]+(v[j>>2]>>1)|0;m=e;e=js(k)+e&-4096;v[j>>2]=m-e;e=id(e|2048,12);e=(e|0)<32767?e:32767;n=wn(d,a,h),o=(e|0)>-32768?e:-32768,u[n>>1]=o;a=a+1|0;continue}}}aa(7150,8947,33,8660);L()}aa(7115,8947,34,8660);L()}aa(5858,8947,35,8660);L()}aa(5828,8947,36,8660);L()}jb=c- -64|0}function Ij(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0;i=jb-32|0;jb=i;v[i+16>>2]=c;v[i+24>>2]=b;c=i+8|0;bd(c,d);b=0;v[23296]=0;j=T(1084,c|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){_b(i+8|0);v[e>>2]=0;a:{while(1){if((g|0)==(h|0)|b){break a}b:{if(Kj(i+24|0,i+16|0)){break b}c:{if((dn(j,v[g>>2])|0)==37){b=g+4|0;if((h|0)==(b|0)){break b}d:{e:{c=dn(j,v[b>>2]);if((c|0)==69){break e}k=0;if((c&255)==48){break e}b=g;break d}if((g+8|0)==(h|0)){break b}k=c;c=dn(j,v[g+8>>2])}l=i,m=nb[v[v[a>>2]+36>>2]](a,v[i+24>>2],v[i+16>>2],d,e,f,c,k)|0,v[l+24>>2]=m;g=b+8|0;break c}if(Ck(j,1,v[g>>2])){while(1){f:{g=g+4|0;if((h|0)==(g|0)){g=h;break f}if(Ck(j,1,v[g>>2])){continue}}break}while(1){if(!Qr(i+24|0,i+16|0)){break c}if(!Ck(j,1,Dk(v[i+24>>2]))){break c}on(i+24|0);continue}}if((ll(j,Dk(v[i+24>>2]))|0)==(ll(j,v[g>>2])|0)){g=g+4|0;on(i+24|0);break c}v[e>>2]=4}b=v[e>>2];continue}break}v[e>>2]=4}if(Kj(i+24|0,i+16|0)){v[e>>2]=v[e>>2]|2}jb=i+32|0;return v[i+24>>2]}a=P()|0;O()|0;_b(i+8|0);S(a|0);L()}function Fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0,z=0,A=0;g=jb-16|0;jb=g;f=v[a+48>>2];i=v[a+40>>2];j=v[a+36>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+32>>2];p=v[a+28>>2];q=v[a+72>>2];b=v[a+68>>2];r=b;s=b>>31;b=v[a+64>>2];u=b;w=b>>31;b=v[a+60>>2];x=b;y=b>>31;z=v[a+8>>2];A=v[a+12>>2];while(1){b=e;if(d){l=t[v[g+12>>2]+n|0]<<16;e=l;e=Sia(e,e>>31,x,y);k=mb;h=e;e=Yb(b,-16777216,16776704);m=Sia(u,w,e,e>>31);h=h+m|0;e=mb+k|0;e=h>>>0<m>>>0?e+1|0:e;f=Yb(f,-16777216,16776704);k=Sia(r,s,f,f>>31);h=k+h|0;f=mb+e|0;f=h>>>0<k>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;j=j+p|0;v[c>>2]=B(e,j>>12)+v[c>>2];i=i+o|0;v[c+4>>2]=v[c+4>>2]+B(i>>12,e);Sb(g+8|0,z,A);e=f-(q&l)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+40>>2]=i;v[a+20>>2]=j>>12;v[a+36>>2]=j;v[a+48>>2]=f;v[a+44>>2]=b;v[a+24>>2]=i>>12;jb=g+16|0}function yga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=Tt(c,d);d=b&63;if(e>>>0>d>>>0){c=zS(c,d);d=0;g=jb-16|0;jb=g;t[a+12|0]=0;Hc(a);e=jb-32|0;jb=e;a:{b:{if(ui(a)>>>0<=14){if(ih(1073741823)>>>0<=14){break b}f=Gb(a);f=fg(e+8|0,15,wc(v[a>>2],v[a+4>>2]),f);Ad(a,f);eg(f)}jb=e+32|0;break a}Wc();L()}h=0-w[c+1|0]|0;while(1){c:{if((d|0)==15){break c}e=c+(d<<1)|0;f=w[e+1|0];if(!f){break c}t[g+7|0]=64;h=f+(h<<16>>16)|0;f=ko(g+8|0,h&65535,w[Wb(e+2|0,g+7|0)|0]);d:{if(y[a+4>>2]<y[Gb(a)>>2]){uS(a,f);break d}i=jb-32|0;jb=i;e=Gb(a);e=fg(i+8|0,Ug(a,wc(v[a>>2],v[a+4>>2])+1|0),wc(v[a>>2],v[a+4>>2]),e);jo(v[e+8>>2],x[f>>1]|x[f+2>>1]<<16);v[e+8>>2]=v[e+8>>2]+4;Ad(a,e);eg(e);jb=i+32|0}d=d+1|0;continue}break}d=w[c+32|0];t[a+14|0]=d>>>4;t[a+13|0]=d&15;c=w[c+31|0];d=c&15;t[a+15|0]=d;t[a+16|0]=d;if(c&16){t[a+12|0]=w[a+12|0]|4}if(c&32){t[a+12|0]=w[a+12|0]|2}jb=g+16|0}e:{if(b<<24>>24>=0){c=w[a+12|0]&-2;a=a+12|0;break e}c=w[a+12|0]&-2|uc(v[a>>2],v[a+4>>2])^1;a=a+12|0}t[a|0]=c}function kia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jb-32|0;jb=h;e=b;b=v[a>>2];b=Xe(e,Eb(b))+b|0;e=KT(c,d);a:{if((e|0)<=0){break a}f=v[Gb(a)>>2];g=v[a+4>>2];if((f-g|0)>=(e|0)){v[h+8>>2]=d;j=g-b|0;if((j|0)<(e|0)){v[h+8>>2]=c;XA(h+8|0,j);f=v[h+8>>2];l=jb-16|0;jb=l;i=uk(l,a,e-j|0);k=jb-16|0;jb=k;v[k+8>>2]=f;while(1){if(Rb(f,d)){Hj(v[i+4>>2],w[f|0]);f=Be(k+8|0);v[i+4>>2]=v[i+4>>2]+1;f=v[f>>2];continue}break}jb=k+16|0;lc(i);jb=l+16|0;if((j|0)<=0){break a}}f=jb-16|0;jb=f;j=v[a+4>>2];d=(j-(b+e|0)|0)+b|0;i=uk(f,a,g-d|0);e=v[i+4>>2];a=d;while(1){if(a>>>0>=g>>>0){lc(i);kq(b,d,j);jb=f+16|0}else{Hj(e,w[a|0]);e=e+1|0;v[i+4>>2]=e;a=a+1|0;continue}break}ch(c,v[h+8>>2],b);break a}f=Gb(a);g=Bl(h+8|0,zl(a,ad(v[a>>2],g)+e|0),b-v[a>>2]|0,f);e=jb-32|0;jb=e;v[e+24>>2]=c;c=Kv(e+8|0,g+8|0,KT(c,d));d=v[c>>2];while(1){if(v[c+4>>2]!=(d|0)){Hj(d,w[v[e+24>>2]]);d=v[c>>2]+1|0;v[c>>2]=d;Be(e+24|0);continue}break}Id(c);jb=e+32|0;b=IT(a,g,b);Al(g)}Eb(b);jb=h+32|0}function gp(a,b,c,d,e,f){var g=C(0),h=0,i=C(0),j=0,k=C(0),l=C(0);c=(c<<2)+b|0;d=c+(d<<2)|0;a=a>>2;b=f<<2;while(1){if((a|0)>0){f=d-4|0;i=z[f>>2];k=z[c>>2];l=z[d>>2];z[c>>2]=k+l;h=c-4|0;g=z[h>>2];z[h>>2]=g+z[f>>2];k=C(k-l);g=C(g-i);z[d>>2]=C(k*z[e>>2])-C(z[e+4>>2]*g);z[f>>2]=C(g*z[e>>2])+C(k*z[e+4>>2]);f=d-12|0;k=z[f>>2];h=c-8|0;g=z[h>>2];j=h;h=d-8|0;l=z[h>>2];z[j>>2]=g+l;j=c-12|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=b+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);f=d-20|0;k=z[f>>2];h=c-16|0;g=z[h>>2];j=h;h=d-16|0;l=z[h>>2];z[j>>2]=g+l;j=c-20|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=b+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);f=d-28|0;k=z[f>>2];h=c-24|0;g=z[h>>2];j=h;h=d-24|0;l=z[h>>2];z[j>>2]=g+l;j=c-28|0;i=z[j>>2];z[j>>2]=i+z[f>>2];g=C(g-l);e=b+e|0;i=C(i-k);z[h>>2]=C(g*z[e>>2])-C(z[e+4>>2]*i);z[f>>2]=C(i*z[e>>2])+C(g*z[e+4>>2]);e=b+e|0;a=a-1|0;d=d-32|0;c=c-32|0;continue}break}}function sia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-2608|0;jb=f;d=nB(f,a);v[d+1060>>2]=0;v[d+1064>>2]=0;e=d+2604|0;a=d+1068|0;while(1){t[a+4|0]=0;u[a>>1]=0;u[a+2>>1]=0;a=a+6|0;if((e|0)!=(a|0)){continue}break}v[23296]=0;Y(304,d|0);a=v[23296];v[23296]=0;a:{b:{if((a|0)!=1){if((u[d+1068>>1]|u[d+1070>>1])<0){break a}c:{while(1){if((c|0)==(g|0)){break a}v[23296]=0;j=Q(152,d|0,1)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}a=0;d:{while(1){v[23296]=0;k=Q(152,d|0,1)|0;e=v[23296];v[23296]=0;if((e|0)==1){break d}a=u[(d+B(a,6)|0)+(k?1070:1068)>>1];e:{if((a|0)>255){break e}e=d+B(a,6)|0;h=w[e+1072|0];if(u[e+1068>>1]<0){break e}if(u[e+1070>>1]>=0){continue}}break}h=(j?-1:0)^h;i=(i&255)+(h&255)|0;t[b+g|0]=i;g=g+1|0;continue}break}a=V(30320)|0;break b}a=V(30320)|0;break b}a=V(30320)|0}if((O()|0)==(ea(30320)|0)){_(a|0)|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0}Ab(d);S(a|0);L()}a=mq(d);Ab(d);jb=f+2608|0;return a|0}function Of(a){var b=0;a:{b:{switch(w[a+3|0]){case 0:if(!w[a+5|0]){break a}t[a+3|0]=1;return;case 1:t[a+3|0]=2;return;case 2:t[a+3|0]=3;return;case 3:t[a+3|0]=4;return;case 4:t[a+3|0]=5;return;case 5:t[a+3|0]=6;return;case 6:t[a+3|0]=7;return;case 7:t[a+3|0]=8;return;case 8:t[a+3|0]=9;return;case 9:t[a+3|0]=10;return;case 10:t[a+3|0]=11;return;case 11:t[a+3|0]=12;return;case 12:t[a+3|0]=13;return;case 13:t[a+3|0]=14;b=a;a=w[a+5|0];t[b+5|0]=B(a>>>4|0,10)+(a&15);return;case 14:t[a+3|0]=19;return;case 15:if(w[a+5|0]<=31){t[a+3|0]=16;return}t[a+3|0]=17;return;case 16:t[a+3|0]=23;return;case 17:t[a+3|0]=24;return;case 20:t[a+3|0]=25;return;case 21:t[a+3|0]=30;return;case 25:t[a+3|0]=29;return;case 27:t[a+3|0]=15;return;case 29:t[a+3|0]=18;return;case 32:t[a+3|0]=37;return;case 33:t[a+3|0]=28;return;case 34:t[a+3|0]=27;return;case 35:t[a+3|0]=31;return;case 36:t[a+3|0]=32;return;case 37:t[a+3|0]=32;return;case 38:t[a+3|0]=34;return;default:break b}}t[a+3|0]=0}}function QW(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb+-64|0;jb=b;e=Kb(a);v[23296]=0;a=ga(114)|0;c=v[23296];v[23296]=0;a:{b:{if((c|0)==1){break b}c:{d:{if(!a){break d}v[23296]=0;c=Q(1,b+32|0,8865)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}v[23296]=0;a=ga(114)|0;d=v[23296];v[23296]=0;e:{f:{g:{h:{if((d|0)==1){break h}v[23296]=0;v[b+12>>2]=a;R(120,b+16|0,b+12|0);a=v[23296];v[23296]=0;if((a|0)==1){break h}v[23296]=0;U(2,b+48|0,c|0,b+16|0);a=v[23296];v[23296]=0;if((a|0)==1){break g}d=b+48|0;a=Hb(e,d);zb(d);zb(b+16|0);zb(c);v[23296]=0;c=ga(116)|0;d=v[23296];v[23296]=0;if((d|0)==1){break b}if(!c){break e}v[23296]=0;Q(121,a|0,17318)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break e}break b}a=P()|0;O()|0;break f}a=P()|0;O()|0;zb(b+16|0)}zb(c);break a}v[23296]=0;c=ga(115)|0;d=v[23296];v[23296]=0;if((d|0)==1){break b}if(!c){break d}v[23296]=0;Q(121,a|0,16620)|0;a=v[23296];v[23296]=0;if((a|0)==1){break b}}jb=b- -64|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0}zb(e);S(a|0);L()}function Bba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0,y=0,z=0;e=jb-16|0;jb=e;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){f=v[e+8>>2];o=(((v[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;p=u[b+14>>1];q=u[b+12>>1];r=u[b+10>>1];s=u[b+8>>1];w=u[b+6>>1];x=u[b+4>>1];y=u[b+2>>1];z=u[b>>1];f=0;while(1){if((f|0)!=2){b=f+o|0;v[(f<<2)+e>>2]=(((((B(t[b+4|0],r)+B(t[b+2|0],s)|0)+B(t[b+6|0],q)|0)+B(t[b+8|0],p)<<8)/2|0)+((((B(t[b-4|0],y)+B(t[b-6|0],z)|0)+B(t[b-2|0],x)|0)+B(t[b|0],w)<<8)/2|0)|0)/16384;f=f+1|0;continue}break}h=h+l|0;v[c>>2]=v[c>>2]+B(v[e>>2],h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g>>12);Sb(e+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;jb=e+16|0}function vF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;a=jb-16|0;jb=a;v[a+12>>2]=c;v[a+8>>2]=f;v[a+12>>2]=c;v[a+8>>2]=f;b=v[a+12>>2];a:{while(1){if(b>>>0>=d>>>0){c=0;break a}c=2;b=v[b>>2];if(b>>>0>1114111|(b&-2048)==55296){break a}b:{c:{if(b>>>0<=127){c=1;f=v[a+8>>2];if((g-f|0)<=0){break a}v[a+8>>2]=f+1;t[f|0]=b;break c}if(b>>>0<=2047){c=v[a+8>>2];if((g-c|0)<2){break b}v[a+8>>2]=c+1;t[c|0]=b>>>6|192;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}c=v[a+8>>2];f=g-c|0;if(b>>>0<=65535){if((f|0)<3){break b}v[a+8>>2]=c+1;t[c|0]=b>>>12|224;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128;break c}if((f|0)<4){break b}v[a+8>>2]=c+1;t[c|0]=b>>>18|240;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>12&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b>>>6&63|128;c=v[a+8>>2];v[a+8>>2]=c+1;t[c|0]=b&63|128}b=v[a+12>>2]+4|0;v[a+12>>2]=b;continue}break}c=1}v[e>>2]=v[a+12>>2];v[h>>2]=v[a+8>>2];jb=a+16|0;return c|0}function Wx(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=jb-16|0;jb=d;f=w[a+2|0];if(!(!f|(f|0)==255)){v[d+12>>2]=f+1;v[d+8>>2]=10;dh(b,v[td(d+12|0,d+8|0)>>2]);i=w[a+3|0];t[b+15|0]=i;t[b+16|0]=i;j=w[a+4|0];t[b+13|0]=j;l=w[a+5|0];t[b+14|0]=l;f=511;a:{b:{switch(c-1|0){case 1:e=4096;f=128;break a;case 0:break b;default:break a}}e=32768;f=1024}o=f>>>1|e;c=v[b>>2];k=re(c,v[b+4>>2]);e=0;c:{while(1){if((e|0)==(k|0)){d:{c=w[b+12|0]&-2|t[a|0]&1;t[b+12|0]=c;if(w[a|0]&2){break d}c=c&251;break c}}else{m=Db(c,e);h=(e<<2)+a|0;g=(w[h+6|0]|w[h+7|0]<<8)>>>4|0;u[m>>1]=g;e:{if(e){n=x[Db(c,e-1|0)>>1];if(g>>>0>=n>>>0){break e}g=n+1|0}else{g=0}p=Db(c,e),q=g,u[p>>1]=q}v[d+12>>2]=(((w[h+8|0]|w[h+9|0]<<8)<<16>>16)+o|0)/(f|0);v[d+8>>2]=0;v[d+4>>2]=64;p=m,q=v[wj(d+12|0,d+8|0,d+4|0)>>2],t[p+2|0]=q;e=e+1|0;continue}break}c=c&-5|(k>>>0>=i>>>0)<<2}t[b+12|0]=c;if(j>>>0<=l>>>0?w[a|0]&4:0){a=c&-3|(k>>>0>=j>>>0)<<1}else{a=c&253}t[b+12|0]=a}jb=d+16|0}function Mx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0);d=jb-48|0;jb=d;a:{b=v[a+20>>2];b:{if(!b){break b}e=v[b+4>>2];b=v[b+8>>2];if(ad(e,b)>>>0<4){break b}ke(d+16|0,e,b);b=$d(d+8|0);e=MT(d+24|0,v[d+16>>2],v[d+20>>2],v[b>>2],v[b+4>>2]);v[23296]=0;b=T(145,e|0)|0;f=v[23296];v[23296]=0;c:{if((f|0)!=1){if(b){break c}b=v[v[a>>2]+40>>2];v[23296]=0;f=T(b|0,a|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break a}b=v[a+20>>2];if(ad(v[b+4>>2],v[b+8>>2])-4>>>0<f<<2>>>0){break c}c=v[v[a>>2]+172>>2];b=0;v[23296]=0;R(c|0,a|0,-1);c=v[23296];v[23296]=0;if((c|0)==1){break a}while(1){if((b|0)==(f|0)){b=v[v[a>>2]+176>>2];v[23296]=0;Y(b|0,a|0);a=v[23296];v[23296]=0;if((a|0)!=1){break c}break a}v[23296]=0;g=C(Ca(408,e|0));c=v[23296];v[23296]=0;d:{if((c|0)==1){break d}c=v[v[a>>2]+44>>2];v[23296]=0;Ba(c|0,a|0,b|0,C(Rl(g)?g:C(0)));c=v[23296];v[23296]=0;if((c|0)==1){break d}b=b+1|0;continue}break}break a}break a}Ab(e)}jb=d+48|0;return}a=P()|0;O()|0;Ab(e);S(a|0);L()}function jJ(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;v[a+4>>2]=b;v[a>>2]=93224;e=(b>>>0)/48|0;d=((0-b|0)!=(B(e,-48)|0))+e|0;v[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;v[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){g=-1<<c}else{g=(1<<c)-1&-1>>>32-c|-1<<c}c=0;v[a+24>>2]=c;f=f?g&65536:0;v[a+28>>2]=f;g=0-c|0;h=Via(c,f,d,0);c=65536-(f+((c|0)!=0)|0)|0;f=mb;if((c|0)==(f|0)&g>>>0>h>>>0|c>>>0>f>>>0){d=d+1|0;v[a+12>>2]=d;e=(b>>>0)/(d>>>0)|0;v[a+8>>2]=e;f=e>>>0<64;c=e&31;if((e&63)>>>0>=32){c=-1<<c}else{c=(1<<c)-1&-1>>>32-c|-1<<c}v[a+24>>2]=0;v[a+28>>2]=f?c&65536:0}v[a+16>>2]=d-((b>>>0)%(d>>>0)|0);b=e>>>0<63;d=63-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}v[a+48>>2]=b?c:-1;v[a+52>>2]=b?d:-1;d=64-e|0;c=d&31;if((d&63)>>>0>=32){d=0;c=-1>>>c|0}else{d=-1>>>c|0;c=d|(1<<c)-1<<32-c}v[a+40>>2]=e?c:0;v[a+44>>2]=e?d:0;c=e+1|0;e=c&31;if((c&63)>>>0>=32){d=-1<<e}else{d=(1<<e)-1&-1>>>32-e|-1<<e}v[a+32>>2]=0;v[a+36>>2]=b?d&65536:0;return a}function N5(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;v[23296]=0;g=Q(12,d+24|0,a|0)|0;c=v[23296];v[23296]=0;a:{b:{c:{if((c|0)!=1){d:{if(!w[g|0]){break d}c=d+16|0;bd(c,v[v[a>>2]-12>>2]+a|0);v[23296]=0;c=T(67,c|0)|0;e=v[23296];v[23296]=0;e:{f:{if((e|0)!=1){_b(d+16|0);e=ym(d+8|0,a);f=v[v[a>>2]-12>>2];v[23296]=0;f=a+f|0;h=T(13,f|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break f}e=v[e>>2];v[23296]=0;c=Ua(68,c|0,e|0,f|0,h|0,+b)|0;e=v[23296];v[23296]=0;if((e|0)==1){break f}v[d+16>>2]=c;if(!Pu(d+16|0)){break d}c=v[v[a>>2]-12>>2];v[23296]=0;R(15,a+c|0,5);c=v[23296];v[23296]=0;if((c|0)!=1){break d}c=V(0)|0;O()|0;break e}c=V(0)|0;O()|0;_b(d+16|0);break e}c=V(0)|0;O()|0}jk(g);break c}jk(g);break b}c=V(0)|0;O()|0}_(c|0)|0;c=v[v[a>>2]-12>>2];v[23296]=0;Y(16,a+c|0);c=v[23296];v[23296]=0;if((c|0)==1){break a}$()}jb=d+32|0;return a|0}a=P()|0;O()|0;v[23296]=0;Z(17);d=v[23296];v[23296]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Gfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-48|0;jb=f;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;c=f+44|0;no(b,c);a:{if(!qP(c)){break a}d=w[f+46|0];g=w[f+47|0];e=w[f+45|0];t[a+4|0]=1;h=e>>>3&3;c=(h|0)!=3;e=(e>>>1^-1)&3;g=g>>>0<192;u[a+2>>1]=x[(B(c,6)+(e<<1)|0)+27208>>1]<<g;i=B(B(w[(e+B(c,3)|0)+26984|0],x[((B(c,90)+B(e,30)|0)+(d>>>3&30)|0)+26992>>1]),1e3);d=d>>>1|0;d=B(((i>>>0)/x[(B(h,6)+(d&6)|0)+27184>>1]|0)+(d&1)|0,e?1:4);u[a>>1]=d;e=w[(g|c<<1)+27220|0];if(e+8>>>0>(d&65535)>>>0){break a}c=jb-32|0;jb=c;v[c+28>>2]=e+4;v[c+8>>2]=36;g=v[b>>2];h=v[b+8>>2];d=v[Ib(c+28|0,c+8|0)>>2];if(!Ob(g,h,d)){d=cf(b)}h=c+8|0;Xq(h,f);g=gc(c+16|0,v[c+8>>2],d);nc(c,v[b>>2],v[b+8>>2],v[g>>2],v[g+4>>2]);Xq(h,f);Xb(v[c+8>>2]+d|0,0,36-d|0);ac(b,v[c+28>>2]);jb=c+32|0;b=2;c=e>>>0>2?e:2;while(1){if((b|0)!=(c|0)){d=b+f|0;b=b+1|0;if(!w[d|0]){continue}break a}break}b=e+f|0;if(Pb(b,9468,4)){b=Pb(b,10986,4)}else{b=0}t[a+5|0]=!b}jb=f+48|0;return a|0}function k2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=jb+-64|0;jb=c;e=v[a>>2];a=v[e>>2];f=v[a+4>>2];v[c+40>>2]=v[a+20>>2];d=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=d;tf(c+48|0,c+32|0,f);a=v[e+4>>2];e=v[a+8>>2];f=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;a:{b:{c:{d:{g=v[c+4>>2];if(f>>>0<=g>>>0){if(f>>>0>y[c+20>>2]){break d}if(e>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(Xe(v[c+24>>2],h)>>>0<e>>>0){break b}i=b+12|0;j=v[c+16>>2];k=v[c>>2];b=0;e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{d=id((v[Kh(k,g,a,b)>>2]+id(is(i),21)|0)+2048|0,12);d=(d|0)<32767?d:32767;l=xn(j,h,a,b),m=(d|0)>-32768?d:-32768,u[l>>1]=m;a=a+1|0;continue}}}aa(7150,8947,33,8660);L()}aa(7115,8947,34,8660);L()}aa(5858,8947,35,8660);L()}aa(5828,8947,36,8660);L()}jb=c- -64|0}function fq(a){var b=0,c=0,d=0,e=0,f=0;e=jb-16|0;jb=e;a:{b:{c:{d:{e:{f:{g:{h:{b=v[a+480180>>2];switch(b-1|0){case 7:break e;case 0:case 1:case 3:break f;case 2:case 4:case 5:case 6:break g;default:break h}}if((b|0)==16){break b}if((b|0)==32){break f}if((b|0)==64|(b|0)==256|((b|0)==512|(b|0)==2048)|(b|0)==8192){break b}if((b|0)==65536){break d}d=1;if((b|0)==2097152){break a}if((b|0)==4194304){break c}if((b|0)==536870912|(b|0)==67108864|(b|0)==134217728){break a}d=b;if((b|0)==16777216){break a}}d=32;break a}d=b;break a}d=4;if(x[a+480192>>1]){break a}c=Eb(v[a+484344>>2]);v[e+8>>2]=c;a=Eb(v[a+484348>>2]);while(1){if(!Rb(c,a)){d=1;break a}if(!(!Rb(v[c>>2],v[c+4>>2])|v[c+12>>2]==64)){break a}c=v[sM(e+8|0)>>2];continue}}d=16777216;break a}d=32;f=x[a+480188>>1];if(f>>>0>16){break a}while(1){if((c|0)==(f|0)){break b}b=(c<<5)+a|0;if(t[b+480281|0]&1){break a}c=c+1|0;if(x[b+480286>>1]==64){continue}break}break a}d=2}jb=e+16|0;return d}function pba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-16|0;jb=e;n=v[a+16>>2];o=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);k=v[a+128>>2];a:{if(!k){i=v[a+8>>2];j=v[a+12>>2];g=v[a>>2];b=v[a+4>>2];h=0;break a}i=v[a+8>>2];j=v[a+12>>2];l=bg(i,j,k);m=mb;h=v[a+76>>2];g=v[a>>2];b=v[a+4>>2];Ff(g,b,ff(i,j,d),mb);h=h>>>0<mb>>>0?d:0}f=a+112|0;p=v[a+24>>2];q=v[a+20>>2];v[e>>2]=g;v[e+4>>2]=b;b:while(1){if(d){b=v[e+4>>2];v[e+8>>2]=v[e>>2];v[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=(b<<1)+n|0;b=k;while(1)if((b|0)<=0){Sb(f,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Ld(f,u[(v[e+12>>2]<<1)+g>>1]/4<<16>>16);Kd(f,b);v[f>>2]=v[f>>2];v[f+4>>2]=0}g=v[c>>2];b=$f(f,o);v[c>>2]=g+B(b,q);v[c+4>>2]=v[c+4>>2]+B(b,p);Sb(e,i,j);c=c+8|0;continue b}else{Ld(f,u[(v[e+12>>2]<<1)+g>>1]/4<<16>>16);Kd(f,4);Sb(e+8|0,l,m);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;jb=e+16|0}function n8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];c=zj(d,v[a+4>>2]);if(c>>>0<b>>>0){g=jb-32|0;jb=g;e=b-c|0;b=v[Gb(a)>>2];c=v[a+4>>2];a:{if(e>>>0<=b-c>>11>>>0){b=jb-16|0;jb=b;v[b>>2]=a;a=v[a+4>>2];v[b+4>>2]=a;v[b+8>>2]=a+(e<<11);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){lc(b);jb=b+16|0}else{Nx(a);a=a+2048|0;v[b+4>>2]=a;continue}break}break a}h=Gb(a);i=g+8|0;b=a;f=zj(v[a>>2],c)+e|0;c=jb-16|0;jb=c;v[c+12>>2]=f;d=jb-16|0;jb=d;v[d+12>>2]=2097151;v[d+8>>2]=2147483647;a=v[Ib(d+12|0,d+8|0)>>2];jb=d+16|0;b:{if(a>>>0>=f>>>0){d=Ox(b);if(d>>>0<a>>>1>>>0){v[c+8>>2]=d<<1;a=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;break b}Wc();L()}d=gL(i,a,zj(v[b>>2],v[b+4>>2]),h);c=d;a=jb-16|0;jb=a;v[a>>2]=v[c+8>>2];f=v[c+8>>2];v[a+8>>2]=c+8;v[a+4>>2]=f+(e<<11);c=v[a>>2];while(1){if(v[a+4>>2]!=(c|0)){Nx(c);c=v[a>>2]+2048|0;v[a>>2]=c;continue}break}Id(a);jb=a+16|0;Ad(b,d);fL(d)}jb=g+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<11)|0)}}function tca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0;g=jb-16|0;jb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;u=v[a+8>>2];w=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Sia(p,q,e,e>>31);i=mb;f=Yb(f,-16777216,16776704);h=Sia(n,o,f,f>>31);e=h+e|0;f=mb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=v[g+12>>2]+l|0;e=t[h|0];x=i;i=((B(t[h+1|0]-e|0,v[g+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)<<8;e=i;h=Sia(e,e>>31,r,s);e=x+h|0;f=mb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(g+8|0,u,w);e=f-(i&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;jb=g+16|0}function G2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=jb-16|0;jb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+24;EJ(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+24;lc(c);jb=c+16|0;return}g=jb-32|0;jb=g;h=Gb(a);c=g+8|0;e=Bn(v[a>>2],v[a+4>>2])+1|0;d=jb-16|0;jb=d;v[d+12>>2]=e;a:{f=ih(178956970);if(e>>>0<=f>>>0){e=Lt(a);if(e>>>0<f>>>1>>>0){v[d+8>>2]=e<<1;f=v[Yc(d+8|0,d+12|0)>>2]}jb=d+16|0;break a}Wc();L()}e=Bn(v[a>>2],v[a+4>>2]);If(c+12|0,h);if(f){if(f>>>0>=178956971){jg();L()}d=xc(B(f,24))}else{d=0}v[c>>2]=d;e=d+B(e,24)|0;v[c+8>>2]=e;v[c+4>>2]=e;i=zc(c),j=d+B(f,24)|0,v[i>>2]=j;EJ(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+24;b=c+4|0;e=v[a>>2];f=v[a+4>>2]-e|0;d=v[b>>2]+B((f|0)/-24|0,24)|0;v[b>>2]=d;if((f|0)>0){qc(d,e,f)}oc(a,b);oc(a+4|0,c+8|0);oc(Gb(a),zc(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];b=v[c+8>>2];while(1){if((a|0)!=(b|0)){b=b-24|0;v[c+8>>2]=b;continue}break}a=v[c>>2];if(a){zc(c);Jb(a)}jb=g+32|0}function ts(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0;o(+a);e=j(1)|0;c=j(0)|0;a:{b:{d=e>>>20&2047;if(d-969>>>0<63){k=d;break b}if(d>>>0<=968){return a+1}if(d>>>0<1033){break b}b=0;if(!c&(e|0)==-1048576){break a}if((d|0)==2047){return a+1}if((e|0)<0){return tr(12882297539194267e-247)}return tr(3105036184601418e216)}b=A[170];f=A[169]*a+b;b=f-b;b=b*A[172]+(b*A[171]+a);a=b*b;g=a*a*(b*A[176]+A[175]);a=a*(b*A[174]+A[173]);o(+f);j(1)|0;h=j(0)|0;c=h<<4&2032;b=g+(a+(A[c+1464>>3]+b));d=c+1472|0;c=h<<13;e=0;i=v[d>>2]+e|0;c=c+v[d+4>>2]|0;c=e>>>0>i>>>0?c+1|0:c;d=i;if(!k){c:{if(!(h&-2147483648)){l(0,d|0);l(1,c-1058013184|0);a=+n();a=(a*b+a)*5486124068793689e288;break c}e=jb-16|0;l(0,d|0);l(1,c+1071644672|0);g=+n();f=g*b;a=f+g;if(a<1){v[e+8>>2]=0;v[e+12>>2]=1048576;A[e+8>>3]=A[e+8>>3]*22250738585072014e-324;b=a+1;a=b+(f+(g-a)+(a+(1-b)))+-1;a=a==0?0:a}a=a*22250738585072014e-324}return a}l(0,d|0);l(1,c|0);a=+n();b=a*b+a}return b}function sca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0;g=jb-16|0;jb=g;f=v[a+48>>2];j=v[a+24>>2];k=v[a+20>>2];e=v[a+44>>2];l=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;m=v[a+72>>2];b=v[a+68>>2];n=b;o=b>>31;b=v[a+64>>2];p=b;q=b>>31;b=v[a+60>>2];r=b;s=b>>31;t=v[a+8>>2];w=v[a+12>>2];while(1){b=e;if(d){e=Yb(b,-16777216,16776704);e=Sia(p,q,e,e>>31);i=mb;f=Yb(f,-16777216,16776704);h=Sia(n,o,f,f>>31);e=h+e|0;f=mb+i|0;f=e>>>0<h>>>0?f+1|0:f;i=e;h=(v[g+12>>2]<<1)+l|0;e=u[h>>1];x=i;i=e+((B(u[h+2>>1]-e|0,v[g+8>>2]>>>18|0)|0)/16384|0)<<8;e=i;h=Sia(e,e>>31,r,s);e=x+h|0;f=mb+f|0;f=e>>>0<h>>>0?f+1|0:f;e=e+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,k)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,j);Sb(g+8|0,t,w);e=f-(i&m)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;jb=g+16|0}function b2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb+-64|0;jb=c;d=v[a>>2];a=v[d>>2];e=v[a+4>>2];v[c+40>>2]=v[a+20>>2];f=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=f;tf(c+48|0,c+32|0,e);a=v[d+4>>2];e=v[a+8>>2];f=v[a+4>>2];d=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=d;d=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=d;v[c+8>>2]=v[a+8>>2];d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;d=c+16|0;a:{b:{c:{d:{h=v[c+4>>2];if(h>>>0>=f>>>0){if(y[d+4>>2]<f>>>0){break d}if(e>>>0>y[c+8>>2]){break c}if(Xe(v[d+8>>2],v[d+12>>2])>>>0<e>>>0){break b}i=b+12|0;j=v[c>>2];b=0;e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{g=id((v[Kh(j,h,a,b)>>2]+id(is(i),21)|0)+2048|0,12);g=(g|0)<32767?g:32767;k=wn(d,a,b),l=(g|0)>-32768?g:-32768,u[k>>1]=l;a=a+1|0;continue}}}aa(7150,8947,33,8660);L()}aa(7115,8947,34,8660);L()}aa(5858,8947,35,8660);L()}aa(5828,8947,36,8660);L()}jb=c- -64|0}function N6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=0,p=0,q=0,r=0,s=0,t=C(0),u=C(0),x=C(0),y=C(0),A=0,B=0,E=0,F=0,G=0,H=C(0);g=jb-16|0;jb=g;m=v[a+4240>>2];a:{if(!m){break a}if(!Vh(a+44|0)){break a}n=z[a+4220>>2];e=v[a+44>>2];F=g,G=Fc(e,0),v[F+8>>2]=G;F=g,G=Fc(e,1),v[F+12>>2]=G;e=v[a+56>>2];o=Fc(e,0);v[g>>2]=o;p=Fc(e,1);v[g+4>>2]=p;y=C(C(1)-n);q=v[a+4208>>2];A=w[a+4264|0];e=d;b:while(1){if(e){k=v[a+4244>>2];B=k<<1;f=0;l=0;while(1)if((f|0)==2){f=k+1|0;v[a+4244>>2]=(f|0)==(m|0)?0:f;e=e-1|0;continue b}else{h=(A?1-l|0:f)&255;j=v[((h<<2)+a|0)+4248>>2];E=v[a+4240>>2];r=f<<2;s=r+(g+8|0)|0;i=v[s>>2];v[s>>2]=i+4;j=k-j|0;t=z[Db(q,h+((j>>31&E)+j<<1)|0)>>2];u=z[i>>2];x=C(C(t*z[a+4224>>2])+C(u*z[a+4260>>2]));F=Db(q,f+B|0),H=C(D(x))<C(10000000195414814e-40)?C(0):x,z[F>>2]=H;h=g+r|0;i=v[h>>2];v[h>>2]=i+4;z[i>>2]=C(u*y)+C(n*t);l=l+1|0;f=f+1|0;continue}}break}ji(a,b,c,o,p,d)}jb=g+16|0}function lw(a,b,c,d,e,f,g,h,i,j,k,l){var m=0;m=jb-16|0;jb=m;t[m+15|0]=a;a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break b}a=0;t[b|0]=0;b=v[e>>2];v[e>>2]=b+1;t[b|0]=46;if(!Fb(h)){break a}b=v[j>>2];if((b-i|0)>159){break a}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c;break a}c:{if((a|0)!=(g|0)){break c}if(!Fb(h)){break c}if(!w[b|0]){break b}a=0;b=v[j>>2];if((b-i|0)>159){break a}a=v[k>>2];v[j>>2]=b+4;v[b>>2]=a;a=0;v[k>>2]=0;break a}a=-1;f=mi(l,l+32|0,m+15|0)-l|0;if((f|0)>31){break a}g=w[f+81808|0];d:{e:{switch((f&-2)-22|0){case 2:b=v[e>>2];if((b|0)!=(d|0)&(w[b-1|0]&95)!=(w[c|0]&127)){break a}v[e>>2]=b+1;t[b|0]=g;a=0;break a;case 0:t[c|0]=80;break d;default:break e}}a=g&95;if((a|0)!=w[c|0]){break d}t[c|0]=a|128;if(!w[b|0]){break d}t[b|0]=0;if(!Fb(h)){break d}a=v[j>>2];if((a-i|0)>159){break d}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b}a=v[e>>2];v[e>>2]=a+1;t[a|0]=g;a=0;if((f|0)>21){break a}v[k>>2]=v[k>>2]+1;break a}a=-1}jb=m+16|0;return a}function D5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-80|0;jb=e;v[e+72>>2]=c;a=Tf(a,e+72|0);c=Cc(a+4|0);h=Cc(a+24|0);i=Cc(a+32|0);j=Qb(a+36|0);v[a+56>>2]=3;k=Qb(a+68|0);v[23296]=0;R(895,a|0,d|0);f=v[23296];v[23296]=0;a:{b:{c:{d:{if((f|0)!=1){f=v[b>>2];g=v[b+4>>2];l=v[b+12>>2];v[e+40>>2]=v[b+8>>2];v[e+44>>2]=l;v[e+32>>2]=f;v[e+36>>2]=g;b=$d(e+24|0);f=v[b+4>>2];b=v[b>>2];g=v[e+44>>2];v[e+16>>2]=v[e+40>>2];v[e+20>>2]=g;v[23296]=0;g=v[e+36>>2];v[e+8>>2]=v[e+32>>2];v[e+12>>2]=g;X(884,e+48|0,e+8|0,b|0,f|0);b=v[23296];v[23296]=0;if((b|0)==1){break d}v[23296]=0;U(896,a|0,e+48|0,d|0);b=v[23296];v[23296]=0;if((b|0)==1){break c}Ab(e+48|0);v[23296]=0;Y(897,a|0);b=v[23296];v[23296]=0;if((b|0)==1){break b}te(e+72|0);jb=e+80|0;return a|0}d=P()|0;O()|0;break a}d=P()|0;O()|0;break a}d=P()|0;O()|0;Ab(e+48|0);break a}d=P()|0;O()|0}Me(k);Wf(j);os(i);dj(h);cj(c);te(a);te(e+72|0);S(d|0);L()}function rp(a){a=a|0;var b=0,c=0,d=C(0),e=C(0),f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=C(0),n=0,o=C(0);b=v[a+36>>2];if(!b){Hc(a+16|0);return}a:{b:{switch(x[a>>1]){case 3:c=a+16|0;if(b>>>0>=1001){Hc(c);return}Qj(c,b);b=u[a+28>>1];d=C(Sl(a,(b<<16)+65536>>16)/Sl(a,b));c=v[a+36>>2]+1|0;d=me(d,C(C(1)/C(c>>>0)));a=v[a+16>>2];b=1;while(1){if((b|0)==(c|0)){break a}e=me(d,C(b>>>0));n=Db(a,b-1|0),o=e,z[n>>2]=o;b=b+1|0;continue};case 1:c=a+16|0;f=x[a+30>>1];if(f>>>0>1e3/(b>>>0)>>>0){Hc(c);return}Qj(c,B(b,f));h=x[a+30>>1];j=In(u[a+28>>1],h);i=v[a+36>>2];d=C(C(1)/C(i+1>>>0));c=0;c:while(1){if((c&65535)>>>0>=f>>>0){break a}b=In(c+j<<16>>16,h)<<16;e=Sl(a,b+65536>>16);b=b>>16;e=me(C(e/Sl(a,b)),d);k=B(b,v[a+36>>2]);l=v[a+16>>2];b=1;while(1){g=b&65535;if(i>>>0<g>>>0){c=c+1|0;continue c}else{m=me(e,C(g>>>0));n=Db(l,(g+k|0)-1|0),o=m,z[n>>2]=o;b=b+1|0;continue}}};case 0:Hc(a+16|0);return;default:break b}}Hc(a+16|0);v[a+36>>2]=0}}function Oga(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;e=jb-32|0;jb=e;b=jb-32|0;jb=b;v[b+16>>2]=1073741824;u[b+22>>1]=12;c=xc(64);v[23296]=0;d=T(788,c|0)|0;f=v[23296];v[23296]=0;a:{b:{c:{if((f|0)!=1){c=xf(b+8|0,d);d=v[c>>2];v[23296]=0;R(789,d|0,a|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}a=v[c>>2];v[23296]=0;a=W(790,a|0,b+22|0,b+16|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break c}d:{if(!a){Cc(b+24|0);break d}a=v[c>>2];v[23296]=0;R(791,a|0,15);a=v[23296];v[23296]=0;if((a|0)==1){break c}Tf(b+24|0,c)}ig(c);jb=b+32|0;b=v[b+24>>2];break a}a=P()|0;O()|0;Jb(c);break b}a=P()|0;O()|0;ig(c)}S(a|0);L()}v[e+24>>2]=b;a=0;e:{f:{g:{while(1){if((a|0)==12){break e}v[23296]=0;c=Q(1,e+8|0,(a<<2)+32e3|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){v[23296]=0;U(433,b|0,a|0,c|0);d=v[23296];v[23296]=0;if((d|0)==1){break g}zb(c);a=a+1|0;continue}break}a=P()|0;O()|0;break f}a=P()|0;O()|0;zb(c)}ig(e+24|0);S(a|0);L()}jb=e+32|0;return b|0}function l2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{g=v[c+4>>2];if(g>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}h=v[c+28>>2];if(Xe(v[c+24>>2],h)>>>0<d>>>0){break b}i=v[c+16>>2];j=v[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{f=id(v[Kh(j,g,a,b)>>2]+2048|0,12);f=(f|0)<32767?f:32767;k=xn(i,h,a,b),l=(f|0)>-32768?f:-32768,u[k>>1]=l;a=a+1|0;continue}}}aa(7150,8947,33,8660);L()}aa(7115,8947,34,8660);L()}aa(5858,8947,35,8660);L()}aa(5828,8947,36,8660);L()}jb=c- -64|0}function jx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}g=v[c+28>>2];if(Xe(v[c+24>>2],g)>>>0<d>>>0){break b}h=v[c+16>>2];i=v[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{j=am(ge(cg(A[Pg(i,f,a,b)>>3])*134217728));k=ix(h,g,a,b),l=C(+(j|0)*7.450580596923828e-9),z[k>>2]=l;a=a+1|0;continue}}}aa(7150,8947,77,8627);L()}aa(7115,8947,78,8627);L()}aa(5858,8947,79,8627);L()}aa(5828,8947,80,8627);L()}jb=c- -64|0}function Wba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){e=(v[f+12>>2]<<1)+j|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(u[e-4>>1],u[h+2>>1])+B(u[e-6>>1],u[h>>1])|0)+B(u[e-2>>1],u[h+4>>1])|0)+B(u[e>>1],u[h+6>>1])|0)+B(u[e+2>>1],u[h+8>>1])|0)+B(u[e+4>>1],u[h+10>>1])|0)+B(u[e+6>>1],u[h+12>>1])|0)+B(u[e+8>>1],u[h+14>>1])|0)/32768|0;v[c>>2]=v[c>>2]+B(e,l);v[c+4>>2]=v[c+4>>2]+B(e,k);Sb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;jb=f+16|0}function i8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=C(0),q=C(0),r=0,s=0,t=0,u=C(0),w=C(0),x=C(0),y=C(0),A=0,B=0,E=0,F=C(0);r=v[a+4220>>2];if(r){f=v[a+44>>2];k=Fc(f,0);l=Fc(f,1);g=v[a+56>>2];s=Fc(g,0);j=v[a+4208>>2];A=v[a+4228>>2];f=d;t=Fc(g,1);m=t;g=s;while(1){if(f){h=v[a+4224>>2];e=h-A|0;e=(v[a+4220>>2]&e>>31)+e<<1;B=Db(j,e);n=z[Db(j,e|1)>>2];u=z[a+4244>>2];o=z[B>>2];w=z[a+4252>>2];p=z[l>>2];x=z[a+4248>>2];q=z[k>>2];y=z[a+4256>>2];i=C(C(n*u)+C(C(o*w)+C(C(p*x)+C(q*y))));e=h<<1;E=Db(j,e),F=C(D(i))<C(10000000195414814e-40)?C(0):i,z[E>>2]=F;i=C(C(o*u)+C(C(n*w)+C(C(q*x)+C(p*y))));E=Db(j,e|1),F=C(D(i))<C(10000000195414814e-40)?C(0):i,z[E>>2]=F;h=h+1|0;v[a+4224>>2]=(h|0)==(r|0)?0:h;z[g>>2]=C(q*z[a+4240>>2])+C(o*z[a+4236>>2]);z[m>>2]=C(p*z[a+4240>>2])+C(n*z[a+4236>>2]);f=f-1|0;m=m+4|0;g=g+4|0;l=l+4|0;k=k+4|0;continue}else{ji(a,b,c,s,t,d)}break}}}function JG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[Ne(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=bu(v[a+32>>2]);if((g|0)==-1){break a}t[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(w[a+53|0]){t[c+23|0]=w[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];g=v[d>>2];j=v[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(WG(v[a+36>>2],d,i,f,c+16|0,c+23|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=g;v[d+4>>2]=j;if((e|0)==8){break b}d=bu(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}t[c+23|0]=w[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((Lr(Lf(t[e+(c+24|0)|0]),v[a+32>>2])|0)!=-1){continue}break a}}d=Lf(t[c+23|0]);v[a+48>>2]=d;break a}d=Lf(t[c+23|0]);break a}d=-1}jb=c+32|0;return d}function qba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=jb-16|0;jb=e;n=v[a+16>>2];o=ag(b+327720|0,v[b+20>>2],(v[a+88>>2]&16384)>>>14|0);k=v[a+128>>2];a:{if(!k){i=v[a+8>>2];j=v[a+12>>2];g=v[a>>2];b=v[a+4>>2];h=0;break a}i=v[a+8>>2];j=v[a+12>>2];l=bg(i,j,k);m=mb;h=v[a+76>>2];g=v[a>>2];b=v[a+4>>2];Ff(g,b,ff(i,j,d),mb);h=h>>>0<mb>>>0?d:0}f=a+112|0;p=v[a+24>>2];q=v[a+20>>2];v[e>>2]=g;v[e+4>>2]=b;b:while(1){if(d){b=v[e+4>>2];v[e+8>>2]=v[e>>2];v[e+12>>2]=0;h=h-1|0;l=h?l:0;m=h?m:0;d=d-1|0;g=b+n|0;b=k;while(1)if((b|0)<=0){Sb(f,v[a+120>>2],v[a+124>>2]);b=v[a+116>>2];if(b){Ld(f,t[v[e+12>>2]+g|0]<<6);Kd(f,b);v[f>>2]=v[f>>2];v[f+4>>2]=0}g=v[c>>2];b=$f(f,o);v[c>>2]=g+B(b,q);v[c+4>>2]=v[c+4>>2]+B(b,p);Sb(e,i,j);c=c+8|0;continue b}else{Ld(f,t[v[e+12>>2]+g|0]<<6);Kd(f,4);Sb(e+8|0,l,m);b=b-1|0;continue}}break}b=v[e+4>>2];v[a>>2]=v[e>>2];v[a+4>>2]=b;jb=e+16|0}function Hu(a){var b=0,c=0,d=0,e=0;c=jb-16|0;jb=c;a:{if(w[a+3|0]!=19){break a}t[a+3|0]=20;b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{m:{n:{b=w[a+5|0];switch(b>>>4|0){case 4:break j;case 3:break k;case 2:break l;case 1:break m;case 0:break n;case 13:break b;case 12:break c;case 11:break d;case 10:break e;case 9:break f;case 7:break g;case 6:break h;case 5:break i;default:break a}}t[a+3|0]=0;break a}t[a+3|0]=2;t[a+5|0]=b|240;break a}t[a+3|0]=3;t[a+5|0]=b|240;break a}t[a+5|0]=b&15|16;break a}t[a+5|0]=b&3|48;break a}t[a+5|0]=b&15|32;break a}t[a+5|0]=b&15|176;break a}t[a+5|0]=b&3|64;break a}t[a+3|0]=15;t[a+5|0]=b&15;break a}if(b&15){t[a+3|0]=11;t[a+5|0]=b<<4|15;break a}t[a+3|0]=0;break a}b=b&15;if(b){t[a+3|0]=11;v[c+12>>2]=b;v[c+8>>2]=14;d=a,e=w[td(c+12|0,c+8|0)|0]|240,t[d+5|0]=e;break a}t[a+3|0]=0;break a}if((b|0)!=192){break a}t[a|0]=254;t[a+3|0]=0;break a}if((b|0)!=208){break a}t[a+3|0]=0}jb=c+16|0}function qF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;b=0;a=c;while(1){a:{if(a>>>0>=d>>>0|b>>>0>=e>>>0){break a}g=1;f=t[a|0];b:{if((f|0)>=0){break b}if(f>>>0<4294967234){break a}if(f>>>0<=4294967263){if((d-a|0)<2){break a}g=2;if((w[a+1|0]&192)==128){break b}break a}g=f&255;c:{d:{if(f>>>0<=4294967279){if((d-a|0)<3){break a}h=w[a+2|0];f=w[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((f&224)==160){break c}break a}if((f&192)!=128){break a}break c}if((d-a|0)<4|f>>>0>4294967284|e-b>>>0<2){break a}h=w[a+3|0];i=w[a+2|0];f=w[a+1|0];e:{f:{switch(g-240|0){case 0:if((f+112&255)>>>0<48){break e}break a;case 4:if((f&240)==128){break e}break a;default:break f}}if((f&192)!=128){break a}}if((i&192)!=128|(h&192)!=128|(g<<18&1835008|(f&48)<<12)>>>0>1114111){break a}b=b+1|0;g=4;break b}if((f&224)!=128){break a}}g=3;if((h&192)!=128){break a}}b=b+1|0;a=a+g|0;continue}break}return a-c|0}function KG(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{if(w[a+52|0]){d=v[a+48>>2];if(!b){break a}t[a+52|0]=0;v[a+48>>2]=-1;break a}v[c+24>>2]=1;e=v[Ne(c+24|0,a+44|0)>>2];h=(e|0)>0?e:0;while(1){if((f|0)!=(h|0)){d=-1;g=bu(v[a+32>>2]);if((g|0)==-1){break a}t[(c+24|0)+f|0]=g;f=f+1|0;continue}break}b:{c:{if(w[a+53|0]){v[c+20>>2]=t[c+24|0];break c}h=c+24|0;while(1){d:{d=v[a+40>>2];g=v[d>>2];j=v[d+4>>2];i=c+24|0;f=i+e|0;e:{switch(WG(v[a+36>>2],d,i,f,c+16|0,c+20|0,h,c+12|0)-1|0){case 0:break e;case 1:break b;case 2:break d;default:break c}}d=v[a+40>>2];v[d>>2]=g;v[d+4>>2]=j;if((e|0)==8){break b}d=bu(v[a+32>>2]);if((d|0)==-1){break b}t[f|0]=d;e=e+1|0;continue}break}v[c+20>>2]=t[c+24|0]}f:{if(!b){while(1){if((e|0)<=0){break f}d=-1;e=e-1|0;if((Lr(t[e+(c+24|0)|0],v[a+32>>2])|0)!=-1){continue}break a}}d=v[c+20>>2];v[a+48>>2]=d;break a}d=v[c+20>>2];break a}d=-1}jb=c+32|0;return d}function Xba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;a:{b:{c:{g=v[a+12>>2];i=v[a+8>>2];d:{if((g|0)<=1&i>>>0<=805306368|(g|0)<=0){if((g|0)>=-2&i>>>0>=3489660928|(g|0)>-2){break c}if((g|0)==-2&i>>>0>2147483647|g>>>0>4294967294){break d}break b}if((g|0)==1&i>>>0>2147483648|g>>>0>1){break b}}b=b+196648|0;break a}b=b+131112|0;break a}b=b+262184|0}j=v[a+16>>2];k=v[a+24>>2];l=v[a+20>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;while(1){if(d){e=v[f+12>>2]+j|0;h=(v[f+8>>2]>>>16&65520)+b|0;e=(((((((B(t[e-2|0],u[h+2>>1])+B(t[e-3|0],u[h>>1])|0)+B(t[e-1|0],u[h+4>>1])|0)+B(t[e|0],u[h+6>>1])|0)+B(t[e+1|0],u[h+8>>1])|0)+B(t[e+2|0],u[h+10>>1])|0)+B(t[e+3|0],u[h+12>>1])|0)+B(t[e+4|0],u[h+14>>1])<<8)/32768|0;v[c>>2]=v[c>>2]+B(e,l);v[c+4>>2]=v[c+4>>2]+B(e,k);Sb(f+8|0,i,g);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;jb=f+16|0}function c2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=v[b+4>>2];e=v[a+8>>2];g=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{h=v[c+4>>2];if(h>>>0>=g>>>0){if(y[d+4>>2]<g>>>0){break d}if(y[c+8>>2]<e>>>0){break c}if(Xe(v[d+8>>2],v[d+12>>2])>>>0<e>>>0){break b}i=v[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(g|0)){b=b+1|0;continue e}else{f=id(v[Kh(i,h,a,b)>>2]+2048|0,12);f=(f|0)<32767?f:32767;j=wn(d,a,b),k=(f|0)>-32768?f:-32768,u[j>>1]=k;a=a+1|0;continue}}}aa(7150,8947,33,8660);L()}aa(7115,8947,34,8660);L()}aa(5858,8947,35,8660);L()}aa(5828,8947,36,8660);L()}jb=c- -64|0}function Kfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;u[e+12>>1]=0;v[e+8>>2]=0;j=8;n=B(c,d)<<1;while(1){if((d|0)!=(l|0)){h=(l<<1)+b|0;o=n+h|0;while(1){if(h>>>0<o>>>0){u[e+6>>1]=0;UR(a,e+15|0,e+12|0,j,e+6|0);g=x[e+6>>1];c=j;while(1){a:{if(!(c&255)){break a}f=x[e+12>>1]<<1;i=f&254;u[e+12>>1]=i;if(i){f=(f&65534)>>>0>255}else{if(!bf(a,e+5|0)){break a}f=w[e+5|0];u[e+12>>1]=f<<1&254|1;f=f>>>7|0}c=c-1|0;g=f|g<<1;continue}break}c=1;i=g&65535;b:{if(i>>>0<4){break b}f=15;while(1){c=f;m=f&255;if(i>>>m&1){break b}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;g=f-1^(g&65534)>>>1;f=g+x[e+8>>1]|0;u[e+6>>1]=f;u[h>>1]=f;v[e+8>>2]=((g>>1)-(k<<16>>16)|0)+(f<<16>>16<<1);h=(d<<1)+h|0;j=(c+j&254)>>>1|0;c=-32768;k=v[e+8>>2];c:{if((k|0)>=-32768){c=32767;if((k|0)<32768){break c}}v[e+8>>2]=c}k=f;continue}break}l=l+1|0;continue}break}jb=e+16|0}function gx(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=v[b+4>>2];e=v[a+8>>2];f=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{g=v[c+4>>2];if(g>>>0>=f>>>0){if(y[d+4>>2]<f>>>0){break d}if(y[c+8>>2]<e>>>0){break c}if(Xe(v[d+8>>2],v[d+12>>2])>>>0<e>>>0){break b}h=v[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{i=am(ge(cg(A[Pg(h,g,a,b)>>3])*134217728));j=fx(d,a,b),k=C(+(i|0)*7.450580596923828e-9),z[j>>2]=k;a=a+1|0;continue}}}aa(7150,8947,77,8627);L()}aa(7115,8947,78,8627);L()}aa(5858,8947,79,8627);L()}aa(5828,8947,80,8627);L()}jb=c- -64|0}function eea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=jb-144|0;jb=g;vo(a);a:{b:{if(!Vf(a,64)){break b}c:{d:{if(!al(a,60)){break d}if(!BQ(a,13983)){break d}c=15;d=450;break c}vo(a);if(!Vf(a,128)){break b}b=0;if(!al(a,124)){break a}if(!BQ(a,15150)){break a}c=31;d=930}vo(a);b=0;e:{while(1){if((b&65535)>>>0>=c>>>0){break e}b=b+1|0;if(zQ(a)>>>0<=131072){continue}break}b=0;break a}dd(a,4);if(!Vf(a,2)){break b}b=0;e=jb-16|0;jb=e;c=jb-16|0;jb=c;ql(c+8|0,e+8|0);f=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);h=v[c+4>>2];if((f|0)==(h|0)){dd(a,v[c+12>>2])}jb=c+16|0;if((f|0)==(h|0)){i=Mb(x[e+8>>1])}jb=e+16|0;if(i>>>0<178){break a}b=-1;if(!Vf(a,d)){break a}dd(a,d);d=jb-16|0;jb=d;e=g+8|0;CR(d+8|0,e);c=v[d+12>>2];md(d,a,v[d+8>>2],v[d+12>>2]);f=v[d+4>>2];if((f|0)==(c|0)){dd(a,v[d+12>>2])}jb=d+16|0;a=(c|0)==(f|0);if(!a){cA(e)}if(!a){break a}b=AQ(w[g+8|0]);break a}b=-1}jb=g+144|0;return b|0}function tF(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=c;while(1){a:{if(e>>>0<=i>>>0|a>>>0>=d>>>0){break a}f=1;b=t[a|0];b:{if((b|0)>=0){break b}if(b>>>0<4294967234){break a}if(b>>>0<=4294967263){if((d-a|0)<2){break a}f=2;if((w[a+1|0]&192)==128){break b}break a}g=b&255;c:{d:{if(b>>>0<=4294967279){if((d-a|0)<3){break a}h=w[a+2|0];b=w[a+1|0];if((g|0)==237){break d}if((g|0)==224){if((b&224)==160){break c}break a}if((b&192)!=128){break a}break c}if((d-a|0)<4|b>>>0>4294967284){break a}f=w[a+3|0];h=w[a+2|0];b=w[a+1|0];e:{f:{switch(g-240|0){case 0:if((b+112&255)>>>0<48){break e}break a;case 4:if((b&240)==128){break e}break a;default:break f}}if((b&192)!=128){break a}}if((h&192)!=128|(f&192)!=128){break a}f=4;if((g<<18&1835008|(b&48)<<12)>>>0>1114111){break a}break b}if((b&224)!=128){break a}}f=3;if((h&192)!=128){break a}}i=i+1|0;a=a+f|0;continue}break}return a-c|0}function TB(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;f=jb-560|0;jb=f;u[f+558>>1]=b;a:{if((b-256&65535)>>>0<65281){break a}e=((b<<2)+a|0)+900380|0;b=v[e>>2];b:{if(b){c=fP(f,c);d=v[c+4>>2];v[b>>2]=v[c>>2];v[b+4>>2]=d;d=w[c+11|0]|w[c+12|0]<<8|(w[c+13|0]<<16|w[c+14|0]<<24);e=w[c+7|0]|w[c+8|0]<<8|(w[c+9|0]<<16|w[c+10|0]<<24);t[b+7|0]=e;t[b+8|0]=e>>>8;t[b+9|0]=e>>>16;t[b+10|0]=e>>>24;t[b+11|0]=d;t[b+12|0]=d>>>8;t[b+13|0]=d>>>16;t[b+14|0]=d>>>24;t[b+15|0]=w[c+15|0];d=v[c+44>>2];v[b+40>>2]=v[c+40>>2];v[b+44>>2]=d;d=v[c+36>>2];v[b+32>>2]=v[c+32>>2];v[b+36>>2]=d;d=v[c+28>>2];v[b+24>>2]=v[c+24>>2];v[b+28>>2]=d;d=v[c+20>>2];v[b+16>>2]=v[c+16>>2];v[b+20>>2]=d;my(b+48|0,c+48|0);my(b+68|0,c+68|0);my(b+88|0,c+88|0);qc(b+108|0,c+108|0,448);d=b;Rt(c);break b}b=Ns(556);if(!b){v[e>>2]=0;break a}d=fP(b,c);v[e>>2]=d}g=a,h=x[We(a+480192|0,f+558|0)>>1],u[g+480192>>1]=h}jb=f+560|0;return d|0}function _V(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;j=jb-32|0;jb=j;d=Jm(j+8|0,a);c=jb-48|0;jb=c;k=-1;a:{if(!eD(d,c+8|0)){break a}k=0;if(!jD(c+8|0)){break a}n=v[d+12>>2];b:{if(!al(d,w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24))){break b}while(1){c:{if((w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24))>>>0>m>>>0){if(Vf(d,5)){break c}}g=l&1;break b}g=0;h=1;d:{if((w[c+12|0]|w[c+13|0]<<8)>>>0>=64){f=Cq(d);a=f&63;e:{if(!(f&64)){break e}e=6;while(1){i=Cq(d);a=(i&127)<<e|a;if(!(i&128)){break e}i=e>>>0<25;e=e+7|0;if(i){continue}break}}e=f>>>7|0;f=e?-2147483648:a;if(((e?(a|0)>=0?0-a|0:f:f)|0)<=0){break d}}while(1){e=Cq(d);if(e){f=g>>>0>4;a=f&h;if(!((h^1)&1|f)){a=(xp(e<<24>>24)&255)==w[g+12955|0]}h=a;g=g+1|0;continue}break}dd(d,4);l=(g|0)==5?h&1?1:l:l}m=m+1|0;continue}}al(d,n);if(!g){break a}k=Ge(d,b,iD(c+8|0),0)}jb=c+48|0;jb=j+32|0;return k|0}function hs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}g=v[c+28>>2];if(Xe(v[c+24>>2],g)>>>0<d>>>0){break b}h=v[c+16>>2];i=v[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{j=Kh(i,f,a,b);k=ix(h,g,a,b),l=C(C(v[j>>2])*C(7.450580596923828e-9)),z[k>>2]=l;a=a+1|0;continue}}}aa(7150,8947,33,8660);L()}aa(7115,8947,34,8660);L()}aa(5858,8947,35,8660);L()}aa(5828,8947,36,8660);L()}jb=c- -64|0}function KM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;a:{g=b;c=jb-16|0;jb=c;d=Kb(a);while(1){b:{c:{d:{if(Fb(g)>>>0>f>>>0){b=v[ij(g,f)>>2];if(b>>>0>=2097152){v[23296]=0;R(50,d|0,63);a=v[23296];v[23296]=0;if((a|0)!=1){break c}break b}a=0;while(1){if((a|0)==6){b=7;a=6;break d}e=b&63;t[(c+10|0)+a|0]=e;if(b>>>0>=64){a=a+1|0;b=b>>>6|0;continue}break}if(a){b=a+1|0;if((b|0)!=2){break d}a=1;b=2;if((e|0)!=1){break d}a=w[c+10|0]|64}else{a=w[c+10|0]}v[23296]=0;R(50,d|0,a<<24>>24);a=v[23296];v[23296]=0;if((a|0)!=1){break c}break b}jb=c+16|0;break a}i=(-1<<b^-1)<<7-a;e=b-1|0;j=e+(c+10|0)|0;a=b;while(1){if(!a){break c}e:{if((a|0)==(b|0)){a=w[j|0];v[23296]=0;R(50,d|0,(a|i)<<24>>24);h=v[23296];v[23296]=0;a=e;break e}v[23296]=0;a=a-1|0;R(50,d|0,t[a+(c+10|0)|0]|-128);h=v[23296];v[23296]=0}if((h|0)!=1){continue}break}break b}f=f+1|0;continue}break}a=P()|0;O()|0;zb(d);S(a|0);L()}}function Baa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;l=jb-16|0;jb=l;d=v[hc(l+8|0,Eb(v[a+4>>2]))>>2];i=jb-32|0;jb=i;e=d;d=v[a>>2];h=(so(e,Eb(d))<<1)+d|0;g=_y(b,c);a:{if((g|0)<=0){break a}e=v[Gb(a)>>2];d=v[a+4>>2];if((g|0)<=e-d>>1){f=d-h|0;j=f>>1;b:{if((j|0)>=(g|0)){e=c;break b}v[i+8>>2]=b;v[i+8>>2]=v[i+8>>2]+(j<<1);e=v[i+8>>2];NO(a,e,c,g-j|0);if((f|0)<=0){break a}}m=jb-16|0;jb=m;j=v[a+4>>2];f=(j-((g<<1)+h|0)|0)+h|0;g=Fi(m,a,d-f>>1);k=v[g+4>>2];c=f;while(1){if(c>>>0>=d>>>0){lc(g);kq(h,f,j);jb=m+16|0}else{Di(k,x[c>>1]);k=k+2|0;v[g+4>>2]=k;c=c+2|0;continue}break}Wn(b,e,h);break a}f=Gb(a);f=xj(i+8|0,yj(a,Nc(v[a>>2],d)+g|0),h-v[a>>2]>>1,f);d=jb-16|0;jb=d;e=Eo(d,f+8|0,_y(b,c));c=v[e>>2];while(1){if(v[e+4>>2]!=(c|0)){Di(c,x[b>>1]);c=v[e>>2]+2|0;v[e>>2]=c;b=b+2|0;continue}break}Id(e);jb=d+16|0;h=TO(a,f,h);Gi(f)}Eb(h);jb=i+32|0;jb=l+16|0;return a|0}function Zaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;v[e+12>>2]=1;a:{if(ho(a)){c=v[a>>2];j=gg(c,v[a+4>>2]);v[e+8>>2]=j;k=v[Ib(e+12|0,e+8|0)>>2];while(1){if(k){k=k-1|0;if((b|0)!=(c|0)){f=Eb(v[b>>2]);g=Eb(v[b+4>>2]);d=jb-16|0;jb=d;h=vB(f,g);b:{if(h>>>0<=Fm(c)>>>0){v[d+8>>2]=g;l=v[c>>2];i=Nc(l,v[c+4>>2]);m=i>>>0>=h>>>0;if(m){i=g}else{v[d+8>>2]=f;WO(d+8|0,i);i=v[d+8>>2]}f=Ji(f,i,l);if(!m){YO(c,v[d+8>>2],g,h-Nc(v[c>>2],v[c+4>>2])|0);break b}Nd(c,f);break b}XO(c);Sp(c,yj(c,h));YO(c,f,g,h)}jb=d+16|0;Po(c+12|0,b+12|0);u[c+28>>1]=x[b+28>>1]}c=c+32|0;continue}break}if(!j){qz(a,1-j|0,b);break a}OO(a,v[a>>2]+32|0);break a}if(v[a>>2]){RO(a);c=v[a>>2];ho(a);Jb(c);n=Gb(a),o=0,v[n>>2]=o;v[a>>2]=0;v[a+4>>2]=0}c=Pp(a,1);if(ih(134217727)>>>0<c>>>0){Wc();L()}d=IP(c);v[a>>2]=d;v[a+4>>2]=d;n=Gb(a),o=d+(c<<5)|0,v[n>>2]=o;qz(a,1,b)}jb=e+16|0}function aF(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;g=jb-32|0;jb=g;f=d&2147483647;e=f-1065418752|0;h=f-1082064896|0;a:{if((e|0)==(h|0)&0|e>>>0<h>>>0){f=(d&33554431)<<7|c>>>25;e=0;i=e;h=c&33554431;if(!(!e&(h|0)==16777216?!(a|b):!e&h>>>0<16777216)){e=f+1073741825|0;break a}e=f+1073741824|0;if(h^16777216|a|(b|i)){break a}e=(f&1)+e|0;break a}if(!(!c&(f|0)==2147418112?!(a|b):f>>>0<2147418112)){e=((d&33554431)<<7|c>>>25)&4194303|2143289344;break a}e=2139095040;if(f>>>0>1082064895){break a}e=0;f=f>>>16|0;if(f>>>0<16145){break a}e=d&65535|65536;vf(g+16|0,a,b,c,e,f-16129|0);fm(g,a,b,c,e,16257-f|0);b=v[g+8>>2];e=(v[g+12>>2]&33554431)<<7|b>>>25;h=v[g>>2]|(v[g+16>>2]|v[g+24>>2]|(v[g+20>>2]|v[g+28>>2]))!=0;f=v[g+4>>2];a=0;b=b&33554431;if(!(!a&(b|0)==16777216?!(h|f):!a&b>>>0<16777216)){e=e+1|0;break a}if(b^16777216|h|(a|f)){break a}e=(e&1)+e|0}jb=g+32|0;return l(2,d&-2147483648|e),q()}function Q8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=v[a>>2];d=ik(e,v[a+4>>2]);if(d>>>0<b>>>0){h=jb-32|0;jb=h;a:{b:{e=b-d|0;b=v[Gb(a)>>2];f=v[a+4>>2];c:{if(e>>>0<=(b-f|0)/52>>>0){Tx(a,e,c);break c}d=Gb(a);f=xL(a,ik(v[a>>2],f)+e|0);g=ik(v[a>>2],v[a+4>>2]);b=h+8|0;If(b+12|0,d);if(f){d=wL(f)}else{d=0}v[b>>2]=d;g=d+B(g,52)|0;v[b+8>>2]=g;v[b+4>>2]=g;i=zc(b),j=d+B(f,52)|0,v[i>>2]=j;v[23296]=0;U(832,b|0,e|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}f=v[a>>2];c=v[a+4>>2];e=b+4|0;while(1){if((c|0)!=(f|0)){c=c-52|0;d=_j(v[e>>2]-52|0,c);v[d+20>>2]=v[c+20>>2];g=v[c+16>>2];v[d+12>>2]=v[c+12>>2];v[d+16>>2]=g;_j(d+24|0,c+24|0);Sc(d+36|0,c+36|0);v[d+48>>2]=v[c+48>>2];v[e>>2]=v[e>>2]-52;continue}break}oc(a,e);oc(a+4|0,b+8|0);oc(Gb(a),zc(b));v[b>>2]=v[b+4>>2];vL(b)}jb=h+32|0;break a}a=P()|0;O()|0;vL(b);S(a|0);L()}return}if(b>>>0<d>>>0){yL(a,e+B(b,52)|0)}}function Hfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;u[e+12>>1]=0;v[e+8>>2]=0;n=B(c,d);k=4;a:while(1){if((d|0)!=(l|0)){i=b+l|0;o=n+i|0;while(1){b:{c:{if(i>>>0<o>>>0){t[e+7|0]=0;TR(a,e+15|0,e+12|0,e+7|0);g=w[e+7|0];f=x[e+12>>1];c=k;while(1){if(c&255){h=f<<1;f=h&254;d:{if(f){h=(h&65534)>>>0>255;break d}if(!bf(a,e+6|0)){break c}f=w[e+6|0];h=f>>>7|0;f=f<<1&254|1}c=c-1|0;g=g<<1|h;continue}break}u[e+12>>1]=f;break b}l=l+1|0;continue a}u[e+12>>1]=0}c=1;h=g&255;e:{if(h>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(h>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=g&1;t[e+15|0]=f;g=f-1^(g&254)>>>1;f=g+w[e+8|0]|0;t[e+7|0]=f;t[i|0]=f;v[e+8>>2]=((g>>1)-(j<<24>>24)|0)+(f<<24>>24<<1);i=d+i|0;k=(c+k&254)>>>1|0;c=-128;j=v[e+8>>2];f:{if((j|0)>=-128){c=127;if((j|0)<128){break f}}v[e+8>>2]=c}j=f;continue}}break}jb=e+16|0}function Gl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[a+4>>2]=0;if(Rd(w[rn(d+8|0,a,1)|0])){a:{b:{c:{if((b|0)==2147483647){while(1){b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23296]=0;b=T(92,b|0)|0;c=v[23296];v[23296]=0;d:{if((c|0)!=1){if(!uc(b,-1)){break d}break b}break c}v[a+4>>2]=v[a+4>>2]+1;continue}}if(v[a+4>>2]>=(b|0)){break a}e:{while(1){c=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23296]=0;c=T(92,c|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break e}if(uc(c,-1)){break b}c=v[a+4>>2]+1|0;v[a+4>>2]=c;if((b|0)>(c|0)){continue}break}c=0;break a}}b=V(0)|0;O()|0;_(b|0)|0;c=1;qn(v[v[a>>2]-12>>2]+a|0,1);f:{g:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23296]=0;Z(93);a=v[23296];v[23296]=0;if((a|0)!=1){break f}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)==1){break g}S(a|0);L()}$();break a}V(0)|0;O()|0;Ub()}L()}c=2}vj(v[v[a>>2]-12>>2]+a|0,c)}jb=d+16|0;return a|0}function Eba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0;e=jb-16|0;jb=e;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){f=v[e+8>>2];m=((((v[e+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;n=u[b+14>>1];o=u[b+12>>1];p=u[b+10>>1];q=u[b+8>>1];r=u[b+6>>1];s=u[b+4>>1];t=u[b+2>>1];w=u[b>>1];f=0;while(1){if((f|0)!=2){b=(f<<1)+m|0;v[(f<<2)+e>>2]=(((((B(u[b+8>>1],p)+B(u[b+4>>1],q)|0)+B(u[b+12>>1],o)|0)+B(u[b+16>>1],n)|0)/2|0)+((((B(u[b-8>>1],t)+B(u[b-12>>1],w)|0)+B(u[b-4>>1],s)|0)+B(u[b>>1],r)|0)/2|0)|0)/16384;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g);Sb(e+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;jb=e+16|0}function f6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0),m=0,n=0,o=C(0),p=C(0),q=C(0),r=C(0),s=C(0),t=C(0),u=C(0),w=C(0),x=C(0);h=jb-16|0;jb=h;if(Vh(a+44|0)){f=v[a+44>>2];g=Fc(f,0);v[h+8>>2]=g;f=Fc(f,1);v[h+12>>2]=f;j=v[a+56>>2];m=Fc(j,0);v[h>>2]=m;j=Fc(j,1);v[h+4>>2]=j;a:{if(z[Db(a+4208|0,2)>>2]!=C(.5)){f=d;b:while(1){g=0;if(!f){break a}while(1)if((g|0)==2){f=f-1|0;continue b}else{k=g<<2;e=k+(h+8|0)|0;i=v[e>>2];v[e>>2]=i+4;e=a+k|0;n=e+4248|0;q=z[n>>2];l=z[i>>2];r=z[a+4236>>2];s=z[a+4232>>2];t=z[a+4228>>2];u=z[a+4220>>2];w=z[a+4224>>2];i=e+4240|0;o=z[i>>2];z[n>>2]=o;z[i>>2]=l;i=e+4264|0;x=z[i>>2];e=e+4256|0;p=z[e>>2];z[i>>2]=p;l=C(C(C(C(t*q)+C(C(u*l)+C(w*o)))-C(s*p))-C(r*x));z[e>>2]=l;k=h+k|0;e=v[k>>2];v[k>>2]=e+4;z[e>>2]=l;g=g+1|0;continue}}}e=g;g=d<<2;qc(m,e,g);qc(j,f,g);f=v[a+56>>2];m=Fc(f,0);j=Fc(f,1)}ji(a,b,c,m,j,d)}jb=h+16|0}function Wda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=wd(d,v[a+4>>2]);if(c>>>0<b>>>0){f=jb-32|0;jb=f;c=b-c|0;b=v[Gb(a)>>2];d=v[a+4>>2];a:{if(c>>>0<=(b-d|0)/12>>>0){d=jb-16|0;jb=d;b=At(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){lc(b);jb=d+16|0}else{bQ(a);a=a+12|0;v[b+4>>2]=a;continue}break}break a}b=Gb(a);b=ok(f+8|0,Tm(a,wd(v[a>>2],d)+c|0),wd(v[a>>2],v[a+4>>2]),b);e=jb-16|0;jb=e;d=cQ(e,b+8|0,c);c=v[d>>2];while(1){if(v[d+4>>2]!=(c|0)){bQ(c);c=v[d>>2]+12|0;v[d>>2]=c;continue}break}Id(d);jb=e+16|0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;_j(v[d>>2]-12|0,c);v[d>>2]=v[d>>2]-12;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Gb(a),zc(b));v[b>>2]=v[b+4>>2];a=v[b+4>>2];while(1){c=v[b+8>>2];if((c|0)!=(a|0)){c=c-12|0;v[b+8>>2]=c;dQ(c);continue}break}a=v[b>>2];if(a){Ro(b);Jb(a)}}jb=f+32|0;return}if(b>>>0<c>>>0){eQ(a,d+B(b,12)|0)}}function gs(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=v[b+4>>2];e=v[a+8>>2];f=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{g=v[c+4>>2];if(g>>>0>=f>>>0){if(y[d+4>>2]<f>>>0){break d}if(y[c+8>>2]<e>>>0){break c}if(Xe(v[d+8>>2],v[d+12>>2])>>>0<e>>>0){break b}h=v[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{i=Kh(h,g,a,b);j=fx(d,a,b),k=C(C(v[i>>2])*C(7.450580596923828e-9)),z[j>>2]=k;a=a+1|0;continue}}}aa(7150,8947,33,8660);L()}aa(7115,8947,34,8660);L()}aa(5858,8947,35,8660);L()}aa(5828,8947,36,8660);L()}jb=c- -64|0}function gaa(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;b=v[a+4>>2];if(Rd(w[b+223884|0])){JN(b+223860|0);b=v[a+4>>2]}v[a+24>>2]=0;v[a+28>>2]=0;v[b>>2]=0;c=v[a>>2];v[b+40>>2]=v[c+480196>>2];v[b+44>>2]=v[c+480204>>2];v[b+80>>2]=v[c+480200>>2];c=x[c+480188>>1];v[f+8>>2]=0;v[f+12>>2]=0;d=f+8|0;u[d+4>>1]=65280;v[d>>2]=0;e=jb-16|0;jb=e;v[e+12>>2]=c;b=a+8|0;a:{if(Qm(b)>>>0>=c>>>0){g=v[b>>2];h=Hg(g,v[b+4>>2]);v[e+8>>2]=h;i=v[Ib(e+12|0,e+8|0)>>2];while(1){if(i){v[g>>2]=v[d>>2];u[g+4>>1]=x[d+4>>1];i=i-1|0;g=g+8|0;continue}break}if(c>>>0>h>>>0){_M(b,c-h|0,d);break a}Nd(b,v[b>>2]+(c<<3)|0);break a}bO(b);ez(b,dr(b,c));_M(b,c,d)}jb=e+16|0;b=0;while(1){c=v[a>>2];if(x[c+480188>>1]<=b>>>0){jb=f+16|0}else{d=B(b,872);$n((d+v[a+4>>2]|0)+616|0,c,b&65535,134217728);c=d+v[a+4>>2]|0;u[c+1432>>1]=0;t[c+1418|0]=0;t[c+1415|0]=0;t[c+1413|0]=0;b=b+1|0;continue}break}}function hA(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;i=jb-32|0;jb=i;ER(a,b);h=jb-16|0;jb=h;pd(c,1);g=Mb(w[b+22|0]|w[b+23|0]<<8)<<1;v[c>>2]=g;t[c+37|0]=w[b+24|0]<<4;t[h+15|0]=w[b+25|0];t[h+14|0]=64;l=c,m=w[Wb(h+15|0,h+14|0)|0]<<2,u[l+30>>1]=m;f=Mb(w[b+26|0]|w[b+27|0]<<8);a=f<<1;j=f;k=Mb(w[b+28|0]|w[b+29|0]<<8);f=k<<1;a=k>>>0>=2?a+f>>>0<=g>>>0?a:j+f>>>0>g>>>0?a:j:a;a:{b:{switch(g|0){case 2:v[c>>2]=0;break a;case 0:break a;default:break b}}v[c+4>>2]=a;f=a+f|0;v[c+8>>2]=f;if(a>>>0>=g>>>0){a=g-1|0;v[c+4>>2]=a}if(!(!(f>>>0<4|a>>>0>f>>>0)&f-a>>>0>3)){v[c+4>>2]=0;v[c+8>>2]=0;f=0;a=0}if(!(f>>>0>8|a|(!e|f>>>0>=g>>>0))){v[c+8>>2]=0;break a}if(a>>>0>=f>>>0){break a}u[c+34>>1]=x[c+34>>1]|2}jb=h+16|0;jl(i,3,b);a=i+16|0;Gc(a,i);c=Ec(d,a);yb(a);a=0;while(1){if((a|0)!=32){d=a+c|0;if((w[d|0]-1&255)>>>0<=30){t[d|0]=32}a=a+1|0;continue}break}a=kA(b);jb=i+32|0;return a}function Ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,w=0,x=0,y=0;g=jb-16|0;jb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];t=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){j=u[(v[g+12>>2]<<1)+n>>1]<<8;e=j;e=Sia(e,e>>31,t,w);i=mb;h=e;e=Yb(b,-16777216,16776704);k=Sia(r,s,e,e>>31);h=h+k|0;e=mb+i|0;e=h>>>0<k>>>0?e+1|0:e;f=Yb(f,-16777216,16776704);i=Sia(p,q,f,f>>31);h=i+h|0;f=mb+e|0;f=h>>>0<i>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Sb(g+8|0,x,y);e=f-(o&j)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;jb=g+16|0}function hw(a,b,c,d,e,f,g,h,i,j,k,l){a:{b:{if((a|0)==(f|0)){if(!w[b|0]){break a}f=0;t[b|0]=0;a=v[e>>2];v[e>>2]=a+1;t[a|0]=46;if(!Fb(h)){break b}a=v[j>>2];if((a-i|0)>159){break b}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b;return 0}c:{if((a|0)!=(g|0)){break c}if(!Fb(h)){break c}if(!w[b|0]){break a}f=0;a=v[j>>2];if((a-i|0)>159){break b}b=v[k>>2];v[j>>2]=a+4;v[a>>2]=b;v[k>>2]=0;return 0}f=-1;a=jw(l,l+128|0,a)-l|0;if((a|0)>124){break b}g=w[(a>>2)+81808|0];d:{e:{f=a&-5;if((f|0)!=88){if((f|0)!=96){break e}a=v[e>>2];if((a|0)!=(d|0)){f=-1;if((w[a-1|0]&95)!=(w[c|0]&127)){break b}}v[e>>2]=a+1;t[a|0]=g;return 0}t[c|0]=80;break d}d=g&95;if((d|0)!=w[c|0]){break d}t[c|0]=d|128;if(!w[b|0]){break d}t[b|0]=0;if(!Fb(h)){break d}b=v[j>>2];if((b-i|0)>159){break d}c=v[k>>2];v[j>>2]=b+4;v[b>>2]=c}b=v[e>>2];v[e>>2]=b+1;t[b|0]=g;f=0;if((a|0)>84){break b}v[k>>2]=v[k>>2]+1}return f}return-1}function PO(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;b=v[a>>2];hc(g+8|0,b);a:{b:{c:{d:{e:{if(xd(v[b+16>>2])){while(1){if(c>>>0>31){break e}v[23296]=0;d=ga(42)|0;e=v[23296];v[23296]=0;if((e|0)!=1){f=d|f;c=c+32|0;continue}break}c=V(92364)|0;if((O()|0)!=(ea(92364)|0)){break c}_(c|0)|0;t[b+20|0]=0;v[23296]=0;Y(30,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break d}$();break e}t[b+20|0]=0}if(!w[b+20|0]){d=v[b+24>>2];b=0;c=1;while(1){if(c){c=0;b=v[d+2496>>2];e=d+(b<<2)|0;i=v[d+((b+397>>>0)%624<<2)>>2];h=(b+1>>>0)%624|0;b=v[d+(h<<2)>>2];b=i^(b&2147483647|v[e>>2]&-2147483648)>>>1^B(b&1,-1727483681);v[e>>2]=b;v[d+2496>>2]=h;b=b^b>>>11;b=b<<7&-1658038656^b;b=b<<15&-272236544^b;b=b>>>18^b;continue}break}f=b^f}jb=g+16|0;break a}c=P()|0;O()|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)==1){break b}}S(c|0);L()}V(0)|0;O()|0;Ub();L()}return v[a+28>>2]&f}function _W(){var a=0,b=0,c=0,d=0;c=jb-32|0;jb=c;a:{a=Vb(c+16|0,15023);if(!Fb(a)){break a}b:{if((tg(a,14489)|0)!=-1){b=tg(a,14489);v[23296]=0;X(118,c|0,a|0,b+1|0,-1);b=v[23296];v[23296]=0;if((b|0)==1){break b}Bc(a,c);yb(c)}if((tg(a,16618)|0)!=-1){b=tg(a,16618);v[23296]=0;X(118,c|0,a|0,b+1|0,-1);b=v[23296];v[23296]=0;if((b|0)==1){break b}Bc(a,c);yb(c)}if((tg(a,13706)|0)!=-1){b=tg(a,13706);v[23296]=0;X(118,c|0,a|0,0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break b}Bc(a,c);yb(c)}if((tg(a,13555)|0)!=-1){b=tg(a,13555);v[23296]=0;X(118,c|0,a|0,0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break b}Bc(a,c);yb(c)}if((tg(a,13598)|0)!=-1){b=tg(a,13598);v[23296]=0;X(118,c|0,a|0,0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break b}Bc(a,c);yb(c)}v[23296]=0;b=T(119,a|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break a}}c=P()|0;O()|0;yb(a);S(c|0);L()}yb(a);jb=c+32|0;return b|0}function Jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,u=0,w=0,x=0,y=0;g=jb-16|0;jb=g;f=v[a+48>>2];l=v[a+24>>2];m=v[a+20>>2];e=v[a+44>>2];n=v[a+16>>2];b=v[a+4>>2];v[g+8>>2]=v[a>>2];v[g+12>>2]=b;o=v[a+72>>2];b=v[a+68>>2];p=b;q=b>>31;b=v[a+64>>2];r=b;s=b>>31;b=v[a+60>>2];u=b;w=b>>31;x=v[a+8>>2];y=v[a+12>>2];while(1){b=e;if(d){j=t[v[g+12>>2]+n|0]<<16;e=j;e=Sia(e,e>>31,u,w);i=mb;h=e;e=Yb(b,-16777216,16776704);k=Sia(r,s,e,e>>31);h=h+k|0;e=mb+i|0;e=h>>>0<k>>>0?e+1|0:e;f=Yb(f,-16777216,16776704);i=Sia(p,q,f,f>>31);h=i+h|0;f=mb+e|0;f=h>>>0<i>>>0?f+1|0:f;e=h+8388608|0;f=e>>>0<8388608?f+1|0:f;f=Rc(e,f,24);e=(f|0)/256|0;v[c>>2]=B(e,m)+v[c>>2];v[c+4>>2]=v[c+4>>2]+B(e,l);Sb(g+8|0,x,y);e=f-(o&j)|0;c=c+8|0;d=d-1|0;f=b;continue}break}c=v[g+12>>2];v[a>>2]=v[g+8>>2];v[a+4>>2]=c;v[a+48>>2]=f;v[a+44>>2]=b;jb=g+16|0}function h2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=C(0);c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=v[b+4>>2];d=v[a+8>>2];e=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;a:{b:{c:{d:{f=v[c+4>>2];if(f>>>0>=e>>>0){if(y[c+20>>2]<e>>>0){break d}if(d>>>0>y[c+8>>2]){break c}g=v[c+28>>2];if(Xe(v[c+24>>2],g)>>>0<d>>>0){break b}h=v[c+16>>2];i=v[c>>2];b=0;e:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue e}else{j=Pg(i,f,a,b);k=ix(h,g,a,b),l=C(A[j>>3]),z[k>>2]=l;a=a+1|0;continue}}}aa(7150,8947,77,8627);L()}aa(7115,8947,78,8627);L()}aa(5858,8947,79,8627);L()}aa(5828,8947,80,8627);L()}jb=c- -64|0}function Jl(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;Gk(a);a:{b:{c:{f=v[b+32>>2];d:{if(!f){e=v[b+2084>>2];if(e){break d}break b}c=v[b+4>>2];if((c|0)<9){break c}e=v[b+2084>>2];if(!e){break c}}h=v[a+1392>>2];j=Il(h);d=v[b+2092>>2];c=0;while(1){if((d|0)>=2){f=d>>>1|0;i=f+c|0;g=y[(i<<2)+e>>2]>j>>>0;d=g?f:d-f|0;c=g?c:i;continue}break}d=v[a+1396>>2];c=w[b+23|0]?c:v[v[b+2088>>2]+(c<<2)>>2];b=w[c+v[b+8>>2]|0];e:{if((d|0)<(b|0)){c=-1;b=0;break e}v[a+1392>>2]=h>>>b;b=d-b|0}v[a+1396>>2]=b;return c}if(w[b+23|0]){break a}e=(c|0)>0?c:0;while(1){if((d|0)!=(e|0)){f:{c=w[v[b+8>>2]+d|0];if((c|0)==255){break f}g=v[a+1392>>2];if(v[f+(d<<2)>>2]!=(g&(-1<<c^-1))){break f}e=v[a+1396>>2];if((e|0)>=(c|0)){v[a+1392>>2]=g>>>c;v[a+1396>>2]=e-w[v[b+8>>2]+d|0];return d}v[a+1396>>2]=0;break b}d=d+1|0;continue}break}bc(a,21);v[a+1396>>2]=0}return-1}aa(11236,13048,1705,5406);L()}function UV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-96|0;jb=d;Ac(b);No(a);a:{if(!iv(b,d+56|0)){break a}if(!dD(d+56|0)){break a}b:{if(!c){break b}if(!Ob(v[b>>2],v[b+8>>2],cc(v[d+60>>2])-28|0)){break a}yv(a);g=d,h=xv(),v[g+32>>2]=h;e=d+32|0;wv(Cj(v[a+4>>2])+32|0,e);gr(e);c=v[Cj(v[a+4>>2])+32>>2];v[23296]=0;R(179,e|0,b|0);b=v[23296];v[23296]=0;c:{if((b|0)==1){break c}b=v[d+32>>2];e=v[d+60>>2];f=v[d+68>>2];v[23296]=0;b=fa(180,b|0,cc(e)-28|0,c|0,cc(f)|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break c}e=0;if(!b){break a}ke(d+16|0,v[c>>2],v[c+4>>2]);Og(d+24|0,v[d+16>>2],v[d+20>>2]);b=$d(d+8|0);b=er(d+32|0,v[d+24>>2],v[d+28>>2],v[b>>2],v[b+4>>2]);cd(Cj(v[a+4>>2])+12|0,b);Ab(b);break b}a=Da(91780,25912)|0;b=O()|0;d:{if((ea(91780)|0)==(b|0)){break d}if((ea(25912)|0)==(b|0)){break d}S(a|0);L()}_(a|0)|0;$();e=0;break a}e=1}jb=d+96|0;return e|0}function sw(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=a;a:{if(b&3){while(1){c=w[b|0];if(!c|(c|0)==61){break a}b=b+1|0;if(b&3){continue}break}}c=v[b>>2];b:{if((c^-1)&c-16843009&-2139062144){break b}while(1){if((c^1027423549)-16843009&(c^-1)&-2139062144){break b}c=v[b+4>>2];b=b+4|0;if(!(c-16843009&(c^-1)&-2139062144)){continue}break}}while(1){c=b;e=w[b|0];if((e|0)!=61){b=c+1|0;if(e){continue}}break}b=c}if((a|0)==(b|0)){return 0}g=b-a|0;c:{if(w[g+a|0]){break c}f=v[116710];if(!f){break c}b=v[f>>2];if(!b){break c}while(1){d:{c=a;e=b;i=0;h=g;d=0;e:{if(!g){break e}d=w[c|0];f:{if(!d){break f}while(1){g:{j=w[e|0];if(!j){break g}h=h-1|0;if(!h|(d|0)!=(j|0)){break g}e=e+1|0;d=w[c+1|0];c=c+1|0;if(d){continue}break f}break}i=d}d=(i&255)-w[e|0]|0}if(!d){b=b+g|0;if(w[b|0]==61){break d}}b=v[f+4>>2];f=f+4|0;if(b){continue}break c}break}k=b+1|0}return k}function LE(a,b,c,d,e,f,g,h){var i=0,j=0,k=C(0);i=jb-96|0;jb=i;ky(v[a+24>>2]);t[v[a+24>>2]+1298420|0]=v[a+52>>2]!=0;v[i+92>>2]=f;v[i+88>>2]=e;v[i+84>>2]=d;v[i+80>>2]=c;e=i+32|0;c=i+80|0;a:{d=0;while(1){b:{if((d|0)!=4){if(v[(d<<2)+c>>2]){break b}}else{d=4}break a}d=d+1|0;continue}}c=Wg(e,c,d,b);k=z[a+48>>2];e=v[a+32>>2];v[i+8>>2]=v[c+8>>2];d=v[c+4>>2];v[i>>2]=v[c>>2];v[i+4>>2]=d;d=jb-16|0;jb=d;v[d+8>>2]=v[i+8>>2];c=v[i+4>>2];v[d>>2]=v[i>>2];v[d+4>>2]=c;c=fJ(i+48|0);v[c+8>>2]=e;v[c+4>>2]=0;v[c>>2]=h;e=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=e;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=k;v[c>>2]=g;jb=d+16|0;while(1){if(b){d=v[a+24>>2];v[i+24>>2]=b;v[i+28>>2]=0;v[i+16>>2]=134217727;v[i+20>>2]=0;d=hJ(d,v[Oq(i+24|0,i+16|0)>>2],c);j=d+j|0;b=b-d|0;if(d){continue}}break}if(!(v[a+52>>2]!=1|j)){a=v[a+24>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=i+96|0;return j}function Fba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,w=0,x=0;e=jb-16|0;jb=e;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];f=v[a+4>>2];v[e+8>>2]=v[a>>2];v[e+12>>2]=f;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){f=v[e+8>>2];m=(((v[e+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;b=(((f>>>16|0)+4&131064)<<1)+j|0;n=u[b+14>>1];o=u[b+12>>1];p=u[b+10>>1];q=u[b+8>>1];r=u[b+6>>1];s=u[b+4>>1];w=u[b+2>>1];x=u[b>>1];f=0;while(1){if((f|0)!=2){b=f+m|0;v[(f<<2)+e>>2]=(((((B(t[b+4|0],p)+B(t[b+2|0],q)|0)+B(t[b+6|0],o)|0)+B(t[b+8|0],n)<<8)/2|0)+((((B(t[b-4|0],w)+B(t[b-6|0],x)|0)+B(t[b-2|0],s)|0)+B(t[b|0],r)<<8)/2|0)|0)/16384;f=f+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[e>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[e+4>>2],g);Sb(e+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[e+12>>2];v[a>>2]=v[e+8>>2];v[a+4>>2]=b;jb=e+16|0}function eda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=jb-32|0;jb=g;d=jb-16|0;jb=d;c=a+33|0;v[b>>2]=w[c+206|0]|w[c+207|0]<<8;LL(c,b+48|0,w[c+192|0],w[c+200|0],w[c+194|0],w[c+195|0],w[c+196|0],0);LL(c,b+68|0,w[c+193|0],w[c+201|0],w[c+197|0],w[c+198|0],w[c+199|0],1);f=b+236|0;while(1){if((e|0)==96){if(w[c+208|0]){t[b+31|0]=w[c+209|0]+1;f=w[b+31|0];a:{b:{if(!f){e=1;break b}e=16;if(f>>>0<17){break a}}t[b+31|0]=e}u[d+14>>1]=w[c+210|0]|w[c+211|0]<<8;u[d+12>>1]=127;i=b,j=w[Zc(d+14|0,d+12|0)|0]+1|0,t[i+30|0]=j}t[b+33|0]=w[c+212|0];jb=d+16|0}else{i=dc(f,e+12|0),j=w[c+e|0],u[i>>1]=j;e=e+1|0;continue}break}e=b+236|0;while(1){if((h|0)!=96){f=dc(e,h+12|0);d=w[c+h|0];u[f>>1]=d>>>0<(w[a+27|0]|w[a+28|0]<<8)>>>0?d:0;h=h+1|0;continue}break}jl(g,3,a+4|0);c=g+16|0;Gc(c,g);Ec(b+492|0,c);yb(c);if(!w[a+241|0]){t[b+30|0]=w[a+26|0]}jb=g+32|0}function _1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);c=jb+-64|0;jb=c;b=v[a>>2];a=v[b>>2];d=v[a+4>>2];v[c+40>>2]=v[a+20>>2];e=v[a+16>>2];v[c+32>>2]=v[a+12>>2];v[c+36>>2]=e;tf(c+48|0,c+32|0,d);a=v[b+4>>2];e=v[a+8>>2];f=v[a+4>>2];b=v[c+60>>2];v[c+24>>2]=v[c+56>>2];v[c+28>>2]=b;b=v[c+52>>2];v[c+16>>2]=v[c+48>>2];v[c+20>>2]=b;v[c+8>>2]=v[a+8>>2];b=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=b;d=c+16|0;b=0;a:{b:{c:{d:{g=v[c+4>>2];if(g>>>0>=f>>>0){if(y[d+4>>2]<f>>>0){break d}if(y[c+8>>2]<e>>>0){break c}if(Xe(v[d+8>>2],v[d+12>>2])>>>0<e>>>0){break b}h=v[c>>2];e:while(1){a=0;if((b|0)==(e|0)){break a}while(1)if((a|0)==(f|0)){b=b+1|0;continue e}else{i=Pg(h,g,a,b);j=fx(d,a,b),k=C(A[i>>3]),z[j>>2]=k;a=a+1|0;continue}}}aa(7150,8947,77,8627);L()}aa(7115,8947,78,8627);L()}aa(5858,8947,79,8627);L()}aa(5828,8947,80,8627);L()}jb=c- -64|0}function SP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,w=0;f=jb-16|0;jb=f;n=v[a+20>>2];g=x[a+34>>1]&65;v[f+8>>2]=g;v[f>>2]=g^65;g=b;i=a+24|0;o=d+1298224|0;e=d+1074992|0;j=gj(d);p=a+4|0;q=a+12|0;r=a+8|0;s=a+16|0;t=d+480180|0;while(1){if((e|0)!=(o|0)){if(v[e+104>>2]==(a|0)){if(v[e+16>>2]){v[e+16>>2]=g}if(y[e+4>>2]>c>>>0){v[e>>2]=0;v[e+4>>2]=0}b=a;if(v[e+76>>2]){yc(e+76|0,c);b=v[e+104>>2]}d=v[e+88>>2];b=$C(d,b);h=v[(b?q:p)>>2];v[e+84>>2]=v[(b?s:r)>>2];v[e+80>>2]=h;b=d|v[f+8>>2];v[e+88>>2]=b;v[e+88>>2]=b&(v[f>>2]^-1);b=e+704|0;h=v[a+24>>2];a:{if(!v[e+704>>2]|!h){break a}if(om(v[t>>2])){break a}d=v[(j?b:i)>>2];k=Sia(v[(j?i:b)>>2],0,v[e+700>>2],0);l=k+(d>>>1|0)|0;m=mb;u=e,w=Vc(Via(l,k>>>0>l>>>0?m+1|0:m,d,0),mb),v[u+700>>2]=w}v[b>>2]=h}e=e+872|0;continue}break}v[a>>2]=c;v[a+20>>2]=g;uz(n);jb=f+16|0}function _C(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;v[23296]=0;e=Q(12,c+24|0,466312)|0;d=v[23296];v[23296]=0;a:{b:{c:{if((d|0)!=1){d:{e:{if(!w[e|0]){break e}f=ym(c+8|0,466312);d=v[v[116578]-12>>2]+466312|0;g=v[d+4>>2];v[23296]=0;h=T(13,d|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break d}f=v[f>>2];v[23296]=0;b=a+b|0;a=ka(14,f|0,a|0,((g&176)==32?b:a)|0,b|0,d|0,h|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break d}v[c+16>>2]=a;if(!Pu(c+16|0)){break e}a=v[v[116578]-12>>2];v[23296]=0;R(15,a+466312|0,5);a=v[23296];v[23296]=0;if((a|0)!=1){break e}break d}jk(e);break b}a=V(0)|0;O()|0;jk(e);break c}a=V(0)|0;O()|0}_(a|0)|0;a=v[v[116578]-12>>2];v[23296]=0;Y(16,a+466312|0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$()}jb=c+32|0;return}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)==1){V(0)|0;O()|0;Ub();L()}S(a|0);L()}function NB(a){var b=0,c=0,d=0,e=0,f=0,g=0;if((w[a|0]-16&255)>>>0>=241){e=a+1954|0;c=a+1698|0;a:{b:{while(1){if((c|0)==(e|0)){c=0;e=0;while(1){b=32;if((c|0)==32){break a}d=B(c,13)+a|0;if(w[d+14|0]){break b}b=(c<<4)+a|0;if(w[b+418|0]|w[b+419|0]<<8|(w[b+420|0]<<16|w[b+421|0]<<24)){break b}f=w[b+422|0]|w[b+423|0]<<8|(w[b+424|0]<<16|w[b+425|0]<<24);if(w[d+942|0]|f>>>0>1048575){break b}d=B(c,11)+a|0;g=d+1346|0;if(w[g|0]>15|w[d+1351|0]>3|w[d+1356|0]>3){break b}c:{d:{if(f){d=w[b+430|0]|w[b+431|0]<<8|(w[b+432|0]<<16|w[b+433|0]<<24);if(d>>>0<=1048574&(d>>>0<(w[b+426|0]|w[b+427|0]<<8|(w[b+428|0]<<16|w[b+429|0]<<24))>>>0|d>>>0>f>>>0)){break b}b=1;if(e){break c}break d}b=1;if(e){break c}if(Pb(g,26109,11)){break d}b=0;break c}b=1}e=b;c=c+1|0;continue}}b=t[c|0];c=c+1|0;if((b|0)>=-1){continue}break}return 0}b=c}a=b>>>0>31&e}else{a=0}return a}function z9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;e=Kb(d+16|0);a:{b:{c:{if(c>>>0<64){break c}v[23296]=0;c=T(177,b|0)|0;f=v[23296];v[23296]=0;d:{if((f|0)!=1){v[d+12>>2]=c;if((c|0)>0){break d}v[23296]=0;Q(54,a|0,21473)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break b}}break a}v[23296]=0;c=T(190,b|0)|0;f=v[23296];v[23296]=0;if((f|0)!=1){g=d,h=wi(c),v[g+8>>2]=h;c=v[td(d+12|0,d+8|0)>>2];v[23296]=0;R(45,e|0,c|0);c=v[23296];v[23296]=0;if((c|0)!=1){break c}}break a}e:{while(1){f:{v[23296]=0;c=T(194,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break f}if(!c){break e}v[23296]=0;W(800,e|0,1,((c-65&255)>>>0<26?c+32|0:c)<<24>>24)|0;c=v[23296];v[23296]=0;if((c|0)!=1){continue}}break}break a}v[23296]=0;Q(176,b|0,4)|0;b=v[23296];v[23296]=0;if((b|0)==1){break a}Sc(a,e)}yb(e);jb=d+32|0;return}a=P()|0;O()|0;yb(e);S(a|0);L()}function yp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;a:{b:{switch(w[a+480224|0]-1|0){default:b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2]<<1;f=Sia(b,d,5e4,0);e=mb;b=v[Yc(c+8|0,c)>>2];b=Ic(Tia(f,e,b,b>>31),mb);v[a+1074404>>2]=b;break a;case 1:b=v[a+24620>>2];v[c+8>>2]=1;v[c+12>>2]=0;g=c,h=Sia(v[a+1074420>>2],0,Sia(v[a+1074408>>2],0,v[a+1074416>>2],0),mb),v[g>>2]=h;v[c+4>>2]=mb;b=Sia(b,0,6e5,0);d=c+8|0;e=b;f=mb;b=_u(v[d>>2],v[d+4>>2],v[c>>2],v[c+4>>2])?c:d;b=Via(e,f,v[b>>2],v[b+4>>2]);v[a+1074404>>2]=b;break a;case 0:break b}}b=v[a+24620>>2];d=b>>31;v[c+8>>2]=1;v[c>>2]=v[a+1074420>>2];f=Sia(b,d,1e4,0);e=mb;b=v[Yc(c+8|0,c)>>2];b=Ic(Tia(f,e,b,b>>31),mb);v[a+1074404>>2]=b}e=a+1074404|0;a=v[a+480244>>2];b=Sia(a,a>>31,b,b>>31)+32768|0;a=mb;a=Ic(Tia(b,b>>>0<32768?a+1|0:a,65536,0),mb);v[e>>2]=a?a:1;jb=c+16|0}function kK(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0),k=0,l=C(0),m=0,n=0,o=0,p=C(0);d=a+4208|0;j=C(C(z[Db(d,2)>>2]*C(2999.9990234375))+C(.0010000000474974513));l=C(z[Db(d,3)>>2]*C(.9980000257492065));f=-3e3/+C(j*C(y[v[a+16>>2]+24620>>2]));h=a+4272|0;c=Nj(10,f*+y[Db(h,4)>>2]);d=a+4232|0;o=Db(d,0),p=C(c),z[o>>2]=p;c=Nj(10,f*+y[Db(h,5)>>2]);o=Db(d,1),p=C(c),z[o>>2]=p;m=f*(1/+C(l+C(.0010000000474974513))+-1);c=0;while(1){if((e|0)==4){e=a+4208|0;f=Nj(10,+iK(z[Db(e,0)>>2])*.05);b=4/K(c)*f;c=Nj(10,+iK(z[Db(e,1)>>2])*.1);z[a+4228>>2]=b*K(c);z[a+4224>>2]=f*K(1-c)}else{g=Db(h,e);k=e>>>1|0;n=v[Db(h,k+4|0)>>2];g=v[g>>2];i=Nj(10,m*+(n+g>>>0));b=Nj(10,f*+(g>>>0));j=z[Db(d,k)>>2];g=e<<1;i=(1-i)*.5;o=Db(d,g+2|0),p=C(b*(1-i)),z[o>>2]=p;o=Db(d,g+3|0),p=C(b*i),z[o>>2]=p;b=b*+j;b=b*(b*(b*(b+1)+1)+1)+1;c=b*b+c;e=e+1|0;continue}break}}function Kda(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;while(1){a:{g=c;if(!c){g=0;break a}c=g-1|0;if(!w[c+b|0]){continue}}break}b:{if((d|0)!=4){break b}c=0;while(1){if((c|0)==(g|0)){if((e|0)==(f|0)){d=2;if((e|0)==(h|0)){break b}}if(e){d=0;if(!f){break b}}d=e?3:f?1:3}else{c:{d:{e:{d=b+c|0;i=w[d|0];switch(i-10|0){case 0:break d;case 3:break e;default:break c}}e=e+1|0;break c}f=f+1|0}h=c?(w[d-1|0]==13&(i|0)==10)+h|0:h;c=c+1|0;continue}break}}e=0;f=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){c=((f&w[b+c|0]==13)+c|0)+1|0;e=e+1|0;continue}break}Nf(a);et(a,e);f=(d|0)==1?32:13;h=d&-3?13:32;d=(d|0)==2;c=0;while(1){if(c>>>0<g>>>0){f:{g:{h:{i:{e=t[b+c|0];switch(e-10|0){case 1:case 2:break f;case 0:break g;case 3:break h;default:break i}}if(e){break f}e=32;break f}c=c+d|0;e=f;break f}e=h}Fp(a,e);c=c+1|0;continue}break}}
function r5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-32|0;jb=e;v[23296]=0;Y(900,a|0);d=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{if((d|0)==1){break g}v[23296]=0;Y(901,b|0);d=v[23296];v[23296]=0;if((d|0)==1){break g}v[23296]=0;Y(901,c|0);d=v[23296];v[23296]=0;if((d|0)==1){break g}f=v[a+24>>2];v[23296]=0;d=Q(54,e+16|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break g}v[23296]=0;c=Q(54,e|0,c|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break f}v[23296]=0;X(916,f|0,d|0,c|0,1);b=v[23296];v[23296]=0;if((b|0)==1){break e}yb(c);yb(d);b=1;break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break d}b=V(0)|0;O()|0;yb(c)}yb(d)}_(b|0)|0;b=0;v[23296]=0;X(887,6370,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$()}jb=e+32|0;return b|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Zm(a,b,c,d){var e=0,f=0;f=jb-16|0;jb=f;v[23296]=0;Y(900,a|0);e=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{h:{i:{if((e|0)!=1){e=v[a+24>>2];v[23296]=0;R(d|0,f|0,e|0);d=v[23296];v[23296]=0;if((d|0)==1){break i}d=v[f>>2];e=wd(d,v[f+4>>2]);if(e>>>0<2147483647){break h}d=ba(8)|0;v[23296]=0;b=Q(954,d|0,7347)|0;e=v[23296];v[23296]=0;if((e|0)==1){break g}v[23296]=0;U(107,b|0,92140,156);b=v[23296];v[23296]=0;if((b|0)!=1){break b}b=V(0)|0;O()|0;break f}b=V(0)|0;O()|0;break e}b=V(0)|0;O()|0;break e}j:{if(!((b|0)<(e|0)&(b|0)>=0)){b=Xf(21473);break j}b=Xf(Jc(Hd(d,b)))}Me(f);break d}b=V(0)|0;O()|0;ca(d|0)}Me(f)}_(b|0)|0;b=0;v[23296]=0;X(887,c|0,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break c}$()}jb=f+16|0;return b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break a}V(0)|0;O()|0;Ub()}L()}S(a|0);L()}function XU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;pd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Gq(a+4|0,a);d=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=d;c=Gq(a+8|0,a);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+8>>2]=f;c=(w[a+15|0]|w[a+16|0]<<8)<<1;v[b+24>>2]=c;c=w[a+15|0]|w[a+16|0]<<8?c:16726;v[b+24>>2]=c;g=b,h=(B(Ju(t[a+17|0],w[a+14|0]<<28>>24),c)>>>0)/8363|0,v[g+24>>2]=h;t[e+15|0]=w[a+18|0];t[e+14|0]=127;g=b,h=(((w[Wb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[g+30>>1]=h;c=w[a+14|0];if(c>>>0>=16){u[b+34>>1]=32;u[b+28>>1]=c&240}c=w[a+19|0];if(c&4){u[b+34>>1]=x[b+34>>1]|1;c=w[a+19|0]}a:{if(!(c&8)|d>>>0>=f>>>0){break a}f=x[b+34>>1];d=f|2;u[b+34>>1]=d;c=w[a+19|0];if(c&16){d=f|6;u[b+34>>1]=d;c=w[a+19|0]}if(!(c&64)){break a}u[b+34>>1]=d|128}jb=e+16|0}function $H(a,b,c,d){var e=0,f=C(0),g=0,h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=0;e=jb-96|0;jb=e;o=(d|0)>0?d:0;while(1){if((j|0)!=(o|0)){z[e+48>>2]=-z[a>>2];z[e>>2]=z[a+68>>2];d=0;while(1){if((d|0)!=4){i=(e+48|0)+(d<<3)|0;g=(d<<4)+a|0;h=z[g+4>>2];f=z[g+8>>2];z[i+4>>2]=h+f;k=d<<1;z[(8-k<<2)+e>>2]=h-f;h=z[g+16>>2];f=z[g+12>>2];z[(7-k<<2)+e>>2]=h-f;z[i+8>>2]=-C(h+f);d=d+1|0;continue}break}_H(e+48|0);_H(e);z[e+4>>2]=-z[e+4>>2];z[e+12>>2]=-z[e+12>>2];z[e+20>>2]=-z[e+20>>2];z[e+28>>2]=-z[e+28>>2];g=0;while(1){if((g|0)!=9){d=g<<2;i=d+b|0;h=z[i>>2];f=z[d+(e+48|0)>>2];l=z[d+7e4>>2];m=z[d+70036>>2];n=z[d+e>>2];z[i>>2]=C(f*l)-C(m*n);i=a+d|0;d=c+d|0;f=C(C(f*m)+C(n*l));z[i>>2]=C(h*z[d>>2])-C(z[d+36>>2]*f);z[(17-g<<2)+a>>2]=C(h*z[d+36>>2])+C(f*z[d>>2]);g=g+1|0;continue}break}b=b+36|0;a=a+72|0;j=j+1|0;continue}break}jb=e+96|0}function d3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb+-64|0;jb=e;a:{b:{if((b|0)>=0){d=v[a+24>>2];if(lj(Zb(v[d+484360>>2],w[d+484376|0]))>>>0>b>>>0){break b}}a=a+16|0;break a}d=0;c:{f=v[a+24>>2];g=v[f+484344>>2];i=v[f+484348>>2];h=x[dc(v[Zb(v[f+484360>>2],w[f+484376|0])>>2],b)>>1];if(!xm(g,i,h)){break c}if((c|0)>=0){d=c;if((d|0)<v[$b(g,h)+12>>2]){break c}}a=a+16|0;break a}u[f+1074448>>1]=b;c=f;f=b&65535;jM(c,f);c=v[a+24>>2];v[c+1074392>>2]=-2;v[c+1074428>>2]=d;g=w[a+64|0];b=e+24|0;u[b+4>>1]=0;t[b+6|0]=255;v[b+16>>2]=2;v[b>>2]=0;v[b+8>>2]=d;u[b+12>>1]=f;d=v[b+20>>2];v[e+16>>2]=v[b+16>>2];v[e+20>>2]=d;d=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=d;d=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=d;b=e+48|0;Kt(b,c,g?7:1,e);j=a,k=A[cM(v[e+52>>2])>>3],A[j+16>>3]=k;vi(b);a=a+16|0}jb=e- -64|0;return+A[a>>3]}function LL(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;k=jb-16|0;jb=k;t[k+15|0]=c;t[k+14|0]=12;dh(b,w[Wb(k+15|0,k+14|0)|0]);c=0;l=v[b>>2];m=v[b+4>>2];p=re(l,m);while(1){if((c|0)==(p|0)){c=0;t[b+12|0]=0;a:{if(!(d&1)){break a}if(uc(l,m)){break a}c=1;t[b+12|0]=1}if(e>>>0<=11){if(d&2){c=c|4;t[b+12|0]=c}t[b+15|0]=e;t[b+16|0]=e}if(!(g>>>0>11|f>>>0>g>>>0)){if(d&4){t[b+12|0]=c|2}t[b+14|0]=g;t[b+13|0]=f}jb=k+16|0}else{b:{c:{d:{switch(h|0){case 0:j=Db(l,c);i=(c<<2)+a|0;u[j>>1]=w[i+96|0]|w[i+97|0]<<8;i=i+98|0;break c;case 1:break d;default:break b}}j=Db(l,c);i=(c<<2)+a|0;u[j>>1]=w[i+144|0]|w[i+145|0]<<8;i=i+146|0}t[j+2|0]=w[i|0]}e:{if(!c){break e}i=Db(l,c);j=x[i>>1];n=Db(l,c-1|0);o=x[n>>1];if(j>>>0>255|j>>>0>=o>>>0){break e}j=j|o&65280;u[i>>1]=j;if(j>>>0>=x[n>>1]){break e}u[i>>1]=j+256}c=c+1|0;continue}break}}function kN(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-16|0;jb=e;h=-1;a:{if(!gy(a,b,2)){break a}f=v[b+656>>2];g=a+1074312|0;Bb(e+8|0,g,31);b:{if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){d=v[b+740>>2];if(d){break b}break a}d=v[b+740>>2]}Bb(e+8|0,g,31);g=d-Cb(v[v[e+8>>2]>>2],v[e+12>>2])|0;i=v[a+480180>>2];d=(i|0)==4096;j=f+88|0;f=d?64:(i|0)==16384?192:512;d=Lp(j,g,f,d?255:64)-(f>>>1|0)|0;if(w[b+746|0]&16){h=Gp(a,b,!(v[b+88>>2]&32768),d);break a}if(oj(v[b+656>>2])){if((d|0)==u[b+772>>1]){break a}k=b,l=Xc(d),u[k+772>>1]=l;t[b+851|0]=w[b+851|0]|64;break a}a=gj(a);v[e+8>>2]=d;c:{if((d|0)<0){v[e+8>>2]=0-d;Wh(e+8|0,255);a=(v[e+8>>2]<<2)+(a?38160:37136)|0;break c}Wh(e+8|0,255);a=(v[e+8>>2]<<2)+(a?37136:38160)|0}a=v[a>>2];b=a;d=a>>31;a=v[c>>2];k=c,l=Ic(Tia(Sia(b,d,a,a>>31),mb,65536,0),mb),v[k>>2]=l}jb=e+16|0;return h}function eca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){f=v[b+8>>2];n=((((v[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;o=u[e+39718>>1];p=u[e+39716>>1];q=u[e+39714>>1];r=u[e+39712>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;v[(e<<2)+b>>2]=(((B(u[f>>1],q)+B(u[f-4>>1],r)|0)+B(u[f+4>>1],p)|0)+B(u[f+8>>1],o)|0)/16384;e=e+1|0;continue}break}h=h+k|0;v[c>>2]=v[c>>2]+B(v[b>>2],h>>12);g=g+j|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g>>12);Sb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;jb=b+16|0}function h9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;pd(c,0);u[c+28>>1]=w[a+36|0]<<2;d=w[a+37|0];u[c+32>>1]=64;u[c+30>>1]=d<<2;v[c>>2]=w[a+40|0]|w[a+41|0]<<8|(w[a+42|0]<<16|w[a+43|0]<<24);v[c+4>>2]=w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24);v[c+8>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[c+24>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);d=w[b+151|0];if(d>>>0<=4){t[c+38|0]=w[d+42714|0]}d=w[b+152|0]|w[b+153|0]<<8;t[c+39|0]=d;e=(w[b+156|0]|w[b+157|0]<<8)>>>4|0;t[c+41|0]=e;b=(w[b+154|0]|w[b+155|0]<<8)>>>2|0;t[c+40|0]=b;if((b|e)&255){t[c+39|0]=d^-1}b=w[a+38|0]|w[a+39|0]<<8;if(b&4){u[c+34>>1]=x[c+34>>1]|1;b=w[a+38|0]|w[a+39|0]<<8}if(b&8){u[c+34>>1]=x[c+34>>1]|2;b=w[a+38|0]|w[a+39|0]<<8}if(b&16){u[c+34>>1]=x[c+34>>1]|4;b=w[a+38|0]|w[a+39|0]<<8}if(b&32){u[c+34>>1]=x[c+34>>1]|32}}function V9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-880|0;jb=b;c=Xb(a,0,76);v[c+84>>2]=0;v[c+88>>2]=0;v[c+80>>2]=256;u[c+76>>1]=65535;v[c+92>>2]=0;v[c+96>>2]=0;t[c+100|0]=1;d=c+223848|0;e=c+616|0;a=e;while(1){a=LP(a)+872|0;if((d|0)!=(a|0)){continue}break}d=Qb(d);g=Gy(c+223860|0);f=b+8|0;Xb(f,0,108);Gz(b+120|0,48e3);Xb(b+664|0,0,72);t[b+754|0]=0;u[b+752>>1]=65535;t[b+746|0]=0;u[b+744>>1]=65535;t[b+738|0]=0;u[b+736>>1]=65535;v[b+748>>2]=0;v[b+740>>2]=0;Xb(b+756|0,0,103);v[b+868>>2]=0;v[b+872>>2]=0;t[b+875|0]=0;t[b+876|0]=0;t[b+877|0]=0;t[b+878|0]=0;v[b+860>>2]=0;v[b+864>>2]=0;t[b+859|0]=w[b+859|0]&128;a=((e+223232|0)-e|0)/872|0;while(1){if((a|0)>0){a=a-1|0;e=Bp(e,f)+872|0;continue}break}v[23296]=0;R(489,d|0,32);a=v[23296];v[23296]=0;if((a|0)!=1){jb=b+880|0;return c|0}a=P()|0;O()|0;Cp(g);fc(d);S(a|0);L()}function Cy(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=x[a+480188>>1];h=d>>>0>256?d:256;f=v[a+1298300>>2];c=d;a:{while(1){if((c|0)!=(h|0)){e=B(c,872)+a|0;if(!v[e+1075068>>2]){if(!Sj(v[e+1075648>>2])|w[e+1075081|0]&24){break a}}if(w[e+1075081|0]&2){if(!xd(f)){break a}if(!XM(f,c&65535)){break a}}c=c+1|0;continue}break}e=0;f=65535;g=8388608;if(b>>>0<=255){b=B(b,872)+a|0;if(!v[b+1075688>>2]){c=65535;if(v[b+1075068>>2]){break a}}g=v[b+1075680>>2]|v[b+1075672>>2]<<9}while(1){if((d|0)==(h|0)){c=f;break a}b=B(d,872)+a|0;if(!(v[b+1075688>>2]?0:v[b+1075068>>2])){c=(v[b+1075680>>2]|v[b+1075672>>2]<<9)>>>(v[b+1075080>>2]>>>1&1)|0;b:{c:{if(c>>>0<g>>>0){b=v[(B(d,872)+a|0)+1075716>>2];break c}if((c|0)!=(g|0)){break b}b=v[(B(d,872)+a|0)+1075716>>2];if(e>>>0>=b>>>0){break b}}g=c;f=d;e=b}d=d+1|0;continue}break}c=d}return c&65535}function t6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;b=li(a,b,c,d);v[b+4260>>2]=0;v[b>>2]=46700;c=b+4960|0;e=b+4504|0;d=e;while(1){d=Qb(d)+24|0;if((d|0)!=(c|0)){continue}break}t[b+5046|0]=1;u[b+5044>>1]=0;a=b+4208|0;f=Db(a,0),g=1063675494,v[f>>2]=g;f=Db(a,1),g=1065185444,v[f>>2]=g;f=Db(a,2),g=0,v[f>>2]=g;f=Db(a,3),g=1032805417,v[f>>2]=g;f=Db(a,4),g=1053079357,v[f>>2]=g;f=Db(a,5),g=1059859440,v[f>>2]=g;f=Db(a,6),g=1047457519,v[f>>2]=g;f=Db(a,7),g=1062836634,v[f>>2]=g;f=Db(a,8),g=1038174126,v[f>>2]=g;f=Db(a,9),g=1065353216,v[f>>2]=g;f=Db(a,10),g=1065353216,v[f>>2]=g;f=Db(a,11),g=1048525618,v[f>>2]=g;f=Db(a,12),g=1059760811,v[f>>2]=g;v[23296]=0;R(851,b+44|0,2);a=v[23296];v[23296]=0;if((a|0)==1){a=P()|0;O()|0;while(1){c=vc(c-24|0);if((e|0)!=(c|0)){continue}break}uf(b);S(a|0);L()}ki(b);return b|0}function XH(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=v[a+32>>2];a:{b:{b=v[a+1380>>2];if((b|0)==-1){d=1;b=-1;break b}e=v[a+1116>>2];d=(b|0)>(e|0)?b:e;while(1){c:{if((b|0)!=(d|0)){f=w[(a+b|0)+1120|0];c=f+c|0;if((f|0)==255){break c}d=b}if(y[a+40>>2]<c>>>0){bc(a,1);break a}b=(d|0)==(e|0)?-1:d;d=0;break b}b=b+1|0;continue}}while(1){if((b|0)!=-1){return 1}e=v[a+40>>2];if(e>>>0<=c+26>>>0){bc(a,1);break a}if(Pb(c,92704,4)){bc(a,21);break a}if(w[c+4|0]){bc(a,21);break a}d:{if(d){if(!v[a+992>>2]|!(t[c+5|0]&1)){break d}bc(a,21);break a}if(t[c+5|0]&1){break d}bc(a,21);break a}b=0;f=c+27|0;d=w[c+26|0];c=f+d|0;if(e>>>0<c>>>0){bc(a,1);break a}while(1){e:{if((b|0)==(d|0)){b=d;break e}g=w[b+f|0];c=g+c|0;if((g|0)!=255){break e}b=b+1|0;continue}break}b=(b|0)==(d|0)?-1:b;d=0;if(c>>>0<=e>>>0){continue}break}bc(a,1)}return 0}function UE(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-48|0;jb=d;v[23296]=0;Y(900,a|0);e=v[23296];v[23296]=0;a:{b:{c:{if((e|0)!=1){e=Kb(d+32|0);v[23296]=0;Y(c|0,d+16|0);c=v[23296];v[23296]=0;d:{e:{if((c|0)!=1){h=d,i=Eb(v[d+16>>2]),v[h+8>>2]=i;f=1;while(1){g=Eb(v[d+20>>2]);c=v[d+8>>2];if(!Rb(c,g)){c=Xf(Jc(e));Me(d+16|0);yb(e);break b}if(!f){v[23296]=0;Q(889,e|0,14464)|0;c=v[23296];v[23296]=0;if((c|0)==1){break e}c=v[d+8>>2]}v[23296]=0;Q(753,e|0,c|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break e}$p(d+8|0);f=0;continue}}c=V(0)|0;O()|0;break d}c=V(0)|0;O()|0;Me(d+16|0)}yb(e);break c}c=V(0)|0;O()|0}_(c|0)|0;c=0;v[23296]=0;X(887,b|0,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$()}jb=d+48|0;return c}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)==1){V(0)|0;O()|0;Ub();L()}S(a|0);L()}function eG(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=jb-32|0;jb=h;a:{b:{c:{if((b|0)!=(c|0)){j=v[115772];v[115772]=0;g=jb-16|0;jb=g;Bd();e=jb-16|0;jb=e;f=jb-16|0;jb=f;rw(f,b,h+28|0,2);k=v[f>>2];i=v[f+4>>2];b=v[f+12>>2];v[e+8>>2]=v[f+8>>2];v[e+12>>2]=b;v[e>>2]=k;v[e+4>>2]=i;jb=f+16|0;i=v[e>>2];f=v[e+4>>2];b=v[e+12>>2];v[g+8>>2]=v[e+8>>2];v[g+12>>2]=b;v[g>>2]=i;v[g+4>>2]=f;jb=e+16|0;f=v[g>>2];e=v[g+4>>2];b=v[g+12>>2];v[h+16>>2]=v[g+8>>2];v[h+20>>2]=b;v[h+8>>2]=f;v[h+12>>2]=e;jb=g+16|0;i=v[h+16>>2];f=v[h+20>>2];g=v[h+8>>2];e=v[h+12>>2];b=v[115772];if(!b){break c}if(v[h+28>>2]!=(c|0)){break b}l=g;m=e;n=i;o=f;if((b|0)!=68){break a}break b}v[d>>2]=4;break a}v[115772]=j;if(v[h+28>>2]==(c|0)){break a}}v[d>>2]=4;g=l;e=m;i=n;f=o}v[a>>2]=g;v[a+4>>2]=e;v[a+8>>2]=i;v[a+12>>2]=f;jb=h+32|0}function fca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;b=jb-16|0;jb=b;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){f=v[b+8>>2];n=(((v[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;o=u[e+39718>>1];p=u[e+39716>>1];q=u[e+39714>>1];r=u[e+39712>>1];e=0;while(1){if((e|0)!=2){f=e+n|0;v[(e<<2)+b>>2]=(((B(t[f|0],q)+B(t[f-2|0],r)|0)+B(t[f+2|0],p)|0)+B(t[f+4|0],o)<<8)/16384;e=e+1|0;continue}break}h=h+k|0;v[c>>2]=v[c>>2]+B(v[b>>2],h>>12);g=g+j|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g>>12);Sb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;jb=b+16|0}function tt(a,b){var c=0,d=0,e=0,f=0;e=jb-48|0;jb=e;d=e+24|0;MP(d,a+8|0,a+10|0,a+12|0,a+16|0,a+14|0);MP(e,b+8|0,b+10|0,b+12|0,b+16|0,b+14|0);b=v[d>>2];b=Mb(w[b|0]|w[b+1|0]<<8);a=v[e>>2];a=Mb(w[a|0]|w[a+1|0]<<8);c=1;a:{if(b>>>0<a>>>0){break a}c=0;if(a>>>0<b>>>0){break a}b=v[d+4>>2];b=Mb(w[b|0]|w[b+1|0]<<8);a=v[e+4>>2];a=Mb(w[a|0]|w[a+1|0]<<8);c=1;b:{if(b>>>0<a>>>0){break b}c=0;if(a>>>0<b>>>0){break b}b=v[d+8>>2];b=Mb(w[b|0]|w[b+1|0]<<8);a=v[e+8>>2];a=Mb(w[a|0]|w[a+1|0]<<8);c=1;c:{if(b>>>0<a>>>0){break c}c=0;if(a>>>0<b>>>0){break c}b=v[d+16>>2];a=v[e+12>>2];f=v[e+16>>2];d=v[d+12>>2];d=Mb(w[d|0]|w[d+1|0]<<8)<<16>>16;a=Mb(w[a|0]|w[a+1|0]<<8)<<16>>16;c=1;d:{if((d|0)<(a|0)){break d}c=0;if((a|0)<(d|0)){break d}c=Mb(w[b|0]|w[b+1|0]<<8)>>>0<Mb(w[f|0]|w[f+1|0]<<8)>>>0}}}}a=c;jb=e+48|0;return a}function bv(a,b,c,d){var e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;a:{if(!c){break a}if(d){b=gc(g+8|0,a,b);a=jb-16|0;jb=a;v[a+12>>2]=c;d=v[b+4>>2];b:{if(!d){d=v[b>>2];break b}e=32-d|0;v[a+8>>2]=e;c=v[b>>2];h=e;e=v[Ib(a+8|0,a+12|0)>>2];v[c>>2]=-1<<d&-1>>>h-e|v[c>>2];f=v[a+12>>2];d=c+4|0;v[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Xb(e,255,d);e=c&31;v[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=d+v[b>>2]|0;v[c>>2]=b;v[b>>2]=v[b>>2]|-1>>>32-e}jb=a+16|0;break a}b=gc(g,a,b);a=jb-16|0;jb=a;v[a+12>>2]=c;d=v[b+4>>2];c:{if(!d){d=v[b>>2];break c}e=32-d|0;v[a+8>>2]=e;c=v[b>>2];f=v[c>>2];h=e;e=v[Ib(a+8|0,a+12|0)>>2];v[c>>2]=(-1<<d&-1>>>h-e^-1)&f;f=v[a+12>>2];d=c+4|0;v[b>>2]=d;c=f-e|0}e=d;d=c>>>5<<2;Xb(e,0,d);e=c&31;v[a+12>>2]=e;if((c&-32)!=(c|0)){c=b;b=d+v[b>>2]|0;v[c>>2]=b;v[b>>2]=v[b>>2]&(-1>>>32-e^-1)}jb=a+16|0}jb=g+16|0}function kga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=jb-432|0;jb=d;Ac(b);xA(b,d+376|0,d+296|0,d+8|0);k=d,l=xi((m=w[d+427|0]+1|0,n=1,o=cc(v[d+408>>2]),o?m:n)),t[k+4|0]=l;i=w[Wb(26640,d+4|0)|0];t[d+7|0]=i;u[d+4>>1]=4;a:{b:{while(1){if((h&255)>>>0>=i>>>0){break b}e=Mb(x[d+8>>1])<<16>>16;if(!((e|0)<0|w[d+291|0]>63)){e=e&65535;f=0;while(1){if((f|0)==(e|0)){c:{e=g;g=cc(v[d+296>>2]);if(e>>>0<g>>>0){if($c(b,g)){break c}}t[d+7|0]=h+1;break b}}else{d:{if(!$c(b,cc(v[d+392>>2])+(f<<2)|0)){break d}if(!$c(b,sm(b))){break d}e:{if(!c){j=Ee(b);break e}j=yq(b)}u[d+2>>1]=j;k=d,l=x[We(d+4|0,d+2|0)>>1],u[k+4>>1]=l}f=f+1|0;continue}break}g=cc(v[d+296>>2]);xA(b,d+376|0,d+296|0,d+8|0);h=h+1|0;continue}break}cv(a);break a}u[a>>1]=x[d+4>>1];t[a+2|0]=w[d+7|0]}jb=d+432|0}function Mia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-48|0;jb=g;h=a+8|0;c=v[a+8>>2];j=zc(a);a:{if((c|0)!=v[j>>2]){break a}i=a+4|0;e=v[a+4>>2];d=v[a>>2];if(e>>>0>d>>>0){a=e;d=((a-d>>1)+1|0)/-2<<1;e=a+d|0;while(1){if((a|0)!=(c|0)){e=wU(e,a)+2|0;a=a+2|0;continue}break}c=e;v[h>>2]=c;v[i>>2]=d+v[i>>2];break a}v[g+24>>2]=c-d;v[g+44>>2]=1;e=g+24|0;c=v[Yc(e,g+44|0)>>2];c=xj(e,c,c>>>2|0,v[a+16>>2]);d=hc(g+16|0,v[a+4>>2]);f=v[hc(g+8|0,v[a+8>>2])>>2];e=jb-32|0;jb=e;d=v[d>>2];v[e+24>>2]=d;d=Eo(e+8|0,c+8|0,vB(d,f));f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){k=f;f=v[e+24>>2];uq(k,w[f|0]|w[f+1|0]<<8);f=v[d>>2]+2|0;v[d>>2]=f;Se(e+24|0);continue}break}Id(d);jb=e+32|0;oc(a,c);oc(i,c+4|0);oc(h,c+8|0);oc(j,zc(c));Gi(c);c=v[a+8>>2]}uq(c,w[b|0]|w[b+1|0]<<8);v[h>>2]=v[h>>2]+2;jb=g+48|0}function Bd(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;if(w[467124]){return v[116780]}c=jb-32|0;jb=c;a:{b:{while(1){e=(c+8|0)+(a<<2)|0;d=1<<a&2147483647;if(d|1){d=AG(a,d?14138:21473)}else{d=v[a<<2>>2]}v[e>>2]=d;if((d|0)==-1){break b}a=a+1|0;if((a|0)!=6){continue}break}if(!zG(0)){b=88800;if(!Pb(c+8|0,88800,24)){break a}b=88824;if(!Pb(c+8|0,88824,24)){break a}a=0;if(!w[466896]){while(1){f=(a<<2)+466848|0,g=AG(a,21473),v[f>>2]=g;a=a+1|0;if((a|0)!=6){continue}break}t[466896]=1;v[116718]=v[116712]}b=466848;if(!Pb(c+8|0,466848,24)){break a}b=466872;if(!Pb(c+8|0,466872,24)){break a}b=Jd(24);if(!b){break b}}a=v[c+12>>2];v[b>>2]=v[c+8>>2];v[b+4>>2]=a;a=v[c+28>>2];v[b+16>>2]=v[c+24>>2];v[b+20>>2]=a;a=v[c+20>>2];v[b+8>>2]=v[c+16>>2];v[b+12>>2]=a;break a}b=0}jb=c+32|0;t[467124]=1;v[116780]=b;return b}function Cba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-16|0;jb=f;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){b=(v[f+12>>2]<<1)+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(u[b+4>>1],u[e+10>>1])+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/2|0)+((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)/2|0)|0)/16384|0;h=h+l|0;v[c>>2]=v[c>>2]+B(b,h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(b,g>>12);Sb(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;jb=f+16|0}function Mz(a,b){var c=0;c=jb-16|0;jb=c;a=Zq(a);a:{b:{c:{switch(b-1|0){default:if((b|0)!=16777216){break b}Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(Nb(a,7,1),9,1),10,1),13,1),15,1),16,1),17,1),18,1),20,1),21,1),24,1),25,1),26,1),28,1),30,1),31,1),33,1),34,1),39,1),41,1),44,1),46,1),45,1),47,1),48,1),50,1),99,1),102,1),104,1),105,1),115,1);break a;case 1:py(c,2);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Bf(a,107);break a;case 3:py(c,4);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b;Bf(a,4);break a;case 2:break b;case 0:break c}}Nb(a,88,1);break a}py(c,b);b=v[c+12>>2];v[a+8>>2]=v[c+8>>2];v[a+12>>2]=b;b=v[c+4>>2];v[a>>2]=v[c>>2];v[a+4>>2]=b}jb=c+16|0}function aK(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0;j=jb-48|0;jb=j;k=v[a+4>>2];l=v[a>>2];a=v[a+8>>2];v[j+32>>2]=b;v[j+44>>2]=a;v[j+36>>2]=l;v[j+40>>2]=k;v[23296]=0;a=Q(880,(d?d:881)|0,e|0)|0;b=v[23296];v[23296]=0;a:{b:{c:{d:{if((b|0)!=1){v[j+16>>2]=a;a=v[Tf(j+24|0,j+16|0)>>2];b=v[j+44>>2];v[j+8>>2]=v[j+40>>2];v[j+12>>2]=b;v[23296]=0;b=v[j+36>>2];v[j>>2]=v[j+32>>2];v[j+4>>2]=b;c=+Aa(882,j|0,+c,a|0);a=v[23296];v[23296]=0;if((a|0)==1){break d}te(j+16|0);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;te(j+16|0)}_(a|0)|0;v[23296]=0;ia(883,14887,d|0,e|0,f|0,g|0,h|0,i|0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();c=0}jb=j+48|0;return+c}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function qM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;a:{c=jb-16|0;jb=c;e=Kb(a);g=c,h=Ii(b),v[g+8>>2]=h;g=c,h=jv(b),v[g>>2]=h;a=0;b:{while(1){c:{if(!Nh(c+8|0,c)){if(!a){break c}v[23296]=0;R(48,e|0,65533);a=v[23296];v[23296]=0;if((a|0)!=1){break c}break b}b=w[v[c+8>>2]];d:{e:{if(!a){if(!(b&128)){a=0;v[23296]=0;R(48,e|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break d}break b}if((b&224)==192){d=b&31;a=1;break d}if((b&240)==224){d=b&15;a=2;break d}d=65533;if((b&248)!=240){break e}d=b&7;a=3;break d}if((b&192)!=128){d=0;v[23296]=0;R(48,e|0,65533);f=v[23296];v[23296]=0;a=0;if((f|0)==1){break b}}d=b&63|d<<6;a=a-1|0;if(a){break d}}a=0;v[23296]=0;R(48,e|0,d|0);b=v[23296];v[23296]=0;d=0;if((b|0)==1){break b}}Be(c+8|0);continue}break}jb=c+16|0;break a}a=P()|0;O()|0;Kc(e);S(a|0);L()}}function o8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;a:{b:{if((zj(v[a>>2],v[a+4>>2])|0)==2){if((zj(v[a+12>>2],v[a+16>>2])|0)==(b|0)){break b}}v[23296]=0;R(853,a|0,2);c=v[23296];v[23296]=0;c:{if((c|0)==1){break c}v[23296]=0;R(853,a+12|0,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break c}v[23296]=0;R(854,a+24|0,2);c=v[23296];v[23296]=0;if((c|0)==1){break c}v[23296]=0;R(854,a+36|0,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break c}c=a;while(1)if((d|0)==2){a=0;while(1){if((a|0)==(b|0)){break b}d=Wq(v[c+12>>2],a);f=Db(v[c+36>>2],a),g=d,v[f>>2]=g;a=a+1|0;continue}}else{e=Wq(v[a>>2],d);f=Db(v[a+24>>2],d),g=e,v[f>>2]=g;d=d+1|0;continue}}b=V(91780)|0;if((O()|0)!=(ea(91780)|0)){break a}_(b|0)|0;Hc(a);iL(a);b=a+12|0;Hc(b);iL(b);b=a+24|0;Hc(b);hL(b);a=a+36|0;Hc(a);hL(a);$()}return}S(b|0);L()}function E2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-32|0;jb=d;j=d,k=DJ(),v[j+24>>2]=k;g=a+24|0;c=d+24|0;BJ(g,de(c));dj(c);u[a+28>>1]=0;nP();f=jb-16|0;jb=f;e=xc(144);v[23296]=0;h=Q(1012,e|0,4)|0;i=v[23296];v[23296]=0;a:{if((i|0)!=1){e=v[xf(f+8|0,h)>>2];jb=f+16|0;break a}a=P()|0;O()|0;Jb(e);S(a|0);L()}v[d+24>>2]=e;AJ(a+32|0,de(c));os(c);j=d,k=CJ(v[a>>2]),v[j+24>>2]=k;zJ(a+4|0,de(c));cj(c);zn(v[g>>2],v[a+4>>2]);v[a+60>>2]=0;v[a+48>>2]=1065353216;v[a+52>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;t[a- -64|0]=0;j=d,k=qj(v[b>>2]),v[j+24>>2]=k;e=yf(b);b:{while(1){b=v[d+24>>2];if(!Ag(b,e)){break b}c=vd(b);b=Rh(d+8|0,c);v[23296]=0;X(916,a|0,b|0,c+12|0,0);c=v[23296];v[23296]=0;if((c|0)!=1){yb(b);Xg(d+24|0);continue}break}a=P()|0;O()|0;yb(b);S(a|0);L()}jb=d+32|0}function jL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;a:{if(wc(v[a>>2],v[a+4>>2])>>>0>511){break a}if(!Kg(v[v[b>>2]-12>>2]+b|0)){break a}d=jb-16|0;jb=d;f=xc(64);v[23296]=0;g=T(788,f|0)|0;h=v[23296];v[23296]=0;b:{c:{if((h|0)!=1){f=xf(d,g);g=v[f>>2];v[23296]=0;g=W(848,g|0,b|0,c|0)|0;h=v[23296];v[23296]=0;d:{e:{if((h|0)!=1){if((g|0)==1){break e}Cc(d+8|0);break d}a=P()|0;O()|0;ig(f);break c}Tf(d+8|0,f)}ig(f);jb=d+16|0;d=v[d+8>>2];break b}a=P()|0;O()|0;Jb(f)}S(a|0);L()}v[e+8>>2]=d;f:{g:{if(!xd(d)){v[23296]=0;b=Q(847,b|0,c|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break g}v[e>>2]=b;XS(e+8|0,de(e));ig(e);d=v[e+8>>2]}if(!xd(d)){break f}v[23296]=0;R(434,a|0,e+8|0);a=v[23296];v[23296]=0;i=d;if((a|0)!=1){break f}}a=P()|0;O()|0;ig(e+8|0);S(a|0);L()}ig(e+8|0)}jb=e+16|0;return i}function G7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=C(0);c=jb-4112|0;jb=c;h=nb[v[v[a>>2]+116>>2]](a)|0;if(!h){nb[v[v[a>>2]+120>>2]](a)}v[c+12>>2]=0;f=jb-16|0;jb=f;while(1){d=v[a+44>>2];if(zj(d,v[a+48>>2])>>>0<=e>>>0){jb=f+16|0}else{v[f+12>>2]=0;d=Wq(d,e);g=(d+2048|0)-d>>2;while(1){if((g|0)>0){z[d>>2]=z[f+12>>2];g=g-1|0;d=d+4|0;continue}break}e=e+1|0;continue}break}f=c+2064|0;a:while(1){if(b){v[c+8>>2]=b;yc(c+8|0,512);e=c+16|0;ty(e);d=v[c+8>>2];nb[v[v[a>>2]+60>>2]](a,e,f,d);e=0;while(1)if((e|0)==(d|0)){b=b-d|0;continue a}else{g=(c+16|0)+(e<<2)|0;z[c+4>>2]=D(z[g>>2]);i=c,j=z[Gx(c+12|0,c+4|0)>>2],z[i+12>>2]=j;z[c+4>>2]=D(z[g+2048>>2]);i=c,j=z[Gx(c+12|0,c+4|0)>>2],z[i+12>>2]=j;e=e+1|0;continue}}break}if(!h){nb[v[v[a>>2]+124>>2]](a)}jb=c+4112|0;return C(z[c+12>>2])}function DB(a,b){var c=0,d=0;d=w[a|0];if(d>>>0>=36){t[a|0]=0;return}c=w[d+26144|0];t[a|0]=c;a:{b:{c:{switch(c-17|0){default:d:{if(c-6>>>0<2){break d}if((c|0)==31){break b}if((c|0)==11){break d}if(w[b|0]|(c|0)!=1){break a}t[a|0]=0;return}c=w[b|0];a=c&240;if(!a|(a|0)==240|(c&15)==15){break a}t[b|0]=a;return;case 6:a=w[b|0];if(a>>>0<=64){t[b|0]=a<<1;return}t[b|0]=128;return;case 2:e:{f:{g:{h:{c=w[b|0];switch((c&240)-48>>>4|0){case 4:break e;case 2:break f;case 1:break g;case 0:break h;default:break a}}t[a|0]=20;t[b|0]=159;return}t[a|0]=20;t[b|0]=192;return}if(c&14){break a}t[a|0]=21;t[b|0]=(w[b|0]!=80)<<6;return}t[a|0]=20;t[b|0]=w[b|0]&15|160;return;case 1:case 3:case 4:case 5:break a;case 0:break c}}if(w[b|0]>31){break a}t[a|0]=16;return}t[b|0]=(d<<5|w[b|0]<<24>>>27)^128}}function od(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;b=v[a+112>>2];d=v[a+116>>2];e=!!(b|d);c=b;a:{i=e;f=v[a+4>>2];e=v[a+44>>2];b=f-e|0;h=b;g=b+v[a+120>>2]|0;b=v[a+124>>2]+(b>>31)|0;b=g>>>0<h>>>0?b+1|0:b;if(!(i&(c>>>0<=g>>>0&(b|0)>=(d|0)|(b|0)>(d|0)))){h=yw(a);if((h|0)>=0){break a}f=v[a+4>>2];e=v[a+44>>2]}v[a+112>>2]=-1;v[a+116>>2]=-1;v[a+104>>2]=f;c=e-f|0;d=c+g|0;b=(c>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<c>>>0?b+1|0:b;return-1}d=g+1|0;b=d?b:b+1|0;f=v[a+4>>2];e=v[a+8>>2];c=v[a+112>>2];g=v[a+116>>2];b:{if(!(c|g)){break b}i=c-d|0;c=g-(b+(d>>>0>c>>>0)|0)|0;j=e-f|0;g=j>>31;if((c|0)>=(g|0)&i>>>0>=j>>>0|(c|0)>(g|0)){break b}e=f+i|0}v[a+104>>2]=e;c=v[a+44>>2];e=c-f|0;d=e+d|0;b=(e>>31)+b|0;v[a+120>>2]=d;v[a+124>>2]=d>>>0<e>>>0?b+1|0:b;if(c>>>0>=f>>>0){t[f-1|0]=h}return h}function Dba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-16|0;jb=f;g=v[a+40>>2];h=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){b=v[f+12>>2]+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(t[b+2|0],u[e+10>>1])+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/2|0)+((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])<<8)/2|0)|0)/16384|0;h=h+l|0;v[c>>2]=v[c>>2]+B(b,h>>12);g=g+k|0;v[c+4>>2]=v[c+4>>2]+B(b,g>>12);Sb(f+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;v[a+40>>2]=g;v[a+20>>2]=h>>12;v[a+36>>2]=h;v[a+24>>2]=g>>12;jb=f+16|0}function Qn(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=v[b+88>>2];d=c|2048;v[b+88>>2]=d;f=v[b+656>>2];if(!(!f|t[b+730|0]&1)){d=c|6144;v[b+88>>2]=d}a:{if(!v[b+76>>2]){break a}b:{if(!(d&8)|c&2048){break b}c=v[b+104>>2];if(!c){break b}e=x[c+34>>1];if(e&2){d=(e&4?d|4:d&-135)|2;v[b+88>>2]=d;e=v[c>>2];v[b+76>>2]=e;g=v[c+4>>2];v[b+80>>2]=g;c=v[c+8>>2];v[b+84>>2]=c;if(c>>>0<e>>>0){v[b+76>>2]=c;h=c}else{h=e}e=v[b+4>>2];if(h>>>0>=e>>>0){break b}v[b>>2]=0;v[b+4>>2]=((e-g>>>0)%(c-g>>>0)|0)+g;break b}d=d&-135;v[b+88>>2]=d;v[b+76>>2]=v[c>>2]}if(!f){break a}if(!(!(v[a+480180>>2]&1064964?1:w[f+60|0]&2)|!v[f>>2])){v[b+88>>2]=d|4096}if(w[f+65|0]==255|x[b+728>>1]!=65535){break a}i=b,j=Xc(Lp(f+48|0,v[b+724>>2],256,64)),u[i+728>>1]=j;i=b,j=x[Db(v[f+48>>2],w[f+65|0])>>1],v[i+724>>2]=j}}function YV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;g=jb-16|0;jb=g;$c(b,w[c+32|0]|w[c+33|0]<<8|(w[c+34|0]<<16|w[c+35|0]<<24));h=Qb(a);a=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);v[23296]=0;R(172,h|0,a|0);a=v[23296];v[23296]=0;if((a|0)!=1){a:{a=0;while(1){b:{if((w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24))>>>0<=a>>>0){break b}e=v[b+8>>2];f=v[b>>2];v[23296]=0;e=W(144,f|0,e|0,4)|0;f=v[23296];v[23296]=0;if((f|0)==1){break a}if(!e){break b}e=w[c+4|0]|w[c+5|0]<<8;v[23296]=0;e=Q(173,b|0,e|0)|0;f=v[23296];v[23296]=0;c:{if((f|0)!=1){v[g+12>>2]=e;if(wd(v[d>>2],v[d+4>>2])>>>0<=e>>>0){break c}v[23296]=0;R(174,h|0,g+12|0);e=v[23296];v[23296]=0;if((e|0)!=1){break c}}break a}a=a+1|0;continue}break}jb=g+16|0;return}}a=P()|0;O()|0;vc(h);S(a|0);L()}function U6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=C(0),g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=C(0),o=C(0),p=0,q=0,r=0,s=0;h=jb-16|0;jb=h;if(Vh(a+44|0)){g=v[a+44>>2];r=h,s=Fc(g,0),v[r+8>>2]=s;r=h,s=Fc(g,1),v[r+12>>2]=s;g=v[a+56>>2];l=Fc(g,0);v[h>>2]=l;m=Fc(g,1);v[h+4>>2]=m;p=w[a+4273|0];q=w[a+4272|0];g=d;while(1){k=0;if(g){while(1){if((k|0)!=2){j=k<<2;i=j+(h+8|0)|0;e=v[i>>2];v[i>>2]=e+4;f=C(z[e>>2]*z[a+4240>>2]);e=a+j|0;i=e+4228|0;f=C(f+C(z[i>>2]*z[a+4236>>2]));z[i>>2]=f;f=BK(C(f*C(1073741824)),q,p);i=e+4244|0;e=e+4252|0;n=z[e>>2];o=z[a+4264>>2];f=C(C(C(f*z[a+4260>>2])-C(z[a+4268>>2]*z[i>>2]))-C(n*o));z[e>>2]=f;z[i>>2]=n+C(f*o);e=h+j|0;j=v[e>>2];v[e>>2]=j+4;z[j>>2]=f*C(9.313225746154785e-10);k=k+1|0;continue}break}g=g-1|0;continue}else{ji(a,b,c,l,m,d)}break}}jb=h+16|0}function pp(a){var b=C(0),c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;e=(p(a),j(2));d=e&2147483647;a:{if(d>>>0<=1061752794){b=C(1);if(d>>>0<964689920){break a}b=_h(+a);break a}if(d>>>0<=1081824209){if(d>>>0>=1075235812){b=C(-_h(((e|0)<0?3.141592653589793:-3.141592653589793)+ +a));break a}f=+a;if((e|0)<0){b=$h(f+1.5707963267948966);break a}b=$h(1.5707963267948966-f);break a}if(d>>>0<=1088565717){if(d>>>0>=1085271520){b=_h(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if((e|0)<0){b=$h(-4.71238898038469-+a);break a}b=$h(+a+-4.71238898038469);break a}b=C(a-a);if(d>>>0>=2139095040){break a}b:{switch(Pw(a,c+8|0)&3){case 0:b=_h(A[c+8>>3]);break a;case 1:b=$h(-A[c+8>>3]);break a;case 2:b=C(-_h(A[c+8>>3]));break a;default:break b}}b=$h(A[c+8>>3])}a=b;jb=c+16|0;return a}function M0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;v[c+28>>2]=0;if(Rd(w[rn(c+24|0,a,0)|0])){d=c+16|0;bd(d,v[v[a>>2]-12>>2]+a|0);v[23296]=0;d=T(1045,d|0)|0;e=v[23296];v[23296]=0;a:{b:{if((e|0)!=1){e=ym(c+8|0,a);f=Cc(c);g=v[v[a>>2]-12>>2];f=v[f>>2];e=v[e>>2];v[23296]=0;ma(1048,d|0,e|0,f|0,a+g|0,c+28|0,c+20|0);d=v[23296];v[23296]=0;if((d|0)!=1){break b}}b=V(0)|0;O()|0;_b(c+16|0);_(b|0)|0;b=v[c+28>>2]|1;v[c+28>>2]=b;qn(v[v[a>>2]-12>>2]+a|0,b);c:{d:{if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23296]=0;Z(93);a=v[23296];v[23296]=0;if((a|0)!=1){break c}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)==1){break d}S(a|0);L()}$();break a}V(0)|0;O()|0;Ub()}L()}_b(c+16|0);v[b>>2]=v[c+20>>2]}vj(v[v[a>>2]-12>>2]+a|0,v[c+28>>2])}jb=c+32|0;return a|0}function Wga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;c=gf(a,c);ae(e,v[a+28>>2]);h=a;a:{if(!c){d=0;if(hd(a,5)){break a}}d=jb-32|0;jb=d;f=v[a+28>>2];Kf(f,d+30|0);b:{c:{d:{e:{a=x[d+30>>1];if(a>>>0>=4001){i=v[b+12>>2];a=jb-16|0;jb=a;g=Vb(a,15750);Sc(d,g);zb(g);jb=a+16|0;v[23296]=0;U(425,d+16|0,d|0,d+30|0);a=v[23296];v[23296]=0;if((a|0)==1){break e}a=v[i+1298464>>2];v[23296]=0;U(353,a|0,2,d+16|0);a=v[23296];v[23296]=0;if((a|0)==1){break d}zb(d+16|0);ec(d);a=4e3}kg(pj(v[b>>2],0),a);b=pj(v[b>>2],0);j=d,k=Eb(v[b>>2]),v[j+16>>2]=k;b=Eb(v[b+4>>2]);break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;zb(d+16|0)}ec(d);S(b|0);L()}while(1){a=v[d+16>>2];if(Rb(a,b)){Kf(f,d);u[a>>1]=x[d>>1];Se(d+16|0);continue}break}jb=d+32|0;d=c}$e(h,d);jb=e+16|0}function XK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;c=jb-16|0;jb=c;e=v[b+4220>>2];f=v[b+4224>>2];g=v[b+4228>>2];h=v[b+4232>>2];i=v[b+4240>>2];j=v[b+4236>>2];l=w[b+4244|0];k=b+4208|0;Li(k,33);d=v[k>>2];t[d+32|0]=l;t[d+24|0]=j;t[d+25|0]=j>>>8;t[d+26|0]=j>>>16;t[d+27|0]=j>>>24;t[d+28|0]=i;t[d+29|0]=i>>>8;t[d+30|0]=i>>>16;t[d+31|0]=i>>>24;t[d+16|0]=g;t[d+17|0]=g>>>8;t[d+18|0]=g>>>16;t[d+19|0]=g>>>24;t[d+20|0]=h;t[d+21|0]=h>>>8;t[d+22|0]=h>>>16;t[d+23|0]=h>>>24;t[d+8|0]=e;t[d+9|0]=e>>>8;t[d+10|0]=e>>>16;t[d+11|0]=e>>>24;t[d+12|0]=f;t[d+13|0]=f>>>8;t[d+14|0]=f>>>16;t[d+15|0]=f>>>24;t[d|0]=76;t[d+1|0]=70;t[d+2|0]=79;t[d+3|0]=32;t[d+4|0]=0;t[d+5|0]=0;t[d+6|0]=0;t[d+7|0]=0;ke(c+8|0,v[k>>2],v[b+4212>>2]);gc(a,v[c+8>>2],v[c+12>>2]);jb=c+16|0}function FK(a){var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;e=(p(a),j(2));c=e&2147483647;a:{if(c>>>0<=1061752794){if(c>>>0<964689920){break a}a=$h(+a);break a}if(c>>>0<=1081824209){d=+a;if(c>>>0<=1075235811){if((e|0)<0){a=C(-_h(d+1.5707963267948966));break a}a=_h(d+-1.5707963267948966);break a}a=$h(-(((e|0)>=0?-3.141592653589793:3.141592653589793)+d));break a}if(c>>>0<=1088565717){if(c>>>0<=1085271519){d=+a;if((e|0)<0){a=_h(d+4.71238898038469);break a}a=C(-_h(d+-4.71238898038469));break a}a=$h(((e|0)<0?6.283185307179586:-6.283185307179586)+ +a);break a}if(c>>>0>=2139095040){a=C(a-a);break a}b:{switch(Pw(a,b+8|0)&3){case 0:a=$h(A[b+8>>3]);break a;case 1:a=_h(A[b+8>>3]);break a;case 2:a=$h(-A[b+8>>3]);break a;default:break b}}a=C(-_h(A[b+8>>3]))}jb=b+16|0;return a}function F8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=jb-16|0;jb=g;j=gf(a,c);ae(g,v[a+28>>2]);k=a;a:{if(!j){c=0;if(hd(a,5)){break a}}e=jb-48|0;jb=e;h=v[a+28>>2];rk(h,e+40|0);c=v[e+44>>2];if(!c&y[e+40>>2]>=257|c){v[e+40>>2]=256;v[e+44>>2]=0}l=v[e+40>>2];m=v[e+44>>2];c=0;b:{c:{d:{e:{while(1){if(!m&c>>>0>=l>>>0){break b}Kf(h,e+38|0);f=Kb(e+24|0);v[23296]=0;Q(432,h|0,f|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){v[23296]=0;U(11,e+8|0,d|0,f|0);a=v[23296];v[23296]=0;if((a|0)==1){break e}v[23296]=0;a=Q(841,b|0,e+38|0)|0;i=v[23296];v[23296]=0;if((i|0)==1){break d}i=a;a=e+8|0;Hb(i,a);zb(a);yb(f);c=c+1|0;continue}break}c=P()|0;O()|0;break c}c=P()|0;O()|0;break c}c=P()|0;O()|0;zb(e+8|0)}yb(f);S(c|0);L()}jb=e+48|0;c=j}$e(k,c);jb=g+16|0}function _H(a){var b=C(0),c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=C(0),j=C(0),k=C(0),l=C(0),m=C(0),n=C(0),o=C(0);f=z[a>>2];i=z[a+24>>2];c=C(f-i);d=z[a+16>>2];b=z[a+32>>2];g=z[a+8>>2];e=C(d+C(b-g));z[a+16>>2]=c+e;j=C(c-C(e*C(.5)));c=z[a+4>>2];e=z[a+20>>2];h=z[a+28>>2];k=C(C(C(c-e)-h)*C(.8660253882408142));z[a+4>>2]=j+k;l=C(C(d-b)*C(.1736481785774231));f=C(f+C(i*C(.5)));i=C(C(g+b)*C(.7660444378852844));m=C(l+C(f-i));n=C(C(c+e)*C(.9848077297210693));b=C(z[a+12>>2]*C(.8660253882408142));c=C(C(c+h)*C(.6427876353263855));o=C(C(n-b)-c);z[a+12>>2]=m+o;z[a+20>>2]=m-o;z[a+28>>2]=j-k;d=C(C(g+d)*C(.9396926164627075));g=C(C(f+d)-l);e=C(C(e-h)*C(.3420201539993286));h=C(C(e-b)-n);z[a+32>>2]=g+h;d=C(C(f-d)+i);b=C(C(b+e)-c);z[a+24>>2]=d+b;z[a+8>>2]=d-b;z[a>>2]=g-h}function a_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=NF(c);b:{if(b){xk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;wk(k,a);break b}wr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Hh(k,a)}Pi(i,k);Kc(k);l=e,m=Ui(a),v[l>>2]=m;l=f,m=Vi(a),v[l>>2]=m;Ng(k,a);Bc(g,k);yb(k);Ih(k,a);Pi(h,k);Kc(k);a=vk(a);break a}a=MF(c);c:{if(b){xk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;wk(k,a);break c}wr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Hh(k,a)}Pi(i,k);Kc(k);l=e,m=Ui(a),v[l>>2]=m;l=f,m=Vi(a),v[l>>2]=m;Ng(k,a);Bc(g,k);yb(k);Ih(k,a);Pi(h,k);Kc(k);a=vk(a)}v[j>>2]=a;jb=k+16|0}function $W(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-192|0;jb=c;b=c+16|0;gi(b,a);v[23296]=0;R(77,c+32|0,b|0);a=v[23296];v[23296]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23296]=0;a=Q(78,c+48|0,c+32|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break e}yb(c+32|0);yb(c+16|0);b=v[v[a>>2]-12>>2];v[23296]=0;d=ga(61)|0;e=v[23296];v[23296]=0;if((e|0)==1){break c}v[23296]=0;U(62,c+8|0,a+b|0,d|0);b=v[23296];v[23296]=0;if((b|0)==1){break c}_b(c+8|0);b=a+v[v[a>>2]-12>>2]|0;v[b+4>>2]=v[b+4>>2]&-75;v[b+4>>2]=v[b+4>>2]|8;v[23296]=0;b=Q(83,a|0,c+32|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break c}a=Hk(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=v[c+32>>2];jf(b);jb=c+192|0;a=a?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(c+32|0)}yb(c+16|0);break b}b=P()|0;O()|0;jf(a)}S(b|0);L()}return a|0}function Lk(a,b,c){var d=0,e=0,f=0,g=0;e=jb-48|0;jb=e;d=v[a+24>>2];g=v[d+24620>>2];a:{if(!((g|0)==(b|0)&v[d+24624>>2]==(c|0))){f=e+8|0;qc(f,d+24604|0,40);v[e+28>>2]=c;v[e+24>>2]=b;c=v[e+44>>2];ps(f,v[e+40>>2]);Zn(f,c);ly(d,f);if((b|0)==(g|0)){break a}b=v[a+24>>2];d=b+946300|0;c=b+906300|0;while(1){if((c|0)!=(d|0)){b=v[c>>2];b:{if(!b){break b}if(!(nb[v[v[b>>2]+116>>2]](b)|0)){break b}nb[v[v[b>>2]+108>>2]](b,0);nb[v[v[b>>2]+96>>2]](b);nb[v[v[b>>2]+124>>2]](b)}c=c+160|0;continue}break}b=v[a+24>>2];d=b+946300|0;c=b+906300|0;while(1){if((c|0)!=(d|0)){b=v[c>>2];c:{if(!b){break c}if(nb[v[v[b>>2]+116>>2]](b)|0){break c}nb[v[v[b>>2]+108>>2]](b,1);nb[v[v[b>>2]+120>>2]](b)}c=c+160|0;continue}break}break a}if(w[a+29|0]){break a}aM(d,1)}t[a+29|0]=1;jb=e+48|0}function e_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=RF(c);b:{if(b){xk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;wk(k,a);break b}wr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Hh(k,a)}Bc(i,k);yb(k);l=e,m=Ui(a),t[l|0]=m;l=f,m=Vi(a),t[l|0]=m;Ng(k,a);Bc(g,k);yb(k);Ih(k,a);Bc(h,k);yb(k);a=vk(a);break a}a=QF(c);c:{if(b){xk(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;wk(k,a);break c}wr(k,a);b=v[k>>2];t[d|0]=b;t[d+1|0]=b>>>8;t[d+2|0]=b>>>16;t[d+3|0]=b>>>24;Hh(k,a)}Bc(i,k);yb(k);l=e,m=Ui(a),t[l|0]=m;l=f,m=Vi(a),t[l|0]=m;Ng(k,a);Bc(g,k);yb(k);Ih(k,a);Bc(h,k);yb(k);a=vk(a)}v[j>>2]=a;jb=k+16|0}function BR(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;while(1){if((c|0)!=20){g=b;b=t[a+c|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b;a:{if(b>>>0>5){break a}while(1){if((h|0)!=15){e=B(h,30)+a|0;f=e+20|0;c=0;b=0;while(1){if((c|0)!=22){g=b;b=t[c+f|0];b=g+((b&255)!=0&(b|0)<32)|0;c=c+1|0;continue}break}d=b+d|0;if(d>>>0>48){break a}c=w[e+45|0];if(w[e+44|0]|c>>>0>64){break a}b=Mb(w[e+42|0]|w[e+43|0]<<8);if(b>>>0>32768){break a}h=h+1|0;i=c|i;j=b+j|0;continue}break}if(!j|!(i&255)){break a}d=w[a+470|0];if(d>>>0>128){break a}b=w[a+471|0];if(b>>>0>220){break a}a=a+472|0;f=bA(a);b:{if((a|0)==(f|0)){break b}c=a;while(1){c=c+1|0;if((f|0)==(c|0)){break b}a=Er(w[a|0],w[c|0])?c:a;continue}}a=w[a|0];if(a>>>0>63){break a}k=(b|(a|d))!=0}return k}function Uo(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;v[d+28>>2]=0;a:{b:{c:{if(Rd(w[rn(d+24|0,a,0)|0])){f=d+16|0;bd(f,v[v[a>>2]-12>>2]+a|0);v[23296]=0;f=T(1045,f|0)|0;e=v[23296];v[23296]=0;d:{e:{if((e|0)==1){break e}e=ym(d+8|0,a);g=Cc(d);h=v[v[a>>2]-12>>2];g=v[g>>2];e=v[e>>2];v[23296]=0;ma(c|0,f|0,e|0,g|0,a+h|0,d+28|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break e}_b(d+16|0);break d}b=V(0)|0;O()|0;_b(d+16|0);_(b|0)|0;b=v[d+28>>2]|1;v[d+28>>2]=b;qn(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23296]=0;Z(93);a=v[23296];v[23296]=0;if((a|0)!=1){break b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)==1){break c}S(a|0);L()}$()}vj(v[v[a>>2]-12>>2]+a|0,v[d+28>>2])}jb=d+32|0;break a}V(0)|0;O()|0;Ub()}L()}return a}function Jfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;t[e+15|0]=0;u[e+12>>1]=0;j=8;n=B(c,d)<<1;while(1){if((d|0)!=(k|0)){g=(k<<1)+b|0;o=n+g|0;while(1){if(g>>>0<o>>>0){u[e+10>>1]=0;UR(a,e+15|0,e+12|0,j,e+10|0);h=x[e+10>>1];c=j;while(1){a:{if(!(c&255)){break a}f=x[e+12>>1]<<1;i=f&254;u[e+12>>1]=i;if(i){f=(f&65534)>>>0>255}else{if(!bf(a,e+9|0)){break a}f=w[e+9|0];u[e+12>>1]=f<<1&254|1;f=f>>>7|0}c=c-1|0;h=f|h<<1;continue}break}c=1;i=h&65535;b:{if(i>>>0<4){break b}f=15;while(1){c=f;m=f&255;if(i>>>m&1){break b}f=c-1|0;if(m>>>0>1){continue}break}}f=h&1;t[e+15|0]=f;l=(f-1^(h&65534)>>>1)+l|0;u[e+10>>1]=l;u[g>>1]=l;g=(d<<1)+g|0;j=(c+j&254)>>>1|0;continue}break}k=k+1|0;continue}break}jb=e+16|0}function Ay(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{if(!d){break a}if(c){t[b+815|0]=c;break a}c=w[b+815|0]}f=v[a+480180>>2];d=f&1048580;c=d?(c&240?-16:15)&c:c;b:{c:{d:{if(!d){d=c&240;e:{f:{g:{h:{c=c&15;if((c|0)==15){a=v[a+480208>>2]&4096;if(!d){break h}if(!a){break b}a=0-(d>>>2|0)|0;break d}a=v[a+480208>>2]&4096;if(!c|(d|0)!=240){break g}if(!a){break b}c=c<<2;break c}d=0;if(!a){break f}break b}if(a){break b}if(!c){break e}}c=c<<2;if(!(f&16777248)|!d){break c}break b}a=0-(d>>>2|0)|0;break d}if(w[a+480209|0]&16){break b}Bb(e+8|0,a+1074312|0,56);a=c&240;a=a?a>>>2|0:0-(c<<2&60)|0;if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break d}a=(a|0)/4<<24>>24}c=a;if(!c){break b}}a=v[b+692>>2];u[b+784>>1]=0;g=b,h=Yb(a+c|0,0,256),v[g+692>>2]=h}jb=e+16|0}function Lp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=jb-16|0;jb=h;f=v[a>>2];e=v[a+4>>2];i=re(f,e)-1|0;while(1){a:{b:{if(re(f,e)-1>>>0<=g>>>0){g=i;break b}if(x[Lc(f,e,g)>>1]<(b|0)){break a}e=v[a+4>>2];f=v[a>>2]}i=x[Lc(f,e,g)>>1];f=0;v[h+12>>2]=0;c:{if((b|0)>=(i|0)){j=h,k=(w[Lc(v[a>>2],v[a+4>>2],g)+2|0]<<16)/(d|0)|0,v[j+12>>2]=k;break c}e=0;if(g){e=g-1|0;f=(w[Lc(v[a>>2],v[a+4>>2],e)+2|0]<<16)/(d|0)|0;v[h+12>>2]=f;e=x[Lc(v[a>>2],v[a+4>>2],e)>>1]}if((b|0)<=(e|0)|e>>>0>=i>>>0){break c}a=((w[Lc(v[a>>2],v[a+4>>2],g)+2|0]<<16)/(d|0)|0)-f|0;d=a;g=a>>31;a=b-e|0;b=Sia(d,g,a,a>>31);a=i-e|0;j=h,k=Ic(Tia(b,mb,a,a>>31),mb)+f|0,v[j+12>>2]=k}he(h+12|0,0,65536);jb=h+16|0;return(B(v[h+12>>2],c)+32768|0)/65536|0}g=g+1|0;e=v[a+4>>2];f=v[a>>2];continue}}function lp(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,k=0,m=0;o(+a);b=j(1)|0;d=j(0)|0;a:{b:{c:{d:{if((b|0)>0|(b|0)>=0){f=b;if(b>>>0>1048575){break d}}if(!(b&2147483647|d)){return-1/(a*a)}if((b|0)>0|(b|0)>=0){break c}return(a-a)/0}if(f>>>0>2146435071){break a}b=1072693248;g=-1023;if((f|0)!=1072693248){b=f;break b}if(d){break b}return 0}o(+(a*0x40000000000000));b=j(1)|0;d=j(0)|0;g=-1077}b=b+614242|0;h=+((b>>>20|0)+g|0);e=h*.6931471803691238;l(0,d|0);l(1,(b&1048575)+1072079006|0);a=+n()+-1;c=a/(a+2);i=e;k=a;m=c;e=a*(a*.5);c=c*c;a=c*c;a=i+(k+(m*(e+(a*(a*(a*.15313837699209373+.22222198432149784)+.3999999999940942)+c*(a*(a*(a*.14798198605116586+.1818357216161805)+.2857142874366239)+.6666666666666735)))+h*1.9082149292705877e-10-e))}return a}function sC(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;e=v[b>>2];d=Nc(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=jb-32|0;jb=i;d=c-d|0;f=v[Gb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>1>>>0){f=jb-16|0;jb=f;e=Fi(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){lc(e);jb=f+16|0}else{Iq(d);d=d+2|0;v[e+4>>2]=d;continue}break}break b}f=Gb(b);e=xj(i+8|0,yj(b,Nc(v[b>>2],e)+d|0),Nc(v[b>>2],v[b+4>>2]),f);h=jb-16|0;jb=h;d=Eo(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){Iq(f);f=v[d>>2]+2|0;v[d>>2]=f;continue}break}Id(d);jb=h+16|0;Ad(b,e);Gi(e)}jb=i+32|0;break a}if(c>>>0<d>>>0){Nd(b,e+(c<<1)|0)}}c=Ob(v[a>>2],v[a+8>>2],c<<1);if(c){d=v[b>>2];ic(g+8|0,d,Nc(d,v[b+4>>2])<<1);qd(g,a,v[g+8>>2],v[g+12>>2])}jb=g+16|0;return c|0}function aba(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-48|0;jb=g;h=a+8|0;c=v[a+8>>2];j=zc(a);a:{if((c|0)!=v[j>>2]){break a}i=a+4|0;d=v[a+4>>2];e=v[a>>2];if(d>>>0>e>>>0){a=((d-e>>2)+1|0)/-2<<2;c=Ji(d,c,a+d|0);v[h>>2]=c;v[i>>2]=a+v[i>>2];break a}v[g+24>>2]=c-e>>1;v[g+44>>2]=1;d=g+24|0;c=v[Yc(d,g+44|0)>>2];c=fg(d,c,c>>>2|0,v[a+16>>2]);e=hc(g+16|0,v[a+4>>2]);f=v[hc(g+8|0,v[a+8>>2])>>2];d=jb-32|0;jb=d;e=v[e>>2];v[d+24>>2]=e;e=ol(d+8|0,c+8|0,Qt(f,e));f=v[e>>2];while(1){if(v[e+4>>2]!=(f|0)){k=f;f=v[d+24>>2];jo(k,x[f>>1]|x[f+2>>1]<<16);f=v[e>>2]+4|0;v[e>>2]=f;Ce(d+24|0);continue}break}Id(e);jb=d+32|0;oc(a,c);oc(i,c+4|0);oc(h,c+8|0);oc(j,zc(c));eg(c);c=v[a+8>>2]}jo(c,x[b>>1]|x[b+2>>1]<<16);v[h>>2]=v[h>>2]+4;jb=g+48|0}function Ifa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=jb-16|0;jb=e;t[e+15|0]=0;u[e+12>>1]=0;n=B(c,d);j=4;a:while(1){if((d|0)!=(k|0)){h=b+k|0;o=n+h|0;while(1){b:{c:{if(h>>>0<o>>>0){t[e+11|0]=0;TR(a,e+15|0,e+12|0,e+11|0);i=w[e+11|0];f=x[e+12>>1];c=j;while(1){if(c&255){g=f<<1;f=g&254;d:{if(f){g=(g&65534)>>>0>255;break d}if(!bf(a,e+10|0)){break c}f=w[e+10|0];g=f>>>7|0;f=f<<1&254|1}c=c-1|0;i=i<<1|g;continue}break}u[e+12>>1]=f;break b}k=k+1|0;continue a}u[e+12>>1]=0}c=1;g=i&255;e:{if(g>>>0<4){break e}f=7;while(1){c=f;m=f&255;if(g>>>m&1){break e}f=c-1|0;if(m>>>0>1){continue}break}}f=i&1;t[e+15|0]=f;l=(f-1^(i&254)>>>1)+l|0;t[e+11|0]=l;t[h|0]=l;h=d+h|0;j=(c+j&254)>>>1|0;continue}}break}jb=e+16|0}function x2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-80|0;jb=d;a=v[a+4>>2];Gv(d+16|0,b);v[23296]=0;b=Q(1,d|0,17588)|0;e=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{g:{h:{if((e|0)!=1){v[23296]=0;U(2,d+32|0,d+16|0,b|0);e=v[23296];v[23296]=0;if((e|0)==1){break h}v[23296]=0;U(424,d+48|0,d+32|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break g}v[23296]=0;R(962,d- -64|0,d+48|0);c=v[23296];v[23296]=0;if((c|0)==1){break f}c=v[v[a>>2]+8>>2];v[23296]=0;R(c|0,a|0,d- -64|0);a=v[23296];v[23296]=0;if((a|0)==1){break e}yb(d- -64|0);zb(d+48|0);zb(d+32|0);zb(b);zb(d+16|0);jb=d+80|0;return}a=P()|0;O()|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;break c}a=P()|0;O()|0;break d}a=P()|0;O()|0;yb(d- -64|0)}zb(d+48|0)}zb(d+32|0)}zb(b)}zb(d+16|0);S(a|0);L()}function rM(a,b){var c=C(0),d=C(0),e=C(0);a:{b:{c:{switch(b|0){case 0:up(a,C(1));Jn(a,C(3.725290298461914e-9));tp(a,C(268435456));sp(a,0);break b;case 1:up(a,C(32));Jn(a,C(4.656612873077393e-10));tp(a,C(2147483648));sp(a,0);break b;case 2:up(a,C(2));Jn(a,C(7.450580596923828e-9));tp(a,C(134217728));sp(a,1);break b;default:up(a,C(1));Jn(a,C(7.450580596923828e-9));tp(a,C(134217728));sp(a,1);dy(a,0);cy(a,1);by(a,1);d=C(256);c=C(128);e=C(128);b=0;break a;case 4:case 5:break c}}up(a,C(.75));Jn(a,C(7.450580596923828e-9));tp(a,C(134217728));sp(a,1);dy(a,0);b=(b|0)==4;cy(a,b?2:3);by(a,1);d=C(256);c=b?C(256):C(192);e=c;b=1;break a}dy(a,1);cy(a,0);by(a,0);d=C(128);e=C(100);c=C(256);b=4}z[a+16>>2]=c;z[a+20>>2]=e;z[a+24>>2]=d;v[a+28>>2]=b}function yH(a,b,c,d){a:{switch(b-9|0){case 0:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];return;case 6:b=v[c>>2];v[c>>2]=b+4;b=u[b>>1];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 7:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=x[b>>1];v[a+4>>2]=0;return;case 8:b=v[c>>2];v[c>>2]=b+4;b=t[b|0];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 9:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=w[b|0];v[a+4>>2]=0;return;case 16:b=v[c>>2]+7&-8;v[c>>2]=b+8;A[a>>3]=A[b>>3];return;case 17:nb[d|0](a,c);default:return;case 1:case 4:case 14:b=v[c>>2];v[c>>2]=b+4;b=v[b>>2];v[a>>2]=b;v[a+4>>2]=b>>31;return;case 2:case 5:case 11:case 15:b=v[c>>2];v[c>>2]=b+4;v[a>>2]=v[b>>2];v[a+4>>2]=0;return;case 3:case 10:case 12:case 13:break a}}b=v[c>>2]+7&-8;v[c>>2]=b+8;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c}function Rn(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;g=jb-16|0;jb=g;if(e){v[e>>2]=0}a:{h=v[a+484344>>2];if(!oe(h,v[a+484348>>2],b)){break a}i=$b(h,b);k=v[i+48>>2];b=fd(v[i>>2],v[k+12>>2],c,d);f=w[b+5|0];b:{c:{d:{e:{j=w[b+3|0];switch(j-10|0){case 1:case 3:case 5:case 6:break a;case 0:break c;case 2:case 4:case 7:break d;default:break e}}if(j-35>>>0>=2){break a}}v[g+12>>2]=1;h=0;if((j|0)!=17){break b}h=v[a+480180>>2]==4;break b}v[g+12>>2]=2;h=0}v[g+8>>2]=v[i+12>>2]+(c^-1);d=0;c=v[Ib(g+8|0,g+12|0)>>2];a=c;while(1){f:{if(a){b=B(Eg(v[k+12>>2]),6)+b|0;if(w[b+3|0]==34){break f}c=d}f=(j-37&255)>>>0<254?f:c?f:f<<8;if(!e){break a}v[e>>2]=c;break a}i=f<<8;f=w[b+5|0]|(h?f>>>0<256?i+-8192|0:i:i);d=d+1|0;a=a-1|0;continue}}jb=g+16|0;return f}function IR(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;o=v[b>>2];while(1){if((i|0)==128){kg(b,c);c=v[a+8>>2];d=c+d|0;i=x[e>>1];a:{b:{c:{if(!f){break c}j=f;f=h&65535;if((c+(j+(f<<11)|0)|0)!=(Ig(v[a>>2])&-2)){break c}$c(a,c+(f<<10)|0);if(!gA(a,16,1)){break b}u[e>>1]=8;break b}if((h&65535)==(k&65535)){h=k;break a}f=k<<8&16776960;if(!g){if((Ig(v[a>>2])|0)!=(d+B(f,i)|0)){break a}}$c(a,c+B(f,x[e>>1])|0);h=gA(a,64,1)?h:k}$c(a,c)}c=l&65535;d:{if(c>>>0>(h&65535)>>>0){if((d+(B(c,x[e>>1])<<8)|0)==(Ig(v[a>>2])|0)){break d}}if(c>>>0>=255){fA(b,254,65534);fA(b,255,65535)}l=h}a=l&65535}else{j=x[dc(o,i)>>1];m=j+1|0;n=(h&65535)>>>0>j>>>0|j>>>0>127;k=n?k:c>>>0>i>>>0?m:k;l=(l&65535)>>>0>j>>>0?l:m;h=n?h:m;i=i+1|0;continue}break}return a}function nda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb+-64|0;jb=c;a:{d=v[a+4>>2];b:{if(d>>>0<b>>>0){f=$d(c+56|0);e=b-d|0;g=rt(a);c:{if(!(e>>>0>g>>>0|d>>>0>g-e>>>0)){gm(c+40|0,v[a>>2],d);gc(f,v[c+40>>2],v[c+44>>2]);v[a+4>>2]=v[a+4>>2]+e;break c}d=bo(c+40|0);v[23296]=0;b=Q(679,a|0,b|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break a}v[23296]=0;R(680,d|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}v[d+4>>2]=v[a+4>>2]+e;$k(c+24|0,v[a>>2]);gm(c+16|0,v[a>>2],v[a+4>>2]);$k(c+8|0,v[d>>2]);SQ(c+32|0,v[c+24>>2],v[c+28>>2],v[c+16>>2],v[c+20>>2],v[c+8>>2],v[c+12>>2]);gc(f,v[c+32>>2],v[c+36>>2]);xt(a,d);Le(d)}a=gc(c,v[f>>2],v[f+4>>2]);bv(v[a>>2],v[a+4>>2],e,0);break b}v[a+4>>2]=b}jb=c- -64|0;return}a=P()|0;O()|0;Le(d);S(a|0);L()}function xda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;e=v[b>>2];d=gg(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=jb-32|0;jb=i;d=c-d|0;f=v[Gb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>5>>>0){f=jb-16|0;jb=f;e=Dz(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){lc(e);jb=f+16|0}else{Xz(d);d=d+32|0;v[e+4>>2]=d;continue}break}break b}f=Gb(b);e=st(i+8|0,Pp(b,gg(v[b>>2],e)+d|0),gg(v[b>>2],v[b+4>>2]),f);h=jb-16|0;jb=h;d=JP(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){Xz(f);f=v[d>>2]+32|0;v[d>>2]=f;continue}break}Id(d);jb=h+16|0;Ad(b,e);KP(e)}jb=i+32|0;break a}if(c>>>0<d>>>0){Nd(b,e+(c<<5)|0)}}if(Ob(v[a>>2],v[a+8>>2],c<<5)){c=v[b>>2];ic(g+8|0,c,gg(c,v[b+4>>2])<<5);qd(g,a,v[g+8>>2],v[g+12>>2])}jb=g+16|0}function vda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;e=v[b>>2];d=hh(e,v[b+4>>2]);a:{if(d>>>0<c>>>0){i=jb-32|0;jb=i;d=c-d|0;f=v[Gb(b)>>2];e=v[b+4>>2];b:{if(d>>>0<=f-e>>4>>>0){f=jb-16|0;jb=f;e=To(f,b,d);d=v[e+4>>2];h=v[e+8>>2];while(1){if((d|0)==(h|0)){lc(e);jb=f+16|0}else{mu(d);d=d+16|0;v[e+4>>2]=d;continue}break}break b}f=Gb(b);e=Iv(i+8|0,Jv(b,hh(v[b>>2],e)+d|0),hh(v[b>>2],v[b+4>>2]),f);h=jb-16|0;jb=h;d=gE(h,e+8|0,d);f=v[d>>2];while(1){if(v[d+4>>2]!=(f|0)){mu(f);f=v[d>>2]+16|0;v[d>>2]=f;continue}break}Id(d);jb=h+16|0;Ad(b,e);jE(e)}jb=i+32|0;break a}if(c>>>0<d>>>0){Nd(b,e+(c<<4)|0)}}if(Ob(v[a>>2],v[a+8>>2],c<<4)){c=v[b>>2];ic(g+8|0,c,hh(c,v[b+4>>2])<<4);qd(g,a,v[g+8>>2],v[g+12>>2])}jb=g+16|0}function WK(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=C(0);c=jb-80|0;jb=c;d=v[b>>2];e=v[b+4>>2];b=$d(c+48|0);b=er(c+56|0,d,e,v[b>>2],v[b+4>>2]);v[23296]=0;d=T(190,b|0)|0;e=v[23296];v[23296]=0;a:{if((e|0)==1){break a}v[23296]=0;d=W(859,b|0,c+8|0,d|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break a}b:{if(!d){break b}if(Pb(c+8|0,17442,4)|v[c+12>>2]){break b}f=a,g=Sd(z[c+16>>2],C(0)),z[f+4220>>2]=g;f=a,g=Sd(z[c+20>>2],C(0)),z[f+4224>>2]=g;f=a,g=Sd(z[c+24>>2],C(0)),z[f+4228>>2]=g;d=v[c+28>>2];if(d>>>0<=5){v[a+4232>>2]=d}v[a+4236>>2]=v[c+32>>2];t[a+4240|0]=w[c+36|0]!=0;t[a+4241|0]=w[c+37|0]!=0;t[a+4242|0]=w[c+38|0]!=0;t[a+4243|0]=w[c+39|0]!=0;t[a+4244|0]=w[c+40|0]!=0;Fs(a)}Ab(b);jb=c+80|0;return}a=P()|0;O()|0;Ab(b);S(a|0);L()}function B5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=jb-48|0;jb=f;v[f+40>>2]=d;d=Tf(a,f+40|0);g=Cc(d+4|0);h=Cc(d+24|0);i=Cc(d+32|0);j=Qb(d+36|0);v[d+56>>2]=3;k=Qb(d+68|0);v[23296]=0;R(895,d|0,e|0);a=v[23296];v[23296]=0;a:{b:{c:{d:{if((a|0)!=1){ic(f+8|0,b,c);a=$d(f);b=v[a+4>>2];c=v[a>>2];v[23296]=0;Ha(899,f+16|0,v[f+8>>2],v[f+12>>2],c|0,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break d}v[23296]=0;U(896,d|0,f+16|0,e|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}Ab(f+16|0);v[23296]=0;Y(897,d|0);a=v[23296];v[23296]=0;if((a|0)!=1){break a}}e=P()|0;O()|0;break b}e=P()|0;O()|0;break b}e=P()|0;O()|0;Ab(f+16|0)}Me(k);Wf(j);os(i);dj(h);cj(g);te(d);te(f+40|0);S(e|0);L()}te(f+40|0);jb=f+48|0;return d|0}function Gj(a,b){var c=0,d=0,e=0,f=0;c=jb+-64|0;jb=c;d=v[v[a>>2]-12>>2]+a|0;e=v[d+16>>2]&-3;Wm(d,e);a:{b:{if(Rd(w[rn(c+56|0,a,1)|0])){d=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23296]=0;f=v[b+12>>2];v[c+16>>2]=v[b+8>>2];v[c+20>>2]=f;f=v[b+4>>2];v[c+8>>2]=v[b>>2];v[c+12>>2]=f;U(96,c+40|0,d|0,c+8|0);b=v[23296];v[23296]=0;c:{if((b|0)!=1){b=jh(c+24|0,-1,-1);b=v[b+8>>2]==v[c+48>>2]&v[c+52>>2]==v[b+12>>2]?e|4:e;break c}b=V(0)|0;O()|0;_(b|0)|0;b=e|1;qn(v[v[a>>2]-12>>2]+a|0,b);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23296]=0;Z(93);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)==1){break b}S(a|0);L()}$()}vj(v[v[a>>2]-12>>2]+a|0,b)}jb=c- -64|0;return a}V(0)|0;O()|0;Ub()}L()}function J5(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;b=jb-48|0;jb=b;c=Kb(b+32|0);v[23296]=0;Y(888,b+16|0);a=v[23296];v[23296]=0;a:{b:{c:{d:{if((a|0)!=1){f=b,g=Eb(v[b+16>>2]),v[f+8>>2]=g;d=1;while(1){e=Eb(v[b+20>>2]);a=v[b+8>>2];if(!Rb(a,e)){a=Xf(Jc(c));Me(b+16|0);yb(c);break b}if(!d){v[23296]=0;Q(889,c|0,14464)|0;a=v[23296];v[23296]=0;if((a|0)==1){break d}a=v[b+8>>2]}v[23296]=0;Q(753,c|0,a|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break d}$p(b+8|0);d=0;continue}}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;Me(b+16|0)}yb(c);_(a|0)|0;a=0;v[23296]=0;X(887,6946,0,0,0);c=v[23296];v[23296]=0;if((c|0)==1){break a}$()}jb=b+48|0;return a|0}b=P()|0;O()|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)==1){V(0)|0;O()|0;Ub();L()}S(b|0);L()}function GG(a,b,c,d,e,f){var g=0;g=jb-80|0;jb=g;a:{if((f|0)>=16384){Fd(g+32|0,b,c,d,e,0,0,0,2147352576);d=v[g+40>>2];e=v[g+44>>2];b=v[g+32>>2];c=v[g+36>>2];if(f>>>0<32767){f=f-16383|0;break a}Fd(g+16|0,b,c,d,e,0,0,0,2147352576);f=((f|0)<49149?f:49149)-32766|0;d=v[g+24>>2];e=v[g+28>>2];b=v[g+16>>2];c=v[g+20>>2];break a}if((f|0)>-16383){break a}Fd(g- -64|0,b,c,d,e,0,0,0,7471104);d=v[g+72>>2];e=v[g+76>>2];b=v[g+64>>2];c=v[g+68>>2];if(f>>>0>4294934644){f=f+16269|0;break a}Fd(g+48|0,b,c,d,e,0,0,0,7471104);f=((f|0)>-48920?f:-48920)+32538|0;d=v[g+56>>2];e=v[g+60>>2];b=v[g+48>>2];c=v[g+52>>2]}Fd(g,b,c,d,e,0,0,0,f+16383<<16);b=v[g+12>>2];v[a+8>>2]=v[g+8>>2];v[a+12>>2]=b;b=v[g+4>>2];v[a>>2]=v[g>>2];v[a+4>>2]=b;jb=g+80|0}function _8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;f=jb-32|0;jb=f;c=Eg(v[v[a+48>>2]+12>>2]);a:{if(!b){break a}c=B(b,c);b:{if(v[a+12>>2]!=(b|0)){break b}if((ck(v[a>>2],v[a+4>>2])|0)!=(c|0)){break b}b=jb-16|0;jb=b;d=Eb(v[a>>2]);a=Eb(v[a+4>>2]);wh(b+8|0);e=Ls(a,d);c=jb-16|0;jb=c;v[c+8>>2]=d;while(1){if((e|0)>0){a=v[c+8>>2];d=w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24);t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;d=w[b+12|0]|w[b+13|0]<<8;t[a+4|0]=d;t[a+5|0]=d>>>8;e=e-1|0;kk(c+8|0);continue}break}jb=c+16|0;jb=b+16|0;break a}e=f+8|0;wh(e);c=cT(f+16|0,c,e);CL(a);v[a>>2]=v[c>>2];v[a+4>>2]=v[c+4>>2];e=Gb(c);g=Gb(a),h=v[e>>2],v[g>>2]=h;v[e>>2]=0;v[c>>2]=0;v[c+4>>2]=0;gk(c);v[a+12>>2]=b}jb=f+32|0}function uca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){e=v[b+8>>2];o=e>>>18|0;p=((((v[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){h=(e<<1)+p|0;i=u[h>>1];v[(e<<2)+b>>2]=i+((B(u[h+4>>1]-i|0,o)|0)/16384|0);e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Sb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;jb=b+16|0}function Pw(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;g=(p(a),j(2));c=g&2147483647;a:{if(c>>>0<=1305022426){h=+a;f=h*.6366197723675814+6755399441055744+-6755399441055744;d=h+f*-1.5707963109016418+f*-1.5893254773528196e-8;A[b>>3]=d;g=d<-.7853981852531433;if(D(f)<2147483648){c=~~f}else{c=-2147483648}if(g){d=f+-1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c-1|0;break a}if(!(d>.7853981852531433)){break a}d=f+1;A[b>>3]=h+d*-1.5707963109016418+d*-1.5893254773528196e-8;c=c+1|0;break a}if(c>>>0>=2139095040){A[b>>3]=C(a-a);c=0;break a}i=c;c=(c>>>23|0)-150|0;A[e+8>>3]=(l(2,i-(c<<23)|0),q());c=DH(e+8|0,e,c,1,0);d=A[e>>3];if((g|0)<0){A[b>>3]=-d;c=0-c|0;break a}A[b>>3]=d}jb=e+16|0;return c}function a0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;h=v[b+44>>2];i=v[b+24>>2];if(h>>>0<i>>>0){v[b+44>>2]=i;h=i}l=-1;m=-1;n=f&24;a:{if(!n|(e|0)==1&(n|0)==24){break a}if(h){g=h-tc(b+32|0)|0;o=g;g=g>>31}b:{c:{switch(e|0){case 1:if(f&8){e=v[b+12>>2]-v[b+8>>2]|0;j=e;k=e>>31;break b}e=i-v[b+20>>2]|0;j=e;k=e>>31;break b;case 0:break b;case 2:break c;default:break a}}j=o;k=g}d=d+k|0;c=c+j|0;d=j>>>0>c>>>0?d+1|0:d;e=c;c=d;if((g|0)<=(d|0)&e>>>0>o>>>0|(d|0)>(g|0)|(d|0)<0){break a}d=f&8;d:{if(!(c|e)){break d}if(v[b+12>>2]?0:d){break a}if(!(f&16)){break d}if(!i){break a}}if(d){d=v[b+8>>2];nn(b,d,d+e|0,h)}if(f&16){Bw(b,v[b+20>>2],v[b+28>>2]);Pr(b,e)}l=e;m=c}jh(a,l,m)}function yR(a,b){var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],1024)){v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;a=64;while(1){if(a){d=w[c+20|0]|w[c+21|0]<<8|(w[c+22|0]<<16|w[c+23|0]<<24);e=w[c+16|0]|w[c+17|0]<<8|(w[c+18|0]<<16|w[c+19|0]<<24);t[b|0]=e;t[b+1|0]=e>>>8;t[b+2|0]=e>>>16;t[b+3|0]=e>>>24;t[b+4|0]=d;t[b+5|0]=d>>>8;t[b+6|0]=d>>>16;t[b+7|0]=d>>>24;d=w[c+28|0]|w[c+29|0]<<8|(w[c+30|0]<<16|w[c+31|0]<<24);e=w[c+24|0]|w[c+25|0]<<8|(w[c+26|0]<<16|w[c+27|0]<<24);t[b+8|0]=e;t[b+9|0]=e>>>8;t[b+10|0]=e>>>16;t[b+11|0]=e>>>24;t[b+12|0]=d;t[b+13|0]=d>>>8;t[b+14|0]=d>>>16;t[b+15|0]=d>>>24;a=a-1|0;b=b+16|0;continue}break}break a}dA(c+8|0,b);qd(c+16|0,a,v[c+8>>2],v[c+12>>2])}jb=c+32|0}function kn(a,b,c,d,e,f,g,h,i,j){var k=0,l=0,m=0,n=0;l=jb-16|0;jb=l;t[l+15|0]=a;a:{b:{c:{k=v[d>>2];if((k|0)!=(c|0)){break c}m=43;n=a&255;if((n|0)!=w[j+24|0]){m=45;if(w[j+25|0]!=(n|0)){break c}}v[d>>2]=c+1;t[c|0]=m;break b}if(!(!Fb(g)|(a|0)!=(f|0))){a=0;b=v[i>>2];if((b-h|0)>159){break a}a=v[e>>2];v[i>>2]=b+4;v[b>>2]=a;break b}a=-1;f=mi(j,j+26|0,l+15|0)-j|0;if((f|0)>23){break a}d:{e:{switch(b-8|0){case 0:case 2:if((b|0)>(f|0)){break d}break a;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<22){break d}if((c|0)==(k|0)|(k-c|0)>2|w[k-1|0]!=48){break a}a=0;v[e>>2]=0;v[d>>2]=k+1;t[k|0]=w[f+81808|0];break a}v[d>>2]=k+1;t[k|0]=w[f+81808|0];v[e>>2]=v[e>>2]+1;a=0;break a}a=0;v[e>>2]=0}jb=l+16|0;return a}function rI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;a:{b:{c:{d:{e:{if((b|0)>=0){g=a;a=v[a+32>>2];if((Eg(a)|0)>(b|0)){break e}}a=ba(8)|0;v[23296]=0;b=Q(54,f|0,10598)|0;c=v[23296];v[23296]=0;if((c|0)==1){break d}a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break b}c=P()|0;O()|0;yb(b);break c}d=(a+(b<<5)|0)+480280|0;c=c?134218752:0;v[d>>2]=c|v[d>>2]&-134218753;d=(a+B(b,872)|0)+1075080|0;v[d>>2]=c|v[d>>2]&-134218753;a=x[a+480188>>1];d=a>>>0>256?a:256;b=b+1|0;g=v[g+32>>2];while(1){if((a|0)==(d|0)){break a}e=g+B(a,872)|0;if((b|0)==x[e+1075778>>1]){e=e+1075080|0;v[e>>2]=c|v[e>>2]&-134218753}a=a+1|0;continue}}c=P()|0;O()|0;ca(a|0)}S(c|0)}L()}jb=f+16|0}function vca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+32>>2];l=v[a+28>>2];m=v[a+8>>2];n=v[a+12>>2];while(1){if(d){e=v[b+8>>2];o=e>>>10&4194048;p=(((v[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){h=e+p|0;i=t[h|0];v[(e<<2)+b>>2]=((B(t[h+2|0]-i|0,o)|0)/16384|0)+(i<<8);e=e+1|0;continue}break}g=g+l|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+k|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Sb(b+8|0,m,n);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;jb=b+16|0}function li(a,b,c,d){var e=0,f=0,g=0;v[a+20>>2]=d;v[a+16>>2]=c;v[a+12>>2]=b;v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=44304;c=a+24|0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;b=Qb(a+44|0);g=Qb(b+12|0);e=Qb(b+24|0);f=Qb(b+36|0);v[23296]=0;R(851,b|0,0);d=v[23296];v[23296]=0;if((d|0)==1){a=P()|0;O()|0;vc(f);vc(e);Ds(g);Ds(b);S(a|0);L()}u[a+4204>>1]=0;v[a+4196>>2]=1065353216;v[a+4200>>2]=0;d=v[a+16>>2];v[d+946300>>2]=v[d+946300>>2]+1;v[23296]=0;e=T(852,a+92|0)|0;d=v[23296];v[23296]=0;a:{if((d|0)!=1){f=a+4200|0;v[c>>2]=e;d=w[a+4200|0];c=v[a+16>>2];b=v[a+20>>2];while(1){if((b|0)==((c+B(d,160)|0)+906300|0)|d>>>0>248){break a}d=d+1|0;t[f|0]=d;continue}}a=P()|0;O()|0;UK(b);S(a|0);L()}return a}function nh(a,b){var c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=0;f=nK(a);h=a+4208|0;c=C(C(z[Db(h,4)>>2]*C(1.899999976158142))+C(.10000000149011612));g=z[a+4268>>2];d=me(C(10),C(C(C(C(C(v[((b<<2)+a|0)+4292>>2])/g)*C(-60))/C(C(z[Db(h,3)>>2]*C(19.899999618530273))+C(.10000000149011612)))/C(20)));c=C(C(me(d,C(C(2)-C(C(2)/c)))+C(-1))/C(C(1)-pp(c>C(1)?C(3.1415927410125732):C(f*C(C(6.2831854820251465)/g)))));a:{if(c==C(0)){break a}if(!Rl(c)){break a}g=C(c+c);f=C(C(-2)-g);c=C(C(f*f)+C(C(c*c)*C(-4)));if(c>C(0)){e=C(K(c))}c=C(C(e-f)/g);if(C(D(c))>C(1)){c=C(C(C(-f)-e)/g)}e=wf(c)}b=(b<<3)+a|0;z[b+4404>>2]=e;z[b+4400>>2]=d;c=z[a+4272>>2];c=C(c*c);e=C(C(1)-c);d=C(d*d);return C(C(C(e*C(d/C(C(1)-C(c*d))))*e)+c)}function ica(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=((((v[b+12>>2]&2147483647)<<1|f>>>31)&2147483646)<<1)+i|0;e=f>>>21&2040;m=u[e+39718>>1];n=u[e+39716>>1];o=u[e+39714>>1];p=u[e+39712>>1];e=0;while(1){if((e|0)!=2){f=(e<<1)+l|0;v[(e<<2)+b>>2]=(((B(u[f>>1],o)+B(u[f-4>>1],p)|0)+B(u[f+4>>1],n)|0)+B(u[f+8>>1],m)|0)/16384;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g);Sb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function sea(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-192|0;jb=c;b=c+16|0;gi(b,a);v[23296]=0;R(77,c+32|0,b|0);a=v[23296];v[23296]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23296]=0;a=Q(78,c+48|0,c+32|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break e}yb(c+32|0);yb(c+16|0);b=v[v[a>>2]-12>>2];v[23296]=0;d=ga(61)|0;e=v[23296];v[23296]=0;if((e|0)==1){break c}v[23296]=0;U(62,c+8|0,a+b|0,d|0);b=v[23296];v[23296]=0;if((b|0)==1){break c}_b(c+8|0);v[23296]=0;b=Q(79,a|0,c+32|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break c}a=Hk(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=x[c+32>>1];jf(b);jb=c+192|0;a=(a?0:d)&65535;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(c+32|0)}yb(c+16|0);break b}b=P()|0;O()|0;jf(a)}S(b|0);L()}return a|0}function mA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-16|0;jb=e;d=w[a|0];if(d&1){t[b+12|0]=w[b+12|0]|1;d=w[a|0]}if(d&2){t[b+12|0]=w[b+12|0]|4;d=w[a|0]}if(d&4){t[b+12|0]=w[b+12|0]|2;d=w[a|0]}if(d&16){t[b+12|0]=w[b+12|0]|16;d=w[a|0]}if(d&32){t[b+12|0]=w[b+12|0]|8}t[e+15|0]=w[a+1|0];t[e+14|0]=25;dh(b,w[Wb(e+15|0,e+14|0)|0]);t[b+15|0]=w[a+2|0];t[b+16|0]=w[a+3|0];t[b+13|0]=w[a+4|0];t[b+14|0]=w[a+5|0];g=v[b>>2];i=re(g,v[b+4>>2]);b=0;while(1){if((b|0)!=(i|0)){h=Db(g,b);f=(b<<2)+a|0;d=w[f+6|0]|w[f+7|0]<<8;u[h>>1]=d;a:{if(!b){break a}j=d;d=x[Db(g,b-1|0)>>1];if(j>>>0>=d>>>0){break a}u[h>>1]=d+1}k=h,l=Yb((w[f+8|0]|w[f+9|0]<<8)<<16>>16>>c,0,64),t[k+2|0]=l;b=b+1|0;continue}break}jb=e+16|0}
function kea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;pd(c,2);t[d+16|0]=w[b+13|0];t[d|0]=64;e=d+16|0;i=c,j=w[Wb(e,d)|0]<<2,u[i+30>>1]=j;v[c+24>>2]=(w[b+14|0]|w[b+15|0]<<8)<<1;ek(d,2,b+1|0);Gc(e,d);ze(c+43|0,e);yb(e);e=_c(a,8,1,0,2);a:{if((w[b|0]&3)!=1){break a}g=w[b+22|0]|w[b+23|0]<<8|(w[b+24|0]<<16|w[b+25|0]<<24);v[c>>2]=g;f=w[b+26|0]|w[b+27|0]<<8|(w[b+28|0]<<16|w[b+29|0]<<24);v[c+4>>2]=f;a=w[b+30|0]|w[b+31|0]<<8|(w[b+32|0]<<16|w[b+33|0]<<24);h=a-(a>>>0>f>>>0)|0;v[c+8>>2]=h;a=w[b|0];if(a&4){u[c+34>>1]=x[c+34>>1]|2;a=w[b|0]}if(a&8){u[c+34>>1]=x[c+34>>1]|4;a=w[b|0]}if(!(a&16)){break a}Fh(e,16);Sf(e,9);v[c+8>>2]=h>>>1;v[c+4>>2]=f>>>1;v[c>>2]=g>>>1}jb=d+32|0}function AG(a,b){var c=0,d=0,e=0;a:{if(w[b|0]){break a}b=sw(13708);if(w[b|0]?b:0){break a}b=sw(B(a,12)+78416|0);if(w[b|0]?b:0){break a}b=sw(13988);if(w[b|0]?b:0){break a}b=14597}b:{while(1){d=w[b+c|0];if(!(!d|(d|0)==47)){d=23;c=c+1|0;if((c|0)!=23){continue}break b}break}d=c}e=14597;c:{d:{c=w[b|0];e:{f:{if(!(w[b+d|0]|(c|0)==46)){e=b;if((c|0)!=67){break f}}if(!w[e+1|0]){break e}}if(!fj(e,14597)){break e}if(fj(e,13370)){break d}}if(!a){c=78488;if(w[e+1|0]==46){break c}}return 0}c=v[116711];if(c){while(1){if(!fj(e,c+8|0)){break c}c=v[c+32>>2];if(c){continue}break}}c=Jd(36);if(c){v[c+4>>2]=20;v[c>>2]=78384;b=c+8|0;qc(b,e,d);t[b+d|0]=0;v[c+32>>2]=v[116711];v[116711]=c}c=a|c?c:78488}return c}function pfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;b=jb-528|0;jb=b;e=-1;a:{if(!Vf(a,1468)){break a}al(a,1464);c=b+524|0;PR(a,c);if(!fe(c,26729)){e=0;if(!fe(b+524|0,15351)){break a}}al(a,20);c=1;while(1){if((c&65535)>>>0<=31){if(MR(a,b)){c=c+1|0;d=kA(b)+d|0;continue}else{e=-1;break a}}break}e=0;if(d>>>0>40){break a}d=b+520|0;c=jb-16|0;jb=c;b:{if(!Vf(a,2)){t[c|0]=0;kC(d,c);break b}ql(c+8|0,d);jA(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;if(w[b+520|0]>128){break a}d=kd(b+520|0);c=jb-16|0;jb=c;c:{if(!Vf(a,512)){xR(b);break c}xu(c+8|0,b);jA(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;c=0;e=1;a=w[d|0];while(1){if((c|0)==512){break a}d=b+c|0;c=c+1|0;if(a>>>0>=w[d|0]){continue}break}e=0}jb=b+528|0;return e|0}function KE(a,b,c,d,e,f){var g=0,h=0,i=C(0),j=0;g=jb-80|0;jb=g;ky(v[a+24>>2]);t[v[a+24>>2]+1298420|0]=v[a+52>>2]!=0;c=Wg(g+32|0,d,c,b);i=z[a+48>>2];j=v[a+32>>2];v[g+8>>2]=v[c+8>>2];d=v[c+4>>2];v[g>>2]=v[c>>2];v[g+4>>2]=d;d=jb-16|0;jb=d;v[d+8>>2]=v[g+8>>2];c=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=c;c=fJ(g+48|0);v[c+8>>2]=j;v[c+4>>2]=0;v[c>>2]=f;f=v[d+4>>2];v[c+12>>2]=v[d>>2];v[c+16>>2]=f;v[c+20>>2]=v[d+8>>2];z[c+24>>2]=i;v[c>>2]=e;jb=d+16|0;while(1){if(b){d=v[a+24>>2];v[g+24>>2]=b;v[g+28>>2]=0;v[g+16>>2]=134217727;v[g+20>>2]=0;d=hJ(d,v[Oq(g+24|0,g+16|0)>>2],c);h=d+h|0;b=b-d|0;if(d){continue}}break}if(!(v[a+52>>2]!=1|h)){a=v[a+24>>2];v[a+480208>>2]=v[a+480208>>2]&-513}jb=g+80|0;return h}function YW(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-192|0;jb=c;b=c+16|0;gi(b,a);v[23296]=0;R(77,c+32|0,b|0);a=v[23296];v[23296]=0;a:{b:{c:{d:{e:{if((a|0)!=1){v[23296]=0;a=Q(78,c+48|0,c+32|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break e}yb(c+32|0);yb(c+16|0);b=v[v[a>>2]-12>>2];v[23296]=0;d=ga(61)|0;e=v[23296];v[23296]=0;if((e|0)==1){break c}v[23296]=0;U(62,c+8|0,a+b|0,d|0);b=v[23296];v[23296]=0;if((b|0)==1){break c}_b(c+8|0);v[23296]=0;b=Q(82,a|0,c+32|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break c}a=Hk(v[(b+v[v[b>>2]-12>>2]|0)+16>>2]);d=v[c+32>>2];jf(b);jb=c+192|0;a=a?0:d;break a}b=P()|0;O()|0;break d}b=P()|0;O()|0;yb(c+32|0)}yb(c+16|0);break b}b=P()|0;O()|0;jf(a)}S(b|0);L()}return a|0}function fV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;pd(b,0);v[b>>2]=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);c=Gq(a+4|0,a);f=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+4>>2]=f;c=Gq(a+8|0,a);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);v[b+8>>2]=c;t[e+15|0]=127;t[e+14|0]=w[a+15|0];g=b,h=(((w[Wb(e+15|0,e+14|0)|0]<<8|64)&65344)>>>0)/127|0,u[g+30>>1]=h;d=w[a+12|0];if(d>>>0>=16){u[b+34>>1]=32;u[b+28>>1]=d&240}d=(w[a+13|0]|w[a+14|0]<<8)<<1;v[b+24>>2]=d;d=w[a+13|0]|w[a+14|0]<<8?d:16726;v[b+24>>2]=d;g=b,h=(B(Ju(0,w[a+12|0]<<28>>24),d)>>>0)/8363|0,v[g+24>>2]=h;if(c>>>0>f>>>0){u[b+34>>1]=x[b+34>>1]|2}if(w[a+16|0]&132){u[b+34>>1]=x[b+34>>1]|1}jb=e+16|0}function cH(a){a=a|0;var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[23296]=0;c=Q(1052,d+8|0,a|0)|0;b=v[23296];v[23296]=0;c:{if((b|0)!=1){d:{if(!Rd(w[c|0])){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23296]=0;b=T(1053,b|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[23296]=0;Y(1054,a+b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;bH(c);break c}bH(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[23296]=0;Y(16,a+c|0);c=v[23296];v[23296]=0;if((c|0)==1){break a}$()}jb=d+16|0;return a|0}a=P()|0;O()|0;v[23296]=0;Z(17);c=v[23296];v[23296]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function V1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-80|0;jb=e;v[e+76>>2]=d;v[e+72>>2]=c;v[23296]=0;c=v[b+12>>2];v[e+16>>2]=v[b+8>>2];v[e+20>>2]=c;c=v[b+4>>2];v[e+8>>2]=v[b>>2];v[e+12>>2]=c;c=T(1028,e+8|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){a:{b:{if(c){v[23296]=0;R(1029,e+48|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){d=e+56|0;pv(d,v[e+48>>2],v[e+52>>2]);b=rg(e- -64|0,d);c=rg(e+40|0,e+72|0);break b}break a}v[23296]=0;R(1030,e+48|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}d=e+56|0;pv(d,v[e+48>>2],v[e+52>>2]);b=rg(e+32|0,d);c=rg(e+24|0,e+72|0)}BD(a,v[b>>2],v[b+4>>2],v[c>>2],v[c+4>>2]);ee(d);ee(e+48|0);ee(e+72|0);jb=e+80|0;return}}a=P()|0;O()|0;ee(e+72|0);S(a|0);L()}function R3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-32|0;jb=d;e=Qb(a);a=0;c=v[b+24>>2];c=ht(v[c+484344>>2],v[c+484348>>2]);v[23296]=0;R(169,e|0,c|0);c=v[23296];v[23296]=0;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){c=v[b+24>>2];f=v[c+484344>>2];if(ht(f,v[c+484348>>2])>>>0<=a>>>0){break b}v[23296]=0;R(969,d|0,$b(f,a)|0);c=v[23296];v[23296]=0;if((c|0)!=1){c=v[b+24>>2];v[23296]=0;U(956,d+16|0,c|0,d|0);c=v[23296];v[23296]=0;if((c|0)==1){break e}v[23296]=0;R(171,e|0,d+16|0);c=v[23296];v[23296]=0;if((c|0)==1){break d}a=a+1|0;yb(d+16|0);yb(d);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;break c}a=P()|0;O()|0;yb(d+16|0)}yb(d);break a}jb=d+32|0;return}a=P()|0;O()|0}Me(e);S(a|0);L()}function Fy(a,b,c){var d=0,e=0,f=0,g=0;d=jb+-64|0;jb=d;e=v[a>>2];f=v[e-4>>2];g=v[e-8>>2];v[d+28>>2]=0;v[d+32>>2]=0;v[d+36>>2]=0;v[d+40>>2]=0;v[d+44>>2]=0;v[d+48>>2]=0;v[d+52>>2]=0;v[d+56>>2]=0;e=0;t[d+59|0]=0;t[d+60|0]=0;t[d+61|0]=0;t[d+62|0]=0;v[d+20>>2]=0;v[d+24>>2]=0;v[d+16>>2]=b;v[d+12>>2]=a;v[d+8>>2]=c;a=a+g|0;a:{if(Jg(f,c,0)){v[d+56>>2]=1;nb[v[v[f>>2]+20>>2]](f,d+8|0,a,a,1,0);e=v[d+32>>2]==1?a:0;break a}nb[v[v[f>>2]+24>>2]](f,d+8|0,a,1,0);b:{switch(v[d+44>>2]){case 0:e=v[d+48>>2]==1?v[d+36>>2]==1?v[d+40>>2]==1?v[d+28>>2]:0:0:0;break a;case 1:break b;default:break a}}if(v[d+32>>2]!=1){if(v[d+48>>2]|v[d+36>>2]!=1|v[d+40>>2]!=1){break a}}e=v[d+24>>2]}jb=d- -64|0;return e}function bh(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb+-64|0;jb=f;a:{b:{if((b|0)==65535|c-1025>>>0<4294966272){break b}d=v[a>>2];e=v[a+4>>2];if(oe(d,e,b)){break b}c:{d:{if(ik(d,e)>>>0<=b>>>0){d=Ux(f+8|0,a);v[23296]=0;U(189,a|0,b+1|0,d|0);e=v[23296];v[23296]=0;if((e|0)==1){break d}Pk(d);d=v[a>>2]}v[23296]=0;R(199,Pf(d,b)|0,c|0);c=v[23296];v[23296]=0;e:{if((c|0)!=1){c=Pf(v[a>>2],b);v[c+16>>2]=0;v[c+20>>2]=0;c=v[a>>2];v[23296]=0;Y(200,Pf(c,b)|0);c=v[23296];v[23296]=0;if((c|0)!=1){break e}}b=V(91780)|0;a=O()|0;break c}a=Pf(v[a>>2],b);g=Rb(v[a>>2],v[a+4>>2]);break b}b=V(91780)|0;a=O()|0;Pk(d)}if((ea(91780)|0)!=(a|0)){break a}_(b|0)|0;$()}jb=f- -64|0;return g|0}S(b|0);L()}function Mea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb+-64|0;jb=c;i=c,j=cf(a)>>>5|0,u[i+32>>1]=j;u[c+16>>1]=3999;h=b+480190|0;d=x[Zc(c+32|0,c+16|0)>>1];u[h>>1]=d;g=1;while(1){f=g&65535;if(d>>>0>=f>>>0){d=$j(b,f);e=c+32|0;It(a,e);pd(d,0);tj(c,2,e);e=c+16|0;Gc(e,c);Ec(((f<<5)+b|0)+946304|0,e);yb(e);v[d+24>>2]=8287;i=c,j=Mb(x[c+60>>1]),u[i+16>>1]=j;u[c>>1]=64;i=d,j=x[Zc(e,c)>>1]<<2,u[i+30>>1]=j;i=d,j=cc(v[c+52>>2])&-2,v[i>>2]=j;e=Mb(x[c+62>>1]);i=Db(d+68|0,0),j=e,v[i>>2]=j;e=Mb(x[c+56>>1]);f=Mb(x[c+58>>1]);a:{if(f>>>0<2){break a}f=e+f<<1;if(f>>>0>y[d>>2]){break a}v[d+16>>2]=f;v[d+12>>2]=e<<1;u[d+34>>1]=x[d+34>>1]|8}g=g+1|0;d=x[h>>1];continue}break}jb=c- -64|0}function jca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+8>>2];l=(((v[b+12>>2]&2147483647)<<1|f>>>31)&-2)+i|0;e=f>>>21&2040;m=u[e+39718>>1];n=u[e+39716>>1];o=u[e+39714>>1];p=u[e+39712>>1];e=0;while(1){if((e|0)!=2){f=e+l|0;v[(e<<2)+b>>2]=(((B(t[f|0],o)+B(t[f-2|0],p)|0)+B(t[f+2|0],n)|0)+B(t[f+4|0],m)<<8)/16384;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],h);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],g);Sb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function Tq(a){a=a|0;var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;a:{b:{if(!v[(v[v[a>>2]-12>>2]+a|0)+24>>2]){break b}v[23296]=0;c=Q(12,d+8|0,a|0)|0;b=v[23296];v[23296]=0;c:{if((b|0)!=1){d:{if(!w[c|0]){break d}b=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23296]=0;b=T(21,b|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){if((b|0)!=-1){break d}b=v[v[a>>2]-12>>2];v[23296]=0;R(15,a+b|0,1);b=v[23296];v[23296]=0;if((b|0)!=1){break d}}b=V(0)|0;O()|0;jk(c);break c}jk(c);break b}b=V(0)|0;O()|0}_(b|0)|0;c=v[v[a>>2]-12>>2];v[23296]=0;Y(16,a+c|0);c=v[23296];v[23296]=0;if((c|0)==1){break a}$()}jb=d+16|0;return a|0}a=P()|0;O()|0;v[23296]=0;Z(17);c=v[23296];v[23296]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function mE(a,b,c,d){var e=0,f=0,g=0;f=jb-32|0;jb=f;v[23296]=0;Y(900,a|0);e=v[23296];v[23296]=0;a:{b:{c:{d:{e:{f:{if((e|0)==1){break f}v[23296]=0;Y(901,b|0);e=v[23296];v[23296]=0;if((e|0)==1){break f}g=v[a+24>>2];v[23296]=0;e=Q(54,f|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break e}v[23296]=0;U(d|0,f+16|0,g|0,e|0);b=v[23296];v[23296]=0;if((b|0)==1){break d}a=f+16|0;b=Xf(Jc(a));yb(a);yb(e);break b}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;break c}b=V(0)|0;O()|0;yb(e)}_(b|0)|0;b=0;v[23296]=0;X(887,c|0,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$()}jb=f+32|0;return b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function _ca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;g=jb-16|0;jb=g;pd(b,4);u[b+30>>1]=w[a+12|0]<<2;ug(b+30|0,256);e=w[a+15|0];u[b+34>>1]=32;u[b+28>>1]=e;t[b+37|0]=w[a+13|0];t[b+36|0]=w[a+16|0];f=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=f;c=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);v[b+4>>2]=c;d=(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+c|0;v[b+8>>2]=d;e=w[a+14|0];if(e&16){d=d>>>1|0;v[b+8>>2]=d;c=c>>>1|0;v[b+4>>2]=c;f=f>>>1|0;v[b>>2]=f;e=w[a+14|0]}if(e&32){d=d>>>1|0;v[b+8>>2]=d;c=c>>>1|0;v[b+4>>2]=c;v[b>>2]=f>>>1;e=w[a+14|0]}if(!(!(e&3)|c>>>0>=d>>>0)){u[b+34>>1]=34;u[b+34>>1]=w[a+14|0]&2?38:34}a=Vb(g,21473);ze(b+43|0,a);yb(a);jb=g+16|0}function G0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;e=v[a+28>>2];v[d+16>>2]=e;f=v[a+20>>2];v[d+28>>2]=c;v[d+24>>2]=b;b=f-e|0;v[d+20>>2]=b;f=b+c|0;i=2;b=d+16|0;a:{while(1){b:{c:{d:{if(!Qw(hb(v[a+60>>2],b|0,i|0,d+12|0)|0)){g=v[d+12>>2];if((g|0)==(f|0)){break d}if((g|0)>=0){break c}break b}if((f|0)!=-1){break b}}b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];a=c;break a}h=v[b+4>>2];j=h>>>0<g>>>0;e=(j<<3)+b|0;h=g-(j?h:0)|0;v[e>>2]=h+v[e>>2];b=(j?12:4)+b|0;v[b>>2]=v[b>>2]-h;f=f-g|0;i=i-j|0;b=e;continue}break}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a>>2]=v[a>>2]|32;a=0;if((i|0)==2){break a}a=c-v[b+4>>2]|0}jb=d+32|0;return a|0}function ZU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=jb-208|0;jb=d;if(!Au(c,a)){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0}QB(c,d+16|0,B(w[a+4|0],3));a:{if(w[a+4|0]<2){break a}c=jb-16|0;jb=c;v[c+12>>2]=64;v[c+8>>2]=255;e=w[Ib(c+12|0,c+8|0)|0];jb=c+16|0;t[d+12|0]=e;dh(b,w[Wb(a+4|0,d+12|0)|0]);t[b+13|0]=w[a+2|0];t[b+14|0]=w[a+3|0];a=w[a+1|0];t[b+15|0]=a;t[b+16|0]=a;e=v[b>>2];f=re(e,v[b+4>>2]);a=0;while(1){if((a|0)==(f|0)){break a}b:{if(!a){b=w[d+18|0];c=Db(e,0);break b}g=x[Db(e,a-1|0)>>1];v[d+12>>2]=1;b=(d+16|0)+B(a,3)|0;v[d+8>>2]=(t[b+1|0]&1)<<8|w[b|0];h=Ne(d+12|0,d+8|0);c=Db(e,a);u[c>>1]=x[h>>1]+g;b=w[b+2|0]}t[c+2|0]=b;a=a+1|0;continue}}jb=d+208|0}function sL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=C(0),j=C(0),k=0,l=C(0);g=jb-16|0;jb=g;e=u[d>>1];f=u[d+2>>1];if(!(!x[b>>1]|(e|0)>(f|0)|(!(z[c>>2]>C(0))|(f-e|0)>32766))){u[a>>1]=3;f=a+4|0;Hc(f);u[a+28>>1]=65472;v[g+12>>2]=1065353216;uL(f,g+12|0);v[a+32>>2]=0;u[a+30>>1]=0;Hc(a+16|0);h=u[d>>1];u[a+28>>1]=h;e=jb-16|0;jb=e;u[e+14>>1]=x[b>>1];u[e+12>>1]=32767;b=u[Zc(e+14|0,e+12|0)>>1];jb=e+16|0;u[a+30>>1]=b;i=C(D(z[c>>2]));z[a+32>>2]=i;i=me(i,C(C(1)/C(b|0)));Qj(f,(u[d+2>>1]-h|0)+1|0);b=v[a+4>>2];c=u[a+28>>1];e=u[d+2>>1];d=u[d>>1];while(1){if((d|0)>(e|0)){rp(a)}else{j=me(i,C(d|0));k=Db(b,d-c|0),l=j,z[k>>2]=l;d=d+1|0;continue}break}h=1}jb=g+16|0;return h|0}function zW(){var a=0,b=0,c=0,d=0;a=UC(v[v[116578]-12>>2]+466312|0,10);c=jb-16|0;jb=c;v[23296]=0;b=Q(12,c+8|0,466312)|0;d=v[23296];v[23296]=0;a:{b:{c:{d:{if((d|0)!=1){e:{if(!w[b|0]){break e}d=ym(c,466312);v[23296]=0;a=Q(20,d|0,a|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){if(!Pu(a)){break e}a=v[v[116578]-12>>2];v[23296]=0;R(15,a+466312|0,1);a=v[23296];v[23296]=0;if((a|0)!=1){break e}}a=V(0)|0;O()|0;jk(b);break d}jk(b);break c}a=V(0)|0;O()|0}_(a|0)|0;b=v[v[116578]-12>>2];v[23296]=0;Y(16,b+466312|0);b=v[23296];v[23296]=0;if((b|0)==1){break b}$()}jb=c+16|0;break a}c=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(c|0);L()}V(0)|0;O()|0;Ub();L()}Tq(466312)}function Un(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;a:{if(c){t[b+809|0]=c;break a}c=w[b+809|0]}e=v[a+480180>>2];d=e&202376205?(c&240?-16:15)&c:c;c=v[b+688>>2];b:{if(e&69206029){break b}g=d&240;f=d&15;if((f|0)==15){if(g){Tn(a,b,(d&240)>>>4|0,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c-60|0;break b}if((g|0)!=240){break b}if(f){Sn(a,b,f,0);return}if(!(t[b+851|0]&1)){break b}c=w[a+480208|0]&2?c:c+60|0}c:{if(!(!(t[b+851|0]&1)|w[a+480208|0]&2)&(v[a+1074416>>2]!=1|(e|0)!=524288)){break c}a=d&255;d=d&15;d:{if(d){if(a&240?e&16777248:0){break c}c=c-(d<<2)|0;break d}c=(a>>>2&60)+c|0}if((e|0)!=1){break c}v[b+88>>2]=v[b+88>>2]|2097152}h=b,i=Yb(c,0,256),v[h+688>>2]=i}function Gba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){b=(v[f+12>>2]<<1)+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(u[b+4>>1],u[e+10>>1])+B(u[b+2>>1],u[e+8>>1])|0)+B(u[b+6>>1],u[e+12>>1])|0)+B(u[b+8>>1],u[e+14>>1])|0)/2|0)+((((B(u[b-4>>1],u[e+2>>1])+B(u[b-6>>1],u[e>>1])|0)+B(u[b-2>>1],u[e+4>>1])|0)+B(u[b>>1],u[e+6>>1])|0)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(b,h);v[c+4>>2]=v[c+4>>2]+B(b,g);Sb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;jb=f+16|0}function Eda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;i=e,j=ak(b),v[i>>2]=j;d=jb-16|0;jb=d;g=a;c=Wd(a);a:{if(c){f=kc(g);while(1){a=c;c=a+13|0;if(ut(b,c)){f=a;c=v[a>>2];if(c){continue}break a}if(!ut(c,b)){break a}f=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=kc(g);f=a}v[d+12>>2]=a;b=v[f>>2];if(!b){c=jb-16|0;jb=c;a=kc(g);h=th(d,xc(20),uh(c+8|0,a));b=v[h>>2];a=v[e>>2];a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);t[b+17|0]=0;t[b+13|0]=a;t[b+14|0]=a>>>8;t[b+15|0]=a>>>16;t[b+16|0]=a>>>24;i=kc(h),j=1,t[i+4|0]=j;jb=c+16|0;Zg(g,v[d+12>>2],f,v[d>>2]);b=de(d);cl(d);h=1}Yg(e+8|0,v[hc(d,b)>>2],h);jb=d+16|0;jb=e+16|0;return v[e+8>>2]+17|0}function Zy(a,b,c){var d=0,e=0,f=0,g=0;d=Kb(a);a=Fb(b);v[23296]=0;R(45,d|0,a|0);a=v[23296];v[23296]=0;if((a|0)!=1){a:{while(1){if(Fb(b)>>>0>e>>>0){f=v[ij(b,e)>>2];g=f&-32;a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if((g|0)==128|v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}else{v[23296]=0;R(46,d|0,a<<24>>24);a=v[23296];v[23296]=0;if((a|0)!=1){break b}break a}}break}d:{while(1){if((a|0)==32){break d}if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}v[23296]=0;R(46,d|0,a<<24>>24);a=v[23296];v[23296]=0;if((a|0)!=1){break b}break a}v[23296]=0;R(46,d|0,63);a=v[23296];v[23296]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;yb(d);S(a|0);L()}function Rga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;v[d+28>>2]=0;bk(a,d+28|0);a:{b:{i=v[d+28>>2];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Kb(d+16|0);v[23296]=0;u[d+14>>1]=0;e=W(430,a|0,g|0,255)|0;h=v[23296];v[23296]=0;if((h|0)==1){break b}if(!e){break d}v[23296]=0;R(419,a|0,d+14|0);e=v[23296];v[23296]=0;if((e|0)==1){break b}v[23296]=0;U(11,d|0,c|0,g|0);e=v[23296];v[23296]=0;if((e|0)!=1){v[23296]=0;e=Q(431,b|0,d+14|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break e}Hb(e,d);zb(d);yb(g);f=f+1|0;continue}break}f=P()|0;O()|0;break a}f=P()|0;O()|0;zb(d);break a}yb(g)}jb=d+32|0;return}f=P()|0;O()|0}yb(g);S(f|0);L()}function Tha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-32|0;jb=e;v[e+24>>2]=b;j=e,k=Zd(a),v[j+8>>2]=k;f=dk(e+24|0,e+8|0);a:{b:{h=pi(c,d);if(!h){break b}if(!Is(a,c)){b=Fb(a);g=Tc(a);c:{if(g-b>>>0>=h>>>0){g=tc(a);if((b|0)==(f|0)){break c}i=f+g|0;rj(i+h|0,i,b-f|0);break c}Ql(a,g,(b+h|0)-g|0,b,f,0,h);g=v[a>>2]}b=b+h|0;Mh(a,b);t[e+8|0]=0;sd(b+g|0,e+8|0);b=f+g|0;while(1){if((c|0)==(d|0)){break b}sd(b,c);c=c+1|0;b=b+1|0;continue}}d=Zf(e+8|0,c,d);c=Jc(d);f=Fb(d);v[23296]=0;c=fa(342,a|0,b|0,c|0,c+f|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){yb(d);break a}a=P()|0;O()|0;yb(d);S(a|0);L()}j=e,k=Zd(a),v[j+8>>2]=k;c=Hi(e+8|0,f)}jb=e+32|0;return c|0}function Uaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;h=gf(a,c);ae(g,v[a+28>>2]);i=a;a:{if(!h){c=0;if(hd(a,5)){break a}}e=v[a+28>>2];a=jb-16|0;jb=a;v[a+12>>2]=0;YG(e,a+12|0,1);c=v[a+12>>2];d=c>>>2&3;t[a+11|0]=d;if(d){t[a+4|0]=3;d=w[Wb(a+4|0,a+11|0)|0];t[a+4|0]=0;t[a|0]=0;t[a+10|0]=0;b:{if(!d){break b}di(e,a+4|0);if((d|0)==1){break b}di(e,a);if(d>>>0<3){break b}di(e,a+10|0);f=w[a+10|0]<<24}c=c&255|w[a+4|0]<<8|w[a|0]<<16|f;v[a+12>>2]=c}d=c>>>4|0;v[a+4>>2]=d;v[a>>2]=1e6;Bx(b,v[Ib(a+4|0,a)>>2]);c=0;while(1){f=Fb(b);if(f>>>0<=c>>>0){if((d|0)!=(f|0)){Gl(e,d-f|0)}jb=a+16|0}else{Bk(e,Oc(b,c),1);c=c+1|0;continue}break}c=h}$e(i,c);jb=g+16|0}function n5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[23296]=0;Y(900,a|0);d=v[23296];v[23296]=0;a:{b:{c:{if((d|0)==1){break c}v[23296]=0;Y(901,b|0);d=v[23296];v[23296]=0;if((d|0)==1){break c}v[23296]=0;Y(901,c|0);f=v[23296];v[23296]=0;d=1;if((f|0)==1){break c}f=v[a+24>>2];b=rc(e+8|0,b);c=rc(e,c);g=v[c+4>>2];c=v[c>>2];h=v[b+4>>2];b=v[b>>2];v[23296]=0;ZE(922,f,b,h,c,g);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,5468,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();d=0}jb=e+16|0;return d|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function mL(a,b,c){var d=0,e=0,f=0,g=0,h=0;a:{e=jb-48|0;jb=e;d=Kb(e+32|0);v[23296]=0;R(842,b|0,e+24|0);f=v[23296];v[23296]=0;if((f|0)!=1){b:{g=v[e+28>>2];f=v[e+24>>2];Nf(d);v[23296]=0;f=!g&f>>>0<255?f:255;R(59,d|0,f|0);g=v[23296];v[23296]=0;if((g|0)==1){break b}c:{while(1){if((f|0)==(h|0)){b=yU(Jc(d),Fb(d));if((b|0)==-1){break c}v[23296]=0;R(59,d|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break c}break b}g=Oc(d,h);v[23296]=0;Q(843,b|0,g|0)|0;g=v[23296];v[23296]=0;if((g|0)!=1){h=h+1|0;continue}break}break b}v[23296]=0;U(11,e+8|0,a|0,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}a=e+8|0;Hb(c,a);zb(a);yb(d);jb=e+48|0;break a}}a=P()|0;O()|0;yb(d);S(a|0);L()}}function Qga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;u[d+30>>1]=0;Kf(a,d+30|0);a:{b:{i=x[d+30>>1];c:{if(i>>>0>500){break c}d:{e:{while(1){if((f|0)==(i|0)){break c}g=Kb(d+16|0);v[23296]=0;u[d+14>>1]=0;e=Q(432,a|0,g|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break b}if(!e){break d}v[23296]=0;R(419,a|0,d+14|0);e=v[23296];v[23296]=0;if((e|0)==1){break b}v[23296]=0;U(11,d|0,c|0,g|0);e=v[23296];v[23296]=0;if((e|0)!=1){v[23296]=0;e=Q(431,b|0,d+14|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break e}Hb(e,d);zb(d);yb(g);f=f+1|0;continue}break}f=P()|0;O()|0;break a}f=P()|0;O()|0;zb(d);break a}yb(g)}jb=d+32|0;return}f=P()|0;O()|0}yb(g);S(f|0);L()}function BN(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;g=jb-112|0;jb=g;v[g+108>>2]=0;e=Rn(a,e&65535,d,c,g+108|0);f=w[b+790|0];if(!v[g+108>>2]){d=(f|0)==15;c=d&!w[b+792|0];e=e<<8;a:{if(e){v[b+664>>2]=e;break a}e=0;if(d){break a}e=v[b+664>>2]}h=c?0:w[b+836|0]<<16}if((f|0)==15){c=w[b+792|0];b:{if(!c){c=v[b+76>>2];v[g>>2]=1;f=v[Yc(g,g+108|0)>>2]<<3;d=Sia(c,0,e,0);e=(256<<f>>>1|0)+d|0;c=mb;c=d>>>0>e>>>0?c+1|0:c;d=f+8|0;f=d&31;if((d&63)>>>0>=32){d=0;c=c>>>f|0}else{d=c>>>f|0;c=((1<<f)-1&c)<<32-f|e>>>f}e=Vc(c,d);break b}iQ(g);if(c>>>0>9){break b}c=v[b+104>>2];if(!c){break b}e=v[Db(c+68|0,w[b+792|0]-1|0)>>2]+e|0}v[b+664>>2]=e}Vn(a,b,e+h|0);jb=g+112|0}function oy(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;b=v[a>>2];if(!uc(b,v[a+4>>2])){b=Eb(b);v[e+8>>2]=b;c=Eb(v[a+4>>2]);while(1){if(Rb(b,c)){Fo(b,4194304,67108864);g=v[b>>2];f=g+f|0;b=d;b=f>>>0<g>>>0?b+1|0:b;d=b;b=v[Ce(e+8|0)>>2];continue}else{c=v[a>>2];b=wc(c,v[a+4>>2]);l=e,m=Eb(c),v[l>>2]=m;d=Via(f,d,b,0);h=d;g=((mb&1)<<31|d>>>1)&2147483647;f=b<<24;d=0;i=Eb(v[a+4>>2]);while(1){b=v[e>>2];if(Rb(b,i)){j=b;c=v[b>>2];b=c>>>8|0;c=g+(c<<24)|0;b=b+k|0;b=Vc(Via(c,c>>>0<g>>>0?b+1|0:b,h,k),mb);v[j>>2]=b;c=f;f=c-b|0;d=d-(b>>>0>c>>>0)|0;Ce(e);continue}else{d=v[a>>2];if(!wc(d,v[a+4>>2])){Tu();L()}v[d>>2]=f+v[d>>2]}break}}break}}jb=e+16|0}function Hba(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[f+8>>2]=v[a>>2];v[f+12>>2]=e;j=b+24|0;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){b=v[f+12>>2]+i|0;e=(((v[f+8>>2]>>>16|0)+4&131064)<<1)+j|0;b=(((((B(t[b+2|0],u[e+10>>1])+B(t[b+1|0],u[e+8>>1])|0)+B(t[b+3|0],u[e+12>>1])|0)+B(t[b+4|0],u[e+14>>1])<<8)/2|0)+((((B(t[b-2|0],u[e+2>>1])+B(t[b-3|0],u[e>>1])|0)+B(t[b-1|0],u[e+4>>1])|0)+B(t[b|0],u[e+6>>1])<<8)/2|0)|0)/16384|0;v[c>>2]=v[c>>2]+B(b,h);v[c+4>>2]=v[c+4>>2]+B(b,g);Sb(f+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}b=v[f+12>>2];v[a>>2]=v[f+8>>2];v[a+4>>2]=b;jb=f+16|0}function tI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=jb-16|0;jb=d;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((Eg(a)|0)>(b|0)){break d}}a=ba(8)|0;v[23296]=0;d=Q(54,d|0,10598)|0;b=v[23296];v[23296]=0;if((b|0)==1){break c}a=sc(a,d);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(d);break b}if(c<0|c>1){a=ba(8)|0;v[23296]=0;d=Q(54,d|0,11610)|0;b=v[23296];v[23296]=0;if((b|0)!=1){a=sc(a,d);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(d);break b}b=P()|0;O()|0;ca(a|0);break b}e=(a+B(b,872)|0)+1075740|0,f=bm(c*64),v[e>>2]=f;jb=d+16|0;return}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function uv(a,b,c,d){var e=0,f=0,g=0;e=jb-48|0;jb=e;v[e+44>>2]=d;a:{f=v[b>>2];b:{if(!(nb[v[v[f>>2]+36>>2]](f,c,d)|0)){Bh(a);break b}vl(e+24|0,v[b>>2],v[b+4>>2]);b=v[b>>2];d=v[v[b>>2]+24>>2];v[23296]=0;b=T(d|0,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}v[e+20>>2]=b-c;d=v[e+24>>2];f=v[e+28>>2];g=v[Ib(e+44|0,e+20|0)>>2];b=jb-16|0;jb=b;v[b+12>>2]=f;v[b+8>>2]=d;d=vl(b,d,f);f=v[d+4>>2];d=v[d>>2];v[23296]=0;da(160,e+32|0,d|0,f|0,c|0,g|0);c=v[23296];v[23296]=0;c:{if((c|0)!=1){ee(b+8|0);jb=b+16|0;break c}a=P()|0;O()|0;ee(b+8|0);S(a|0);L()}b=$d(e+8|0);BD(a,v[e+32>>2],v[e+36>>2],v[b>>2],v[b+4>>2])}jb=e+48|0;return}a=P()|0;O()|0;ee(e+24|0);S(a|0);L()}function gca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){e=(v[b+12>>2]<<1)+i|0;h=v[b+8>>2]>>>21&2040;e=(((B(u[e>>1],u[h+39714>>1])+B(u[e-2>>1],u[h+39712>>1])|0)+B(u[e+2>>1],u[h+39716>>1])|0)+B(u[e+4>>1],u[h+39718>>1])|0)/16384|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Sb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;jb=b+16|0}function f4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-32|0;jb=e;f=Qb(a);a=b;b=x[v[b+24>>2]+480192>>1];v[23296]=0;R(169,f|0,b|0);c=v[23296];v[23296]=0;b=1;a:{if((c|0)!=1){b:{c:{d:{e:{while(1){d=b&65535;c=v[a+24>>2];if(d>>>0>x[c+480192>>1]){break b}c=gM(c,d);v[23296]=0;c=Q(54,e|0,c|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){d=v[a+24>>2];v[23296]=0;U(956,e+16|0,d|0,c|0);d=v[23296];v[23296]=0;if((d|0)==1){break e}v[23296]=0;R(171,f|0,e+16|0);d=v[23296];v[23296]=0;if((d|0)==1){break d}yb(e+16|0);yb(c);b=b+1|0;continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(e+16|0)}yb(c);break a}jb=e+32|0;return}b=P()|0;O()|0}Me(f);S(b|0);L()}function rha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;g=b;c=jb-48|0;jb=c;d=a;a:{if(Wt(v[d>>2],v[d+8>>2])){v[g>>2]=0;break a}JS(c+16|0,c+32|0);nc(c+24|0,v[d>>2],v[d+8>>2],v[c+16>>2],v[c+20>>2]);h=v[c+28>>2];i=w[c+32|0];f=i&127;v[g>>2]=f;a=f;b=0;while(1){if(a){b=b+1|0;a=a>>>1|0;continue}break}a=b;e=1;while(1){b=(B(h,7)+a|0)+B(e,-7)|0;b:{while(1){if(i<<24>>24>=0|e>>>0>=h>>>0){break b}i=w[(c+32|0)+e|0];f=i&127|f<<7;v[g>>2]=f;a=a+7|0;e=e+1|0;if((h|0)!=(e|0)){continue}break}ac(d,h);JS(c+8|0,c+32|0);nc(c+24|0,v[d>>2],v[d+8>>2],v[c+8>>2],v[c+12>>2]);h=v[c+28>>2];f=v[g>>2];e=0;a=b;continue}break}ac(d,e);if(a>>>0<33){break a}v[g>>2]=-1}jb=c+48|0}function hn(a,b,c,d,e,f,g,h,i,j){var k=0,l=0;a:{b:{k=v[d>>2];if((k|0)!=(c|0)){break b}l=43;if(v[j+96>>2]!=(a|0)){l=45;if(v[j+100>>2]!=(a|0)){break b}}v[d>>2]=c+1;t[c|0]=l;break a}c:{if(!(!Fb(g)|(a|0)!=(f|0))){g=0;a=v[i>>2];if((a-h|0)>159){break c}b=v[e>>2];v[i>>2]=a+4;v[a>>2]=b;break a}g=-1;f=jw(j,j+104|0,a)-j|0;if((f|0)>92){break c}a=f>>2;d:{e:{switch(b-8|0){case 0:case 2:if((a|0)<(b|0)){break d}break c;case 1:break d;default:break e}}if((b|0)!=16|(f|0)<88){break d}if((c|0)==(k|0)|(k-c|0)>2|w[k-1|0]!=48){break c}v[e>>2]=0;v[d>>2]=k+1;t[k|0]=w[a+81808|0];return 0}v[d>>2]=k+1;t[k|0]=w[a+81808|0];v[e>>2]=v[e>>2]+1;g=0}return g}v[e>>2]=0;return 0}function jz(a,b,c,d,e){var f=0,g=0,h=0,i=0;g=jb-16|0;jb=g;i=Xk(a,b);a:{if((i|0)==255){break a}if(Vj(v[a>>2])){break a}b:{if(c>>>0>6208431){f=7;c=1023;break b}f=7;c:{if(c>>>0>3104215){break c}f=6;if(c>>>0>1552107){break c}f=5;if(c>>>0>776053){break c}f=4;if(c>>>0>388026){break c}f=3;if(c>>>0>194013){break c}f=2;if(c>>>0>97006){break c}f=c>>>0>48503}c=Sia(1<<20-f,0,c,0)+24858e3|0;h=mb;c=Vc(Via(c,c>>>0<24858e3?h+1|0:h,49716e3,0),mb)}if(e){u[g+14>>1]=(b&3)+c;u[g+12>>1]=1023;c=x[Zc(g+14|0,g+12|0)>>1]}h=lt(i);e=Lb(a+8|0,i);t[e|0]=(f<<10|c)>>>8|(d?0:32);Tg(v[a>>2],v[a+4>>2],b,h|160,c&255);Tg(v[a>>2],v[a+4>>2],b,h|176,w[e|0]);t[a+534|0]=1}jb=g+16|0}function Wl(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;f=a+1074312|0;Bb(e+8|0,f,84);a:{if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}b:{if(v[a+480208>>2]&16384){break b}if((d|0)!=8){Bb(e+8|0,f,10);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break b}}v[b+88>>2]=v[b+88>>2]&-257}c:{d:{e:{switch(d-4|0){case 0:c=((c<<8|8)>>>0)/15|0;break d;case 2:c=(c>>>0<64?c:64)<<2;break d;default:break e}}if(!(v[a+480180>>2]&2107410)){break d}if(c>>>0<=128){c=c<<1;break d}if((c|0)!=164){break c}v[b+88>>2]=v[b+88>>2]|256;c=128}v[b+692>>2]=c}u[b+784>>1]=0;v[b+88>>2]=v[b+88>>2]|2097152;Bb(e+8|0,f,10);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}t[b+831|0]=0;u[b+778>>1]=0}jb=e+16|0}function J3(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-32|0;jb=e;f=Qb(a);a=b;b=x[v[b+24>>2]+480190>>1];v[23296]=0;R(169,f|0,b|0);d=v[23296];v[23296]=0;b=1;a:{if((d|0)!=1){b:{c:{d:{e:{while(1){c=b&65535;d=v[a+24>>2];if(c>>>0>x[d+480190>>1]){break b}v[23296]=0;d=Q(54,e|0,hM(d,c)|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){c=v[a+24>>2];v[23296]=0;U(956,e+16|0,c|0,d|0);c=v[23296];v[23296]=0;if((c|0)==1){break e}v[23296]=0;R(171,f|0,e+16|0);c=v[23296];v[23296]=0;if((c|0)==1){break d}yb(e+16|0);yb(d);b=b+1|0;continue}break}b=P()|0;O()|0;break a}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(e+16|0)}yb(d);break a}jb=e+32|0;return}b=P()|0;O()|0}Me(f);S(b|0);L()}function qaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-80|0;jb=d;e=Mf(d+48|0);v[23296]=0;g=Q(750,b|0,e|0)|0;f=v[23296];v[23296]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23296]=0;T(751,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break b}}break a}g=v[e+4>>2];v[23296]=0;U(178,d|0,b|0,g|0);f=v[23296];v[23296]=0;if((f|0)==1){break a}f=jc(d+24|0,d);cd(e+8|0,f);Ab(f);Ab(d);d:{if(c>>>0<2){break d}c=g&1;if(!c){break d}v[23296]=0;Q(176,b|0,2-c|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break d}break a}gl(a,e)}Md(e);jb=d+80|0;return}a=P()|0;O()|0;Md(e);S(a|0);L()}function b0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-16|0;jb=g;a:{b:{if(!uc(b,-1)){i=v[a+8>>2];j=v[a+12>>2];d=v[a+24>>2];if((d|0)==v[a+28>>2]){e=-1;if(!(w[a+48|0]&16)){break a}h=v[a+20>>2];k=v[a+44>>2];v[23296]=0;c=a+32|0;R(46,c|0,0);f=v[23296];v[23296]=0;if((f|0)==1){break b}f=Tc(c);v[23296]=0;R(59,c|0,f|0);f=v[23296];v[23296]=0;if((f|0)==1){break b}e=tc(c);Bw(a,e,Fb(c)+e|0);Pr(a,d-h|0);v[a+44>>2]=v[a+20>>2]+(k-h|0);d=v[a+24>>2]}v[g+12>>2]=d+1;d=v[Yc(g+12|0,a+44|0)>>2];v[a+44>>2]=d;if(w[a+48|0]&8){c=tc(a+32|0);nn(a,c,c+(j-i|0)|0,d)}e=hH(a,An(b));break a}e=Aw(b);break a}a=V(0)|0;O()|0;_(a|0)|0;$()}jb=g+16|0;return e|0}function z0(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;if(KH(1,e+16|0)){Wr(v[115772],12569);L()}c=Vr(e+8|0,v[e+16>>2]);g=Vr(e,v[e+20>>2]);d=jb-32|0;jb=d;b=jb-16|0;jb=b;a=jb-16|0;jb=a;h=a,i=Sia(v[c>>2],v[c+4>>2],1e9,0),v[h>>2]=i;v[a+4>>2]=mb;c=qt(a+8|0,a);f=v[c+4>>2];c=v[c>>2];jb=a+16|0;v[b+8>>2]=c;v[b+12>>2]=f;a=v[b+12>>2];v[d+8>>2]=v[b+8>>2];v[d+12>>2]=a;jb=b+16|0;f=v[d+8>>2];c=v[d+12>>2];a=v[g+4>>2];v[d>>2]=v[g>>2];v[d+4>>2]=a;a=d;c=v[a+4>>2]+c|0;b=v[a>>2];f=f+b|0;v[a+16>>2]=f;v[a+20>>2]=b>>>0>f>>>0?c+1|0:c;a=qt(a+24|0,a+16|0);b=v[a+4>>2];a=v[a>>2];jb=d+32|0;a=tn(e+24|0,a,b);b=v[a+4>>2];a=v[a>>2];jb=e+32|0;mb=b;return a|0}function y1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-32|0;jb=e;h=Kb(a);f=Kb(e+16|0);a=1;a:{b:{c:{while(1){d=a&65535;c=v[b+24>>2];if(d>>>0>x[c+480192>>1]){if(!(i&1)){break c}v[23296]=0;R(235,h|0,f|0);a=v[23296];v[23296]=0;if((a|0)!=1){break c}a=P()|0;O()|0;break a}c=gM(c,d);v[23296]=0;c=Q(54,e|0,c|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break b}d=De(c);v[23296]=0;g=Q(753,f|0,c|0)|0;j=v[23296];v[23296]=0;d:{if((j|0)==1){break d}v[23296]=0;Q(889,g|0,21443)|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}i=d^1|i;yb(c);a=a+1|0;continue}break}a=P()|0;O()|0;yb(c);break a}yb(f);jb=e+32|0;return}a=P()|0;O()|0}yb(f);yb(h);S(a|0);L()}function hca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){e=v[b+12>>2]+i|0;h=v[b+8>>2]>>>21&2040;e=(((B(t[e|0],u[h+39714>>1])+B(t[e-1|0],u[h+39712>>1])|0)+B(t[e+1|0],u[h+39716>>1])|0)+B(t[e+2|0],u[h+39718>>1])<<8)/16384|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Sb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;jb=b+16|0}function _l(a,b,c){var d=0,e=0,f=0;d=Kb(a);a=Fb(b);v[23296]=0;R(45,d|0,a|0);a=v[23296];v[23296]=0;if((a|0)!=1){a:{while(1){if(Fb(b)>>>0>e>>>0){f=v[ij(b,e)>>2];a=32;b:{while(1){c:{if((a|0)==256){a=0;break c}if(v[(a<<2)+c>>2]==(f|0)){v[23296]=0;R(46,d|0,a<<24>>24);a=v[23296];v[23296]=0;if((a|0)!=1){break b}break a}else{a=a+1|0;continue}}break}d:{while(1){if((a|0)==32){break d}if(v[(a<<2)+c>>2]!=(f|0)){a=a+1|0;continue}break}v[23296]=0;R(46,d|0,a<<24>>24);a=v[23296];v[23296]=0;if((a|0)!=1){break b}break a}v[23296]=0;R(46,d|0,63);a=v[23296];v[23296]=0;if((a|0)!=1){break b}break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;yb(d);S(a|0);L()}function XW(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{b:{c:{d:{if(h=gh(v[b+4>>2],w[b+11|0]),i=1,j=v[b+12>>2],j?h:i){Kb(a);break d}e=Kb(c+16|0);d=Cd(v[b+4>>2],w[b+11|0]);f=Ef(14159);g=rd(b);v[23296]=0;X(90,e|0,g|0,d|0,d+f|0);d=v[23296];v[23296]=0;e:{if((d|0)!=1){v[23296]=0;W(91,e|0,14159,f|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break e}}a=P()|0;O()|0;zb(e);S(a|0);L()}v[23296]=0;R(120,c|0,b+12|0);b=v[23296];v[23296]=0;if((b|0)==1){break c}v[23296]=0;U(2,a|0,c+16|0,c|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}zb(c);zb(c+16|0)}jb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;zb(c)}zb(c+16|0);S(b|0);L()}function Kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];h=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;i=v[a+32>>2];j=v[a+28>>2];k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){d=d-1|0;m=((((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&2147483646)<<1)+h|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=u[(e<<1)+m>>1];e=e+1|0;continue}break}g=g+j|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+i|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Sb(b+8|0,k,l);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;jb=b+16|0}function x1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-32|0;jb=e;h=Kb(a);f=Kb(e+16|0);a=1;a:{b:{c:{while(1){d=a&65535;c=v[b+24>>2];if(d>>>0>x[c+480190>>1]){if(!(i&1)){break c}v[23296]=0;R(235,h|0,f|0);a=v[23296];v[23296]=0;if((a|0)!=1){break c}a=P()|0;O()|0;break a}v[23296]=0;c=Q(54,e|0,hM(c,d)|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break b}d=De(c);v[23296]=0;g=Q(753,f|0,c|0)|0;j=v[23296];v[23296]=0;d:{if((j|0)==1){break d}v[23296]=0;Q(889,g|0,21443)|0;g=v[23296];v[23296]=0;if((g|0)==1){break d}i=d^1|i;yb(c);a=a+1|0;continue}break}a=P()|0;O()|0;yb(c);break a}yb(f);jb=e+32|0;return}a=P()|0;O()|0}yb(f);yb(h);S(a|0);L()}function Jr(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;h=jb-16|0;jb=h;f=d?d:466836;d=v[f>>2];a:{b:{c:{if(!b){if(d){break c}break a}e=-2;if(!c){break a}i=a?a:h+12|0;d:{if(d){a=c;break d}a=w[b|0];d=a<<24>>24;if((d|0)>=0){v[i>>2]=a;e=(d|0)!=0;break a}if(!v[v[115798]>>2]){v[i>>2]=d&57343;e=1;break a}a=a-194|0;if(a>>>0>50){break c}d=v[(a<<2)+81600>>2];a=c-1|0;if(!a){break b}b=b+1|0}g=w[b|0];j=g>>>3|0;if((j-16|(d>>26)+j)>>>0>7){break c}while(1){a=a-1|0;d=g-128|d<<6;if((d|0)>=0){v[f>>2]=0;v[i>>2]=d;e=c-a|0;break a}if(!a){break b}b=b+1|0;g=w[b|0];if((g&192)==128){continue}break}}v[f>>2]=0;v[115772]=25;e=-1;break a}v[f>>2]=d}jb=h+16|0;return e}function saa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-80|0;jb=d;e=Mf(d+48|0);v[23296]=0;c=Q(746,b|0,e|0)|0;f=v[23296];v[23296]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23296]=0;T(747,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break b}}break a}c=v[e+4>>2];v[23296]=0;c=cc(c);c=c?c:-1;U(178,d|0,b|0,c|0);f=v[23296];v[23296]=0;if((f|0)==1){break a}f=jc(d+24|0,d);cd(e+8|0,f);Ab(f);Ab(d);d:{c=c&1;if(!c){break d}v[23296]=0;Q(176,b|0,2-c|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break d}break a}gl(a,e)}Md(e);jb=d+80|0;return}a=P()|0;O()|0;Md(e);S(a|0);L()}function wha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=v[a>>2];d=nq(c,v[a+4>>2]);if(d>>>0<b>>>0){f=jb-32|0;jb=f;c=b-d|0;b=v[Gb(a)>>2];e=v[a+4>>2];a:{if(c>>>0<=(b-e|0)/48>>>0){d=jb-16|0;jb=d;b=$T(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){lc(b);jb=d+16|0}else{ES(a);a=a+48|0;v[b+4>>2]=a;continue}break}break a}b=Gb(a);d=YT(f+8|0,ZT(a,nq(v[a>>2],e)+c|0),nq(v[a>>2],v[a+4>>2]),b);b=jb-16|0;jb=b;v[b>>2]=v[d+8>>2];e=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=B(c,48)+e;c=v[b>>2];while(1){if(v[b+4>>2]!=(c|0)){ES(c);c=v[b>>2]+48|0;v[b>>2]=c;continue}break}Id(b);jb=b+16|0;XT(a,d);WT(d)}jb=f+32|0;return}if(b>>>0<d>>>0){Nd(a,c+B(b,48)|0)}}function AM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-16|0;jb=d;v[d+12>>2]=b;if(b>>>0<4294967280){a:{if(lm(a)>>>0>=b>>>0){break a}i=d,j=Cd(v[a+4>>2],w[a+11|0]),v[i+8>>2]=j;e=zi(v[Yc(d+12|0,d+8|0)>>2]);if((e|0)==(lm(a)|0)){break a}f=Cd(v[a+4>>2],w[a+11|0]);b:{c:{if((e|0)==10){g=v[a>>2];h=1;b=a;c=f;break c}b=e+1|0;d:{if(lm(a)>>>0<e>>>0){b=xc(b);break d}v[23296]=0;b=T(51,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break d}a=V(0)|0;O()|0;_(a|0)|0;$();break b}c=w[a+11|0];h=Uf(c);g=rd(a);c=Cd(v[a+4>>2],c)}b=He(b,g,c+1|0);if(h){Jb(g)}if((e|0)!=10){Af(a,e+1|0);Td(a,f);yd(a,b);break b}xe(a,f)}}jb=d+16|0;return}of();L()}function dv(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=jb-16|0;jb=f;t[f+15|0]=d;t[b+12|0]=w[a|0]&15|w[b+12|0]&240;i=a+1|0;e=f+15|0;dh(b,w[Wb(i,e)|0]);g=w[Wb(a+2|0,e)|0];t[b+13|0]=g;k=b,l=Xd(w[a+3|0],g,d),t[k+14|0]=l;e=w[Wb(a+4|0,e)|0];t[b+15|0]=e;k=b,l=Xd(w[a+5|0],e,d),t[k+16|0]=l;g=v[b>>2];b=0;while(1){t[f+14|0]=25;if(b>>>0<w[Wb(f+14|0,i)|0]){e=B(b,3)+a|0;h=Yb(w[e+6|0]+c<<24>>24,0,64);d=Db(g,b);t[d+2|0]=h;e=w[e+7|0]|w[e+8|0]<<8;u[d>>1]=e;a:{if(!b){break a}h=Db(g,b-1|0);j=x[h>>1];if(e>>>0>255|e>>>0>=j>>>0){break a}e=e|j&65280;u[d>>1]=e;if(x[h>>1]<=(e&65535)>>>0){break a}u[d>>1]=e+256}b=b+1|0;continue}break}jb=f+16|0}function c9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-80|0;jb=d;e=Mf(d+48|0);v[23296]=0;g=Q(821,b|0,e|0)|0;f=v[23296];v[23296]=0;a:{b:{c:{if((f|0)!=1){if(g){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23296]=0;T(822,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break b}}break a}g=v[e+4>>2];v[23296]=0;U(178,d|0,b|0,g|0);f=v[23296];v[23296]=0;if((f|0)==1){break a}f=jc(d+24|0,d);cd(e+8|0,f);Ab(f);Ab(d);d:{if(!(g&1)|c>>>0<2){break d}v[23296]=0;Q(176,b|0,1)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break d}break a}gl(a,e)}Md(e);jb=d+80|0;return}a=P()|0;O()|0;Md(e);S(a|0);L()}function E5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;i=e,j=ak(b),v[i>>2]=j;c=jb-16|0;jb=c;g=a;d=Wd(a);a:{if(d){f=kc(g);while(1){a=d;d=a+16|0;if(dt(b,d)){f=a;d=v[a>>2];if(d){continue}break a}if(!dt(d,b)){break a}f=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=kc(g);f=a}v[c+12>>2]=a;b=v[f>>2];if(!b){a=jb-16|0;jb=a;b=kc(g);b=th(c,xc(40),uh(a+8|0,b));Kb(Sc(v[b>>2]+16|0,v[e>>2])+12|0);i=kc(b),j=1,t[i+4|0]=j;jb=a+16|0;Zg(g,v[c+12>>2],f,v[c>>2]);b=de(c);a=v[c>>2];v[c>>2]=0;if(a){if(w[kc(c)+4|0]){Zl(a+16|0)}if(a){Jb(a)}}h=1}Yg(e+8|0,v[hc(c,b)>>2],h);jb=c+16|0;a=vd(v[e+8>>2]);jb=e+16|0;return a+12|0}function uaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-80|0;jb=d;e=Mf(d+48|0);v[23296]=0;c=Q(742,b|0,e|0)|0;f=v[23296];v[23296]=0;a:{b:{c:{if((f|0)!=1){if(c){break c}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23296]=0;T(743,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break b}}break a}c=v[e+4>>2];v[23296]=0;c=cc(c);U(178,d|0,b|0,c|0);f=v[23296];v[23296]=0;if((f|0)==1){break a}f=jc(d+24|0,d);cd(e+8|0,f);Ab(f);Ab(d);d:{c=c&1;if(!c){break d}v[23296]=0;Q(176,b|0,2-c|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break d}break a}gl(a,e)}Md(e);jb=d+80|0;return}a=P()|0;O()|0;Md(e);S(a|0);L()}function jD(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{if(Pb(a,3878,4)){break a}b=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);if(b>>>0<36){break a}c=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);if(c>>>0<36){break a}d=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);if(d>>>0<36){break a}e=w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24);if(e-1>>>0>858993458){break a}f=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);if(f-1>>>0>536870910){break a}a=w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24);if(B(e,-5)-1>>>0<b>>>0|a-1>>>0>1073741822|(f<<3^-1)>>>0<c>>>0){break a}g=(a<<2^-1)>>>0>=d>>>0}return g}function dU(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;a:{if(!d){break a}i=w[e|0];if(!i){break a}g=d-6|0;j=(g&255)>>>0<6&35>>>g;l=d-2|0;m=0-c|0;while(1){if(!b){break a}k=(l&255)>>>0>2;h=B(m,6);c=a;a=h+c|0;f=w[a+3|0];b:{if(!(k|(f-2&255)>>>0>2)){g=1;if(w[(c+h|0)+5|0]<224){break b}break a}g=(d|0)==(f|0);if(!(1<<f&2240)|(!j|f>>>0>11)){break b}g=1}c:{if(k){break c}f=c+h|0;if((w[f+2|0]-11&255)>>>0>2){break c}if(w[f+4|0]){break a}}d:{if(!j){break d}f=c+h|0;if((w[f+2|0]-3&255)>>>0>3){break d}if(w[f+4|0]){break a}}b=b-1|0;if(!g){continue}c=w[(c+h|0)+5|0];if(c?(c|0)!=(i|0):0){break a}if((c|0)!=(i|0)){continue}break}t[e|0]=0}}function Lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];h=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;i=v[a+32>>2];j=v[a+28>>2];k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){d=d-1|0;m=(((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&-2)+h|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=t[e+m|0]<<8;e=e+1|0;continue}break}g=g+j|0;v[c>>2]=v[c>>2]+B(v[b>>2],g>>12);f=f+i|0;v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f>>12);Sb(b+8|0,k,l);c=c+8|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;jb=b+16|0}function LX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;if(Jg(a,v[b+8>>2],f)){cw(b,c,d,e);return}g=w[b+53|0];i=v[a+12>>2];t[b+53|0]=0;h=w[b+52|0];t[b+52|0]=0;m=a+16|0;Zv(v[m>>2],v[a+20>>2],b,c,d,e,f);j=w[b+53|0];l=g|j;k=w[b+52|0];h=h|k;g=a+24|0;i=(i<<3)+m|0;a:{if(g>>>0>=i>>>0){break a}while(1){if(w[b+54|0]){break a}b:{if(k){if(v[b+24>>2]==1){break a}if(w[a+8|0]&2){break b}break a}if(!j){break b}if(!(t[a+8|0]&1)){break a}}u[b+52>>1]=0;Zv(v[g>>2],v[g+4>>2],b,c,d,e,f);j=w[b+53|0];l=j|l;k=w[b+52|0];h=k|h;g=g+8|0;if(i>>>0>g>>>0){continue}break}}t[b+53|0]=(l&255)!=0;t[b+52|0]=(h&255)!=0}function qZ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=v[a>>2];c=wc(d,v[a+4>>2]);if(c>>>0<b>>>0){g=jb-32|0;jb=g;d=b-c|0;b=v[Gb(a)>>2];e=v[a+4>>2];a:{if(d>>>0<=b-e>>2>>>0){FF(a,d);break a}c=gw(a);e=Ug(a,wc(v[a>>2],e)+d|0);f=wc(v[a>>2],v[a+4>>2]);b=g+8|0;If(b+12|0,c);if(e){c=BF(v[b+16>>2],e)}else{c=0}v[b>>2]=c;f=c+(f<<2)|0;v[b+8>>2]=f;v[b+4>>2]=f;h=zc(b),i=c+(e<<2)|0,v[h>>2]=i;e=jb-16|0;jb=e;c=ol(e,b+8|0,d);d=v[c>>2];while(1){if(v[c+4>>2]!=(d|0)){CF(d);d=v[c>>2]+4|0;v[c>>2]=d;continue}break}Id(c);jb=e+16|0;Ad(a,b);oP(b);a=v[b>>2];if(a){EF(v[b+16>>2],a,yz(b))}}jb=g+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function qS(a){var b=0,c=0,d=0,e=0,f=0;b=jb-32|0;jb=b;e=b,f=cc(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788|0,v[e>>2]=f;v[b+4>>2]=0;e=b,f=cc(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24)),v[e+8>>2]=f;v[b+12>>2]=0;c=cc(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24));v[b+16>>2]=c?c:52;v[b+20>>2]=0;e=b,f=cc(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))+80|0,v[e+24>>2]=f;v[b+28>>2]=0;a=b;d=Re(a,4);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+8|0;if((d|0)==(c|0)){break a}a=_u(v[a>>2],v[a+4>>2],v[c>>2],v[c+4>>2])?c:a;continue}}jb=b+32|0;c=v[a>>2];b=c-52|0;mb=v[a+4>>2]-(c>>>0<52)|0;return b}function BH(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=jb-208|0;jb=f;v[f+204>>2]=c;c=f+160|0;Xb(c,0,40);v[f+200>>2]=v[f+204>>2];a:{if((AH(0,b,f+200|0,f+80|0,c,d,e)|0)<0){e=-1;break a}i=v[a+76>>2]>=0;g=v[a>>2];if(v[a+72>>2]<=0){v[a>>2]=g&-33}b:{c:{d:{if(!v[a+48>>2]){v[a+48>>2]=80;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;h=v[a+44>>2];v[a+44>>2]=f;break d}if(v[a+16>>2]){break c}}c=-1;if(cC(a)){break b}}c=AH(a,b,f+200|0,f+80|0,f+160|0,d,e)}if(h){nb[v[a+36>>2]](a,0,0)|0;v[a+48>>2]=0;v[a+44>>2]=h;v[a+28>>2]=0;b=v[a+20>>2];v[a+16>>2]=0;v[a+20>>2]=0;c=b?c:-1}b=a;a=v[a>>2];v[b>>2]=a|g&32;e=a&32?-1:c;if(!i){break a}}jb=f+208|0;return e}function B9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;h=jb-16|0;jb=h;f=c;e=jb-16|0;jb=e;g=b;d=Wd(b);a:{if(d){c=kc(g);while(1){b=d;d=b+16|0;if(RL(f,d)){c=b;d=v[b>>2];if(d){continue}break a}if(!RL(d,f)){break a}c=b+4|0;d=v[b+4>>2];if(d){continue}break}break a}b=kc(g);c=b}v[e+12>>2]=b;b=v[c>>2];if(!b){b=jb-16|0;jb=b;d=kc(g);d=th(e,xc(28),uh(b+8|0,d));i=v[d>>2];v[23296]=0;R(799,i+16|0,f|0);f=v[23296];v[23296]=0;b:{if((f|0)!=1){j=kc(d),k=1,t[j+4|0]=k;jb=b+16|0;break b}a=P()|0;O()|0;QL(d);S(a|0);L()}Zg(g,v[e+12>>2],c,v[e>>2]);b=de(e);QL(e);i=1}c=h+8|0;Yg(c,v[hc(e,b)>>2],i);jb=e+16|0;cP(a,c);jb=h+16|0}function gP(a,b,c){a:{b:{c:{d:{e:{f:{g:{h:{i:{j:{k:{l:{b=b&15;switch(b-3|0){case 2:break j;case 1:break k;case 0:break l;case 10:case 11:break b;case 9:break c;case 8:break d;case 7:break e;case 6:break f;case 5:break g;case 4:break h;case 3:break i;default:break a}}t[a+798|0]=0;return}t[a+798|0]=1;return}t[a+798|0]=2;return}t[a+798|0]=3;return}t[a+730|0]=w[a+730|0]&254;return}t[a+730|0]=w[a+730|0]|1;return}t[a+738|0]=w[a+738|0]&254;return}t[a+738|0]=w[a+738|0]|1;return}t[a+746|0]=w[a+746|0]&254;return}t[a+746|0]=w[a+746|0]|1;return}if((c|0)!=16777216){break a}c=a;a=w[a+746|0];t[c+746|0]=(b|0)==13?a&238|1:a|17}}function S9(a){a=a|0;var b=0,c=0,d=0;c=a+1298224|0;b=a+1074992|0;while(1){if((b|0)==(c|0)){Rs(a+484344|0);Nf(a+1298308|0);lA(a+1298320|0);Nf(a+1298332|0);Hc(a+1298408|0);b=a+900380|0;c=a+484380|0;while(1){if((b|0)==(c|0)){a:{c=a+901404|0;while(1){if((b|0)==(c|0)){c=a+946300|0;b=a+906300|0;while(1){if((b|0)==(c|0)){break a}AB(b);b=b+160|0;continue}}d=v[b>>2];if(d){Jb(Rt(d))}v[b>>2]=0;b=b+4|0;continue}}}else{hm(c);c=c+104|0;continue}break}v[a+480180>>2]=0;v[a+480184>>2]=0;a=a+480186|0;u[a>>1]=0;u[a+2>>1]=0;u[a+4>>1]=0;u[a+6>>1]=0}else{v[b+104>>2]=0;v[b+656>>2]=0;v[b+76>>2]=0;v[b+16>>2]=0;b=b+872|0;continue}break}}function Bfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0,m=0;c=jb-16|0;jb=c;a:{b:{d=v[b+8>>2];if((d|0)==v[a+8>>2]){f=v[a+4>>2];e=v[b+4>>2];if((f|0)!=(e|0)){break b}v[c+12>>2]=d;v[c+8>>2]=d;d=v[Ib(c+12|0,c+8|0)>>2];v[c+12>>2]=e;v[c+8>>2]=e;e=v[Ib(c+12|0,c+8|0)>>2];i=v[a>>2];j=v[b>>2];b=0;c:while(1){a=0;if((b|0)==(d|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue c}else{k=(B(b,f)+a|0)+i|0;g=Qh(C(Sd(z[Up(j,a,b)>>2],C(-1))*C(128)));d:{if(C(D(g))<C(2147483648)){h=~~g;break d}h=-2147483648}l=k,m=RR(h),t[l|0]=m;a=a+1|0;continue}}}aa(17155,8885,27,9412);L()}aa(17105,8885,28,9412);L()}jb=c+16|0}function WA(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=jb-16|0;jb=e;d=(c<<3)+a|0;f=w[d+356|0];t[b+12|0]=w[b+12|0]&248|f&1|f<<1&4|f>>>1&2;dh(b,Xd(w[d+352|0],2,16));t[b+13|0]=w[d+354|0];t[b+14|0]=w[d+355|0];d=w[d+353|0];t[b+15|0]=d;t[b+16|0]=d;d=0;u[e+14>>1]=0;f=((c|0)!=0)<<1;h=v[b>>2];j=re(h,v[b+4>>2]);k=(c<<6)+a|0;c=((c|0)==2?-1:0)&255;while(1){if((d|0)==(j|0)){VA(b,32);jb=e+16|0}else{a=k+(d<<2)|0;u[e+12>>1]=w[a+160|0]|w[a+161|0]<<8;g=We(e+14|0,e+12|0);i=Db(h,d);g=x[g>>1];u[i>>1]=g;u[e+14>>1]=g+1;t[e+11|0]=(c^w[a+162|0])>>>f;t[e+10|0]=64;l=i,m=w[Wb(e+11|0,e+10|0)|0],t[l+2|0]=m;d=d+1|0;continue}break}}function $_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-48|0;jb=f;v[f+40>>2]=b;a:{if(!(v[c+4>>2]&1)){c=nb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+24|0;bd(a,c);v[23296]=0;a=T(1067,a|0)|0;b=v[23296];v[23296]=0;b:{if((b|0)!=1){_b(f+24|0);c:{if(e){Ih(f+24|0,a);break c}Hh(f+24|0,a)}g=f,h=Zd(f+24|0),v[g+16>>2]=h;while(1){g=f,h=oh(f+24|0),v[g+8>>2]=h;if(!Nh(f+16|0,f+8|0)){c=v[f+40>>2];yb(f+24|0);break a}a=t[v[f+16>>2]];v[23296]=0;Q(20,f+40|0,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){Be(f+16|0);continue}break}c=P()|0;O()|0;yb(f+24|0);break b}c=P()|0;O()|0;_b(f+24|0)}S(c|0);L()}jb=f+48|0;return c|0}function D2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=jb+-64|0;jb=d;f=d+16|0;h=jb-16|0;jb=h;i=bP(h+8|0);while(1){if((j|0)==12){jb=h+16|0}else{g=jb+-64|0;jb=g;c=v[i+4>>2];e=v[i>>2];a:{if((c|0)==(e|0)){break a}c=(c-e|0)+1|0;if(!c){c=iJ(jJ(g+8|0,32));break a}e=E(c);e=jJ(g+8|0,(c<<e+1?32:31)-e|0);while(1){k=iJ(e);if(c>>>0<=k>>>0){continue}break}c=v[i>>2]+k|0}jb=g- -64|0;l=Db(f,j),m=c,v[l>>2]=m;j=j+1|0;continue}break}f=jP(d,f,mP(f));dP(a,f);im(f);jb=d- -64|0;d=ox(a+120|0,a,b);t[d+20|0]=1;v[23296]=0;R(1017,a|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){a=P()|0;O()|0;yn(d);S(a|0);L()}return a|0}function HL(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;h=jb-16|0;jb=h;t[h+15|0]=b;t[h+14|0]=10;dh(g,w[Wb(h+15|0,h+14|0)|0]);t[g+15|0]=c;t[g+16|0]=c;t[g+14|0]=e;t[g+13|0]=d;j=v[g>>2];k=re(j,v[g+4>>2]);b=0;a:{while(1){if((b|0)==(k|0)){b:{b=w[g+12|0]&-2|a&1;if(a&2){break b}b=b&251;break a}}else{m=Db(j,b);l=B(b,3)+f|0;i=(w[l|0]|w[l+1|0]<<8)>>>4|0;u[m>>1]=i;c:{if(b){n=x[Db(j,b-1|0)>>1];if(i>>>0>=n>>>0){break c}i=n+1|0}else{i=0}o=Db(j,b),p=i,u[o>>1]=p}o=m,p=Xd(w[l+2|0],0,64),t[o+2|0]=p;b=b+1|0;continue}break}b=b&-5|(c>>>0<=k>>>0)<<2}t[g+12|0]=(d>>>0<=e>>>0?a&4:0)?b&-3|(d>>>0<=k>>>0)<<1:b&253;jb=h+16|0}function zD(a,b){var c=0,d=0,e=0,f=0;c=v[a>>2];d=Hg(c,v[a+4>>2]);if(d>>>0<b>>>0){f=jb-32|0;jb=f;c=b-d|0;b=v[Gb(a)>>2];e=v[a+4>>2];a:{if(c>>>0<=b-e>>3>>>0){d=jb-16|0;jb=d;b=ar(d,a,c);a=v[b+4>>2];c=v[b+8>>2];while(1){if((a|0)==(c|0)){lc(b);jb=d+16|0}else{ul(a);a=a+8|0;v[b+4>>2]=a;continue}break}break a}b=Gb(a);d=cr(f+8|0,dr(a,Hg(v[a>>2],e)+c|0),Hg(v[a>>2],v[a+4>>2]),b);b=jb-16|0;jb=b;v[b>>2]=v[d+8>>2];e=v[d+8>>2];v[b+8>>2]=d+8;v[b+4>>2]=(c<<3)+e;c=v[b>>2];while(1){if(v[b+4>>2]!=(c|0)){ul(c);c=v[b>>2]+8|0;v[b>>2]=c;continue}break}Id(b);jb=b+16|0;Ad(a,d);br(d)}jb=f+32|0;return}if(b>>>0<d>>>0){Nd(a,c+(b<<3)|0)}}function Qo(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=jb-16|0;jb=e;f=jb-32|0;jb=f;c=Je(f+16|0,1,0);b:{c:{d:{while(1){d=tc(c);Ex(f+8|0,d,Fb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break d}d=Hf(Fb(c));v[23296]=0;R(58,c|0,d|0);d=v[23296];v[23296]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=tc(c);v[23296]=0;R(59,c|0,b-d|0);b=v[23296];v[23296]=0;e:{if((b|0)!=1){v[23296]=0;R(71,e|0,c|0);b=v[23296];v[23296]=0;if((b|0)!=1){break e}break c}break c}yb(c);jb=f+32|0;break b}a=P()|0;O()|0;yb(c);S(a|0);L()}v[23296]=0;R(70,a|0,e|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(e);jb=e+16|0;break a}a=P()|0;O()|0;zb(e);S(a|0);L()}}function ET(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{e=jb-16|0;jb=e;f=jb-32|0;jb=f;c=Je(f+16|0,1,0);b:{c:{d:{while(1){d=tc(c);zx(f+8|0,d,Fb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break d}d=Hf(Fb(c));v[23296]=0;R(58,c|0,d|0);d=v[23296];v[23296]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=tc(c);v[23296]=0;R(59,c|0,b-d|0);b=v[23296];v[23296]=0;e:{if((b|0)!=1){v[23296]=0;R(71,e|0,c|0);b=v[23296];v[23296]=0;if((b|0)!=1){break e}break c}break c}yb(c);jb=f+32|0;break b}a=P()|0;O()|0;yb(c);S(a|0);L()}v[23296]=0;R(70,a|0,e|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(e);jb=e+16|0;break a}a=P()|0;O()|0;zb(e);S(a|0);L()}}function Cfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=C(0),h=0,i=0,j=0,k=0,l=0;c=jb-16|0;jb=c;a:{b:{d=v[b+8>>2];if((d|0)==v[a+8>>2]){f=v[a+4>>2];e=v[b+4>>2];if((f|0)!=(e|0)){break b}v[c+12>>2]=d;v[c+8>>2]=d;h=v[Ib(c+12|0,c+8|0)>>2];v[c+12>>2]=e;v[c+8>>2]=e;e=v[Ib(c+12|0,c+8|0)>>2];i=v[a>>2];j=v[b>>2];b=0;c:while(1){a=0;if((b|0)==(h|0)){break a}while(1)if((a|0)==(e|0)){b=b+1|0;continue c}else{g=Qh(C(Sd(z[Up(j,a,b)>>2],C(-1))*C(32768)));d:{if(C(D(g))<C(2147483648)){d=~~g;break d}d=-2147483648}d=Xc(d);k=SR(i,f,a,b),l=d,u[k>>1]=l;a=a+1|0;continue}}}aa(17155,8885,27,9412);L()}aa(17105,8885,28,9412);L()}jb=c+16|0}function BX(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-32|0;jb=k;m=v[c>>2];l=v[c+8>>2];c=v[c+4>>2];v[k+8>>2]=c;v[k+12>>2]=l;v[k+24>>2]=c;v[k+28>>2]=l;v[k+20>>2]=m;v[k+16>>2]=d;v[23296]=0;c=v[k+20>>2];v[k>>2]=v[k+16>>2];v[k+4>>2]=c;a=La(996,a|0,b|0,k|0)|0;b=v[23296];v[23296]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23296]=0;ia(883,10307,e|0,f|0,g|0,h|0,i|0,j|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}$();a=-255}jb=k+32|0;break a}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}return a|0}function op(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-16|0;jb=e;f=jb-32|0;jb=f;c=Je(f+16|0,1,0);a:{b:{c:{while(1){d=tc(c);Ex(f+8|0,d,Fb(c)+d|0,v[b>>2]);if(!v[f+12>>2]){break c}d=Hf(Fb(c));v[23296]=0;R(58,c|0,d|0);d=v[23296];v[23296]=0;if((d|0)!=1){continue}break}break b}b=v[f+8>>2];d=tc(c);v[23296]=0;R(59,c|0,b-d|0);b=v[23296];v[23296]=0;d:{if((b|0)!=1){v[23296]=0;R(60,e|0,c|0);b=v[23296];v[23296]=0;if((b|0)!=1){break d}break b}break b}yb(c);jb=f+32|0;break a}a=P()|0;O()|0;yb(c);S(a|0);L()}v[23296]=0;R(57,a|0,e|0);a=v[23296];v[23296]=0;if((a|0)!=1){yb(e);jb=e+16|0;return}a=P()|0;O()|0;yb(e);S(a|0);L()}function I7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-16|0;jb=e;f=jb-32|0;jb=f;c=Je(f+16|0,1,0);a:{b:{c:{while(1){d=tc(c);Ex(f+8|0,d,Fb(c)+d|0,w[b|0]);if(!v[f+12>>2]){break c}d=Hf(Fb(c));v[23296]=0;R(58,c|0,d|0);d=v[23296];v[23296]=0;if((d|0)!=1){continue}break}break b}b=v[f+8>>2];d=tc(c);v[23296]=0;R(59,c|0,b-d|0);b=v[23296];v[23296]=0;d:{if((b|0)!=1){v[23296]=0;R(60,e|0,c|0);b=v[23296];v[23296]=0;if((b|0)!=1){break d}break b}break b}yb(c);jb=f+32|0;break a}a=P()|0;O()|0;yb(c);S(a|0);L()}v[23296]=0;R(57,a|0,e|0);a=v[23296];v[23296]=0;if((a|0)!=1){yb(e);jb=e+16|0;return}a=P()|0;O()|0;yb(e);S(a|0);L()}function TK(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-16|0;jb=e;Dh(e+8|0,b);f=jb-16|0;jb=f;Og(f+8|0,v[e+8>>2],v[e+12>>2]);c=v[f+12>>2];b=v[f+8>>2];g=jb-16|0;jb=g;k=g,l=Eb(a),v[k+8>>2]=l;h=b;a=c;b=jb-16|0;jb=b;i=v[g+8>>2];c=i;d=v[c+12>>2];c=v[c+8>>2];a:{if((d|0)<0){break a}j=v[i+4>>2];if(!d&j>>>0<c>>>0|d){break a}v[b+8>>2]=j-c;v[b+12>>2]=0-(d+(c>>>0>j>>>0)|0);v[b>>2]=a;v[b+4>>2]=0;d=PB(b+8|0,b);if((Vy(v[d>>2],v[d+4>>2])|0)!=(a|0)){break a}Ji(h,a+h|0,c+v[i>>2]|0);c=v[g+8>>2];h=c;d=a+v[c+8>>2]|0;c=v[c+12>>2];v[h+8>>2]=d;v[h+12>>2]=a>>>0>d>>>0?c+1|0:c}jb=b+16|0;jb=g+16|0;jb=f+16|0;jb=e+16|0}function oea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;pd(b,0);Uh(d,1,a);c=d+16|0;Gc(c,d);ze(b+43|0,c);yb(c);v[b>>2]=w[a+48|0]|w[a+49|0]<<8|(w[a+50|0]<<16|w[a+51|0]<<24);v[b+4>>2]=w[a+52|0]|w[a+53|0]<<8|(w[a+54|0]<<16|w[a+55|0]<<24);v[b+8>>2]=w[a+56|0]|w[a+57|0]<<8|(w[a+58|0]<<16|w[a+59|0]<<24);v[b+24>>2]=w[a+62|0]|w[a+63|0]<<8;iq(b,+((w[a+60|0]^8)-120|0)/192);t[d+16|0]=w[a+61|0];t[d|0]=64;f=b,g=w[Wb(c,d)|0]<<2,u[f+30>>1]=g;u[b+34>>1]=0;c=w[a+47|0];if(c&4){u[b+34>>1]=1;v[b>>2]=v[b>>2]>>>1;e=1;c=w[a+47|0]}if(c&32){e=e|4;u[b+34>>1]=e;c=w[a+47|0]}if(c<<24>>24<0){u[b+34>>1]=e|2}jb=d+32|0}function k_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=NF(b);xk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;wk(k,a);Pi(i,k);Kc(k);Hh(k,a);Pi(h,k);Kc(k);l=d,m=Ui(a),v[l>>2]=m;l=e,m=Vi(a),v[l>>2]=m;Ng(k,a);Bc(f,k);yb(k);Ih(k,a);Pi(g,k);Kc(k);a=vk(a);break a}a=MF(b);xk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;wk(k,a);Pi(i,k);Kc(k);Hh(k,a);Pi(h,k);Kc(k);l=d,m=Ui(a),v[l>>2]=m;l=e,m=Vi(a),v[l>>2]=m;Ng(k,a);Bc(f,k);yb(k);Ih(k,a);Pi(g,k);Kc(k);a=vk(a)}v[j>>2]=a;jb=k+16|0}function Gda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(b){if(ih(119304647)>>>0<b>>>0){Wc();L()}b=B(b,36);c=xc(b);v[a>>2]=c;v[a+4>>2]=c;f=Gb(a),g=b+c|0,v[f>>2]=g;d=jb-16|0;jb=d;v[d>>2]=a;c=v[a+4>>2];v[d+4>>2]=c;v[d+8>>2]=b+c;b=v[d+4>>2];e=v[d+8>>2];while(1){if((b|0)==(e|0)){lc(d);jb=d+16|0}else{c=Xb(b,0,36);v[c>>2]=0;v[c+4>>2]=0;u[c+22>>1]=0;u[c+24>>1]=0;u[c+26>>1]=0;u[c+28>>1]=0;t[c+21|0]=64;t[c+19|0]=64;t[c+20|0]=100;t[c+15|0]=0;t[c+16|0]=0;t[c+17|0]=0;t[c+18|0]=0;v[c+8>>2]=0;v[c+12>>2]=0;u[c+30>>1]=0;u[c+32>>1]=0;b=b+36|0;v[d+4>>2]=b;continue}break}}return a|0}function rJ(a,b){var c=0,d=0,e=0,f=0;a:{e=jb-16|0;jb=e;f=jb-32|0;jb=f;c=Je(f+16|0,1,0);b:{c:{d:{while(1){d=tc(c);px(f+8|0,d,Fb(c)+d|0,x[b>>1]);if(!v[f+12>>2]){break d}d=Hf(Fb(c));v[23296]=0;R(58,c|0,d|0);d=v[23296];v[23296]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=tc(c);v[23296]=0;R(59,c|0,b-d|0);b=v[23296];v[23296]=0;e:{if((b|0)!=1){v[23296]=0;R(71,e|0,c|0);b=v[23296];v[23296]=0;if((b|0)!=1){break e}break c}break c}yb(c);jb=f+32|0;break b}a=P()|0;O()|0;yb(c);S(a|0);L()}v[23296]=0;R(70,a|0,e|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(e);jb=e+16|0;break a}a=P()|0;O()|0;zb(e);S(a|0);L()}}function r_(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0;k=jb-16|0;jb=k;a:{if(a){a=RF(b);xk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;wk(k,a);Bc(i,k);yb(k);Hh(k,a);Bc(h,k);yb(k);l=d,m=Ui(a),t[l|0]=m;l=e,m=Vi(a),t[l|0]=m;Ng(k,a);Bc(f,k);yb(k);Ih(k,a);Bc(g,k);yb(k);a=vk(a);break a}a=QF(b);xk(k,a);b=v[k>>2];t[c|0]=b;t[c+1|0]=b>>>8;t[c+2|0]=b>>>16;t[c+3|0]=b>>>24;wk(k,a);Bc(i,k);yb(k);Hh(k,a);Bc(h,k);yb(k);l=d,m=Ui(a),t[l|0]=m;l=e,m=Vi(a),t[l|0]=m;Ng(k,a);Bc(f,k);yb(k);Ih(k,a);Bc(g,k);yb(k);a=vk(a)}v[j>>2]=a;jb=k+16|0}function cs(a,b,c){var d=0,e=0;d=a,e=bj(C(C(z[c+1792>>2]*C(75038))+C(C(C(z[c+2048>>2]-z[c+1536>>2])*C(37489))+C(C(C(z[c+1280>>2]+z[c+2304>>2])*C(6574))+C(C(C(z[c+2560>>2]-z[c+1024>>2])*C(5153))+C(C(C(z[c+768>>2]+z[c+2816>>2])*C(2037))+C(C(C(z[c+3072>>2]-z[c+512>>2])*C(459))+C(C(C(z[c+256>>2]+z[c+3328>>2])*C(213))+C(C(z[c+3584>>2]-z[c>>2])*C(29)))))))))),u[d>>1]=e;d=(b<<5)+a|0,e=bj(C(C(z[c+8>>2]*C(-5))+C(C(z[c+520>>2]*C(146))+C(C(z[c+1032>>2]*C(-45))+C(C(z[c+1544>>2]*C(-9975))+C(C(z[c+2056>>2]*C(64019))+C(C(z[c+2568>>2]*C(9727))+C(C(z[c+3080>>2]*C(1567))+C(z[c+3592>>2]*C(104)))))))))),u[d>>1]=e}function ae(a,b){var c=0,d=0,e=0;c=jb-32|0;jb=c;a=jh(a,-1,-1);a:{b:{if(Rd(w[rn(c+24|0,b,1)|0])){d=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[23296]=0;R(95,c+8|0,d|0);d=v[23296];v[23296]=0;c:{if((d|0)!=1){d=v[c+12>>2];v[a>>2]=v[c+8>>2];v[a+4>>2]=d;d=v[c+20>>2];v[a+8>>2]=v[c+16>>2];v[a+12>>2]=d;break c}a=V(0)|0;O()|0;_(a|0)|0;e=1;qn(v[v[b>>2]-12>>2]+b|0,1);if(v[(v[v[b>>2]-12>>2]+b|0)+20>>2]&1){v[23296]=0;Z(93);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)==1){break b}S(a|0);L()}$()}vj(v[v[b>>2]-12>>2]+b|0,e)}jb=c+32|0;return}V(0)|0;O()|0;Ub()}L()}function NJ(a,b){var c=0,d=0,e=0,f=0;a:{e=jb-16|0;jb=e;f=jb-32|0;jb=f;c=Je(f+16|0,1,0);b:{c:{d:{while(1){d=tc(c);GJ(f+8|0,d,Fb(c)+d|0,w[b|0]);if(!v[f+12>>2]){break d}d=Hf(Fb(c));v[23296]=0;R(58,c|0,d|0);d=v[23296];v[23296]=0;if((d|0)!=1){continue}break}break c}b=v[f+8>>2];d=tc(c);v[23296]=0;R(59,c|0,b-d|0);b=v[23296];v[23296]=0;e:{if((b|0)!=1){v[23296]=0;R(71,e|0,c|0);b=v[23296];v[23296]=0;if((b|0)!=1){break e}break c}break c}yb(c);jb=f+32|0;break b}a=P()|0;O()|0;yb(c);S(a|0);L()}v[23296]=0;R(70,a|0,e|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(e);jb=e+16|0;break a}a=P()|0;O()|0;zb(e);S(a|0);L()}}function K2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=jb-16|0;jb=c;a=To(c,a,1);rx(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+16;lc(a);jb=c+16|0;return}e=jb-32|0;jb=e;c=Gb(a);c=Iv(e+8|0,Jv(a,hh(v[a>>2],v[a+4>>2])+1|0),hh(v[a>>2],v[a+4>>2]),c);rx(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+16;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-16|0;rx(v[b>>2]-16|0,d);v[b>>2]=v[b>>2]-16;continue}break}oc(a,b);oc(a+4|0,c+8|0);oc(Gb(a),zc(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];while(1){b=v[c+8>>2];if((b|0)!=(a|0)){b=b-16|0;v[c+8>>2]=b;qs(b);continue}break}a=v[c>>2];if(a){Ro(c);Jb(a)}jb=e+32|0}function qN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-16|0;jb=c;a:{if(w[b+791|0]!=27){a=t[b+831|0];break a}d=c+8|0;f=a+1074312|0;Bb(d,f,21);e=a;a=w[b+821|0];a=iy(e,w[b+828|0],Cb(v[v[c+8>>2]>>2],v[c+12>>2])?a:a+16>>>2|0);Bb(d,f,45);b:{if(!(!Cb(v[v[c+8>>2]>>2],v[c+12>>2])|w[b+828|0]!=3)){d=w[b+821|0];c:{if(!(!d|d>>>0>=w[b+829|0])){a=w[b+832|0];e=d+1|0;break c}t[b+832|0]=a;e=1}t[b+821|0]=e;a=a<<24>>24;break b}t[b+821|0]=w[b+821|0]+w[b+829|0]}Bb(c+8|0,f,47);if(!Cb(v[v[c+8>>2]>>2],v[c+12>>2])){break a}t[b+831|0]=a}if(a){g=b,h=Yb(v[b+684>>2]+((B(w[b+830|0],a)+2|0)/8|0)|0,0,256),v[g+684>>2]=h}jb=c+16|0}function cga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;i=e,j=ak(b),v[i>>2]=j;f=x[b>>1];d=jb-16|0;jb=d;g=a;c=Wd(a);a:{if(c){b=kc(g);while(1){a=c;c=x[a+14>>1];if(mo(f,c)){b=a;c=v[a>>2];if(c){continue}break a}if(!mo(c,f)){break a}b=a+4|0;c=v[a+4>>2];if(c){continue}break}break a}a=kc(g);b=a}v[d+12>>2]=a;a=v[b>>2];if(!a){a=jb-16|0;jb=a;c=kc(g);f=th(d,xc(20),uh(a+8|0,c));c=v[f>>2];h=x[v[e>>2]>>1];u[c+16>>1]=0;u[c+14>>1]=h;i=kc(f),j=1,t[i+4|0]=j;jb=a+16|0;Zg(g,v[d+12>>2],b,v[d>>2]);a=de(d);cl(d);h=1}Yg(e+8|0,v[hc(d,a)>>2],h);jb=d+16|0;a=Wp(v[e+8>>2]);jb=e+16|0;return a+2|0}function jX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;a:{g=jb+-64|0;jb=g;Vm(g+16|0,c);v[23296]=0;c=g+28|0;R(101,c|0,d|0);d=v[23296];v[23296]=0;b:{c:{d:{if((d|0)==1){break d}v[23296]=0;c=g+40|0;R(101,c|0,e|0);d=v[23296];v[23296]=0;if((d|0)==1){break d}v[23296]=0;c=g+52|0;R(101,c|0,f|0);d=v[23296];v[23296]=0;if((d|0)==1){break d}Hv(g+8|0,g+16|0);v[23296]=0;X(102,a|0,b|0,v[g+8>>2],v[g+12>>2]);a=v[23296];v[23296]=0;if((a|0)==1){break c}bE(g+16|0);jb=g- -64|0;break a}a=P()|0;O()|0;while(1){c=zb(c-12|0);if((c|0)!=(g+16|0)){continue}break}break b}a=P()|0;O()|0;bE(g+16|0)}S(a|0);L()}}function nk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;f=a+36|0;c=v[a+32>>2];a:{b:{while(1){if((b|0)<=(c|0)){break b}c:{d=v[a+20>>2];if(d>>>0>=y[a+24>>2]){jn(e,f,GD(f));qd(e+8|0,a,v[e>>2],v[e+4>>2]);c=v[e+12>>2];v[a+24>>2]=c;v[a+20>>2]=0;if(!c){break c}d=0;c=v[a+32>>2]}v[a+20>>2]=d+1;g=w[(a+d|0)+36|0];d=c+8|0;v[a+32>>2]=d;v[a+28>>2]=v[a+28>>2]|g<<c;c=d;continue}break}a=ba(8)|0;v[23296]=0;b=T(155,a|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}v[a+32>>2]=c-b;d=a;a=v[a+28>>2];v[d+28>>2]=a>>>b;jb=e+16|0;return a&(-1<<b^-1)}ha(b|0,30320,156);L()}function yca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=jb-16|0;jb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>18|0;n=((((v[b+12>>2]&2147483647)<<1|e>>>31)&2147483646)<<1)+j|0;e=0;while(1){if((e|0)!=2){f=(e<<1)+n|0;g=u[f>>1];v[(e<<2)+b>>2]=g+((B(u[f+4>>1]-g|0,m)|0)/16384|0);e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],h);Sb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function oZ(a){a=a|0;if(w[467264]){return v[116815]}if(!w[468368]){a=468080;while(1){a=Kb(a)+12|0;if((a|0)!=468368){continue}break}t[468368]=1}nd(468080,88072);nd(468092,88104);nd(468104,88140);nd(468116,88164);nd(468128,88188);nd(468140,88204);nd(468152,88224);nd(468164,88244);nd(468176,88272);nd(468188,88312);nd(468200,88344);nd(468212,88380);nd(468224,88416);nd(468236,88432);nd(468248,88448);nd(468260,88464);nd(468272,88188);nd(468284,88480);nd(468296,88496);nd(468308,88512);nd(468320,88528);nd(468332,88544);nd(468344,88560);nd(468356,88576);t[467264]=1;v[116815]=468080;return 468080}function X5(a,b,c){a=a|0;b=+b;c=c|0;var d=0,e=0,f=0;d=jb-80|0;jb=d;v[d+72>>2]=c;c=v[a>>2];e=v[a+4>>2];f=v[a+12>>2];v[d+40>>2]=v[a+8>>2];v[d+44>>2]=f;v[d+32>>2]=c;v[d+36>>2]=e;a=$d(d+24|0);c=v[a+4>>2];a=v[a>>2];e=v[d+44>>2];v[d+8>>2]=v[d+40>>2];v[d+12>>2]=e;v[23296]=0;e=v[d+36>>2];v[d>>2]=v[d+32>>2];v[d+4>>2]=e;X(884,d+48|0,d|0,a|0,c|0);a=v[23296];v[23296]=0;a:{b:{if((a|0)!=1){a=v[Tf(d+16|0,d+72|0)>>2];v[23296]=0;b=+Aa(885,d+48|0,+b,a|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}Ab(d+48|0);te(d+72|0);jb=d+80|0;return+b}a=P()|0;O()|0;break a}a=P()|0;O()|0;Ab(d+48|0)}te(d+72|0);S(a|0);L()}function t5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;v[23296]=0;Y(900,a|0);d=v[23296];v[23296]=0;a:{b:{c:{if((d|0)==1){break c}v[23296]=0;Y(901,b|0);d=v[23296];v[23296]=0;if((d|0)==1){break c}d=v[a+24>>2];b=rc(c+8|0,b);e=v[b+4>>2];b=v[b>>2];v[23296]=0;da(913,c+16|0,d|0,b|0,e|0,1);b=v[23296];v[23296]=0;if((b|0)==1){break c}a=c+16|0;b=Xf(Jc(a));yb(a);break b}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23296]=0;X(887,5496,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$()}jb=c+32|0;return b|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function s8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=jb-16|0;jb=c;a=Bz(c,a);Px(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+4;lc(a);jb=c+16|0;return}e=jb-32|0;jb=e;c=Gb(a);c=fg(e+8|0,Ug(a,wc(v[a>>2],v[a+4>>2])+1|0),wc(v[a>>2],v[a+4>>2]),c);Px(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+4;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-4|0;Px(v[b>>2]-4|0,d);v[b>>2]=v[b>>2]-4;continue}break}oc(a,b);oc(a+4|0,c+8|0);oc(Gb(a),zc(c));v[c>>2]=v[c+4>>2];a=v[c+4>>2];while(1){b=v[c+8>>2];if((b|0)!=(a|0)){b=b-4|0;v[c+8>>2]=b;ig(b);continue}break}a=v[c>>2];if(a){yz(c);Jb(a)}jb=e+32|0}function Zg(a,b,c,d){var e=0,f=0;v[d+8>>2]=b;v[d>>2]=0;v[d+4>>2]=0;v[c>>2]=d;b=v[v[a>>2]>>2];if(b){v[a>>2]=b;d=v[c>>2]}f=v[kc(a)>>2];t[d+12|0]=(f|0)==(d|0);while(1){a:{if((d|0)==(f|0)){break a}c=v[d+8>>2];if(w[c+12|0]){break a}b:{if(sh(c)){b=v[c+8>>2];e=v[b+4>>2];if(!(!e|w[e+12|0])){break b}if(!sh(d)){Zp(c);c=v[c+8>>2]}t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;Yp(b);break a}b=v[c+8>>2];e=v[b>>2];if(!(!e|w[e+12|0])){break b}if(sh(d)){Yp(c);c=v[c+8>>2]}t[c+12|0]=1;b=v[c+8>>2];t[b+12|0]=0;Zp(b);break a}t[c+12|0]=1;d=b;t[d+12|0]=(d|0)==(f|0);t[e+12|0]=1;continue}break}a=Gb(a);v[a>>2]=v[a>>2]+1}function A0(){var a=0,b=0,c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;if(KH(0,d+16|0)){Wr(v[115772],12532);L()}b=Vr(d+8|0,v[d+16>>2]);e=Vr(d,v[d+20>>2]/1e3|0);c=jb-32|0;jb=c;a=jb-16|0;jb=a;f=jb-16|0;jb=f;b=tn(f+8|0,Sia(v[b>>2],v[b+4>>2],1e6,0),mb);g=v[b+4>>2];b=v[b>>2];jb=f+16|0;v[a+8>>2]=b;v[a+12>>2]=g;b=v[a+12>>2];v[c+16>>2]=v[a+8>>2];v[c+20>>2]=b;jb=a+16|0;a=v[c+16>>2];f=v[c+20>>2];b=v[e+4>>2];v[c+8>>2]=v[e>>2];v[c+12>>2]=b;e=v[c+8>>2];b=a+e|0;a=v[c+12>>2]+f|0;a=tn(c+24|0,b,b>>>0<e>>>0?a+1|0:a);b=v[a+4>>2];a=v[a>>2];jb=c+32|0;c=tn(d+24|0,a,b);a=v[c+4>>2];c=v[c>>2];jb=d+32|0;mb=a;return c|0}function km(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=1;j=d&2147483647;l=j;k=(j|0)==2147418112;a:{if(k&!c?a|b:k&(c|0)!=0|j>>>0>2147418112){break a}j=h&2147483647;k=(j|0)==2147418112;if(k&!g?e|f:k&(g|0)!=0|j>>>0>2147418112){break a}if(!(a|e|(c|g)|(b|f|(j|l)))){return 0}i=d&h;if((i|0)>0|(i|0)>=0){i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0<e>>>0|b>>>0<f>>>0:c>>>0<g>>>0&(d|0)<=(h|0)|(d|0)<(h|0)){break a}return(a^e|c^g|(b^f|d^h))!=0}i=-1;if((c|0)==(g|0)&(d|0)==(h|0)?(b|0)==(f|0)&a>>>0>e>>>0|b>>>0>f>>>0:c>>>0>g>>>0&(d|0)>=(h|0)|(d|0)>(h|0)){break a}i=(a^e|c^g|(b^f|d^h))!=0}return i}function WH(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0;if(Pe(a)){bc(a,31);return 0}g=a,h=Pe(a),t[g+1375|0]=h;d=$i(a);b=$i(a);$i(a);g=a,h=$i(a),v[g+1112>>2]=h;$i(a);c=Pe(a);v[a+1116>>2]=c;if(!Ww(a,a+1120|0,c)){bc(a,10);return 0}v[a+1404>>2]=-2;a:{if((b&d)==-1){break a}b=v[a+1116>>2];while(1){if((b|0)<=0){break a}b=b-1|0;if(w[(b+a|0)+1120|0]==255){continue}break}v[a+1408>>2]=d;v[a+1404>>2]=b}if(w[a+1377|0]){b=0;e=v[a+1116>>2];f=(e|0)>0?e:0;c=0;while(1){if((b|0)!=(f|0)){c=w[(a+b|0)+1120|0]+c|0;b=b+1|0;continue}break}v[a- -64>>2]=d;v[a+60>>2]=(v[a+56>>2]+(c+e|0)|0)+27}v[a+1380>>2]=0;return 1}function rn(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;t[a|0]=0;a:{d=v[v[b>>2]-12>>2]+b|0;b:{if(Kg(d)){d=v[d+72>>2];if(d){Tq(d)}c:{if(c){break c}c=v[v[b>>2]-12>>2]+b|0;if(!(v[c+4>>2]&4096)){break c}d=e+24|0;bd(d,c);v[23296]=0;f=T(18,d|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}_b(e+24|0);c=ym(e+16|0,b);d=Cc(e+8|0);while(1){d:{if(!ep(c,d)){break d}g=Ek(v[c>>2]);if(!lh(v[f+8>>2],1,g)){break d}Hl(c);continue}break}if(!Yi(c,d)){break c}vj(v[v[b>>2]-12>>2]+b|0,6)}h=a,i=Kg(v[v[b>>2]-12>>2]+b|0),t[h|0]=i;break b}vj(d,4)}jb=e+32|0;return a}a=P()|0;O()|0;_b(e+24|0);S(a|0);L()}function zca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;b=jb-16|0;jb=b;h=v[a+24>>2];i=v[a+20>>2];j=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){e=v[b+8>>2];m=e>>>10&4194048;n=(((v[b+12>>2]&2147483647)<<1|e>>>31)&-2)+j|0;e=0;while(1){if((e|0)!=2){f=e+n|0;g=t[f|0];v[(e<<2)+b>>2]=((B(t[f+2|0]-g|0,m)|0)/16384|0)+(g<<8);e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],i);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],h);Sb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function iw(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;g=f+8|0;bd(g,b);v[23296]=0;b=T(1084,g|0)|0;g=v[23296];v[23296]=0;a:{if((g|0)==1){break a}v[23296]=0;X(1096,b|0,81808,81840,c|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}v[23296]=0;b=T(1085,f+8|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}v[23296]=0;c=T(1097,b|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break a}v[d>>2]=c;v[23296]=0;c=T(1094,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}v[e>>2]=c;v[23296]=0;R(1095,a|0,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break a}_b(f+8|0);jb=f+16|0;return}a=P()|0;O()|0;_b(f+8|0);S(a|0);L()}function zX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=c;c=jb-16|0;jb=c;v[23296]=0;Y(900,a|0);e=v[23296];v[23296]=0;a:{b:{c:{d:{if((e|0)==1){break d}v[23296]=0;Y(901,b|0);e=v[23296];v[23296]=0;if((e|0)==1){break d}e=v[a+24>>2];b=rc(c+8|0,b);g=v[b+4>>2];b=v[b>>2];v[23296]=0;ZE(921,e,b,g,f,d);d=v[23296];v[23296]=0;b=1;if((d|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,8544,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break b}$();b=0}jb=c+16|0;break a}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}return b|0}function R_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-32|0;jb=f;v[f+24>>2]=b;a:{if(!(v[c+4>>2]&1)){c=nb[v[v[a>>2]+24>>2]](a,b,c,d,e)|0;break a}a=f+8|0;bd(a,c);v[23296]=0;a=T(1085,a|0)|0;b=v[23296];v[23296]=0;b:{if((b|0)!=1){_b(f+8|0);c:{if(e){Ih(f+8|0,a);break c}Hh(f+8|0,a)}g=f,h=Zd(f+8|0),v[g>>2]=h;while(1){a=zk(f+8|0);b=v[f>>2];if(!Rb(b,a)){c=v[f+24>>2];Kc(f+8|0);break a}a=v[b>>2];v[23296]=0;Q(1100,f+24|0,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){Ce(f);continue}break}c=P()|0;O()|0;Kc(f+8|0);break b}c=P()|0;O()|0;_b(f+8|0)}S(c|0);L()}jb=f+32|0;return c|0}function Aga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=jb-48|0;jb=e;d=v[a+8>>2];c=v[a>>2];v[23296]=0;d=W(144,c|0,d|0,1)|0;c=v[23296];v[23296]=0;a:{if((c|0)==1){break a}b:{if(!d){break b}v[23296]=0;Y(451,b|0);d=v[23296];v[23296]=0;if((d|0)==1){break a}v[23296]=0;d=T(194,a|0)|0;c=v[23296];v[23296]=0;c:{if((c|0)!=1){while(1){if(!(d&255)){break b}v[23296]=0;c=Q(452,a|0,e+8|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break c}d:{if(!c){break d}c=w[e+8|0];if(c>>>0>63){break d}qc(zS(v[b>>2],c),e+8|0,33)}d=d-1|0;continue}}break a}break a}Ab(a);jb=e+48|0;return}b=P()|0;O()|0;Ab(a);S(b|0);L()}function mw(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;g=f+8|0;bd(g,b);v[23296]=0;b=T(18,g|0)|0;g=v[23296];v[23296]=0;a:{if((g|0)==1){break a}v[23296]=0;X(1082,b|0,81808,81840,c|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}v[23296]=0;b=T(1067,f+8|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}v[23296]=0;c=T(1083,b|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break a}t[d|0]=c;v[23296]=0;c=T(1080,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}t[e|0]=c;v[23296]=0;R(1081,a|0,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break a}_b(f+8|0);jb=f+16|0;return}a=P()|0;O()|0;_b(f+8|0);S(a|0);L()}function BJ(a,b){var c=0,d=0;c=v[a>>2];v[a>>2]=b;if(c){v[23296]=0;Y(766,c|0);a=v[23296];v[23296]=0;a:{if((a|0)!=1){a=v[c+4>>2];if(a){if(v[a>>2]){d=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(d|0)){b=b-4|0;ig(b);continue}break}v[a+4>>2]=d;b=v[a>>2];ui(a);Jb(b)}Jb(a)}v[c+4>>2]=0;FM(c+1298408|0);wy(c+1298344|0);yb(c+1298332|0);zb(c+1298320|0);yb(c+1298308|0);vy(c+1298304|0);uy(c+1298300|0);at(c+1298264|0);Iy(c+1074376|0);b=c+946300|0;a=c+906300|0;while(1){b=Ss(b-160|0);if((a|0)!=(b|0)){continue}break}rz(c+484360|0);xM(c+484344|0);vc(c+480248|0);break a}V(0)|0;O()|0;Ub();L()}Jb(c)}}function dh(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=wc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=jb-32|0;jb=e;b=b-c|0;c=v[Gb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){c=jb-16|0;jb=c;b=Ph(c,a,b);a=v[b+4>>2];d=v[b+8>>2];while(1){if((a|0)==(d|0)){lc(b);jb=c+16|0}else{cv(a);a=a+4|0;v[b+4>>2]=a;continue}break}break a}c=Gb(a);c=fg(e+8|0,Ug(a,wc(v[a>>2],d)+b|0),wc(v[a>>2],v[a+4>>2]),c);f=jb-16|0;jb=f;b=ol(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){cv(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Id(b);jb=f+16|0;Ad(a,c);eg(c)}jb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function PK(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a=li(a,b,c,d);t[a+4260|0]=e;v[a>>2]=46244;c=Qb(a+4264|0);d=Qb(a+4276|0);v[a+4328>>2]=0;b=a+4320|0;v[b>>2]=0;v[b+4>>2]=0;v[a+4312>>2]=0;v[a+4316>>2]=0;b=a+4208|0;f=Db(b,0),g=1056964608,v[f>>2]=g;f=Db(b,1),g=1036831949,v[f>>2]=g;f=Db(b,2),g=1038174126,v[f>>2]=g;f=Db(b,3),g=1065353216,v[f>>2]=g;f=Db(b,4),g=1061158912,v[f>>2]=g;f=Db(b,5),g=1059082943,v[f>>2]=g;f=Db(b,6),g=1061997773,v[f>>2]=g;v[23296]=0;R(851,a+44|0,2);b=v[23296];v[23296]=0;if((b|0)!=1){ki(a);return a|0}b=P()|0;O()|0;vc(d);vc(c);uf(a);S(b|0);L()}function iD(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;v[b+4>>2]=B(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),5)+(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24));v[b+8>>2]=(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))+((w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24))<<3);v[b+12>>2]=(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))+((w[a+28|0]|w[a+29|0]<<8|(w[a+30|0]<<16|w[a+31|0]<<24))<<2);a=b+4|0;d=Db(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=aq(v[a>>2],v[c>>2])?c:a;continue}}jb=b+16|0;return v[a>>2]-36|0}function aZ(a){a=a|0;if(w[467256]){return v[116813]}if(!w[468064]){a=467776;while(1){a=Kb(a)+12|0;if((a|0)!=468064){continue}break}t[468064]=1}jd(467776,4995);jd(467788,4986);jd(467800,10734);jd(467812,10482);jd(467824,5222);jd(467836,11510);jd(467848,5079);jd(467860,5570);jd(467872,8788);jd(467884,8771);jd(467896,8779);jd(467908,8798);jd(467920,9965);jd(467932,13104);jd(467944,8861);jd(467956,7632);jd(467968,5222);jd(467980,9654);jd(467992,10370);jd(468004,10746);jd(468016,9151);jd(468028,6424);jd(468040,5453);jd(468052,13022);t[467256]=1;v[116813]=467776;return 467776}function G$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-32|0;jb=c;a:{b:{c:{if(uc(b,-1)){break c}i=c,j=An(b),t[i+23|0]=j;if(w[a+44|0]){d=-1;if((fk(c+23|0,1,1,v[a+32>>2])|0)==1){break c}break a}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+23|0;while(1){e=Nr(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((fk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((fk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}d=Aw(b);break a}d=-1}jb=c+32|0;return d|0}function AX(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[23296]=0;Y(900,a|0);c=v[23296];v[23296]=0;a:{b:{c:{d:{if((c|0)==1){break d}v[23296]=0;Y(901,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break d}e=v[a+24>>2];b=rc(d+8|0,b);c=v[b+4>>2];b=v[b>>2];v[23296]=0;b=_E(e,b,c,1);e=v[23296];v[23296]=0;c=mb;if((e|0)!=1){break c}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,8575,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break b}$();b=0;c=0}jb=d+16|0;a=c;break a}b=P()|0;O()|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)!=1){S(b|0);L()}V(0)|0;O()|0;Ub();L()}ra(a|0);return b|0}function p5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;v[23296]=0;Y(900,a|0);d=v[23296];v[23296]=0;a:{b:{c:{if((d|0)==1){break c}v[23296]=0;Y(901,b|0);d=v[23296];v[23296]=0;if((d|0)==1){break c}d=v[a+24>>2];b=rc(e+8|0,b);f=v[b+4>>2];b=v[b>>2];v[23296]=0;da(918,d|0,b|0,f|0,(c|0)!=0|0,1);c=v[23296];v[23296]=0;b=1;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,9897,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();b=0}jb=e+16|0;return b|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function VM(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{if(v[a+480180>>2]!=1){break a}c=w[b+846|0];if(!c){break a}d=v[b+104>>2];if(!d){break a}if(!Ud(v[d>>2],v[d+20>>2])){break a}f=x[d+34>>1];if(!(f&10)){break a}c=w[b+847|0]+w[(c&15)+33232|0]|0;t[b+847|0]=c;if(c<<24>>24>=0){break a}t[b+847|0]=0;h=f&2;c=v[(h?4:12)+d>>2];g=b;b=v[b+760>>2]+1|0;b=b>>>0<v[(h?8:16)+d>>2]-c>>>0?b:0;v[g+760>>2]=b;g=v[d+20>>2];c=b+c|0;b=mk(f);ic(e+8|0,g+B(c,b)|0,b);b=v[e+8>>2];f=Lb(b,v[e+12>>2]);while(1){if((b|0)==(f|0)){mj(d,a)}else{t[b|0]=w[b|0]^-1;b=b+1|0;continue}break}}jb=e+16|0}function xca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){h=v[b+12>>2]+i|0;e=t[h|0];e=((B(t[h+1|0]-e|0,v[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Sb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;jb=b+16|0}function C$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;d=w[a+52|0];a:{if(uc(b,-1)){if(d){break a}b=v[a+48>>2];e=a,f=uc(b,-1)^1,t[e+52|0]=f;break a}b:{if(!d){break b}e=c,f=An(v[a+48>>2]),t[e+19|0]=f;c:{d:{e:{d=c+20|0;switch(Nr(v[a+36>>2],v[a+40>>2],c+19|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((Lr(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}jb=c+32|0;return b|0}function wca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;b=jb-16|0;jb=b;f=v[a+40>>2];g=v[a+36>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+32>>2];k=v[a+28>>2];l=v[a+8>>2];m=v[a+12>>2];while(1){if(d){h=(v[b+12>>2]<<1)+i|0;e=u[h>>1];e=e+((B(u[h+2>>1]-e|0,v[b+8>>2]>>>18|0)|0)/16384|0)|0;g=g+k|0;v[c>>2]=v[c>>2]+B(e,g>>12);f=f+j|0;v[c+4>>2]=v[c+4>>2]+B(e,f>>12);Sb(b+8|0,l,m);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=f;v[a+20>>2]=g>>12;v[a+36>>2]=g;v[a+24>>2]=f>>12;jb=b+16|0}function Q5(a){a=a|0;var b=0;b=7934;a:{b:{c:{switch(a-277|0){default:if((a|0)==357){break b}d:{if((a|0)!=257){if((a|0)==267){break d}if(a){break a}b=21473;break a}b=7967;break a}b=17373;break a;case 0:b=4972;break a;case 9:b=7990;break a;case 10:b=8004;break a;case 11:b=5349;break a;case 12:b=5369;break a;case 19:b=8016;break a;case 20:b=7948;break a;case 21:b=12688;break a;case 22:b=12011;break a;case 1:case 2:case 3:case 4:case 5:case 6:case 7:case 8:case 13:case 14:case 15:case 16:case 17:case 18:break a;case 23:break c}}b=5980;break a}b=7901}return Xf(b)|0}function Po(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){if(!Uf(w[a+11|0])){c=w[b+11|0];if(!Uf(c)){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return}d=rd(b);b=Cd(v[b+4>>2],c);c=jb-16|0;jb=c;a:{if(b>>>0<=10){xe(a,b);a=He(a,d,b);t[c+15|0]=0;sd(a+b|0,c+15|0);break a}f=a;a=Lf(w[a+11|0]);Ut(f,10,b-10|0,a,0,a,b,d)}jb=c+16|0;return}d=rd(b);b=Cd(v[b+4>>2],w[b+11|0]);c=jb-16|0;jb=c;e=fB(v[a+8>>2]);b:{if(e>>>0>b>>>0){e=v[a>>2];Td(a,b);a=He(e,d,b);t[c+15|0]=0;sd(a+b|0,c+15|0);break b}f=a;a=v[a+4>>2];Ut(f,e-1|0,(b-e|0)+1|0,a,0,a,b,d)}jb=c+16|0}}
function Gea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;f=jb-32|0;jb=f;a:{c=v[a+12>>2];b:{if((c|0)==(b|0)){break b}d=b>>>0>c>>>0;c=B(Eg(v[v[a+48>>2]+12>>2]),d?b-c|0:c-b|0);e=Eb(v[a+4>>2]);c:{if(d){e=hc(f+24|0,e);d=f+16|0;wh(d);e=v[e>>2];v[23296]=0;X(587,a|0,e|0,c|0,d|0);c=v[23296];v[23296]=0;if((c|0)!=1){break c}a=V(91780)|0;if((O()|0)!=(ea(91780)|0)){break a}_(a|0)|0;$();break b}c=hc(f+8|0,ZA(e,c));e=v[hc(f,Eb(v[a+4>>2]))>>2];d=v[c>>2];c=v[a>>2];c=B(Ls(d,Eb(c)),6)+c|0;if(Rb(d,e)){Nd(a,DL(c+B(Ls(e,d),6)|0,v[a+4>>2],c))}Eb(c)}v[a+12>>2]=b}jb=f+32|0;return}S(a|0);L()}function o5(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;e=jb-16|0;jb=e;v[23296]=0;Y(900,a|0);d=v[23296];v[23296]=0;a:{b:{c:{if((d|0)==1){break c}v[23296]=0;Y(901,b|0);d=v[23296];v[23296]=0;if((d|0)==1){break c}d=v[a+24>>2];b=rc(e+8|0,b);f=v[b+4>>2];b=v[b>>2];v[23296]=0;_a(920,d|0,b|0,f|0,+c,1);d=v[23296];v[23296]=0;b=1;if((d|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,5887,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();b=0}jb=e+16|0;return b|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function daa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;v[d+12>>2]=b;if(b>>>0<1073741808){a:{if(cn(a)>>>0>=b>>>0){break a}h=d,i=Fb(a),v[h+8>>2]=i;e=El(v[Yc(d+12|0,d+8|0)>>2]);if((e|0)==(cn(a)|0)){break a}f=1;c=cn(a);g=Fb(a);b:{c:{if((e|0)==1){b=a;c=v[a>>2];break c}b=e+1|0;d:{if(c>>>0<e>>>0){b=ri(b);break d}v[23296]=0;b=T(1173,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break d}a=V(0)|0;O()|0;_(a|0)|0;$();break b}f=Ve(a);c=tc(a)}ei(b,c,Fb(a)+1|0);if(f){Jb(c)}if((e|0)!=1){Af(a,e+1|0);Td(a,g);yd(a,b);break b}xe(a,g)}}jb=d+16|0;return}of();L()}function et(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-16|0;jb=c;v[c+12>>2]=b;if(b>>>0<4294967280){a:{if(Tc(a)>>>0>=b>>>0){break a}h=c,i=Fb(a),v[h+8>>2]=i;d=zi(v[Yc(c+12|0,c+8|0)>>2]);if((d|0)==(Tc(a)|0)){break a}f=Fb(a);b:{c:{if((d|0)==10){g=1;b=a;e=v[a>>2];break c}b=d+1|0;d:{if(Tc(a)>>>0<d>>>0){b=xc(b);break d}v[23296]=0;b=T(51,b|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){break d}a=V(0)|0;O()|0;_(a|0)|0;$();break b}g=Ve(a);e=tc(a)}b=He(b,e,Fb(a)+1|0);if(g){Jb(e)}if((d|0)!=10){Af(a,d+1|0);Td(a,f);yd(a,b);break b}xe(a,f)}}jb=c+16|0;return}of();L()}function j7(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[v[a+16>>2]+24620>>2];b=Ic(Tia(Sia(b,b>>31,3840,0),mb,1e3,0),mb);v[a+4316>>2]=b;v[23296]=0;v[c+12>>2]=0;U(857,a+4264|0,b|0,c+12|0);b=v[23296];v[23296]=0;a:{b:{c:{if((b|0)!=1){d:{if(!w[a+4260|0]){break d}b=v[a+4316>>2];v[23296]=0;v[c+12>>2]=0;U(857,a+4276|0,b|0,c+12|0);b=v[23296];v[23296]=0;if((b|0)!=1){break d}b=V(91780)|0;break c}v[c+12>>2]=0;b=c+12|0;LK(a+4288|0,b);v[c+12>>2]=0;LK(a+4300|0,b);break b}b=V(91780)|0}if((O()|0)!=(ea(91780)|0)){break a}_(b|0)|0;v[a+4316>>2]=0;$()}jb=c+16|0;return}S(b|0);L()}function fP(a,b){var c=0,d=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+14|0]=5;u[a+12>>1]=0;v[a+8>>2]=128;v[a>>2]=256;v[a+4>>2]=64;v[a+28>>2]=0;t[a+27|0]=60;v[a+40>>2]=0;v[a+44>>2]=0;t[a+33|0]=2;t[a+34|0]=0;t[a+35|0]=0;t[a+36|0]=2;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=255;t[a+26|0]=0;t[a+32|0]=0;wz(a+48|0);wz(a+68|0);wz(a+88|0);ot(a+492|0);ot(a+524|0);Dm(a,0,0);Cm(a,0,0);v[a+40>>2]=0;v[a+44>>2]=0;St(a,b);b=a+108|0;d=bA(b);c=1;while(1){if((b|0)!=(d|0)){t[b|0]=c;c=c+1|0;b=b+1|0;continue}break}return a}function jr(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;a=Kb(a);a:{b:{c:{switch(b|0){case 0:v[23296]=0;b=Q(1,d|0,15680)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}Hb(a,b);zb(b);break b;case 1:v[23296]=0;b=Q(1,d|0,15705)|0;c=v[23296];v[23296]=0;if((c|0)!=1){Hb(a,b);zb(b);break b}break a;case 2:v[23296]=0;b=Q(1,d|0,15653)|0;c=v[23296];v[23296]=0;if((c|0)!=1){Hb(a,b);zb(b);break b}break a;case 3:break c;default:break b}}v[23296]=0;b=Q(1,d|0,15627)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}Hb(a,b);zb(b)}jb=d+16|0;return}b=P()|0;O()|0;zb(a);S(b|0);L()}function Bk(a,b,c){var d=0,e=0;e=jb-16|0;jb=e;v[a+4>>2]=0;d=4;a:{b:{c:{if(!Rd(w[rn(e+8|0,a,1)|0])){break c}d=v[(v[v[a>>2]-12>>2]+a|0)+24>>2];v[23296]=0;b=W(94,d|0,b|0,c|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){v[a+4>>2]=b;d=(b|0)==(c|0)?0:6;break c}b=V(0)|0;O()|0;_(b|0)|0;d=1;qn(v[v[a>>2]-12>>2]+a|0,1);if(v[(v[v[a>>2]-12>>2]+a|0)+20>>2]&1){v[23296]=0;Z(93);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)==1){break b}S(a|0);L()}$()}vj(v[v[a>>2]-12>>2]+a|0,d);jb=e+16|0;return a}V(0)|0;O()|0;Ub()}L()}function N$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-32|0;jb=c;a:{b:{c:{if(pn(b)){break c}v[c+20>>2]=b;if(w[a+44|0]){d=-1;if((fk(c+20|0,4,1,v[a+32>>2])|0)==1){break c}break a}f=c+24|0;v[c+16>>2]=f;h=c+32|0;d=c+20|0;while(1){e=Nr(v[a+36>>2],v[a+40>>2],d,f,c+12|0,c+24|0,h,c+16|0);if(v[c+12>>2]==(d|0)){break b}if((e|0)==3){if((fk(d,1,1,v[a+32>>2])|0)==1){break c}break b}if(e>>>0>1){break b}g=c+24|0;d=v[c+16>>2]-g|0;if((fk(g,1,d,v[a+32>>2])|0)!=(d|0)){break b}d=v[c+12>>2];if((e|0)==1){continue}break}}d=pn(b)?0:b;break a}d=-1}jb=c+32|0;return d|0}function w5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;v[23296]=0;Y(900,a|0);c=v[23296];v[23296]=0;a:{b:{c:{if((c|0)==1){break c}v[23296]=0;Y(901,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break c}c=v[a+24>>2];b=rc(d+8|0,b);f=v[b+4>>2];b=v[b>>2];v[23296]=0;e=+za(911,c|0,b|0,f|0,1);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,5924,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();e=0}jb=d+16|0;return+e}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function y5(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;v[23296]=0;Y(900,a|0);c=v[23296];v[23296]=0;a:{b:{c:{if((c|0)==1){break c}v[23296]=0;Y(901,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break c}c=v[a+24>>2];b=rc(d+8|0,b);e=v[b+4>>2];b=v[b>>2];v[23296]=0;b=fa(907,c|0,b|0,e|0,1)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,9928,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();b=0}jb=d+16|0;return b|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function _r(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0,l=0;h=jb-240|0;jb=h;v[h+236>>2]=d;v[h+232>>2]=c;v[h>>2]=a;a:{b:{c:{d:{if((c|0)!=1){j=a;k=1;break d}j=a;k=1;if(d){break d}i=a;break c}while(1){i=j-v[(e<<2)+g>>2]|0;if((nb[b|0](i,a)|0)<=0){i=j;break c}e:{if(!((e|0)<2|f)){f=v[((e<<2)+g|0)-8>>2];l=j-4|0;if((nb[b|0](l,i)|0)>=0){break e}if((nb[b|0](l-f|0,i)|0)>=0){break e}}v[(k<<2)+h>>2]=i;c=IH(c,d);$r(h+232|0,c);k=k+1|0;e=c+e|0;f=0;j=i;d=v[h+236>>2];c=v[h+232>>2];if(d|(c|0)!=1){continue}break b}break}i=j;break b}if(f){break a}}HH(h,k);Sw(i,b,e,g)}jb=h+240|0}function KH(a,b){var c=0,d=0,e=0;if(!w[463092]){d=Fa()|0;t[463092]=1;t[463093]=d}a:{b:{c:{d:{switch(a|0){case 0:break b;case 1:case 4:break d;default:break c}}if(!w[463093]){break c}e=+Ea();break a}v[115772]=28;return-1}e=+Na()}c=e/1e3;e:{if(D(c)<0x8000000000000000){d=D(c)>=1?~~(c>0?F(H(c*2.3283064365386963e-10),4294967295):I((c-+(~~c>>>0>>>0))*2.3283064365386963e-10))>>>0:0;a=~~c>>>0;break e}d=-2147483648;a=0}v[b>>2]=a;c=(e-(+(Sia(a,d,1e3,0)>>>0)+ +(mb|0)*4294967296))*1e3*1e3;f:{if(D(c)<2147483648){a=~~c;break f}a=-2147483648}v[b+4>>2]=a;return 0}function kR(a){var b=0,c=0,d=0;a:{if((w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))!=1196314451){break a}c=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);if(c>>>0<1108){break a}b=a+1104|0;if((c-1108|0)!=(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))|c>>>0>262144){break a}c=a+1094|0;if(w[c|0]|w[c+1|0]<<8){break a}b=a+1096|0;if((w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24))-5>>>0<4294967292){break a}if(!Ht(a+8|0)){break a}a=a+40|0;while(1){d=(a|0)==(c|0);if(d|w[a+32|0]>15|w[a+33|0]>64){break a}b=Ht(a);a=a+34|0;if(b){continue}break}}return d}function J$(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;d=w[a+52|0];a:{if(pn(b)){if(d){break a}b=v[a+48>>2];e=a,f=pn(b)^1,t[e+52|0]=f;break a}b:{if(!d){break b}v[c+16>>2]=v[a+48>>2];c:{d:{e:{d=c+20|0;switch(Nr(v[a+36>>2],v[a+40>>2],c+16|0,d,c+12|0,c+24|0,c+32|0,d)-1|0){case 0:case 1:break c;case 2:break e;default:break d}}d=v[a+48>>2];v[c+20>>2]=c+25;t[c+24|0]=d}while(1){d=v[c+20>>2];if(d>>>0<=c+24>>>0){break b}d=d-1|0;v[c+20>>2]=d;if((Lr(t[d|0],v[a+32>>2])|0)!=-1){continue}break}}b=-1;break a}t[a+52|0]=1;v[a+48>>2]=b}jb=c+32|0;return b|0}function v8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{e=jb-48|0;jb=e;d=v[a+28>>2];Wm(v[v[d>>2]-12>>2]+d|0,0);d=v[v[b>>2]+4>>2];if(d){g=v[a+28>>2];f=v[a+12>>2];h=d;d=v[a+8>>2]+d|0;f=h>>>0>d>>>0?f+1|0:f;d=jh(e+32|0,d,f);f=v[d+12>>2];v[e+8>>2]=v[d+8>>2];v[e+12>>2]=f;f=v[d+4>>2];v[e>>2]=v[d>>2];v[e+4>>2]=f;Gj(g,e)}d=e+16|0;ae(d,v[a+28>>2]);nz(v[a+28>>2],c,v[v[b>>2]+8>>2]);b=v[b>>2];c=$m(d,Lb(v[a+32>>2],v[b>>2]),x[b+12>>1]);v[23296]=0;Q(846,a|0,b|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){Tb(c);jb=e+48|0;break a}a=P()|0;O()|0;Tb(c);S(a|0);L()}}function QA(a,b){var c=0,d=0;a:{b:{c:{d:{e:{f:{g:{h:{d=w[a+3|0];switch(d|0){case 9:break d;case 10:break e;case 16:case 17:break g;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break h;default:break a}}if(!w[a|0]){break a}switch(d|0){case 9:break d;case 10:break e;case 0:case 1:case 2:case 3:case 11:case 12:case 13:case 14:case 15:break f;case 16:case 17:break g;default:break c}}c=8;break c}c=w[a|0];if(!(c&7)){break c}}c=b+1>>>1|0;b=((d|0)==10)<<4;break b}c=16}c=B(c>>>3|0,b);b=((d|0)==10)<<4}c=b+B(cq(w[a+1|0]),c)|0}return c}function $aa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;g=jb-16|0;jb=g;h=x[c>>1];i=c;e=jb-16|0;jb=e;f=b;d=Wd(b);a:{if(d){c=kc(f);while(1){b=d;d=x[b+14>>1];if(rl(h,d)){c=b;d=v[b>>2];if(d){continue}break a}if(!rl(d,h)){break a}c=b+4|0;d=v[b+4>>2];if(d){continue}break}break a}b=kc(f);c=b}v[e+12>>2]=b;b=v[c>>2];if(!b){b=jb-16|0;jb=b;d=kc(f);d=th(e,xc(16),uh(b+8|0,d));Di(v[d>>2]+14|0,x[i>>1]);k=kc(d),l=1,t[k+4|0]=l;jb=b+16|0;Zg(f,v[e+12>>2],c,v[e>>2]);b=de(e);cl(e);j=1}c=g+8|0;Yg(c,v[hc(e,b)>>2],j);jb=e+16|0;cP(a,c);jb=g+16|0}function h4(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-32|0;jb=c;a:{f=a+36|0;b=v[f>>2];d=v[a+40>>2];b:{if(Rb(b,d)){Cc(c+24|0);break b}b=c+8|0;Cn(b,a);v[23296]=0;b=T(959,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}v[c+24>>2]=b;Wf(c+8|0);d=v[a+40>>2];b=v[a+36>>2]}b=(g=f,h=v[c+24>>2],i=Rb(b,d),i?g:h);a=v[a+8>>2];c:{if((a|0)==-1){g=c,h=Eb(v[b>>2]),v[g+8>>2]=h;a=Eb(v[b+4>>2]);while(1){b=v[c+8>>2];if(!Rb(b,a)){break c}e=e+A[b>>3];JI(c+8|0);continue}}e=A[bl(v[b>>2],a)>>3]}Ik(c+24|0);jb=c+32|0;return+e}a=P()|0;O()|0;Wf(c+8|0);S(a|0);L()}function Tda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(b){c=jb-16|0;jb=c;v[c+12>>2]=477218588;v[c+8>>2]=2147483647;d=v[Ib(c+12|0,c+8|0)>>2];jb=c+16|0;if(b>>>0>d>>>0){Wc();L()}b=B(b,9);c=xc(b);v[a>>2]=c;v[a+4>>2]=c;e=Gb(a),f=b+c|0,v[e>>2]=f;c=jb-16|0;jb=c;v[c>>2]=a;d=v[a+4>>2];v[c+4>>2]=d;v[c+8>>2]=b+d;b=v[c+4>>2];d=v[c+8>>2];while(1){if((b|0)==(d|0)){lc(c);jb=c+16|0}else{t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;b=b+9|0;v[c+4>>2]=b;continue}break}}return a|0}function Nha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;g=x[kl(v[a>>2],v[a+4>>2],b)>>1];a:{b:{if(!rq(a,b)){break b}c=v[a+24>>2];d=Eb(v[c+484360>>2]);v[f+8>>2]=d;h=Eb(v[c+484364>>2]);while(1){if(!Rb(d,h)){break b}e=0;i=fl(v[d>>2],v[d+4>>2]);c:{while(1){if((e|0)!=(i|0)){if(!(!((a|0)!=(d|0)|(b|0)!=(e|0))|x[dc(v[d>>2],e)>>1]!=(g|0))){c=rR(v[a+24>>2]+484344|0,g);if((c|0)!=65535){break c}}e=e+1|0;continue}break}d=v[sz(f+8|0)>>2];continue}break}j=kl(v[a>>2],v[a+4>>2],b),k=c,u[j>>1]=k;break a}c=g}jb=f+16|0;return c&65535}function FC(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=jb-16|0;jb=f;v[f+8>>2]=e;v[f+12>>2]=d;Nf(a);et(a,c);d=0;e=0;a:while(1){if(c>>>0>d>>>0){i=c-d|0;v[f+4>>2]=i;g=v[Ib(f+12|0,f+4|0)>>2];h=g+e|0;l=e>>>0>h>>>0?e:h;j=su(vr(a,b+d|0,g),1,13);while(1)if((e|0)==(l|0)){v[f+4>>2]=i-g;e=h+1|0;d=v[Ib(f+8|0,f+4|0)>>2]+(d+g|0)|0;continue a}else{b:{c:{d:{k=t[Oc(j,e)|0];switch(k-10|0){case 1:case 2:break b;case 0:case 3:break c;default:break d}}if(k){break b}}m=Oc(j,e),n=32,t[m|0]=n}e=e+1|0;continue}}break}jb=f+16|0}function n4(a){a=a|0;var b=0,c=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){a=v[a+24>>2];b=v[a+24>>2];c=x[b+1074448>>1];a:{if(c>>>0>=lj(Zb(v[b+484360>>2],w[b+484376|0]))>>>0){a=x[v[a+24>>2]+1074446>>1];break a}a=v[a+24>>2];b=x[dc(v[Zb(v[a+484360>>2],w[a+484376|0])>>2],c)>>1];a=xm(v[a+484344>>2],v[a+484348>>2],b)?b:-1}return a|0}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,9658,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function NM(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){break c}d=c>>31;d=(d^c)-d|0;if(d>>>0<224){break c}Bb(e+8|0,a+1074312|0,3);if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break c}if(!(t[(B(b,872)+a|0)+1075843|0]&1)){break a}c=B((c>>31)+((c|0)>0)|0,d&15);c=d>>>0>239?c<<2:c;break b}if(t[(B(b,872)+a|0)+1075843|0]&1){Bb(e+8|0,a+1074312|0,3);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])){break a}}c=c<<2}if(!c){break a}f=B(b,872)+a|0;d=v[f+1075648>>2];a=Us(a,v[f+1075080>>2],d);if(!a){break a}nb[v[v[a>>2]+84>>2]](a,c,(d?w[d+33|0]:13)<<24>>24,b)}jb=e+16|0}function oI(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;a:{b:{c:{a=v[a+32>>2];e=vs(a);d:{if(!e){if(us(a)>>>0<=b>>>0){break d}a=$j(a,b+1&65535);u[a+34>>1]=x[a+34>>1]&64511|(c?1024:0);break b}if(b>>>0<e>>>0){break c}}a=ba(8)|0;v[23296]=0;b=Q(54,d|0,5961)|0;c=v[23296];v[23296]=0;e:{if((c|0)!=1){a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break e}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}a=v[(a+(b<<2)|0)+900384>>2];if(!a){break b}t[a+15|0]=w[a+15|0]&253|(c?2:0)}jb=d+16|0;return}L()}function Zw(a,b,c){var d=0,e=0,f=C(0),g=C(0),h=C(0),i=C(0),j=0,k=C(0),l=C(0),m=C(0);e=jb-32|0;jb=e;g=z[a+24>>2];f=z[a+12>>2];h=z[a+48>>2];i=z[a+36>>2];ZH(C(-z[a>>2]),C(g+f),C(h+i),e+20|0);ZH(z[a+60>>2],C(h-i),C(g-f),e+8|0);z[e+12>>2]=-z[e+12>>2];a=0;while(1){if((a|0)!=3){d=a<<2;j=d+c|0;g=z[j>>2];f=z[d+(e+20|0)>>2];h=z[d+70080>>2];i=z[d+70092>>2];k=z[d+(e+8|0)>>2];z[j>>2]=C(f*h)-C(i*k);j=b+d|0;l=z[(0-a<<2)+70088>>2];d=5-a<<2;m=z[d+70080>>2];f=C(C(f*i)+C(k*h));z[j>>2]=C(g*l)-C(m*f);z[b+d>>2]=C(g*m)+C(f*l);a=a+1|0;continue}break}jb=e+32|0}function Q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-208|0;jb=e;u[a+480212>>1]=0;v[a+480240>>2]=65536;v[a+480244>>2]=65536;BM(a+946304|0);d=e+48|0;Xb(d,0,160);d=HM(d);v[23296]=0;f=a+906300|0;U(773,f|0,f+4e4|0,d|0);f=v[23296];v[23296]=0;a:{if((f|0)!=1){Ss(d);d=ie(e+24|0,b);v[23296]=0;f=v[d+12>>2];v[e+8>>2]=v[d+8>>2];v[e+12>>2]=f;v[e+16>>2]=v[d+16>>2];f=v[d+4>>2];v[e>>2]=v[d>>2];v[e+4>>2]=f;a=W(774,a|0,e|0,c|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){a=P()|0;O()|0;break a}Ab(b);jb=e+208|0;return a|0}a=P()|0;O()|0;Ss(d)}Ab(b);S(a|0);L()}function w8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=jb-48|0;jb=f;e=v[a+28>>2];Wm(v[v[e>>2]-12>>2]+e|0,0);e=v[v[b>>2]+4>>2];if(e){h=v[a+28>>2];g=v[a+12>>2];i=e;e=v[a+8>>2]+e|0;g=i>>>0>e>>>0?g+1|0:g;e=jh(f+32|0,e,g);g=v[e+12>>2];v[f+8>>2]=v[e+8>>2];v[f+12>>2]=g;g=v[e+4>>2];v[f>>2]=v[e>>2];v[f+4>>2]=g;Gj(h,f)}e=f+16|0;ae(e,v[a+28>>2]);mL(d,v[a+28>>2],c);b=v[b>>2];c=$m(e,Lb(v[a+32>>2],v[b>>2]),x[b+12>>1]);v[23296]=0;Q(846,a|0,b|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){Tb(c);jb=f+48|0;return}a=P()|0;O()|0;Tb(c);S(a|0);L()}function u8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;f=jb-48|0;jb=f;e=v[a+28>>2];Wm(v[v[e>>2]-12>>2]+e|0,0);e=v[v[b>>2]+4>>2];if(e){h=v[a+28>>2];g=v[a+12>>2];i=e;e=v[a+8>>2]+e|0;g=i>>>0>e>>>0?g+1|0:g;e=jh(f+32|0,e,g);g=v[e+12>>2];v[f+8>>2]=v[e+8>>2];v[f+12>>2]=g;g=v[e+4>>2];v[f>>2]=v[e>>2];v[f+4>>2]=g;Gj(h,f)}e=f+16|0;ae(e,v[a+28>>2]);jL(c,v[a+28>>2],d);b=v[b>>2];c=$m(e,Lb(v[a+32>>2],v[b>>2]),x[b+12>>1]);v[23296]=0;Q(846,a|0,b|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){Tb(c);jb=f+48|0;return}a=P()|0;O()|0;Tb(c);S(a|0);L()}function _n(a){var b=0,c=0,d=0,e=0,f=0,g=0;c=x[v[a+4>>2]+28>>1]>>>(!w[a+77|0]<<1)|0;d=x[a+24>>1];b=c+(d<<2)|0;v[a+40>>2]=((b&3)<<4)+27664;e=b>>>2|0;b=b>>>0<48;f=b?12-e|0:0;u[a+32>>1]=f;u[a+36>>1]=b?1:1<<e-12;u[a+34>>1]=-1<<f^-1;if((d|0)==15){u[a+36>>1]=4095}b=c+(x[a+26>>1]<<2)|0;v[a+52>>2]=((b&3)<<4)+27664;d=b>>>2|0;b=b>>>0<48;e=b?12-d|0:0;u[a+44>>1]=e;c=c+(x[a+30>>1]<<2)|0;v[a+64>>2]=((c&3)<<4)+27664;f=c>>>2|0;c=c>>>0<48;g=c?12-f|0:0;u[a+56>>1]=g;u[a+48>>1]=b?1:1<<d-12;u[a+60>>1]=c?1:1<<f-12;u[a+46>>1]=-1<<e^-1;u[a+58>>1]=-1<<g^-1}function pQ(a,b,c,d,e){var f=0;f=w[(w[a+3|0]&15)+26864|0];t[a+3|0]=f;a:{b:{switch(f-11|0){case 0:b=w[a+5|0];c=b&15;if(c){t[a+5|0]=c;return}t[a+5|0]=b&240;return;case 3:c=w[a+5|0];c=B(c&240,10)|c&15;t[a+5|0]=c;f=c&255;c=x[d>>1];if(!(f|(c|0)==65535)){t[a+5|0]=c;t[a+3|0]=12;u[d>>1]=65535}yc(e,b);return;case 1:u[d>>1]=w[a+5|0];v[e>>2]=63;t[a+3|0]=0;return;case 5:b=w[a+5|0];if(c>>>0<=20){c=((b&255)>>>0)/10|0;b=c<<4|B(c,-10)+b;t[a+5|0]=b}if(b&255){break a}t[a+3|0]=0;return;case 7:break a;default:break b}}if(w[a+5|0]){break a}t[a+3|0]=0}}function Pd(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;v[b+4>>2]=1078;v[b>>2]=a;v[b+8>>2]=0;d=jb-16|0;jb=d;if(v[a>>2]!=-1){a:{c=hc(d,xf(d+8|0,b));while(1){if(v[a>>2]==1){continue}break}b:{if(!v[a>>2]){yd(a,1);c=v[v[c>>2]>>2];v[23296]=0;Y(1079,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}v[a>>2]=-1}break a}b=V(0)|0;O()|0;_(b|0)|0;yd(a,0);v[23296]=0;Z(93);a=v[23296];v[23296]=0;c:{if((a|0)==1){a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){break c}V(0)|0;O()|0;Ub()}L()}S(a|0);L()}}jb=d+16|0;jb=b+16|0;return v[a+4>>2]-1|0}function kca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){e=(v[b+12>>2]<<1)+i|0;f=v[b+8>>2]>>>21&2040;e=(((B(u[e>>1],u[f+39714>>1])+B(u[e-2>>1],u[f+39712>>1])|0)+B(u[e+2>>1],u[f+39716>>1])|0)+B(u[e+4>>1],u[f+39718>>1])|0)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Sb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function n9(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;a:{f=jb-32|0;jb=f;a=Qb(a);b:{c:{d:{e:{while(1){e=v[b+8>>2];g=v[b>>2];v[23296]=0;e=W(144,g|0,e|0,8)|0;g=v[23296];v[23296]=0;if((g|0)==1){break c}if(e){v[23296]=0;U(819,f|0,b|0,c|0);e=v[23296];v[23296]=0;if((e|0)==1){break e}v[23296]=0;R(820,a|0,f|0);e=v[23296];v[23296]=0;if((e|0)==1){break d}Md(f);e=QQ(v[a+4>>2]);yi(f,v[e>>2],v[e+4>>2]);if(v[f>>2]!=(d|0)){continue}}break}jb=f+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;Md(f);break b}b=P()|0;O()|0}_d(a);S(b|0);L()}}function ZK(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=0;Jx(a);c=Sd(c,C(0));a:{switch(b|0){case 0:z[a+4220>>2]=c;return;case 1:z[a+4224>>2]=c;return;case 2:z[a+4228>>2]=c;Fs(a);return;case 3:t[a+4240|0]=c>=C(.5);Fs(a);return;case 4:b=jb-16|0;jb=b;e=b,f=Oh(C(c*C(32))),v[e+12>>2]=f;v[b+8>>2]=0;v[b+4>>2]=5;d=v[wj(b+12|0,b+8|0,b+4|0)>>2];jb=b+16|0;v[a+4232>>2]=d;return;case 5:t[a+4241|0]=c>=C(.5);return;case 6:t[a+4242|0]=c>=C(.5);return;case 7:t[a+4244|0]=c>=C(.5);return;case 8:if(c==C(0)){Hx(a)}A[a+4256>>3]=c;break;default:break a}}}function u_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=jb-416|0;jb=h;d=h+416|0;v[h+12>>2]=d;c=jb-144|0;jb=c;v[c+28>>2]=c+132;i=c+32|0;VF(v[a+8>>2],i,c+28|0,e,f,g);v[c+16>>2]=0;v[c+20>>2]=0;v[c+12>>2]=i;e=h+16|0;g=wc(e,v[h+12>>2]);f=jb-16|0;jb=f;i=bi(f+8|0,v[a+8>>2]);a=vG(e,c+12|0,g,c+16|0);ai(i);jb=f+16|0;if((a|0)==-1){Kr(12451);L()}v[h+12>>2]=(a<<2)+e;jb=c+144|0;c=v[h+12>>2];a=jb-16|0;jb=a;v[a+8>>2]=b;while(1){if((c|0)!=(e|0)){XG(a+8|0,v[e>>2]);e=e+4|0;continue}break}jb=a+16|0;jb=d;return v[a+8>>2]}function u9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-48|0;jb=d;c=d+24|0;sj(c,b,1819307379);cd(a+40|0,c);Ab(c);sj(c,b,1953721961);cd(a+60|0,c);Ab(c);sj(c,b,543520099);cd(a+120|0,c);Ab(c);sj(c,b,1414744396);v[23296]=0;c=Q(348,c|0,13612)|0;e=v[23296];v[23296]=0;a:{if((e|0)!=1){b:{if(c){v[23296]=0;U(723,d|0,d+24|0,2);c=v[23296];v[23296]=0;if((c|0)==1){break b}Ft(a+140|0,d);_d(d)}v[23296]=0;U(724,d|0,b|0,1634890872);b=v[23296];v[23296]=0;if((b|0)!=1){break a}}}a=P()|0;O()|0;Ab(d+24|0);S(a|0);L()}cd(a+80|0,d);Ab(d);Ab(d+24|0);jb=d+48|0}function QV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[c+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[c+8>>2]=16384;d=v[Ib(c+12|0,c+8|0)>>2];v[a+1072>>2]=d;v[c+4>>2]=17;while(1){a:{if(!d){break a}e=v[c+4>>2];if((e|0)>17){break a}f=1<<e-1;d=nk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Vq(c+4|0,nk(a,4));break b}if(e>>>0>16){break c}e=f-8|0;if((e|0)>(d|0)|(d|0)>(f+7|0)){break d}Vq(c+4|0,d-e|0);break b}XC(a,d,f,b);break b}e=d&(f^-1);if(d&f){v[c+4>>2]=e+1;break b}XC(a,e,0,b)}d=v[a+1072>>2];continue}break}jb=c+16|0}function oM(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=16777216;h=e+12|0;d=v[a>>2];c=wc(d,v[a+4>>2]);a:{if(c>>>0<b>>>0){f=jb-32|0;jb=f;b=b-c|0;c=v[Gb(a)>>2];d=v[a+4>>2];b:{if(b>>>0<=c-d>>2>>>0){rC(a,b,h);break b}c=Gb(a);c=fg(f+8|0,Ug(a,wc(v[a>>2],d)+b|0),wc(v[a>>2],v[a+4>>2]),c);g=jb-16|0;jb=g;b=ol(g,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){Qp(d,v[h>>2]);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Id(b);jb=g+16|0;Ad(a,c);eg(c)}jb=f+32|0;break a}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}oy(a);jb=e+16|0}function x4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;e=Qb(a);a=b;b=0;a:{b:{c:{d:{e:{while(1){d=v[a+24>>2];if(x[d+480188>>1]<=b>>>0){break a}v[23296]=0;R(955,c|0,(d+(b<<5)|0)+480289|0);d=v[23296];v[23296]=0;if((d|0)!=1){d=v[a+24>>2];v[23296]=0;U(956,c+16|0,d|0,c|0);d=v[23296];v[23296]=0;if((d|0)==1){break e}v[23296]=0;R(171,e|0,c+16|0);d=v[23296];v[23296]=0;if((d|0)==1){break d}b=b+1|0;yb(c+16|0);yb(c);continue}break}b=P()|0;O()|0;break b}b=P()|0;O()|0;break c}b=P()|0;O()|0;yb(c+16|0)}yb(c)}Me(e);S(b|0);L()}jb=c+32|0}function PV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[c+12>>2]=v[v[a+1060>>2]>>2]-v[a+1064>>2];v[c+8>>2]=32768;d=v[Ib(c+12|0,c+8|0)>>2];v[a+1072>>2]=d;v[c+4>>2]=9;while(1){a:{if(!d){break a}e=v[c+4>>2];if((e|0)>9){break a}f=1<<e-1;d=nk(a,e);b:{c:{d:{if((e|0)<=6){if((d|0)!=(f|0)){break d}Vq(c+4|0,nk(a,3));break b}if(e>>>0>8){break c}e=f-4|0;if((e|0)>(d|0)|(d|0)>(f+3|0)){break d}Vq(c+4|0,d-e|0);break b}WC(a,d,f,b);break b}e=d&(f^-1);if(d&f){v[c+4>>2]=e+1;break b}WC(a,e,0,b)}d=v[a+1072>>2];continue}break}jb=c+16|0}function uia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;pd(b,0);g=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);v[b>>2]=g;e=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);v[b+12>>2]=e;f=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);v[b+16>>2]=f;c=w[a+12|0]|w[a+13|0]<<8;u[b+32>>1]=64;v[b+24>>2]=c;c=w[a+14|0];u[b+30>>1]=c?c+1|0:256;d=x[b+34>>1]&32767|!w[a+14|0]<<15;u[b+34>>1]=d;c=w[a+15|0];if(!(!(c&1)|e>>>0>=f>>>0)){d=d|8;u[b+34>>1]=d;c=w[a+15|0]}if(c&2){v[b+16>>2]=f>>>1;v[b+12>>2]=e>>>1;v[b>>2]=g>>>1;u[b+34>>1]=d|1}}function lca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){e=v[b+12>>2]+i|0;f=v[b+8>>2]>>>21&2040;e=(((B(t[e|0],u[f+39714>>1])+B(t[e-1|0],u[f+39712>>1])|0)+B(t[e+1|0],u[f+39716>>1])|0)+B(t[e+2|0],u[f+39718>>1])<<8)/16384|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Sb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function Qea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-80|0;jb=c;d=Mf(c+48|0);v[23296]=0;e=Q(575,b|0,d|0)|0;f=v[23296];v[23296]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23296]=0;T(576,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break a}}break c}e=v[d+4>>2];v[23296]=0;U(178,c|0,b|0,(e>>>0<9?0:e-8|0)|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Md(d);S(a|0);L()}b=jc(c+24|0,c);cd(d+8|0,b);Ab(b);Ab(c);gl(a,d)}Md(d);jb=c+80|0}function Oi(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;o(+b);g=j(1)|0;d=j(0)|0;c=g&2147483647;e=c+-1048576|0;a:{if((e|0)==2145386495|e>>>0<2145386495){h=d<<28;e=c>>>4|0;c=(c&15)<<28|d>>>4;d=e+1006632960|0;break a}if((c|0)==2146435072|c>>>0>2146435072){h=d<<28;c=(g&15)<<28|d>>>4;d=g>>>4|2147418112;break a}if(!(c|d)){c=0;d=0;break a}e=c;c=c?E(c):E(d)+32|0;vf(f,d,e,0,0,c+49|0);i=v[f>>2];h=v[f+4>>2];e=15372-c<<16;c=v[f+8>>2];d=e|v[f+12>>2]^65536}v[a>>2]=i;v[a+4>>2]=h;v[a+8>>2]=c;v[a+12>>2]=g&-2147483648|d;jb=f+16|0}function tV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;pd(b,0);Uh(d,1,a+33|0);e=d+16|0;Gc(e,d);ze(b+43|0,e);yb(e);f=w[a+50|0]|w[a+51|0]<<8|(w[a+52|0]<<16|w[a+53|0]<<24);v[b>>2]=f;v[b+24>>2]=w[a+54|0]|w[a+55|0]<<8;t[d+16|0]=w[a+56|0];t[d|0]=64;h=b,i=w[Wb(e,d)|0]<<2,u[h+30>>1]=i;e=w[a+57|0]|w[a+58|0]<<8|(w[a+59|0]<<16|w[a+60|0]<<24);v[b+4>>2]=e;g=w[a+61|0]|w[a+62|0]<<8|(w[a+63|0]<<16|w[a+64|0]<<24);c=c?e?f:g:g;v[b+8>>2]=c;if(!(!w[a|0]|c>>>0<=e+2>>>0|c>>>0>f>>>0)){u[b+34>>1]=x[b+34>>1]|2}jb=d+32|0}function pga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-80|0;jb=c;d=Mf(c+48|0);v[23296]=0;e=Q(456,b|0,d|0)|0;f=v[23296];v[23296]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23296]=0;T(457,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break a}}break c}e=x[d+2>>1]|x[d+4>>1]<<16;v[23296]=0;U(178,c|0,b|0,e|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Md(d);S(a|0);L()}b=jc(c+24|0,c);cd(d+8|0,b);Ab(b);Ab(c);sS(a,d)}Md(d);jb=c+80|0}function laa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;f=Kb(a);a=0;a:{b:{c:{d:{while(1){d=v[b>>2];if(wd(d,v[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=Hd(d,0);break e}v[23296]=0;Q(753,f|0,c|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break b}d=Hd(v[b>>2],a)}v[23296]=0;R(754,e|0,d|0);d=v[23296];v[23296]=0;if((d|0)!=1){v[23296]=0;Q(753,f|0,e|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break d}a=a+1|0;yb(e);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(e);break a}jb=e+16|0;return}a=P()|0;O()|0}yb(f);S(a|0);L()}function N3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=C(0);v[23296]=0;Y(900,a|0);d=v[23296];v[23296]=0;a:{if((d|0)==1){break a}v[23296]=0;Y(971,c|0);d=v[23296];v[23296]=0;if((d|0)==1){break a}d=v[a+24>>2];e=z[d+48>>2];d=v[d+24>>2];v[23296]=0;b=Za(972,d|0,C(e),b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}v[c>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,10245,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function sfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;f=jb-608|0;jb=f;b=jb-16|0;jb=b;d=f+8|0;AR(b+8|0,d);c=v[b+12>>2];md(b,a,v[b+8>>2],v[b+12>>2]);e=v[b+4>>2];if((e|0)==(c|0)){dd(a,v[b+12>>2])}jb=b+16|0;c=(c|0)==(e|0);if(!c){zR(d)}b=-1;a:{if(!c){break a}b=0;if(!BR(f+8|0)){break a}b=-1;if(!Vf(a,1024)){break a}b=0;d=jb-1024|0;jb=d;c=jb-16|0;jb=c;dA(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((e|0)==(g|0)){dd(a,v[c+12>>2])}jb=c+16|0;if((e|0)==(g|0)){b=eA(d,0)>>>0<17}jb=d+1024|0}jb=f+608|0;return b|0}function iy(a,b,c){var d=0,e=0;e=jb-16|0;jb=e;Bb(e+8|0,a+1074312|0,21);a:{if(Cb(v[v[e+8>>2]>>2],v[e+12>>2])){c=c&255;b:{switch((b&3)-1|0){default:d=t[c+33440|0];break a;case 0:d=64-(c+1>>>1|0)|0;break a;case 1:d=(c>>>0<128)<<6;break a;case 2:break b}}d=XL(Pn(a))+-64|0;break a}d=t[(c>>>1&31)+31952|0];if(x[a+480182>>1]&1032){break a}a=c&63;c:{switch((b&3)-1|0){default:d=t[a+33312|0];break a;case 0:d=(a>>>0<32?0:255)-(a<<2)|0;break a;case 1:d=a>>>0<32?127:-127;break a;case 2:break c}}d=t[a+33376|0]}a=d;jb=e+16|0;return a}function Oca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;f=v[a+24>>2];g=v[a+20>>2];h=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;i=v[a+8>>2];j=v[a+12>>2];while(1){if(d){k=((((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&2147483646)<<1)+h|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=u[(e<<1)+k>>1];e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],g);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f);Sb(b+8|0,i,j);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function vaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=jb-16|0;jb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+7;RN(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+7;lc(c);jb=c+16|0;return}f=jb-32|0;jb=f;g=Gb(a);h=f+8|0;d=Xy(v[a>>2],v[a+4>>2])+1|0;c=jb-16|0;jb=c;v[c+12>>2]=d;a:{e=ih(613566756);if(d>>>0<=e>>>0){d=Yy(a);if(d>>>0<e>>>1>>>0){v[c+8>>2]=d<<1;e=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;break a}Wc();L()}c=UN(h,e,Xy(v[a>>2],v[a+4>>2]),g);RN(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+7;TN(a,c);SN(c);jb=f+32|0}function NW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;f=Kb(a);a=0;a:{b:{c:{d:{while(1){d=v[b>>2];if(wd(d,v[b+4>>2])>>>0<=a>>>0){break c}e:{if(!a){d=Hd(d,0);break e}v[23296]=0;Q(87,f|0,c|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break b}d=Hd(v[b>>2],a)}v[23296]=0;R(141,e|0,d|0);d=v[23296];v[23296]=0;if((d|0)!=1){v[23296]=0;Q(87,f|0,e|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break d}a=a+1|0;zb(e);continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;zb(e);break a}jb=e+16|0;return}a=P()|0;O()|0}zb(f);S(a|0);L()}function M5(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;a:{b:{if(!a){a=Xf(21473);break b}v[23296]=0;c=Q(54,b|0,a|0)|0;a=v[23296];v[23296]=0;c:{d:{if((a|0)!=1){v[23296]=0;R(886,b+16|0,c|0);a=v[23296];v[23296]=0;if((a|0)==1){break d}d=b+16|0;a=Xf(Jc(d));yb(d);yb(c);break b}a=V(0)|0;O()|0;break c}a=V(0)|0;O()|0;yb(c)}_(a|0)|0;a=0;v[23296]=0;X(887,10874,0,0,0);c=v[23296];v[23296]=0;if((c|0)==1){break a}$()}jb=b+32|0;return a|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function du(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=jb-16|0;jb=g;v[g+12>>2]=0;v[g+8>>2]=a;i=jb-16|0;jb=i;b=gc(i+8|0,v[g+8>>2],v[g+12>>2]);e=jb-16|0;jb=e;d=117;v[e+12>>2]=117;c=v[b+4>>2];a:{if(!c){c=v[b>>2];break a}f=32-c|0;v[e+8>>2]=f;d=v[b>>2];j=v[d>>2];h=f;f=v[Ib(e+8|0,e+12|0)>>2];v[d>>2]=(-1<<c&-1>>>h-f^-1)&j;j=v[e+12>>2];c=d+4|0;v[b>>2]=c;d=j-f|0}h=c;c=d>>>5<<2;Xb(h,0,c);f=d&31;v[e+12>>2]=f;if((d&-32)!=(d|0)){h=b;b=c+v[b>>2]|0;v[h>>2]=b;v[b>>2]=v[b>>2]&(-1>>>32-f^-1)}jb=e+16|0;jb=i+16|0;jb=g+16|0;return a}function Cea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{d=jb-32|0;jb=d;a=Qb(a);b:{c:{d:{e:{while(1){c=v[b+8>>2];e=v[b>>2];v[23296]=0;c=W(144,e|0,c|0,8)|0;e=v[23296];v[23296]=0;if((e|0)==1){break c}if(c){v[23296]=0;R(604,d|0,b|0);c=v[23296];v[23296]=0;if((c|0)==1){break e}v[23296]=0;R(605,a|0,d|0);c=v[23296];v[23296]=0;if((c|0)==1){break d}Md(d);c=QQ(v[a+4>>2]);yi(d,v[c>>2],v[c+4>>2]);if(v[d>>2]!=1413891155){continue}}break}jb=d+32|0;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;Md(d);break b}b=P()|0;O()|0}_d(a);S(b|0);L()}}function Y5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;t[a+4202|0]=1;c=Wj(C(C(y[v[a+16>>2]+24620>>2])*C(.04500000178813934)));d=Wj(C(C(c>>>0)*C(1.1892070770263672)));e=Wj(C(C(d>>>0)*C(1.1892070770263672)));h=Wj(C(C(e>>>0)*C(1.1892070770263672)));f=Wj(C(C(c+e>>>0)*C(.11546666920185089)));g=Wj(C(C(d+h>>>0)*C(.11546666920185089)));b=a+4272|0;i=Db(b,0),j=c-f|0,v[i>>2]=j;i=Db(b,1),j=e-f|0,v[i>>2]=j;i=Db(b,2),j=d-g|0,v[i>>2]=j;i=Db(b,3),j=h-g|0,v[i>>2]=j;i=Db(b,4),j=f,v[i>>2]=j;i=Db(b,5),j=g,v[i>>2]=j;kK(a);jK(a)}function T8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;v[f+12>>2]=b;a:{if(Qs(a)>>>0>=b>>>0){e=v[a>>2];g=ik(e,v[a+4>>2]);v[f+8>>2]=g;d=v[Ib(f+12|0,f+8|0)>>2];while(1){if(d){d=d-1|0;e=BL(e,c)+52|0;continue}break}if(b>>>0>g>>>0){Tx(a,b-g|0,c);break a}yL(a,v[a>>2]+B(b,52)|0);break a}if(v[a>>2]){Rs(a);d=v[a>>2];Qs(a);Jb(d);h=Gb(a),i=0,v[h>>2]=i;v[a>>2]=0;v[a+4>>2]=0}d=xL(a,b);if(ih(82595524)>>>0<d>>>0){Wc();L()}e=wL(d);v[a>>2]=e;v[a+4>>2]=e;h=Gb(a),i=e+B(d,52)|0,v[h>>2]=i;Tx(a,b,c)}jb=f+16|0}function C9(a){a=a|0;var b=0,c=0;b=32048;a=Qb(a);a:{b:{while(1){c:{if((b|0)==32624){b=32624;break c}d:{c=v[a+4>>2];if(!uc(v[a>>2],c)){if(!fj(v[b+8>>2],v[Kn(c)>>2])){break d}}v[23296]=0;R(797,a|0,b+8|0);c=v[23296];v[23296]=0;if((c|0)!=1){break d}break b}b=b+12|0;continue}break}while(1){if((b|0)==32672){break a}e:{c=v[a+4>>2];f:{if(!uc(v[a>>2],c)){if(!fj(v[b+8>>2],v[Kn(c)>>2])){break f}}v[23296]=0;R(797,a|0,b+8|0);c=v[23296];v[23296]=0;if((c|0)==1){break e}}b=b+12|0;continue}break}}b=P()|0;O()|0;vc(a);S(b|0);L()}}function RM(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;a:{if(b){t[c|0]=b;break a}b=w[c|0]}e=v[a+480180>>2];b=e&1048580?(b&240?-16:15)&b:b;c=b&240;f=b&255;b=b&15;b:{c:{d:{if(!(!c|(b|0)!=15)){if(!(w[a+480209|0]&16)){break b}b=f>>>3&30;break d}g=v[a+480208>>2]&4096;if(!(!b|(c|0)!=240)){if(!g){break b}b=0-(b<<1)|0;break c}if(g){break b}if(c){if(b?e&59314208:0){break b}b=f>>>3&30;break d}b=0-(b<<1)|0}if(!b){break b}}a=a+1074456|0;v[d+12>>2]=v[a>>2]+(b<<!(e&59314208));he(d+12|0,0,256);v[a>>2]=v[d+12>>2]}jb=d+16|0}
function Mga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=jb-16|0;jb=c;a=Ev(c,a);d=v[a+4>>2];v[23296]=0;R(435,d|0,b|0);b=v[23296];v[23296]=0;a:{if((b|0)!=1){v[a+4>>2]=v[a+4>>2]+12;lc(a);jb=c+16|0;break a}b=P()|0;O()|0;lc(a);S(b|0);L()}return}d=jb-32|0;jb=d;c=Gb(a);c=ok(d+8|0,Tm(a,wd(v[a>>2],v[a+4>>2])+1|0),wd(v[a>>2],v[a+4>>2]),c);e=v[c+8>>2];v[23296]=0;R(435,e|0,b|0);b=v[23296];v[23296]=0;b:{if((b|0)!=1){v[c+8>>2]=v[c+8>>2]+12;nr(a,c);Dv(c);jb=d+32|0;break b}a=P()|0;O()|0;Dv(c);S(a|0);L()}}function Iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;c=jb-48|0;jb=c;f=vO(a,1<<b-1);v[f+12>>2]=b;b=1<<b;h=-6.283185307179586/+(b>>>0);a=1;g=b>>>2|0;b=g;while(1){if(b){e=v[10465];d=c+16|0;v[d+8>>2]=v[10464];v[d+12>>2]=e;e=v[10463];v[d>>2]=v[10462];v[d+4>>2]=e;fz(d,h*+(b>>>0));qO(c+32|0,A[c+16>>3],A[c+24>>3]);d=ed(v[f>>2],a);e=v[c+44>>2];v[d+8>>2]=v[c+40>>2];v[d+12>>2]=e;e=v[c+36>>2];v[d>>2]=v[c+32>>2];v[d+4>>2]=e;b=b>>>1|0;a=a<<1;continue}break}a=Wk(c,1,0);Zx(f,0,g,A[a>>3],A[a+8>>3]);jb=c+48|0;return f|0}function nI(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;a:{b:{c:{a=v[a+32>>2];c=vs(a);d:{if(!c){if(us(a)>>>0<=b>>>0){break d}c=(w[$j(a,b+1&65535)+35|0]&4)>>>2|0;break b}if(b>>>0<c>>>0){break c}}a=ba(8)|0;v[23296]=0;b=Q(54,d|0,5961)|0;c=v[23296];v[23296]=0;e:{if((c|0)!=1){a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break e}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}a=v[(a+(b<<2)|0)+900384>>2];c=1;if(!a){break b}c=(w[a+15|0]&2)>>>1|0}jb=d+16|0;return c|0}L()}function ZO(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;j=b?33:32;c=w[a+16|0];k=c?-1:1;l=c?1:-1;e=v[a+8>>2]-1|0;m=c?e-(w[a+17|0]!=0&(e|0)!=0)|0:0;f=v[a+12>>2];n=(f|0)>0?f:0;o=c?0:e;h=v[a>>2]+B(f,62)|0;d=b?1:-1;p=B(f,d)<<1;c=e;a:while(1){if((i|0)!=(j|0)){g=B(c,f);q=v[a+4>>2];b=0;while(1)if((b|0)==(n|0)){b:{if((c|0)==(e|0)){b=m;g=k;if((d|0)>0){break b}}b=c+d|0;c=!c&(d|0)<0;b=c?o:b;g=c?l:d}h=h+p|0;i=i+1|0;c=b;d=g;continue a}else{u[(b<<1)+h>>1]=x[q+(b+g<<1)>>1];b=b+1|0;continue}}break}}function RX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Jg(a,v[b+8>>2],e)){bw(b,c,d);return}a:{if(Jg(a,v[b>>2],e)){if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+32>>2]=d;b:{if(v[b+44>>2]==4){break b}u[b+52>>1]=0;a=v[a+8>>2];nb[v[v[a>>2]+20>>2]](a,b,c,c,1,e);if(w[b+53|0]){v[b+44>>2]=3;if(!w[b+52|0]){break b}break a}v[b+44>>2]=4}v[b+20>>2]=c;v[b+40>>2]=v[b+40>>2]+1;if(v[b+36>>2]!=1|v[b+24>>2]!=2){break a}t[b+54|0]=1;return}a=v[a+8>>2];nb[v[v[a>>2]+24>>2]](a,b,c,d,e)}}function v4(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;e=Qb(a);Qd(c+24|0);a=0;b=v[c+28>>2];d=v[c+24>>2];v[23296]=0;R(169,e|0,GI(d,b)|0);b=v[23296];v[23296]=0;a:{if((b|0)!=1){b:{while(1){b=v[c+24>>2];if((GI(b,v[c+28>>2])|0)<=(a|0)){jb=c+32|0;return}b=v[b+(a<<3)>>2];v[23296]=0;b=Q(54,c+8|0,b|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){v[23296]=0;R(171,e|0,b|0);d=v[23296];v[23296]=0;if((d|0)==1){break b}yb(b);a=a+1|0;continue}break}a=P()|0;O()|0;break a}a=P()|0;O()|0;yb(b);break a}a=P()|0;O()|0}Me(e);S(a|0);L()}function rea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-80|0;jb=c;d=Mf(c+48|0);v[23296]=0;e=Q(610,b|0,d|0)|0;f=v[23296];v[23296]=0;a:{b:{c:{d:{if((f|0)!=1){if(e){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23296]=0;T(611,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break a}}break c}e=v[d+4>>2];v[23296]=0;U(178,c|0,b|0,e|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Md(d);S(a|0);L()}b=jc(c+24|0,c);cd(d+8|0,b);Ab(b);Ab(c);gl(a,d)}Md(d);jb=c+80|0}function oG(a,b,c,d){var e=0,f=0,g=0;f=jb-16|0;jb=f;a:{b:{if((a|0)!=(b|0)){c:{g=v[115772];v[115772]=0;Bd();d=nG(a,f+12|0,d);e=mb;d:{a=v[115772];if(a){if(v[f+12>>2]!=(b|0)){break c}if((a|0)!=68){break d}v[c>>2]=4;a=2147483647;if(!!d&(e|0)>=0|(e|0)>0){break a}break b}v[115772]=g;if(v[f+12>>2]==(b|0)){break d}break c}if((e|0)<0&d>>>0<=2147483647|(e|0)<-1){v[c>>2]=4;break b}if((e|0)>=0&d>>>0>=2147483648|(e|0)>0){v[c>>2]=4;a=2147483647;break a}a=d;break a}}v[c>>2]=4;a=0;break a}a=-2147483648}jb=f+16|0;return a}function iI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=jb-32|0;jb=d;A[d+24>>3]=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23296]=0;d=Q(54,d+8|0,10598)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}a=sc(b,d);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(d);break b}a=v[a+32>>2];v[d+8>>2]=0;v[d+12>>2]=-1074790400;v[d>>2]=0;v[d+4>>2]=1072693248;e=(a+B(b,872)|0)+1075684|0,f=bm(A[zg(d+24|0,d+8|0,d)>>3]*128+128),v[e>>2]=f;jb=d+32|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function cfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;ic(c+8|0,b,26);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+16|0]=0;t[b+17|0]=0;t[b+18|0]=0;t[b+19|0]=0;t[b+20|0]=0;t[b+21|0]=0;t[b+22|0]=0;t[b+23|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0;t[b+15|0]=0}}function Pca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;f=v[a+24>>2];g=v[a+20>>2];h=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;i=v[a+8>>2];j=v[a+12>>2];while(1){if(d){k=(((v[b+12>>2]&2147483647)<<1|v[b+8>>2]>>>31)&-2)+h|0;e=0;while(1){if((e|0)!=2){v[(e<<2)+b>>2]=t[e+k|0]<<8;e=e+1|0;continue}break}v[c>>2]=v[c>>2]+B(v[b>>2],g);v[c+4>>2]=v[c+4>>2]+B(v[b+4>>2],f);Sb(b+8|0,i,j);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function SC(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;d=w[a+8|0];h=v[a>>2];e=v[a+4>>2];f=Jc(b);a=Fb(b);b=jb-16|0;jb=b;v[b+8>>2]=a;v[b+12>>2]=e;a=h;g=v[Ib(b+12|0,b+8|0)>>2];c=g;while(1){a:{if(!c){c=0;break a}i=w[f|0];t[a|0]=i;if(!i){break a}f=f+1|0;a=a+1|0;c=c-1|0;continue}break}b:{if((d-1&255)>>>0<=1){t[b+7|0]=0;Pl(a,((a+e|0)-g|0)+c|0,b+7|0);break b}if((d-3&255)>>>0>1){break b}t[b+6|0]=32;Pl(a,((a+e|0)-g|0)+c|0,b+6|0)}c:{switch(d-1|0){case 0:case 3:t[(v[b+12>>2]+h|0)-1|0]=0;break;default:break c}}jb=b+16|0}function h_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;h=jb-16|0;jb=h;d=Fb(a);e=cn(a);g=re(b,c);a:{if(!g){break a}b:{f=tc(a);if(f>>>0<=b>>>0){f=(Fb(a)<<2)+f>>>0>=b>>>0}else{f=0}if(!f){if(e-d>>>0<g>>>0){KF(a,e,(d+g|0)-e|0,d,d)}e=tc(a)+(d<<2)|0;while(1){if((b|0)==(c|0)){break b}yd(e,v[b>>2]);b=b+4|0;e=e+4|0;continue}}b=sG(h,b,c);c=tc(b);d=Fb(b);v[23296]=0;W(1120,a|0,c|0,d|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){Kc(b);break a}a=P()|0;O()|0;Kc(b);S(a|0);L()}yd(e,0);Mh(a,d+g|0)}jb=h+16|0;return a|0}function Bq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if((a|0)!=(b|0)){if(!Ve(a)){if(!Ve(b)){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return}d=Jc(b);b=Fb(b);c=jb-16|0;jb=c;a:{if(b>>>0<=10){xe(a,b);a=He(a,d,b);t[c+15|0]=0;sd(a+b|0,c+15|0);break a}f=a;a=w[a+11|0];Zo(f,10,b-10|0,a,0,a,b,d)}jb=c+16|0;return}d=Jc(b);b=Fb(b);c=jb-16|0;jb=c;e=ml(a);b:{if(e>>>0>b>>>0){e=v[a>>2];Td(a,b);a=He(e,d,b);t[c+15|0]=0;sd(a+b|0,c+15|0);break b}f=a;a=v[a+4>>2];Zo(f,e-1|0,(b-e|0)+1|0,a,0,a,b,d)}jb=c+16|0}}function pia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-32|0;jb=c;pd(b,0);Uh(c,1,a);d=c+16|0;Gc(d,c);ze(b+43|0,d);yb(d);v[b+24>>2]=w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24);u[b+34>>1]=x[b+34>>1]&65533|(w[a+13|0]|w[a+14|0]<<8)<<1&2;v[b>>2]=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);v[b+4>>2]=w[a+20|0]|w[a+21|0]<<8|(w[a+22|0]<<16|w[a+23|0]<<24);v[b+8>>2]=w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24);t[c+16|0]=w[a+15|0];t[c|0]=64;e=b,f=w[Wb(d,c)|0]<<2,u[e+30>>1]=f;jb=c+32|0}function Mca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=jb-16|0;jb=b;e=v[a+40>>2];f=v[a+36>>2];i=v[a+16>>2];g=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=g;g=v[a+32>>2];j=v[a+28>>2];k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){h=u[(v[b+12>>2]<<1)+i>>1];f=f+j|0;v[c>>2]=v[c>>2]+B(h,f>>12);e=e+g|0;v[c+4>>2]=v[c+4>>2]+B(e>>12,h);Sb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=e;v[a+20>>2]=f>>12;v[a+36>>2]=f;v[a+24>>2]=e>>12;jb=b+16|0}function xE(a,b,c,d){var e=0,f=0,g=0;e=jb-80|0;jb=e;f=Mf(e+48|0);v[23296]=0;d=Q(d|0,b|0,f|0)|0;g=v[23296];v[23296]=0;a:{b:{c:{d:{if((g|0)!=1){if(d){break d}v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[23296]=0;T(c|0,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break a}}break c}c=v[f+4>>2];v[23296]=0;U(178,e|0,b|0,cc(c)|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}a=P()|0;O()|0;Md(f);S(a|0);L()}b=jc(e+24|0,e);cd(f+8|0,b);Ab(b);Ab(e);gl(a,f)}Md(f);jb=e+80|0}function fm(a,b,c,d,e,f){var g=0,h=0,i=0,j=0;a:{if(f&64){c=f+-64|0;b=c&31;if((c&63)>>>0>=32){c=0;b=e>>>b|0}else{c=e>>>b|0;b=((1<<b)-1&e)<<32-b|d>>>b}d=0;e=0;break a}if(!f){break a}i=d;h=64-f|0;g=h&31;if((h&63)>>>0>=32){h=i<<g;j=0}else{h=(1<<g)-1&i>>>32-g|e<<g;j=i<<g}i=b;b=f&31;if((f&63)>>>0>=32){g=0;b=c>>>b|0}else{g=c>>>b|0;b=((1<<b)-1&c)<<32-b|i>>>b}b=j|b;c=g|h;g=d;d=f&31;if((f&63)>>>0>=32){h=0;d=e>>>d|0}else{h=e>>>d|0;d=((1<<d)-1&e)<<32-d|g>>>d}e=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function yia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(b){if(ih(715827882)>>>0<b>>>0){Wc();L()}d=B(b,6);c=xc(d);v[a>>2]=c;v[a+4>>2]=c;f=Gb(a),g=c+d|0,v[f>>2]=g;d=jb-16|0;jb=d;c=oq(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){lc(c);jb=d+16|0}else{t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+4|0]=6;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=8;t[b+3|0]=4;b=b+6|0;v[c+4>>2]=b;continue}break}}t[a+16|0]=6;v[a+12>>2]=2015363072;return a|0}function t4(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=C(0);v[23296]=0;Y(900,a|0);d=v[23296];v[23296]=0;if((d|0)!=1){a=v[v[a+24>>2]+24>>2];if(!((b|0)<0|x[a+480188>>1]<=b>>>0)){a=a+B(b,872)|0;c=C(C(w[a+1075834|0])*C(.0078125));e=C(c*c);c=C(C(w[a+1075835|0])*C(.0078125));c=C(K(C(e+C(c*c))))}return C(c)}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,9279,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return C(C(0))}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function hl(a,b,c){var d=0;d=512;a:{if(b){break a}d=0;if(!(w[a+35|0]&2)){break a}Bo(a)}d=x[a+34>>1]&-513|d;u[a+34>>1]=d;if(b){v[a>>2]=4;u[a+34>>1]=d&65470;Bg(a);b=w[c+8|0]|w[c+9|0]<<8|(w[c+10|0]<<16|w[c+11|0]<<24);t[a+76|0]=b;t[a+77|0]=b>>>8;t[a+78|0]=b>>>16;t[a+79|0]=b>>>24;b=w[c+4|0]|w[c+5|0]<<8|(w[c+6|0]<<16|w[c+7|0]<<24);c=w[c|0]|w[c+1|0]<<8|(w[c+2|0]<<16|w[c+3|0]<<24);t[a+68|0]=c;t[a+69|0]=c>>>8;t[a+70|0]=c>>>16;t[a+71|0]=c>>>24;t[a+72|0]=b;t[a+73|0]=b>>>8;t[a+74|0]=b>>>16;t[a+75|0]=b>>>24}}function xO(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;h=jt(b);v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);ez(a,2048);g=jb-16|0;jb=g;f=ar(g,a,2048);d=v[f+4>>2];i=v[f+8>>2];while(1){if((d|0)==(i|0)){lc(f);jb=g+16|0}else{v[d>>2]=0;v[d+4>>2]=0;d=d+8|0;v[f+4>>2]=d;continue}break}while(1){a:{c=1;if((e|0)!=1024){if((e|0)==2048){break a}c=+(e-1024|0);j=jt(K(c*c*-9.5367431640625e-7+1)*b);c=c*.0372006759294457;c=j*ti(c)/(h*c)}k=Re(v[a>>2],e),l=c*.011841342921061943,A[k>>3]=l;e=e+1|0;continue}break}}function Nca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=jb-16|0;jb=b;e=v[a+40>>2];f=v[a+36>>2];i=v[a+16>>2];g=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=g;g=v[a+32>>2];j=v[a+28>>2];k=v[a+8>>2];l=v[a+12>>2];while(1){if(d){h=t[v[b+12>>2]+i|0]<<8;f=f+j|0;v[c>>2]=v[c>>2]+B(h,f>>12);e=e+g|0;v[c+4>>2]=v[c+4>>2]+B(e>>12,h);Sb(b+8|0,k,l);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;v[a+40>>2]=e;v[a+20>>2]=f>>12;v[a+36>>2]=f;v[a+24>>2]=e>>12;jb=b+16|0}function sda(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=jb-48|0;jb=f;vq(f+8|0,c);v[23296]=0;c=f+20|0;R(526,c|0,d|0);d=v[23296];v[23296]=0;b:{c:{d:{if((d|0)==1){break d}v[23296]=0;c=f+32|0;R(526,c|0,e|0);d=v[23296];v[23296]=0;if((d|0)==1){break d}Av(f,f+8|0);v[23296]=0;X(282,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23296];v[23296]=0;if((a|0)==1){break c}OP(f+8|0);jb=f+48|0;break a}a=P()|0;O()|0;while(1){c=yb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;OP(f+8|0)}S(a|0);L()}}function TQ(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-16|0;jb=c;v[a>>2]=0;v[a+4>>2]=0;Zj(a+8|0,0);e=v[b+4>>2];if(e){Pq(a,e);$k(c+8|0,v[b>>2]);gm(c,v[b>>2],v[b+4>>2]);d=jb-16|0;jb=d;f=v[a+4>>2];b=v[c+8>>2];j=v[c+12>>2];e=v[c>>2];k=v[c+4>>2];g=f+RQ(b,j,e,k)|0;v[a+4>>2]=g;a:{b:{if(!f){h=g-1|0;break b}h=g-1|0;if((h^f-1)>>>0>31){break b}i=v[a>>2];break a}i=v[a>>2];v[i+((g>>>0<33?0:h>>>5|0)<<2)>>2]=0}Co(d+8|0,i,f);SQ(d,b,j,e,k,v[d+8>>2],v[d+12>>2]);jb=d+16|0}jb=c+16|0;return a|0}function RW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;a:{f=jb-48|0;jb=f;Qo(f+8|0,c);v[23296]=0;c=f+20|0;R(127,c|0,d|0);d=v[23296];v[23296]=0;b:{c:{d:{if((d|0)==1){break d}v[23296]=0;c=f+32|0;R(127,c|0,e|0);d=v[23296];v[23296]=0;if((d|0)==1){break d}Av(f,f+8|0);v[23296]=0;X(102,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23296];v[23296]=0;if((a|0)==1){break c}kr(f+8|0);jb=f+48|0;break a}a=P()|0;O()|0;while(1){c=zb(c-12|0);if((c|0)!=(f+8|0)){continue}break}break b}a=P()|0;O()|0;kr(f+8|0)}S(a|0);L()}}function vea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-32|0;jb=d;pd(b,0);_A(d,a+1|0);c=d+16|0;Gc(c,d);ze(b+43|0,c);yb(c);v[b+24>>2]=w[a+73|0]|w[a+74|0]<<8|(w[a+75|0]<<16|w[a+76|0]<<24);c=w[a+54|0]|w[a+55|0]<<8|(w[a+56|0]<<16|w[a+57|0]<<24);v[b>>2]=c;v[b+4>>2]=w[a+58|0]|w[a+59|0]<<8|(w[a+60|0]<<16|w[a+61|0]<<24);e=w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24);if(e){v[b+8>>2]=e+1}u[b+30>>1]=(w[a+68|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;yc(b+8|0,c);yc(b+4|0,v[b+8>>2]);jb=d+32|0}function aha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-32|0;jb=c;e=c+8|0;f=Qb(e+8|0);v[23296]=0;d=T(190,b|0)|0;g=v[23296];v[23296]=0;a:{b:{if((g|0)==1){break b}v[23296]=0;U(232,e|0,b|0,d|0);d=v[23296];v[23296]=0;if((d|0)==1){break b}d=v[e>>2];v[23296]=0;Q(176,b|0,d|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break a}}a=P()|0;O()|0;fc(f);S(a|0);L()}Fu(c,e);v[23296]=0;U(410,a|0,v[c>>2],v[c+4>>2]);a=v[23296];v[23296]=0;if((a|0)!=1){Pc(c+8|0);jb=c+32|0;return}a=P()|0;O()|0;Pc(c+8|0);S(a|0);L()}function ey(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;a:{if((c|0)<2){break a}k=c-2>>>1|0;f=d-a|0;if((k|0)<f>>1){break a}h=f+1|0;e=(h<<1)+a|0;g=x[e>>1];i=f+2|0;if((i|0)<(c|0)){j=x[e+2>>1];f=vp(b,g&65535,j);e=f?e+2|0:e;h=f?i:h;g=f?j:g}i=x[d>>1];if(vp(b,g&65535,i)){break a}while(1){b:{f=e;u[d>>1]=g;if((h|0)>(k|0)){break b}d=h<<1;h=d|1;e=(h<<1)+a|0;g=x[e>>1];j=d+2|0;if((j|0)<(c|0)){l=x[e+2>>1];d=vp(b,g&65535,l);e=d?e+2|0:e;h=d?j:h;g=d?l:g}d=f;if(!vp(b,g&65535,i)){continue}}break}u[f>>1]=i}}function eM(a,b){var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;a:{f=b-4e3&65535;if(f>>>0<61537){break a}c=B(b,104)+a|0;e=c+484380|0;if(!Ud(v[e>>2],v[c+484400>>2])){break a}g=a+1298224|0;c=a+1074992|0;while(1){if((c|0)==(g|0)){hm(e);v[e>>2]=0;a=(B(b,104)+a|0)+484414|0;u[a>>1]=x[a>>1]&65470;v[d+24>>2]=0;v[d+8>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d>>2]=0;v[d+4>>2]=0;hl(e,0,d);break a}if(v[c+104>>2]==(e|0)){v[c+76>>2]=0;v[c>>2]=0;v[c+4>>2]=0;v[c+16>>2]=0}c=c+872|0;continue}}jb=d+32|0;return f>>>0>61536}function _O(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;j=b?33:32;c=v[a+8>>2]-1|0;e=v[a+12>>2];f=v[a>>2]+B(e,31)|0;g=b?1:-1;d=g;a:while(1){b:{b=0;if((h|0)==(j|0)){break b}while(1)if((b|0)>=(e|0)){b=B(e,g);i=v[a+8>>2]-1|0;c:{if(!((i|0)!=(c|0)|(d|0)<=0)){if(!w[a+16|0]){d=1;c=0;break c}d=-1;c=c-(w[a+17|0]!=0&(c|0)!=0)|0;break c}if(!((d|0)>=0|c)){c=w[a+16|0];d=c?1:-1;c=c?0:i;break c}c=c+d|0}f=b+f|0;h=h+1|0;continue a}else{t[b+f|0]=w[v[a+4>>2]+(B(c,e)+b|0)|0];b=b+1|0;e=v[a+12>>2];continue}}break}}function zr(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=jb-16|0;jb=i;a:{b:{if(!a){break b}h=v[e+12>>2];g=c-b|0;if((g|0)>0){g=g>>>2|0;if((vm(a,b,g)|0)!=(g|0)){break b}}b=d-b>>2;b=(b|0)<(h|0)?h-b|0:0;if((b|0)>0){f=aG(i,b,f);h=tc(f);v[23296]=0;h=W(1103,a|0,h|0,b|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break a}Kc(f);if((b|0)!=(h|0)){break b}}b=d-c|0;if((b|0)>0){b=b>>>2|0;if((vm(a,c,b)|0)!=(b|0)){break b}}vo(e);j=a}jb=i+16|0;return j|0}a=P()|0;O()|0;Kc(f);S(a|0);L()}function T3(a,b){a=a|0;b=b|0;var c=0,d=0;v[23296]=0;Y(900,a|0);c=v[23296];v[23296]=0;if((c|0)!=1){a=v[a+24>>2];c=-1;a:{if((b|0)<0){break a}d=v[a+24>>2];if(lj(Zb(v[d+484360>>2],w[d+484376|0]))>>>0<=b>>>0){break a}a=v[a+24>>2];c=x[dc(v[Zb(v[a+484360>>2],w[a+484376|0])>>2],b)>>1]}return c|0}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,9693,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function xz(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;f=a+14|0;c=v[a>>2];e=v[a+4>>2];if(uc(c,e)){b=c}else{u[c>>1]=0;nf(c+2|0,b);g=d,h=cm(Eb(v[a>>2]),1),v[g+8>>2]=h;while(1){e=Eb(v[a+4>>2]);c=v[d+8>>2];if(Rb(c,e)){g=c,h=x[We(c,cm(c,-1))>>1],u[g>>1]=h;nf(c+2|0,b);ZP(d+8|0);continue}else{e=v[a+4>>2];b=v[a>>2]}break}}nf(f,re(b,e)-1&255);nf(a+13|0,w[a+14|0]);nf(a+16|0,re(v[a>>2],v[a+4>>2])-1&255);nf(a+15|0,w[a+16|0]);if(w[a+17|0]!=255){nf(a+17|0,re(v[a>>2],v[a+4>>2])-1&255)}jb=d+16|0}function bH(a){var b=0,c=0;a:{b=v[a+4>>2];b=v[v[b>>2]-12>>2]+b|0;b:{if(!v[b+24>>2]){break b}if(!Kg(b)|!(v[b+4>>2]&8192)){break b}if(tH()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[23296]=0;b=T(1053,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[23296]=0;Y(1054,a+b|0);a=v[23296];v[23296]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ub();L()}function aD(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;g=v[b+16>>2];v[a+4>>2]=0;v[a>>2]=g;a:{if(!g){break a}e=b+80|0;c=v[b+84>>2];if(c>>>0<=15){d=v[e>>2]}else{v[f+12>>2]=c-16;d=v[Yc(e,f+12|0)>>2]}v[a+8>>2]=d;c=v[b+88>>2];if(!(c&2)|!w[b+794|0]){break a}d=c;c=v[b+104>>2];b:{if(!(!$C(d,c)|v[e>>2]!=v[c+12>>2])){e=1;d=v[b+84>>2];if((d|0)==v[c+16>>2]){break b}}e=0;d=v[b+84>>2];if((d|0)!=v[c+8>>2]){break a}}h=a,i=B((v[c>>2]-d|0)+(e?112:48)|0,mk(x[c+34>>1]))+g|0,v[h+4>>2]=i}jb=f+16|0}function yv(a){var b=0,c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){b=jb-16|0;jb=b;a=sD(b,a);c=v[a+4>>2];v[23296]=0;Y(158,c|0);c=v[23296];v[23296]=0;a:{if((c|0)!=1){v[a+4>>2]=v[a+4>>2]+36;lc(a);jb=b+16|0;break a}b=P()|0;O()|0;lc(a);S(b|0);L()}return}c=jb-32|0;jb=c;b=Gb(a);b=qD(c+8|0,rD(a,$q(v[a>>2],v[a+4>>2])+1|0),$q(v[a>>2],v[a+4>>2]),b);d=v[b+8>>2];v[23296]=0;Y(158,d|0);d=v[23296];v[23296]=0;b:{if((d|0)!=1){v[b+8>>2]=v[b+8>>2]+36;pD(a,b);ov(b);jb=c+32|0;break b}a=P()|0;O()|0;ov(b);S(a|0);L()}}function jk(a){var b=0,c=0;a:{b=v[a+4>>2];b=v[v[b>>2]-12>>2]+b|0;b:{if(!v[b+24>>2]){break b}if(!Kg(b)|!(v[b+4>>2]&8192)){break b}if(tH()){break b}b=v[a+4>>2];b=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];v[23296]=0;b=T(21,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){if((b|0)!=-1){break b}a=v[a+4>>2];b=v[v[a>>2]-12>>2];v[23296]=0;R(15,a+b|0,1);a=v[23296];v[23296]=0;if((a|0)!=1){break b}}a=V(0)|0;O()|0;_(a|0)|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ub();L()}function iJ(a){var b=0,c=0,d=0,e=0,f=0;while(1){d=v[a+16>>2];if(d>>>0<=e>>>0){while(1){if(!(y[a+12>>2]<=d>>>0)){while(1){e=sy(v[a>>2]);c=mb;f=v[a+36>>2];if((c|0)==(f|0)&y[a+32>>2]<=e>>>0|c>>>0>f>>>0){continue}break}c=b;b=v[a+8>>2];b=(e&v[a+48>>2])+(b>>>0<31?c<<b+1:0)|0;d=d+1|0;continue}break}}else{while(1){d=sy(v[a>>2]);c=mb;f=v[a+28>>2];if((c|0)==(f|0)&y[a+24>>2]<=d>>>0|c>>>0>f>>>0){continue}break}c=b;b=v[a+8>>2];b=(d&v[a+40>>2])+(b>>>0<32?c<<b:0)|0;e=e+1|0;continue}break}return b}function oga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=jb-16|0;jb=c;a=vU(c,a);AA(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;lc(a);jb=c+16|0;return}e=jb-32|0;jb=e;c=Gb(a);c=sU(e+8|0,uU(a,wq(v[a>>2],v[a+4>>2])+1|0),wq(v[a>>2],v[a+4>>2]),c);AA(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;AA(v[b>>2]-28|0,d);v[b>>2]=v[b>>2]-28;continue}break}oc(a,b);oc(a+4|0,c+8|0);oc(Gb(a),zc(c));v[c>>2]=v[c+4>>2];rU(c);jb=e+32|0}function hk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=jb-16|0;jb=c;a=vU(c,a);uB(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+28;lc(a);jb=c+16|0;return}e=jb-32|0;jb=e;c=Gb(a);c=sU(e+8|0,uU(a,wq(v[a>>2],v[a+4>>2])+1|0),wq(v[a>>2],v[a+4>>2]),c);uB(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+28;f=v[a>>2];d=v[a+4>>2];b=c+4|0;while(1){if((d|0)!=(f|0)){d=d-28|0;uB(v[b>>2]-28|0,d);v[b>>2]=v[b>>2]-28;continue}break}oc(a,b);oc(a+4|0,c+8|0);oc(Gb(a),zc(c));v[c>>2]=v[c+4>>2];rU(c);jb=e+32|0}function UI(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;if((e|0)==10){zx(a,b,c,d);return}g=d;i=B(e,e);k=B(i,e);j=B(i,i);a:{while(1){h=f|1;if(e>>>0>g>>>0){break a}h=f|2;if(g>>>0<i>>>0){break a}h=f|3;if(g>>>0<k>>>0){break a}if(g>>>0<j>>>0){h=f+4|0}else{f=f+4|0;g=(g>>>0)/(j>>>0)|0;continue}break}}f=h;if((f|0)>(c-b|0)){v[a+4>>2]=61;v[a>>2]=c;return}f=b+f|0;c=f;while(1){c=c-1|0;b=(d>>>0)/(e>>>0)|0;t[c|0]=w[(d-B(b,e)|0)+4856|0];g=d>>>0>=e>>>0;d=b;if(g){continue}break}v[a+4>>2]=0;v[a>>2]=f}function vf(a,b,c,d,e,f){var g=0,h=0,i=0;a:{if(f&64){d=b;e=f+-64|0;b=e&31;if((e&63)>>>0>=32){e=d<<b;d=0}else{e=(1<<b)-1&d>>>32-b|c<<b;d=d<<b}b=0;c=0;break a}if(!f){break a}g=d;d=f&31;if((f&63)>>>0>=32){h=g<<d;i=0}else{h=(1<<d)-1&g>>>32-d|e<<d;i=g<<d}g=b;e=64-f|0;d=e&31;if((e&63)>>>0>=32){e=0;b=c>>>d|0}else{e=c>>>d|0;b=((1<<d)-1&c)<<32-d|g>>>d}d=i|b;e=e|h;b=f&31;if((f&63)>>>0>=32){h=g<<b;b=0}else{h=(1<<b)-1&g>>>32-b|c<<b;b=g<<b}c=h}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e}function oQ(a){var b=0,c=0;a:{if(Pb(a+60|0,13667,4)){break a}b=w[a+28|0]|w[a+29|0]<<8;b:{if(b>>>0<=63){if((b|0)==26){break b}break a}if(b>>>0>2112){break a}}b=w[a+42|0];if(b>>>0>64&(b|0)!=88|(w[a+48|0]|w[a+49|0]<<8)>>>0>64|(w[a+50|0]|w[a+51|0]<<8)>>>0>96){break a}b=w[a+52|0]|w[a+53|0]<<8;if(b>>>0>129&(b|0)!=257|(w[a+30|0]|w[a+31|0]<<8)|(w[a+38|0]|w[a+39|0]<<8|(w[a+40|0]<<16|w[a+41|0]<<24)|(w[a+44|0]|w[a+45|0]<<8|(w[a+46|0]<<16|w[a+47|0]<<24))!=1)){break a}c=rQ(a+20|0)}return c}function WE(a,b,c,d,e,f,g,h){var i=0,j=0;i=jb-16|0;jb=i;v[23296]=0;Y(900,a|0);j=v[23296];v[23296]=0;a:{b:{if((j|0)!=1){c:{j=v[a+24>>2];v[23296]=0;ia(h|0,i|0,j|0,b|0,c|0,d|0,e|0,(f|0)!=0|0);b=v[23296];v[23296]=0;if((b|0)==1){break c}b=Xf(Jc(i));yb(i);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23296]=0;X(887,g|0,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$()}jb=i+16|0;return b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function BL(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;if((a|0)!=(b|0)){c=jb-16|0;jb=c;d=v[b>>2];f=v[b+4>>2];e=ck(d,f);a:{if(e>>>0<=lu(a)>>>0){g=f;h=v[a>>2];i=ck(h,v[a+4>>2]);j=i>>>0>=e>>>0;if(!j){v[c+12>>2]=d;v[c+12>>2]=v[c+12>>2]+B(i,6);g=v[c+12>>2]}d=DL(d,g,h);if(!j){Vx(a,g,f,e-ck(v[a>>2],v[a+4>>2])|0);break a}Nd(a,d);break a}CL(a);cu(a,IA(a,e));Vx(a,d,f,e)}jb=c+16|0}v[a+12>>2]=v[b+12>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=v[b+20>>2];AL(a+24|0,b+24|0);Bq(a+36|0,b+36|0);return a}function J1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;e=Ko(a);v[e>>2]=60140;a=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=a;a=c;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;b=zc(e);c=jb-16|0;jb=c;d=v[a+12>>2];v[c+8>>2]=v[a+8>>2];v[c+12>>2]=d;d=v[a+4>>2];v[c>>2]=v[a>>2];v[c+4>>2]=d;d=LI(c);b=Nm(b);t[b+8|0]=0;v[b+4>>2]=d;v[b>>2]=60540;Qb(b+12|0);v[b>>2]=60304;d=v[a+4>>2];v[b+24>>2]=v[a>>2];v[b+28>>2]=d;d=v[a+12>>2];v[b+32>>2]=v[a+8>>2];v[b+36>>2]=d;jb=c+16|0;jb=a+16|0;return e|0}function WW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-48|0;jb=d;a:{b:{e=wT(rd(b),Cd(v[b+4>>2],w[b+11|0]),rd(c),Cd(v[c+4>>2],w[c+11|0]));if((e|0)!=-1){f=d,g=Ii(b),v[f+16>>2]=g;f=d,g=Hi(d+16|0,e),v[f+24>>2]=g;f=d,g=Hi(d+24|0,1),v[f+32>>2]=g;c=Gf(d+40|0,d+32|0);f=d,g=jv(b),v[f>>2]=g;e=Gf(d+8|0,d);hD(b,v[c>>2],v[e>>2]);break b}if(!tl(v[b+4>>2],w[b+11|0])){break b}if(dT(rd(b),Cd(v[b+4>>2],w[b+11|0]),rd(c),Cd(v[c+4>>2],w[c+11|0]))){break b}Kb(a);break a}Sc(a,b)}jb=d+48|0}function VE(a,b,c,d,e,f,g){var h=0,i=0;h=jb-16|0;jb=h;v[23296]=0;Y(900,a|0);i=v[23296];v[23296]=0;a:{b:{if((i|0)!=1){c:{i=v[v[a+24>>2]+24>>2];v[23296]=0;ma(g|0,h|0,i|0,b|0,c|0,d|0,e|0);b=v[23296];v[23296]=0;if((b|0)==1){break c}b=Xf(Jc(h));yb(h);break b}}b=V(0)|0;O()|0;_(b|0)|0;b=0;v[23296]=0;X(887,f|0,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$()}jb=h+16|0;return b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function uM(a){var b=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;g=v[a+104>>2];e=(g<<3)+a|0;c=((g+7>>>0)%12<<3)+a|0;f=v[c>>2];c=v[c+4>>2];h=v[a+96>>2];i=v[a+100>>2];a:{if(!(h|i)){b=v[e+4>>2];d=v[e>>2];j=(b|0)==(c|0)&d>>>0>f>>>0|c>>>0<b>>>0;break a}b=v[e+4>>2];d=v[e>>2];j=!(c|f)|((b|0)==(c|0)&d>>>0>=f>>>0|c>>>0<b>>>0)}b=b+i|0;d=h+d|0;b=d>>>0<h>>>0?b+1|0:b;v[e>>2]=f-d;v[e+4>>2]=c-(b+(f>>>0<d>>>0)|0)&65535;v[a+104>>2]=(g+1>>>0)%12;v[a+96>>2]=j;v[a+100>>2]=0;mb=v[e+4>>2];return v[e>>2]}function q2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=jb-16|0;jb=c;a:{d=Oh(C(z[a+24>>2]*C(65536)));if((d|0)==65536){break a}i=v[b+4>>2];j=v[b+8>>2];k=d>>31;b:while(1){if((f|0)==(j|0)){break a}l=v[b+4>>2];m=v[b>>2];e=0;while(1)if((e|0)==(i|0)){f=f+1|0;continue b}else{g=Kh(m,l,e,f);h=v[g>>2];n=g,o=Ic(Tia(Sia(h,h>>31,d,k),mb,65536,0),mb),v[n>>2]=o;e=e+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;eJ(a,c);jb=c+16|0}function g2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=jb-16|0;jb=c;a:{d=Oh(C(z[a+24>>2]*C(65536)));if((d|0)==65536){break a}i=v[b+4>>2];j=v[b+8>>2];k=d>>31;b:while(1){if((f|0)==(j|0)){break a}l=v[b+4>>2];m=v[b>>2];e=0;while(1)if((e|0)==(i|0)){f=f+1|0;continue b}else{g=Kh(m,l,e,f);h=v[g>>2];n=g,o=Ic(Tia(Sia(h,h>>31,d,k),mb,65536,0),mb),v[n>>2]=o;e=e+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;ZI(a,c);jb=c+16|0}function tJ(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[d+12>>2]=c;a:{if(!b){a=a+120|0;yn(a);g=nJ(a,v[d+12>>2]),h=0,t[g+20|0]=h;break a}e=jb-16|0;jb=e;v[e+12>>2]=c;b:{if((b|0)==1){b=a+120|0;yn(b);g=ox(b,a,v[e+12>>2]),h=1,t[g+20|0]=h;break b}f=jb-16|0;jb=f;v[f+12>>2]=c;c:{if((b|0)==2){a=a+120|0;yn(a);a=nJ(a,v[f+12>>2]);$d(a+12|0);t[a+20|0]=2;break c}b=jb-16|0;jb=b;v[b+12>>2]=c;c=a+120|0;yn(c);g=ox(c,a,v[b+12>>2]),h=3,t[g+20|0]=h;jb=b+16|0}jb=f+16|0}jb=e+16|0}jb=d+16|0}function _7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=li(a,b,c,d);v[a>>2]=44072;b=Qb(a+4208|0);v[a+4236>>2]=-1;v[a+4240>>2]=0;v[a+4228>>2]=1049926264;v[a+4232>>2]=0;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;t[a+4244|0]=0;Xb(a+4248|0,0,48);v[23296]=0;Z(763);c=v[23296];v[23296]=0;a:{if((c|0)==1){break a}e=a,f=CM(),v[e+4296>>2]=f;Fs(a);Es(a);v[23296]=0;R(851,a+44|0,2);c=v[23296];v[23296]=0;if((c|0)==1){break a}ki(a);return a|0}c=P()|0;O()|0;fc(b);uf(a);S(c|0);L()}function TR(a,b,c,d){var e=0,f=0,g=0;f=jb-16|0;jb=f;while(1){a:{e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){if(!bf(a,f+15|0)){break a}e=w[f+15|0];u[c>>1]=e<<1|1;t[b|0]=e>>>7;u[c>>1]=w[c|0]}t[d|0]=w[b|0]+(w[d|0]<<1);e=x[c>>1]<<1;u[c>>1]=e;t[b|0]=(e&65534)>>>0>255;e=w[c|0];u[c>>1]=e;if(!e){e=bf(a,f+14|0);if(e){g=w[f+14|0];u[c>>1]=g<<1|1;t[b|0]=g>>>7;u[c>>1]=w[c|0]}if(!e){break a}if(w[b|0]){continue}break a}if(w[b|0]){continue}}break}jb=f+16|0}function Kga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;i=e,j=ak(b),v[i>>2]=j;g=x[b>>1];c=jb-16|0;jb=c;f=a;d=Wd(a);a:{if(d){b=kc(f);while(1){a=d;d=x[a+16>>1];if(mo(g,d)){b=a;d=v[a>>2];if(d){continue}break a}if(!mo(d,g)){break a}b=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=kc(f);b=a}v[c+12>>2]=a;a=v[b>>2];if(!a){VS(c,f,e);Zg(f,v[c+12>>2],b,v[c>>2]);a=de(c);US(c);h=1}Yg(e+8|0,v[hc(c,a)>>2],h);jb=c+16|0;a=vd(v[e+8>>2]);jb=e+16|0;return a+4|0}function rL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;i=e,j=ak(b),v[i>>2]=j;g=x[b>>1];c=jb-16|0;jb=c;f=a;d=Wd(a);a:{if(d){b=kc(f);while(1){a=d;d=x[a+16>>1];if(Js(g,d)){b=a;d=v[a>>2];if(d){continue}break a}if(!Js(d,g)){break a}b=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=kc(f);b=a}v[c+12>>2]=a;a=v[b>>2];if(!a){VS(c,f,e);Zg(f,v[c+12>>2],b,v[c>>2]);a=de(c);US(c);h=1}Yg(e+8|0,v[hc(c,a)>>2],h);jb=c+16|0;a=vd(v[e+8>>2]);jb=e+16|0;return a+4|0}function vV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-32|0;jb=d;pd(b,0);Uh(d,1,a+33|0);c=d+16|0;Gc(c,d);ze(b+43|0,c);yb(c);e=w[a+50|0]|w[a+51|0]<<8;v[b>>2]=e;v[b+24>>2]=w[a+52|0]|w[a+53|0]<<8;t[d+16|0]=w[a+54|0];t[d|0]=64;g=b,h=w[Wb(c,d)|0]<<2,u[g+30>>1]=h;f=w[a+55|0]|w[a+56|0]<<8;v[b+4>>2]=f;c=w[a+57|0]|w[a+58|0]<<8;v[b+8>>2]=c;a:{if((c|0)==65535){v[b+4>>2]=0;v[b+8>>2]=0;break a}if(!w[a|0]|c>>>0<=f+2>>>0|c>>>0>e>>>0){break a}u[b+34>>1]=x[b+34>>1]|2}jb=d+32|0}function i9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;el(d,2,a+2|0);e=d+16|0;Gc(e,d);Ec(b+492|0,e);f=b+236|0;g=c+1|0;yb(e);c=0;while(1){if((c|0)==120){v[b>>2]=(w[a+223|0]|w[a+224|0]<<8)<<5;a=a+158|0;HL(w[a|0]&15,w[a+1|0]&15,w[a+2|0]&15,w[a+3|0]&15,w[a+4|0]&15,a+5|0,b+48|0);HL(w[a|0]>>>4|0,w[a+1|0]>>>4|0,w[a+2|0]>>>4|0,w[a+3|0]>>>4|0,w[a+4|0]>>>4|0,a+35|0,b+68|0);jb=d+32|0}else{h=dc(f,c),i=w[(a+c|0)+31|0]+g|0,u[h>>1]=i;c=c+1|0;continue}break}}function hD(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;v[d+16>>2]=c;v[d+24>>2]=b;i=d,j=Ii(a),v[i+8>>2]=j;c=d+24|0;b=dk(c,d+8|0);c=dk(d+16|0,c);a:{if(Cd(v[a+4>>2],w[a+11|0])>>>0>=b>>>0){if((c|0)==-1){PA(a,rd(a),b);break a}f=a;e=jb-16|0;jb=e;v[e+12>>2]=c;if(c){g=Cd(v[f+4>>2],w[f+11|0]);h=rd(f);c=g-b|0;v[e+8>>2]=c;a=v[Ib(e+12|0,e+8|0)>>2];v[e+12>>2]=a;b:{if((a|0)==(c|0)){a=c;break b}b=b+h|0;rj(b,a+b|0,c-a|0)}PA(f,h,g-a|0)}jb=e+16|0;break a}mm();L()}jb=d+32|0}function E8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=C(0);e=jb-16|0;jb=e;f=gf(a,c);ae(e,v[a+28>>2]);h=a;a:{if(!f){c=0;if(hd(a,5)){break a}}c=0;d=jb-32|0;jb=d;g=v[a+28>>2];rk(g,d+24|0);i=d,j=Vc(v[d+24>>2],v[d+28>>2]),v[i+16>>2]=j;v[d+12>>2]=256;Qj(b,v[Ib(d+16|0,d+12|0)>>2]);a=v[b>>2];while(1){if(wc(a,v[b+4>>2])>>>0<=c>>>0){jb=d+32|0}else{v[d+16>>2]=0;qp(g,d+16|0);a=v[b>>2];i=Db(a,c),k=z[d+16>>2],z[i>>2]=k;c=c+1|0;continue}break}c=f}$e(h,c);jb=e+16|0}function xy(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=v[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=w[b+813|0];if(c){t[b+813|0]=e&240|c&15;break a}c=e&15;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}Rj(a,b,b+700|0,0-(c<<2)|0,0);if(v[b+700>>2]<65536){break b}Bb(d+8|0,a+1074312|0,7);if(Cb(v[v[d+8>>2]>>2],v[d+12>>2])|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}jb=d+16|0}function mf(a,b,c,d,e,f,g,h,i){var j=0,k=0,l=0,m=0;h=Sia(b,c,h,i);i=mb;j=h;h=Sia(d,e,f,g);e=j+h|0;d=mb+i|0;i=e;h=i>>>0<h>>>0?d+1|0:d;j=i;k=g;e=0;l=c;d=0;i=Sia(g,e,c,d);g=j+i|0;c=mb+h|0;j=g;g=g>>>0<i>>>0?c+1|0:c;h=f;i=b;f=Sia(h,0,i,0);b=mb;c=0;d=Sia(h,c,l,d);b=b+d|0;c=mb+c|0;c=b>>>0<d>>>0?c+1|0:c;h=c;c=c+j|0;d=g;d=c>>>0<h>>>0?d+1|0:d;h=c;c=d;d=Sia(i,m,k,e)+b|0;e=mb;e=b>>>0>d>>>0?e+1|0:e;g=a;i=e;h=i+h|0;v[g+8>>2]=h;v[g+12>>2]=h>>>0<i>>>0?c+1|0:c;v[g>>2]=f;v[g+4>>2]=d}function lG(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[115772];v[115772]=0;Bd();a=nw(a,e+12|0,d);d=mb;g=v[115772];e:{if(g){if(v[e+12>>2]!=(b|0)){break c}if(!d&a>>>0>65535|d|(g|0)==68){break e}break b}v[115772]=h;if((b|0)!=v[e+12>>2]){break c}if(!d&a>>>0<65536){break b}}v[c>>2]=4;a=65535;break a}}v[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}jb=e+16|0;return a&65535}function T1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;v[d+4>>2]=1;g=d,h=xc(56),v[g+8>>2]=h;c=jb-16|0;jb=c;e=Ko(v[d+8>>2]);v[e>>2]=60640;f=v[b+12>>2];v[c+8>>2]=v[b+8>>2];v[c+12>>2]=f;f=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=f;b=Nm(zc(e));v[b>>2]=61004;Qb(b+4|0);t[b+20|0]=0;v[b+16>>2]=0;v[b>>2]=60804;e=v[c+4>>2];v[b+24>>2]=v[c>>2];v[b+28>>2]=e;e=v[c+12>>2];v[b+32>>2]=v[c+8>>2];v[b+36>>2]=e;t[b+40|0]=0;jb=c+16|0;b=a;a=Mo(d);Lo(b,zc(a),a);Om(d);jb=d+16|0}function Nfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(b){if(ih(178956970)>>>0<b>>>0){Wc();L()}c=B(b,24);b=xc(c);v[a>>2]=b;v[a+4>>2]=b;f=Gb(a),g=b+c|0,v[f>>2]=g;b=jb-16|0;jb=b;v[b>>2]=a;d=v[a+4>>2];v[b+4>>2]=d;v[b+8>>2]=c+d;c=v[b+4>>2];d=v[b+8>>2];a:{while(1){if((c|0)==(d|0)){break a}v[23296]=0;Y(527,c|0);e=v[23296];v[23296]=0;if((e|0)!=1){c=c+24|0;v[b+4>>2]=c;continue}break}a=P()|0;O()|0;lc(b);S(a|0);L()}lc(b);jb=b+16|0}return a|0}function KW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-48|0;jb=d;a:{b:{e=TD(rd(b),Cd(v[b+4>>2],w[b+11|0]),rd(c),Cd(v[c+4>>2],w[c+11|0]));if((e|0)!=-1){f=d,g=Ii(b),v[f+32>>2]=g;c=Gf(d+40|0,d+32|0);f=d,g=Ii(b),v[f+8>>2]=g;f=d,g=Hi(d+8|0,e),v[f+16>>2]=g;e=Gf(d+24|0,d+16|0);hD(b,v[c>>2],v[e>>2]);break b}e=tl(v[b+4>>2],w[b+11|0]);if(!e){break b}if((SD(rd(b),Cd(v[b+4>>2],w[b+11|0]),rd(c),Cd(v[c+4>>2],w[c+11|0]))|0)!=(e-1|0)){break b}Kb(a);break a}Sc(a,b)}jb=d+48|0}function Jq(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;i=jb-16|0;jb=i;a:{b:{if(!a){break b}g=v[e+12>>2];h=c-b|0;if((h|0)>0){if((vm(a,b,h)|0)!=(h|0)){break b}}b=d-b|0;b=(b|0)<(g|0)?g-b|0:0;if((b|0)>0){f=Je(i,b,f);g=tc(f);v[23296]=0;g=W(22,a|0,g|0,b|0)|0;h=v[23296];v[23296]=0;if((h|0)==1){break a}yb(f);if((b|0)!=(g|0)){break b}}b=d-c|0;if((b|0)>0){if((vm(a,c,b)|0)!=(b|0)){break b}}vo(e);j=a}jb=i+16|0;return j|0}a=P()|0;O()|0;yb(f);S(a|0);L()}function sE(a,b,c,d,e,f){var g=0;a:{g=jb-48|0;jb=g;Vm(g+8|0,c);v[23296]=0;c=g+20|0;R(f|0,c|0,d|0);d=v[23296];v[23296]=0;b:{c:{d:{if((d|0)==1){break d}v[23296]=0;c=g+32|0;R(101,c|0,e|0);d=v[23296];v[23296]=0;if((d|0)==1){break d}Av(g,g+8|0);v[23296]=0;X(102,a|0,b|0,v[g>>2],v[g+4>>2]);a=v[23296];v[23296]=0;if((a|0)==1){break c}kr(g+8|0);jb=g+48|0;break a}a=P()|0;O()|0;while(1){c=zb(c-12|0);if((c|0)!=(g+8|0)){continue}break}break b}a=P()|0;O()|0;kr(g+8|0)}S(a|0);L()}}function Yt(a,b,c){var d=0,e=0;d=(c|0)!=0;a:{b:{c:{d:{if(!(a&3)|!c){break d}e=b&255;while(1){if((e|0)==w[a|0]){break c}c=c-1|0;d=(c|0)!=0;a=a+1|0;if(!(a&3)){break d}if(c){continue}break}}if(!d){break a}if(w[a|0]==(b&255)|c>>>0<4){break c}d=B(b&255,16843009);while(1){e=d^v[a>>2];if((e^-1)&e-16843009&-2139062144){break b}a=a+4|0;c=c-4|0;if(c>>>0>3){continue}break}}if(!c){break a}}while(1){if(w[a|0]==(b&255)){return a}a=a+1|0;c=c-1|0;if(c){continue}break}}return 0}function PM(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=v[a+480180>>2];a:{if((e|0)!=1048576){if((e|0)!=4){break a}e=w[b+814|0];if(c){t[b+814|0]=e&240|c&15;break a}c=e&15;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}Rj(a,b,b+700|0,0-c|0,0);if(v[b+700>>2]<65536){break b}Bb(d+8|0,a+1074312|0,7);if(Cb(v[v[d+8>>2]>>2],v[d+12>>2])|(v[a+480180>>2]!=4?w[a+480208|0]&16:0)){break b}v[b+700>>2]=65535}jb=d+16|0}function Y4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;var f=0,g=0;v[23296]=0;Y(925,a|0);f=v[23296];v[23296]=0;a:{b:{if((f|0)!=1){f=v[a+28>>2];g=v[v[f>>2]+72>>2];v[23296]=0;b=Va(g|0,f|0,b|0,c|0,+d,+e)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,11156,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function DX(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;var m=0;v[23296]=0;m=a;a=b;b=0;a=Ma(995,m|b,a|0,c|0,d|0,b|e,f|0)|0;b=v[23296];v[23296]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23296]=0;ia(883,8745,g|0,h|0,i|0,j|0,k|0,l|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}return a|0}function uL(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=v[a>>2];c=wc(d,v[a+4>>2]);if(c>>>0<=127){f=jb-32|0;jb=f;c=128-c|0;e=v[Gb(a)>>2];d=v[a+4>>2];a:{if(c>>>0<=e-d>>2>>>0){Sx(a,c,b);break a}e=Gb(a);d=fg(f+8|0,Ug(a,wc(v[a>>2],d)+c|0),wc(v[a>>2],v[a+4>>2]),e);g=jb-16|0;jb=g;c=ol(g,d+8|0,c);e=v[c>>2];while(1){if(v[c+4>>2]!=(e|0)){Ks(e,z[b>>2]);e=v[c>>2]+4|0;v[c>>2]=e;continue}break}Id(c);jb=g+16|0;Ad(a,d);eg(d)}jb=f+32|0;return}if((c|0)!=128){Nd(a,d+512|0)}}function iG(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{if((a|0)!=(b|0)){b:{c:{f=w[a|0];if((f|0)!=45){break c}a=a+1|0;if((b|0)!=(a|0)){break c}break b}h=v[115772];v[115772]=0;Bd();a=nw(a,e+12|0,d);d=mb;d:{g=v[115772];if(g){if(v[e+12>>2]!=(b|0)){break b}if((g|0)!=68){break d}v[c>>2]=4;b=-1;a=-1;break a}v[115772]=h;if(v[e+12>>2]==(b|0)){break d}break b}c=(f|0)==45;b=c?0-a|0:a;a=c?0-(d+((a|0)!=0)|0)|0:d;break a}}v[c>>2]=4;b=0;a=0}jb=e+16|0;mb=a;return b}function n_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;d=Fb(a);e=Tc(a);g=pi(b,c);a:{if(!g){break a}b:{if(!Is(a,b)){if(e-d>>>0<g>>>0){Ql(a,e,(d+g|0)-e|0,d,d,0,0)}e=tc(a)+d|0;while(1){if((b|0)==(c|0)){break b}sd(e,b);b=b+1|0;e=e+1|0;continue}}b=Zf(f,b,c);c=Jc(b);d=Fb(b);v[23296]=0;W(1014,a|0,c|0,d|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){yb(b);break a}a=P()|0;O()|0;yb(b);S(a|0);L()}t[f+15|0]=0;sd(e,f+15|0);Mh(a,d+g|0)}jb=f+16|0;return a|0}function GN(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=jb-16|0;jb=d;j=d,k=ak(b),v[j>>2]=k;c=jb-16|0;jb=c;g=Dy(a,c+12|0,w[b|0],v[b+4>>2]);b=v[g>>2];if(!b){e=jb-16|0;jb=e;b=kc(a);h=th(c,xc(28),uh(e+8|0,b));b=v[h>>2];f=v[d>>2];i=v[f+4>>2];f=v[f>>2];v[b+24>>2]=0;v[b+16>>2]=f;v[b+20>>2]=i;j=kc(h),k=1,t[j+4|0]=k;jb=e+16|0;Zg(a,v[c+12>>2],g,v[c>>2]);b=de(c);cl(c);e=1}Yg(d+8|0,v[hc(c,b)>>2],e);jb=c+16|0;a=vd(v[d+8>>2]);jb=d+16|0;return a+8|0}function nE(a,b,c,d,e){var f=0,g=0,h=0;a:{f=jb-32|0;jb=f;h=Qb(a);b:{c:{d:{e:{while(1){a=v[b+8>>2];g=v[b>>2];v[23296]=0;a=W(144,g|0,a|0,8)|0;g=v[23296];v[23296]=0;if((g|0)==1){break c}if(!a){break d}v[23296]=0;U(e|0,f|0,b|0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){v[23296]=0;R(d|0,h|0,f|0);a=v[23296];v[23296]=0;if((a|0)==1){break e}Md(f);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Md(f);break b}jb=f+32|0;break a}a=P()|0;O()|0}_d(h);S(a|0);L()}}function S8(a,b){a=a|0;b=b|0;var c=0,d=0;a:{v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);c=ck(v[b>>2],v[b+4>>2]);if(c){cu(a,c);Vx(a,v[b>>2],v[b+4>>2],c)}v[a+20>>2]=v[b+20>>2];c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;v[23296]=0;c=Q(831,a+24|0,b+24|0)|0;d=v[23296];v[23296]=0;b:{c:{if((d|0)!=1){v[23296]=0;Q(53,a+36|0,b+36|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break c}v[a+48>>2]=v[b+48>>2];break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;vc(c)}gk(a);S(b|0);L()}}function Bca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=v[b+12>>2]+i|0;e=t[f|0];e=((B(t[f+1|0]-e|0,v[b+8>>2]>>>10&4194048)|0)/16384|0)+(e<<8)|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Sb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function $4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23296]=0;Y(925,a|0);e=v[23296];v[23296]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+12>>2];v[23296]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,11301,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function cV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;a:{b:{if(!Vf(a,7)){break b}c=0;if(!iC(a,17646)){break a}if(!Vf(a,1)){break b}c=-1;if(!dd(a,Cq(a))){break a}c=jb-16|0;jb=c;f=d+8|0;wo(c+8|0,f);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(g|0);if(!e){Du(f)}c=-1;if(!e){break a}c=0;if(!WB(w[d+8|0],w[d+9|0])){break a}c=Ge(a,b,VB(d+8|0),mb);break a}c=-1}jb=d+16|0;return c|0}function _4(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;v[23296]=0;Y(925,a|0);e=v[23296];v[23296]=0;a:{b:{if((e|0)!=1){e=v[a+28>>2];f=v[v[e>>2]+8>>2];v[23296]=0;b=fa(f|0,e|0,b|0,c|0,d|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,11337,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Wo(a,b,c,d,e){var f=0,g=0,h=0;a:{f=jb-32|0;jb=f;h=Qb(a);b:{c:{d:{e:{while(1){a=v[b+8>>2];g=v[b>>2];v[23296]=0;a=W(144,g|0,a|0,e|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break c}if(!a){break d}v[23296]=0;R(d|0,f|0,b|0);a=v[23296];v[23296]=0;if((a|0)!=1){v[23296]=0;R(c|0,h|0,f|0);a=v[23296];v[23296]=0;if((a|0)==1){break e}Md(f);continue}break}a=P()|0;O()|0;break b}a=P()|0;O()|0;Md(f);break b}jb=f+32|0;break a}a=P()|0;O()|0}_d(h);S(a|0);L()}}function y0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-32|0;jb=e;v[e+16>>2]=b;d=v[a+48>>2];v[e+20>>2]=c-((d|0)!=0);f=v[a+44>>2];v[e+28>>2]=d;v[e+24>>2]=f;a:{b:{if(Qw(fb(v[a+60>>2],e+16|0,2,e+12|0)|0)){b=32}else{d=v[e+12>>2];if((d|0)>0){break b}b=d?32:16}v[a>>2]=b|v[a>>2];break a}g=d;f=v[e+20>>2];if(f>>>0>=d>>>0){break a}d=v[a+44>>2];v[a+4>>2]=d;v[a+8>>2]=d+(g-f|0);if(v[a+48>>2]){v[a+4>>2]=d+1;t[(b+c|0)-1|0]=w[d|0]}g=c}jb=e+32|0;return g|0}function VW(a,b){a=a|0;b=b|0;var c=0;a=Kb(a);a:{if(w[b+16|0]){v[23296]=0;Q(121,a|0,4906)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}}if(w[b+17|0]){v[23296]=0;Q(121,a|0,12398)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}}if(gh(v[a+4>>2],w[a+11|0])){v[23296]=0;Q(121,a|0,9959)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}}if(w[b+18|0]){v[23296]=0;Q(121,a|0,10991)|0;b=v[23296];v[23296]=0;if((b|0)==1){break a}}return}b=P()|0;O()|0;zb(a);S(b|0);L()}function uea(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-32|0;jb=d;pd(b,0);_A(d,a+1|0);c=d+16|0;Gc(c,d);ze(b+43|0,c);yb(c);v[b+24>>2]=w[a+78|0]|w[a+79|0]<<8;c=w[a+58|0]|w[a+59|0]<<8|(w[a+60|0]<<16|w[a+61|0]<<24);v[b>>2]=c;v[b+4>>2]=w[a+62|0]|w[a+63|0]<<8|(w[a+64|0]<<16|w[a+65|0]<<24);v[b+8>>2]=w[a+66|0]|w[a+67|0]<<8|(w[a+68|0]<<16|w[a+69|0]<<24);u[b+30>>1]=(w[a+73|0]<<1)+2;u[b+34>>1]=x[b+34>>1]&65533|w[a|0]>>>6&2;yc(b+8|0,c);yc(b+4|0,v[b+8>>2]);jb=d+32|0}function W4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[23296]=0;Y(925,a|0);d=v[23296];v[23296]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+64>>2];v[23296]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,6621,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function U4(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;v[23296]=0;Y(925,a|0);d=v[23296];v[23296]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+56>>2];v[23296]=0;U(f|0,d|0,b|0,(c|0)!=0|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,6675,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function SE(a,b,c,d){var e=0,f=C(0);v[23296]=0;Y(900,a|0);e=v[23296];v[23296]=0;if((e|0)!=1){a=v[v[a+24>>2]+24>>2];a:{if((b|0)<0|x[a+480188>>1]<=b>>>0){break a}a=a+B(b,872)|0;if(!(t[a+1075081|0]&1)){break a}f=C(C(w[a+d|0])*C(.0078125))}return f}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,c|0,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return C(0)}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Qda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb+-64|0;jb=c;em(c+48|0,b);ke(c+16|0,v[c+48>>2],v[c+52>>2]);b=$d(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23296]=0;b=wg(154,c+24|0,v[c+16>>2],v[c+20>>2],b,d);d=v[23296];v[23296]=0;a:{if((d|0)!=1){d=Qb(a);a=v[c+52>>2];e=v[c+48>>2];v[23296]=0;U(654,b|0,d|0,ad(e,a)>>>5|0);a=v[23296];v[23296]=0;if((a|0)==1){a=P()|0;O()|0;vi(d);Ab(b);break a}Ab(b);fc(c+48|0);jb=c- -64|0;return}a=P()|0;O()|0}fc(c+48|0);S(a|0);L()}function Nda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb+-64|0;jb=c;em(c+48|0,b);ke(c+16|0,v[c+48>>2],v[c+52>>2]);b=$d(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23296]=0;b=wg(154,c+24|0,v[c+16>>2],v[c+20>>2],b,d);d=v[23296];v[23296]=0;a:{if((d|0)!=1){d=Qb(a);a=v[c+52>>2];e=v[c+48>>2];v[23296]=0;U(655,b|0,d|0,ad(e,a)>>>2|0);a=v[23296];v[23296]=0;if((a|0)==1){a=P()|0;O()|0;vc(d);Ab(b);break a}Ab(b);fc(c+48|0);jb=c- -64|0;return}a=P()|0;O()|0}fc(c+48|0);S(a|0);L()}function Mda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb+-64|0;jb=c;em(c+48|0,b);ke(c+16|0,v[c+48>>2],v[c+52>>2]);b=$d(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23296]=0;b=wg(154,c+24|0,v[c+16>>2],v[c+20>>2],b,d);d=v[23296];v[23296]=0;a:{if((d|0)!=1){d=Qb(a);a=v[c+52>>2];e=v[c+48>>2];v[23296]=0;U(656,b|0,d|0,ad(e,a)>>>8|0);a=v[23296];v[23296]=0;if((a|0)==1){a=P()|0;O()|0;zt(d);Ab(b);break a}Ab(b);fc(c+48|0);jb=c- -64|0;return}a=P()|0;O()|0}fc(c+48|0);S(a|0);L()}function Lda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb+-64|0;jb=c;em(c+48|0,b);ke(c+16|0,v[c+48>>2],v[c+52>>2]);b=$d(c+8|0);d=v[b+4>>2];b=v[b>>2];v[23296]=0;b=wg(154,c+24|0,v[c+16>>2],v[c+20>>2],b,d);d=v[23296];v[23296]=0;a:{if((d|0)!=1){d=Qb(a);a=v[c+52>>2];e=v[c+48>>2];v[23296]=0;U(657,b|0,d|0,ad(e,a)>>>4|0);a=v[23296];v[23296]=0;if((a|0)==1){a=P()|0;O()|0;dl(d);Ab(b);break a}Ab(b);fc(c+48|0);jb=c- -64|0;return}a=P()|0;O()|0}fc(c+48|0);S(a|0);L()}function H9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;d=x[a+30>>1];if(d){b=In(b<<16>>16,d<<16>>16)}u[e+14>>1]=b;a=a+52|0;a:{if(!gh(v[c+4>>2],w[c+11|0])){Po(rL(a,e+14|0),c);break a}b=Rx(a,e+14|0);if(!Ag(b,yf(a))){break a}c=jb-16|0;jb=c;b=v[hc(c,b)>>2];d=jb-16|0;jb=d;f=Xg(hc(d+8|0,b));if((b|0)==v[a>>2]){v[a>>2]=v[f>>2]}g=Gb(a);v[g>>2]=v[g>>2]-1;qL(v[kc(a)>>2],b);a=v[f>>2];jb=d+16|0;$t(vd(b));Jb(b);hc(c+8|0,a);jb=c+16|0}jb=e+16|0}function Aca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;j=v[a+8>>2];k=v[a+12>>2];while(1){if(d){f=(v[b+12>>2]<<1)+i|0;e=u[f>>1];e=e+((B(u[f+2>>1]-e|0,v[b+8>>2]>>>18|0)|0)/16384|0)|0;v[c>>2]=v[c>>2]+B(e,h);v[c+4>>2]=v[c+4>>2]+B(e,g);Sb(b+8|0,j,k);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function tC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=Nc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=jb-32|0;jb=e;b=b-c|0;c=v[Gb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>1>>>0){mC(a,b);break a}c=Gb(a);c=xj(e+8|0,yj(a,Nc(v[a>>2],d)+b|0),Nc(v[a>>2],v[a+4>>2]),c);f=jb-16|0;jb=f;b=Eo(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){lC(d);d=v[b>>2]+2|0;v[b>>2]=d;continue}break}Id(b);jb=f+16|0;Ad(a,c);Gi(c)}jb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<1)|0)}}function Qj(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=wc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=jb-32|0;jb=e;b=b-c|0;c=v[Gb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){wP(a,b);break a}c=Gb(a);c=fg(e+8|0,Ug(a,wc(v[a>>2],d)+b|0),wc(v[a>>2],v[a+4>>2]),c);f=jb-16|0;jb=f;b=ol(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){uP(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Id(b);jb=f+16|0;Ad(a,c);eg(c)}jb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function TE(a,b,c,d){var e=0,f=C(0);v[23296]=0;Y(900,a|0);e=v[23296];v[23296]=0;if((e|0)!=1){a=v[v[a+24>>2]+24>>2];a:{if((b|0)<0|x[a+480188>>1]<=b>>>0){break a}a=a+B(b,872)|0;if(t[a+1075081|0]&1){break a}f=C(C(w[a+d|0])*C(.0078125))}return f}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,c|0,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return C(0)}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function u1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-32|0;jb=e;a:{if(!c){break a}g=tl(v[b+4>>2],w[b+11|0]);h=g-1|0;d=d<<24>>24;while(1){if((f|0)==(g|0)){break a}b:{if(!f|(f>>>0)%(c>>>0)){break b}if((f|0)==(h|0)){if(w[rd(b)|0]==(lf(43)&255)){break b}if(w[rd(b)|0]==(lf(45)&255)){break b}}i=e,j=Ii(b),v[i+8>>2]=j;i=e,j=Hi(e+8|0,g-f|0),v[i+16>>2]=j;BI(b,v[Gf(e+24|0,e+16|0)>>2],1,lf(d))}f=f+1|0;continue}}Sc(a,b);jb=e+32|0}function rk(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;v[b>>2]=0;v[b+4>>2]=0;t[e+15|0]=0;Jh(a,e+15|0);c=w[e+15|0];f=(c&252)>>>2|0;i=-1<<(c&3)^-1;while(1){v[b>>2]=f;v[b+4>>2]=d;if(!g&(h|0)==(i|0)){jb=e+16|0}else{t[e+15|0]=0;Jh(a,e+15|0);c=v[b>>2];j=v[b+4>>2];f=w[e+15|0];d=g;g=h+1|0;d=g?d:d+1|0;h=g;g=d;k=c;d=(h<<3)-2|0;c=d&31;if((d&63)>>>0>=32){d=f<<c;c=0}else{d=(1<<c)-1&f>>>32-c;c=f<<c}f=k|c;d=d|j;continue}break}}function Xf(a){var b=0,c=0,d=0;d=np(Ef(a)+1|0,1);if(d){a:{c=d;b:{if((c^a)&3){b=w[a|0];break b}if(a&3){while(1){b=w[a|0];t[c|0]=b;if(!b){break a}c=c+1|0;a=a+1|0;if(a&3){continue}break}}b=v[a>>2];if((b^-1)&b-16843009&-2139062144){break b}while(1){v[c>>2]=b;b=v[a+4>>2];c=c+4|0;a=a+4|0;if(!(b-16843009&(b^-1)&-2139062144)){continue}break}}t[c|0]=b;if(!(b&255)){break a}while(1){b=w[a+1|0];t[c+1|0]=b;c=c+1|0;a=a+1|0;if(b){continue}break}}}return d}function As(a){var b=0,c=0,d=0,e=0;a:{while(1){if(!a){b=0;if(v[23292]){b=As(v[23292])}if(!v[23216]){break a}c=b|c;a=v[23216];continue}break}d=v[a+76>>2]>=0;b:{c:{if(v[a+20>>2]==v[a+28>>2]){break c}nb[v[a+36>>2]](a,0,0)|0;if(v[a+20>>2]){break c}b=-1;if(d){break b}break a}b=v[a+8>>2];e=v[a+4>>2];if((b|0)!=(e|0)){b=e-b|0;nb[v[a+40>>2]](a,b,b>>31,1)|0}b=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;if(!d){break a}}}return b|c}function zL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;d=Tc(a);a:{b:{c:{f=pi(b,c);if(d>>>0<f>>>0){if(Is(a,b)){break c}g=d;h=f-d|0;d=Fb(a);Ql(a,g,h,d,0,d,0)}d=tc(a);while(1){if((b|0)==(c|0)){break b}sd(d,b);b=b+1|0;d=d+1|0;continue}}b=Zf(e,b,c);c=Jc(b);d=Fb(b);v[23296]=0;U(56,a|0,c|0,d|0);c=v[23296];v[23296]=0;if((c|0)!=1){yb(b);break a}a=P()|0;O()|0;yb(b);S(a|0);L()}t[e+15|0]=0;sd(d,e+15|0);Mh(a,f)}jb=e+16|0;return a|0}function pc(a,b){var c=0,d=0,e=0;c=v[a+1396>>2];if((c|0)>=0){a:{b:{if((b|0)<=(c|0)){break b}if((b|0)>24){return pc(a,24)+(pc(a,b-24|0)<<24)|0}if(!c){v[a+1392>>2]=0}while(1){if((b|0)<=(c|0)){break b}c=-1;e=bs(a);d=0;if((e|0)==-1){break a}d=v[a+1396>>2];c=d+8|0;v[a+1396>>2]=c;v[a+1392>>2]=v[a+1392>>2]+(e<<d);continue}}if((b|0)>(c|0)){aa(9969,13048,1632,6791);L()}d=v[a+1392>>2];v[a+1392>>2]=d>>>b;c=c-b|0;d=d&(-1<<b^-1)}v[a+1396>>2]=c}return d}function ut(a,b){var c=0,d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;e=d+16|0;NP(e,a,a+1|0,a+2|0,a+3|0);NP(d,b,b+1|0,b+2|0,b+3|0);jb=d+32|0;a=w[v[e>>2]];b=w[v[d>>2]];c=1;a:{if(a>>>0<b>>>0){break a}c=0;if(a>>>0>b>>>0){break a}a=t[v[e+4>>2]];b=t[v[d+4>>2]];c=1;b:{if((a|0)<(b|0)){break b}c=0;if((a|0)>(b|0)){break b}f=v[e+12>>2];g=v[d+12>>2];a=w[v[d+8>>2]];b=w[v[e+8>>2]];c=1;c:{if(a>>>0>b>>>0){break c}c=0;if(a>>>0<b>>>0){break c}c=w[f|0]<w[g|0]}}}return c}function Ow(a,b){a:{if(a){if(b>>>0<=127){break a}b:{if(!v[v[115798]>>2]){if((b&-128)==57216){break a}break b}if(b>>>0<=2047){t[a+1|0]=b&63|128;t[a|0]=b>>>6|192;return 2}if(!((b&-8192)!=57344&b>>>0>=55296)){t[a+2|0]=b&63|128;t[a|0]=b>>>12|224;t[a+1|0]=b>>>6&63|128;return 3}if(b-65536>>>0<=1048575){t[a+3|0]=b&63|128;t[a|0]=b>>>18|240;t[a+2|0]=b>>>6&63|128;t[a+1|0]=b>>>12&63|128;return 4}}v[115772]=25;a=-1}else{a=1}return a}t[a|0]=b;return 1}function ML(a,b,c,d,e,f,g,h){var i=0,j=0;i=jb-16|0;jb=i;v[i+12>>2]=d;a:{if(!(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24))){break a}v[i+8>>2]=w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24);j=b;b=v[Ib(i+8|0,i+12|0)>>2];v[j>>2]=b;b=Xd(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24),b,d);v[c>>2]=((h^1)&b>>>0<d>>>0)+b;b=x[e>>1]|f;u[e>>1]=b;if((w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))!=1){break a}u[e>>1]=b|g}jb=i+16|0}function S4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23296]=0;Y(925,a|0);d=v[23296];v[23296]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+48>>2];v[23296]=0;ta(f|0,d|0,b|0,+c);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,11536,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Oda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0;c=jb-4096|0;jb=c;em(a,b);a:while(1){if(ad(v[a>>2],v[a+4>>2])>>>12>>>0>e>>>0){f=e<<12;b=0;d=0;while(1)if((b|0)==2048){g=f|2048;b=0;while(1){if((b|0)!=2048){h=Lb(v[a>>2],b+g|0);i=Lb(c,b<<1);d=w[h|0]+d|0;t[i|0]=d;b=b+1|0;continue}break}ch(c,XP(c),$g(Eb(v[a>>2]),f));e=e+1|0;continue a}else{g=Lb(v[a>>2],b+f|0);h=Lb(c,b<<1|1);d=w[g|0]+d|0;t[h|0]=d;b=b+1|0;continue}}break}jb=c+4096|0}function I4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23296]=0;Y(925,a|0);d=v[23296];v[23296]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+96>>2];v[23296]=0;ta(f|0,d|0,b|0,+c);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,11474,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function G4(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;v[23296]=0;Y(925,a|0);d=v[23296];v[23296]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+28>>2];f=v[v[d>>2]+88>>2];v[23296]=0;ta(f|0,d|0,b|0,+c);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,10925,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Qaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=gg(e,v[a+4>>2]);if(d>>>0<b>>>0){e=jb-32|0;jb=e;a:{b:{d=b-d|0;b=v[Gb(a)>>2];f=v[a+4>>2];c:{if(d>>>0<=b-f>>5>>>0){qz(a,d,c);break c}b=Gb(a);b=st(e+8|0,Pp(a,gg(v[a>>2],f)+d|0),gg(v[a>>2],v[a+4>>2]),b);v[23296]=0;U(710,b|0,d|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}MO(a,b);oz(b)}jb=e+32|0;break a}a=P()|0;O()|0;oz(b);S(a|0);L()}return}if(b>>>0<d>>>0){OO(a,e+(b<<5)|0)}}function Li(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[a>>2];c=ad(d,v[a+4>>2]);if(c>>>0<b>>>0){e=jb-32|0;jb=e;b=b-c|0;c=v[Gb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>>0){kE(a,b);break a}c=Gb(a);c=Bl(e+8|0,zl(a,ad(v[a>>2],d)+b|0),ad(v[a>>2],v[a+4>>2]),c);f=jb-16|0;jb=f;b=Kv(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){vg(d);d=v[b>>2]+1|0;v[b>>2]=d;continue}break}Id(b);jb=f+16|0;Ad(a,c);Al(c)}jb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,b+d|0)}}function Afa(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0;g=jb-32|0;jb=g;a:{if(x[a+480192>>1]<b>>>0){break a}b=v[((b<<2)+a|0)+900380>>2];if(!b){break a}h=g+16|0;lS(h,b);i=g,j=Eb(v[g+16>>2]),v[i+8>>2]=j;h=Jf(h);while(1){b=v[g+8>>2];if(Rb(b,h)){b=x[Wp(b)>>1];if(b>>>0<=x[a+480190>>1]){b=B(b,104)+a|0;t[b+484421|0]=f;t[b+484418|0]=c;t[b+484420|0]=e;t[b+484419|0]=d}Xg(g+8|0);continue}else{uA(g+16|0)}break}}jb=g+32|0}function y3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-16|0;jb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[23296]=0;b=Q(54,h|0,8118)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(b);break b}Lk(a,b,4);c=kx(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=h+16|0;return c|0}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function k3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=jb-16|0;jb=h;a:{b:{c:{if(g?!f|(!d|!e):1){a=ba(8)|0;v[23296]=0;b=Q(54,h|0,8118)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(b);break b}Lk(a,b,4);c=mx(a,c,d,e,f,g);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=h+16|0;return c|0}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function ZN(a,b){var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=jb-16|0;jb=e;j=e,k=ak(b),v[j>>2]=k;c=jb-16|0;jb=c;f=bz(a,c+12|0,x[b>>1],v[b+4>>2]);b=v[f>>2];if(!b){b=jb-16|0;jb=b;d=kc(a);g=th(c,xc(36),uh(b+8|0,d));d=v[g>>2]+16|0;h=v[e>>2];i=v[h+4>>2];v[d>>2]=v[h>>2];v[d+4>>2]=i;Qb(d+8|0);j=kc(g),k=1,t[j+4|0]=k;jb=b+16|0;Zg(a,v[c+12>>2],f,v[c>>2]);b=de(c);cO(c);d=1}Yg(e+8|0,v[hc(c,b)>>2],d);jb=c+16|0;a=vd(v[e+8>>2]);jb=e+16|0;return a+8|0}function Q3(a,b){a=a|0;b=b|0;var c=0,d=0;v[23296]=0;Y(900,a|0);c=v[23296];v[23296]=0;if((c|0)!=1){a=v[v[a+24>>2]+24>>2];c=0;a:{if(!es(b)){break a}d=v[a+484344>>2];if(!oe(d,v[a+484348>>2],b&65535)){break a}c=v[$b(d,b)+12>>2]}return c|0}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,6585,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function DS(a,b){var c=0,d=0,e=0,f=0;d=v[a>>2];c=wc(d,v[a+4>>2]);if(c>>>0<b>>>0){e=jb-32|0;jb=e;b=b-c|0;c=v[Gb(a)>>2];d=v[a+4>>2];a:{if(b>>>0<=c-d>>2>>>0){DA(a,b);break a}c=Gb(a);c=fg(e+8|0,Ug(a,wc(v[a>>2],d)+b|0),wc(v[a>>2],v[a+4>>2]),c);f=jb-16|0;jb=f;b=ol(f,c+8|0,b);d=v[b>>2];while(1){if(v[b+4>>2]!=(d|0)){tm(d);d=v[b>>2]+4|0;v[b>>2]=d;continue}break}Id(b);jb=f+16|0;Ad(a,c);eg(c)}jb=e+32|0;return}if(b>>>0<c>>>0){Nd(a,d+(b<<2)|0)}}function p2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-32|0;jb=e;a:{if(!c){break a}f=Fb(b);g=f-1|0;h=d<<24>>24;d=0;while(1){if((d|0)==(f|0)){break a}b:{if(!d|(d>>>0)%(c>>>0)){break b}if((d|0)==(g|0)){if(w[Oc(b,0)|0]==(lf(43)&255)){break b}if(w[Oc(b,0)|0]==(lf(45)&255)){break b}}i=e,j=Zd(b),v[i+8>>2]=j;i=e,j=Hi(e+8|0,f-d|0),v[i+16>>2]=j;hx(b,v[Gf(e+24|0,e+16|0)>>2],1,lf(h))}d=d+1|0;continue}}Sc(a,b);jb=e+32|0}function yda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;d=_c(c+8|0,16,1,1,0);v[c+4>>2]=0;pd(a,0);Ac(b);a:{b:{if(Hq(b,13604)){$c(b,12);if(!sm(b)){Ao(d,2)}$c(b,24);break b}if(Ah(b,13476)){Ac(b);v[c+4>>2]=4;e=1;break a}Fh(d,8)}e=0}f=a,g=(cf(b)>>>0)/(B(w[d|0],cq(w[d+1|0]))>>>3>>>0)|0,v[f>>2]=g;b=lg(d,a,b);if(!(!b|!e)){d=v[a+20>>2];f=c,g=uj(v[a>>2],x[a+34>>1]),v[f>>2]=g;Xb(d,0,v[Ib(c+4|0,c)>>2])}jb=c+16|0;return(b|0)!=0|0}function jG(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{if((a|0)!=(b|0)){c:{d:{f=w[a|0];if((f|0)!=45){break d}a=a+1|0;if((b|0)!=(a|0)){break d}break c}h=v[115772];v[115772]=0;Bd();a=nw(a,e+12|0,d);d=mb;g=v[115772];e:{if(g){if(v[e+12>>2]!=(b|0)){break c}if((g|0)==68|d){break e}break b}v[115772]=h;if((b|0)!=v[e+12>>2]){break c}if(!d){break b}}v[c>>2]=4;a=-1;break a}}v[c>>2]=4;a=0;break a}a=(f|0)==45?0-a|0:a}jb=e+16|0;return a}function xga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=v[a>>2];c=Df(d,v[a+4>>2]);if(c>>>0<b>>>0){d=jb-32|0;jb=d;a:{b:{c=b-c|0;b=v[Gb(a)>>2];e=v[a+4>>2];c:{if(c>>>0<=(b-e|0)/20>>>0){qC(a,c);break c}b=Gb(a);b=bB(d+8|0,cB(a,Df(v[a>>2],e)+c|0),Df(v[a>>2],v[a+4>>2]),b);v[23296]=0;R(455,b|0,c|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}aB(a,b);fu(b)}jb=d+32|0;break a}a=P()|0;O()|0;fu(b);S(a|0);L()}return}if(b>>>0<c>>>0){oC(a,d+B(b,20)|0)}}function pW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-16|0;jb=e;v[e+4>>2]=1;k=e,l=xc(32),v[k+8>>2]=l;h=jb-16|0;jb=h;f=Ko(v[e+8>>2]);v[f>>2]=42968;i=zc(f);g=vl(h+8|0,v[b>>2],v[b+4>>2]);f=v[g>>2];j=v[c>>2];d=v[d>>2];b=jb-16|0;jb=b;g=v[g+4>>2];v[b+12>>2]=g;v[b+8>>2]=f;c=Nm(i);v[c>>2]=43104;vl(c+4|0,f,g);v[c+16>>2]=d;v[c+12>>2]=j;ee(b+8|0);jb=b+16|0;jb=h+16|0;b=a;a=Mo(e);Lo(b,zc(a),a);Om(e);jb=e+16|0}function TT(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a+1064>>2];a:{while(1){if((b|0)>255){break a}f=(B(b,6)+a|0)+1072|0,g=nk(a,7),t[f|0]=g;d=nk(a,1);e=nk(a,1);c=v[a+1060>>2];if((c|0)>255){break a}b=v[a+1064>>2]+1|0;v[a+1060>>2]=b;v[a+1064>>2]=b;b:{if(d){u[(B(c,6)+a|0)+1068>>1]=b;TT(a);b=v[a+1064>>2];break b}u[(B(c,6)+a|0)+1068>>1]=65535}v[a+1060>>2]=b;if(e){u[(B(c,6)+a|0)+1070>>1]=b;continue}break}u[(B(c,6)+a|0)+1070>>1]=65535}}function Z4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23296]=0;Y(925,a|0);c=v[23296];v[23296]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+76>>2];v[23296]=0;R(e|0,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,11166,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function K4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23296]=0;Y(925,a|0);c=v[23296];v[23296]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+16>>2];v[23296]=0;R(e|0,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,12637,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function F4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23296]=0;Y(925,a|0);c=v[23296];v[23296]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+84>>2];v[23296]=0;R(e|0,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,12120,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function E4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23296]=0;Y(925,a|0);c=v[23296];v[23296]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+80>>2];v[23296]=0;R(e|0,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,11015,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function x0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=v[a+16>>2];d=v[a+12>>2];b:{if(g>>>0>d>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=g-d;v[e+4>>2]=c-f;g=d;d=v[td(e+12|0,td(e+8|0,e+4|0))>>2];b=He(b,g,d);v[a+12>>2]=v[a+12>>2]+d;b=b+d|0;break b}d=nb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}h=b,i=An(d),t[h|0]=i;d=1;b=b+1|0}f=d+f|0;continue}break}jb=e+16|0;return f|0}function iF(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=jb-16|0;jb=i;if(1073741806-b>>>0>=c>>>0){j=tc(a);k=1073741807;if(b>>>0<=536870886){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=El(v[Yc(i+12|0,i+8|0)>>2])+1|0}c=ri(k);if(e){ei(c,j,e)}if(g){ei(c+(e<<2)|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){d=e<<2;ei((d+c|0)+(g<<2)|0,(d+j|0)+(f<<2)|0,h)}if((b|0)!=1){Jb(j)}yd(a,c);Af(a,k);b=a;a=h+(e+g|0)|0;Td(b,a);yd(c+(a<<2)|0,0);jb=i+16|0;return}of();L()}function Q4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23296]=0;Y(925,a|0);c=v[23296];v[23296]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+40>>2];v[23296]=0;qa(e|0,c|0,+b);c=v[23296];v[23296]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23296]=0;X(887,11574,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23296]=0;Z(17);d=v[23296];v[23296]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function L4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23296]=0;Y(925,a|0);c=v[23296];v[23296]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+20>>2];v[23296]=0;R(e|0,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,9214,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function J4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23296]=0;Y(925,a|0);c=v[23296];v[23296]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+100>>2];v[23296]=0;d=+sa(e|0,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,11492,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function eX(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;b=Vb(c,16590);v[23296]=0;U(108,c+16|0,a|0,b|0);a=v[23296];v[23296]=0;a:{if((a|0)!=1){zb(b);a=0;b=0;while(1){d=v[c+16>>2];if(!(b>>>0<=3&wd(d,v[c+20>>2])>>>0>b>>>0)){xl(c+16|0);jb=c+32|0;return a|0}v[23296]=0;d=T(109,Hd(d,b)|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){a=(d&255)<<24-(b<<3)|a;b=b+1|0;continue}break}a=P()|0;O()|0;xl(c+16|0);break a}a=P()|0;O()|0;zb(b)}S(a|0);L()}function dL(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=jb-32|0;jb=d;v[d+16>>2]=c;v[d+24>>2]=b;i=d,j=Zd(a),v[i+8>>2]=j;c=d+24|0;b=dk(c,d+8|0);c=dk(d+16|0,c);a:{if(Fb(a)>>>0>=b>>>0){if((c|0)==-1){bL(a,b);break a}f=a;e=jb-16|0;jb=e;v[e+12>>2]=c;if(c){g=Fb(f);h=tc(f);c=g-b|0;v[e+8>>2]=c;a=v[Ib(e+12|0,e+8|0)>>2];v[e+12>>2]=a;b:{if((a|0)==(c|0)){a=c;break b}b=b+h|0;rj(b,a+b|0,c-a|0)}Ix(f,h,g-a|0)}jb=e+16|0;break a}mm();L()}jb=d+32|0}function T4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23296]=0;Y(925,a|0);c=v[23296];v[23296]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+52>>2];v[23296]=0;d=+sa(e|0,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,11555,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function O4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23296]=0;Y(925,a|0);c=v[23296];v[23296]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+32>>2];v[23296]=0;qa(e|0,c|0,+b);c=v[23296];v[23296]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23296]=0;X(887,7695,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23296]=0;Z(17);d=v[23296];v[23296]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function M4(a,b){a=a|0;b=+b;var c=0,d=0,e=0;v[23296]=0;Y(925,a|0);c=v[23296];v[23296]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+24>>2];v[23296]=0;qa(e|0,c|0,+b);c=v[23296];v[23296]=0;if((c|0)!=1){break b}}d=V(0)|0;O()|0;_(d|0)|0;v[23296]=0;X(887,7643,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23296]=0;Z(17);d=v[23296];v[23296]=0;if((d|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Hq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(!w[b+7|0]){while(1){if((d|0)==7){d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=gc(c+8|0,c+24|0,7);nc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=7){break b}if(Pb(c+24|0,b,7)){break b}ac(a,7);d=1}jb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17284,8981,413,13012);L()}aa(17263,8981,411,13012);L()}return d|0}function H4(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[23296]=0;Y(925,a|0);c=v[23296];v[23296]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];e=v[v[c>>2]+92>>2];v[23296]=0;d=+sa(e|0,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,10945,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();d=0}return+d}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function zs(a,b){var c=0,d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;c=Wd(a);d=kc(a);f=jb-16|0;jb=f;while(1){if(c){g=dt(c+16|0,b);d=g?d:c;c=v[(g?c+4|0:c)>>2];continue}break}c=v[hc(f+8|0,d)>>2];jb=f+16|0;a:{if(Rb(c,Jf(a))){if(!dt(b,vd(c))){break a}}c=Jf(a)}if(!uc(c,Jf(a))){b=v[hc(e+8|0,c)>>2];c=jb-16|0;jb=c;d=Xg(hc(c+8|0,b));if((b|0)==v[a>>2]){v[a>>2]=v[d>>2]}d=Gb(a);v[d>>2]=v[d>>2]-1;qL(v[kc(a)>>2],b);jb=c+16|0;Zl(vd(b));Jb(b)}jb=e+16|0}function nQ(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;v[b+4>>2]=((w[a+48|0]|w[a+49|0]<<8)<<1)+((w[a+32|0]|w[a+33|0]<<8)<<4);v[b+8>>2]=((w[a+50|0]|w[a+51|0]<<8)<<1)+((w[a+34|0]|w[a+35|0]<<8)<<4);v[b+12>>2]=(B(w[a+52|0]|w[a+53|0]<<8,5)+((w[a+36|0]|w[a+37|0]<<8)<<4)|0)+32;a=b+4|0;d=Db(a,3);a:{if((a|0)==(d|0)){break a}c=a;while(1){c=c+4|0;if((d|0)==(c|0)){break a}a=cp(v[a>>2],v[c>>2])?c:a;continue}}jb=b+16|0;a=v[a>>2];mb=a>>31;return a}function X4(a,b){a=a|0;b=b|0;var c=0,d=0;v[23296]=0;Y(925,a|0);c=v[23296];v[23296]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+68>>2];v[23296]=0;b=Q(d|0,c|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,6648,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function V4(a,b){a=a|0;b=b|0;var c=0,d=0;v[23296]=0;Y(925,a|0);c=v[23296];v[23296]=0;a:{b:{if((c|0)!=1){c=v[a+28>>2];d=v[v[c>>2]+60>>2];v[23296]=0;b=Q(d|0,c|0,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,6699,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();b=-1}return b|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function hx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-16|0;jb=g;v[g+8>>2]=b;j=g,k=Zd(a),v[j>>2]=k;b=dk(g+8|0,g);h=jb-16|0;jb=h;a:{f=Fb(a);if(b>>>0<=f>>>0){if(c){e=Tc(a);b:{if(e-f>>>0>=c>>>0){e=tc(a);if((b|0)==(f|0)){break b}i=b+e|0;rj(i+c|0,i,f-b|0);break b}Ql(a,e,(c+f|0)-e|0,f,b,0,c);e=v[a>>2]}qq(b+e|0,c,d);b=c+f|0;Mh(a,b);t[h+15|0]=0;sd(b+e|0,h+15|0)}jb=h+16|0;break a}mm();L()}Zd(a);jb=g+16|0}function SG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-48|0;jb=e;v[e+44>>2]=c;v[e+40>>2]=b;b=Vb(e+8|0,d);v[23296]=0;U(1056,e+24|0,e+40|0,b|0);c=v[23296];v[23296]=0;a:{b:{if((c|0)!=1){v[23296]=0;a=Q(1057,a|0,e+24|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break b}yb(e+24|0);yb(b);v[a>>2]=91052;b=v[e+44>>2];v[a+8>>2]=v[e+40>>2];v[a+12>>2]=b;jb=e+48|0;return a|0}c=P()|0;O()|0;break a}c=P()|0;O()|0;yb(e+24|0)}yb(b);S(c|0);L()}function Jaa(a,b,c){a=a|0;b=b|0;c=c|0;a:{switch(b|0){case 0:ph(a,0,c);return;case 1:ph(a,1,c);return;case 2:ph(a,2,c);return;case 3:ph(a,3,c);return;case 4:ph(a,4,c);return;case 5:ph(a,5,c);return;case 6:$N(a,23552,c);return;case 7:$N(a,24576,c);return;case 8:ph(a,6,c);return;case 9:ph(a,7,c);return;case 10:ph(a,8,c);return;case 11:ph(a,9,c);return;case 12:ph(a,10,c);return;case 13:ph(a,11,c);return;default:break a}}Kb(a)}function H5(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;if(a){a=rc(d+8|0,a);e=v[a+4>>2];f=v[a>>2];b=jb-16|0;jb=b;a=0;a:{if(!e){break a}a=32048;while(1){if((a|0)==32624){c=32624;while(1){a=c;if((a|0)!=32672){c=a+12|0;if(!TL(f,e,v[rc(b,v[a+8>>2])>>2],v[b+4>>2])){continue}}break}a=(a|0)!=32672;break a}c=v[a+8>>2];a=a+12|0;if(!TL(f,e,v[rc(b+8|0,c)>>2],v[b+12>>2])){continue}break}a=1}jb=b+16|0}else{a=0}jb=d+16|0;return a|0}function kg(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;u[d+12>>1]=65535;u[d+14>>1]=b;f=d+12|0;b=x[Zc(42956,d+14|0)>>1];e=v[a>>2];c=Nc(e,v[a+4>>2]);a:{if(b>>>0>c>>>0){e=jb-32|0;jb=e;b=b-c|0;c=v[Gb(a)>>2];g=v[a+4>>2];b:{if(b>>>0<=c-g>>1>>>0){xo(a,b,f);break b}c=Gb(a);c=xj(e+8|0,yj(a,Nc(v[a>>2],g)+b|0),Nc(v[a>>2],v[a+4>>2]),c);DC(c,b,f);Ad(a,c);Gi(c)}jb=e+32|0;break a}if(b>>>0<c>>>0){Nd(a,e+(b<<1)|0)}}jb=d+16|0}function e7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=li(a,b,c,d);v[a>>2]=45136;c=Qb(a+4256|0);b=a+4208|0;e=Db(b,0),f=1056964608,v[e>>2]=f;e=Db(b,1),f=1017370378,v[e>>2]=f;e=Db(b,2),f=1028670828,v[e>>2]=f;e=Db(b,3),f=1059760811,v[e>>2]=f;e=Db(b,4),f=1017370378,v[e>>2]=f;e=Db(b,5),f=1065353216,v[e>>2]=f;v[23296]=0;R(851,a+44|0,2);b=v[23296];v[23296]=0;if((b|0)!=1){ki(a);return a|0}b=P()|0;O()|0;vc(c);uf(a);S(b|0);L()}function YR(a,b,c,d,e){var f=0,g=0,h=0,i=0;h=-1;f=d&2147483647;i=f;g=(f|0)==2147418112;a:{if(g&!c?a|b:g&(c|0)!=0|f>>>0>2147418112){break a}f=e&2147483647;g=(f|0)==2147418112;if(g?0:g&0|f>>>0>2147418112){break a}if(!(a|c|(f|i|b))){return 0}f=d&e;if((f|0)>0|(f|0)>=0){if(!c&(d|0)==(e|0)?0:(d|0)<(e|0)){break a}return(a|c|(d^e|b))!=0}if(!c&(d|0)==(e|0)?a|b:(c|0)!=0&(d|0)>=(e|0)|(d|0)>(e|0)){break a}h=(a|c|(d^e|b))!=0}return h}function pZ(a){a=a|0;if(w[467248]){return v[116811]}if(!w[467768]){a=467600;while(1){a=Kb(a)+12|0;if((a|0)!=467768){continue}break}t[467768]=1}nd(467600,87732);nd(467612,87760);nd(467624,87788);nd(467636,87820);nd(467648,87860);nd(467660,87896);nd(467672,87924);nd(467684,87960);nd(467696,87976);nd(467708,87992);nd(467720,88008);nd(467732,88024);nd(467744,88040);nd(467756,88056);t[467248]=1;v[116811]=467600;return 467600}function _2(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;b=jb-32|0;jb=b;v[b+24>>2]=e;v[b+28>>2]=f;a:{e=a;a=gc(b+16|0,c,d);a=Os(e,v[a>>2],v[a+4>>2],b+24|0);if(a+1>>>0>=3){a=ba(8)|0;v[23296]=0;b=Q(54,b|0,7975)|0;c=v[23296];v[23296]=0;b:{if((c|0)!=1){a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}jb=b+32|0;return a|0}L()}function QE(a,b,c,d,e,f,g,h,i){var j=0;v[23296]=0;Y(900,a|0);j=v[23296];v[23296]=0;a:{b:{if((j|0)!=1){j=v[a+24>>2];v[23296]=0;b=ua(i|0,j|0,b|0,c|0,d|0,e|0,f|0,g|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,h|0,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Aea(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;t[b+15|0]=128;a=um(a,127,b+15|0);v[23296]=0;t[b+14|0]=64;d=W(528,a+12|0,127,b+14|0)|0;c=v[23296];v[23296]=0;a:{b:{if((c|0)!=1){v[23296]=0;t[b+13|0]=0;Q(603,a+24|0,b+13|0)|0;c=v[23296];v[23296]=0;if((c|0)==1){break b}v[a+36>>2]=-1;v[a+40>>2]=108855296;v[a+44>>2]=0;v[a+48>>2]=0;u[a+52>>1]=0;jb=b+16|0;return a|0}b=P()|0;O()|0;break a}b=P()|0;O()|0;fc(d)}fc(a);S(b|0);L()}function SH(a){var b=0,c=C(0),d=C(0),e=C(0),f=C(0),g=C(0),h=C(0),i=0,j=0,k=0,l=C(0),m=C(0),n=C(0),o=C(0),p=0;c=z[a>>2];i=a-16|0;d=z[i>>2];e=C(c+d);b=a-8|0;f=z[b>>2];j=a-24|0;g=z[j>>2];h=C(f+g);z[a>>2]=e+h;z[b>>2]=e-h;b=a-12|0;h=z[b>>2];k=a-28|0;l=z[k>>2];e=C(h+l);p=b;b=a-4|0;m=z[b>>2];a=a-20|0;n=z[a>>2];o=C(m+n);z[p>>2]=o-e;f=C(f-g);g=C(m-n);z[k>>2]=f+g;c=C(c-d);d=C(h-l);z[i>>2]=c+d;z[j>>2]=c-d;z[b>>2]=e+o;z[a>>2]=g-f}function vx(a,b,c,d,e){var f=0,g=0;a:{if(!es(b)){break a}f=v[a+484344>>2];if(!oe(f,v[a+484348>>2],b&65535)){break a}b=$b(f,b);if(v[b+12>>2]<=(c|0)|e>>>0>5|x[a+480188>>1]<=d>>>0|(c|d)<0){break a}b=fd(v[b>>2],v[v[b+48>>2]+12>>2],c,d&65535);b:{c:{switch(e|0){case 1:b=b+1|0;break b;case 2:b=b+2|0;break b;case 3:b=b+3|0;break b;case 4:b=b+4|0;break b;case 0:break b;case 5:break c;default:break a}}b=b+5|0}g=w[b|0]}return g}function a3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[23296]=0;Y(900,a|0);d=v[23296];v[23296]=0;e=1;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[23296]=0;U(994,d|0,b|0,c|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,10213,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();e=0}return e|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Ge(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;g=Ig(a);a:{b:{if(!b){i=e,j=Ig(a),v[i+8>>2]=j;v[e+12>>2]=0;break b}f=v[b+4>>2];h=v[b>>2];v[e+8>>2]=h;v[e+12>>2]=f;a=v[a+12>>2];v[e>>2]=2048;v[e+4>>2]=0;b=a+c|0;d=a>>>0>b>>>0?d+1|0:d;a=Oq(e+8|0,e);c=v[a>>2];a=v[a+4>>2];if(!a&c>>>0>g>>>0|a){a=-1;if(!d&b>>>0<=g>>>0){break b}break a}a=0;if((d|0)==(f|0)&b>>>0>h>>>0|d>>>0>f>>>0){break a}}a=1}jb=e+16|0;return a}function j0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+12>>2];f=v[a+16>>2];b:{if(d>>>0<f>>>0){v[e+12>>2]=2147483647;v[e+8>>2]=f-d>>2;v[e+4>>2]=c-g;f=d;d=v[td(e+12|0,td(e+8|0,e+4|0))>>2];ei(b,f,d);f=d<<2;v[a+12>>2]=f+v[a+12>>2];b=b+f|0;break b}d=nb[v[v[a>>2]+40>>2]](a)|0;if((d|0)==-1){break a}v[b>>2]=d;d=1;b=b+4|0}g=d+g|0;continue}break}jb=e+16|0;return g|0}function mV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+12>>2]=-1;if(og(a,d+8|0)){v[d+4>>2]=w[d+8|0];f=v[Ib(d+4|0,d+12|0)>>2];c=jb+-64|0;jb=c;e=c+40|0;Cf(e,a,f);g=v[c+40>>2];a=c+8|0;Rf(a,3,ye(e),g);v[23296]=0;R(210,c+24|0,a|0);a=v[23296];v[23296]=0;a:{if((a|0)!=1){gc(c,b,11);a=c+24|0;nl(c,a);yb(a);Pc(c+40|0);jb=c- -64|0;e=!f|(g|0)!=0;break a}a=P()|0;O()|0;Pc(c+40|0);S(a|0);L()}}jb=d+16|0;return e|0}function iha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=ck(e,v[a+4>>2]);if(d>>>0<b>>>0){e=jb-32|0;jb=e;d=b-d|0;b=v[Gb(a)>>2];f=v[a+4>>2];a:{if(d>>>0<=(b-f|0)/6>>>0){MA(a,d,c);break a}b=Gb(a);b=QS(e+8|0,IA(a,ck(v[a>>2],f)+d|0),ck(v[a>>2],v[a+4>>2]),b);PS(b,d,c);c=b+4|0;NS(v[a>>2],v[a+4>>2],c);oc(a,c);oc(a+4|0,b+8|0);oc(Gb(a),zc(b));v[b>>2]=v[b+4>>2];OS(b)}jb=e+32|0;return}if(b>>>0<d>>>0){Nd(a,e+B(b,6)|0)}}function iO(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-32|0;jb=d;v[a+4>>2]=0;a:{if(b){b:{if(rt(a)>>>0>=b>>>0){v[a+4>>2]=b;break b}e=bo(d+16|0);v[23296]=0;f=Q(679,a|0,b|0)|0;g=v[23296];v[23296]=0;if((g|0)==1){break a}v[23296]=0;R(680,e|0,f|0);f=v[23296];v[23296]=0;if((f|0)==1){break a}v[e+4>>2]=b;xt(a,e);Le(e)}$k(d+8|0,v[a>>2]);bv(v[d+8>>2],v[d+12>>2],b,w[c|0])}jb=d+32|0;return}a=P()|0;O()|0;Le(e);S(a|0);L()}function FE(a,b,c,d,e,f){var g=0,h=0;g=jb-256|0;jb=g;v[g+248>>2]=37;v[g+252>>2]=0;h=g+248|0;Br(h|1,10479,f,v[b+4>>2]);f=Bd();v[g>>2]=d;v[g+4>>2]=e;d=g+224|0;e=Lg(d,24,f,h,g)+d|0;f=Ti(d,e,b);h=g+16|0;bd(h,b);v[23296]=0;ia(1101,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=v[23296];v[23296]=0;a:{if((d|0)!=1){_b(g+16|0);a=zr(a,g+32|0,v[g+28>>2],v[g+24>>2],b,c);jb=g+256|0;break a}a=P()|0;O()|0;_b(g+16|0);S(a|0);L()}return a}function CX(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;v[23296]=0;a=Ka(997,a|0,b|0,c|0,d|0)|0;b=v[23296];v[23296]=0;a:{b:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23296]=0;ia(883,11038,e|0,f|0,g|0,h|0,i|0,j|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}$();a=-255}break a}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}return a|0}function BI(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;g=jb-16|0;jb=g;v[g+8>>2]=b;j=g,k=Ii(a),v[j>>2]=k;b=dk(g+8|0,g);h=jb-16|0;jb=h;a:{f=Cd(v[a+4>>2],w[a+11|0]);if(b>>>0<=f>>>0){if(c){e=lm(a);b:{if(e-f>>>0>=c>>>0){e=rd(a);if((b|0)==(f|0)){break b}i=b+e|0;rj(i+c|0,i,f-b|0);break b}ry(a,e,(c+f|0)-e|0,f,b,c);e=v[a>>2]}qq(b+e|0,c,d);b=c+f|0;au(a,b);t[h+15|0]=0;sd(b+e|0,h+15|0)}jb=h+16|0;break a}mm();L()}Ii(a);jb=g+16|0}function e3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;v[23296]=0;Y(900,a|0);d=v[23296];v[23296]=0;a:{b:{if((d|0)!=1){d=v[a+24>>2];v[23296]=0;e=+ya(990,d|0,b|0,c|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,5311,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();e=0}return+e}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function R4(a){a=a|0;var b=0,c=0,d=0;v[23296]=0;Y(925,a|0);b=v[23296];v[23296]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+44>>2];v[23296]=0;c=+na(d|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,11592,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function HE(a,b,c,d,e,f){var g=0,h=0;g=jb-112|0;jb=g;v[g+104>>2]=37;v[g+108>>2]=0;h=g+104|0;Br(h|1,10479,f,v[b+4>>2]);f=Bd();v[g>>2]=d;v[g+4>>2]=e;d=g+80|0;e=Lg(d,24,f,h,g)+d|0;f=Ti(d,e,b);h=g+16|0;bd(h,b);v[23296]=0;ia(1098,d|0,f|0,e|0,g+32|0,g+28|0,g+24|0,h|0);d=v[23296];v[23296]=0;a:{if((d|0)!=1){_b(g+16|0);a=Jq(a,g+32|0,v[g+28>>2],v[g+24>>2],b,c);jb=g+112|0;break a}a=P()|0;O()|0;_b(g+16|0);S(a|0);L()}return a}function RH(a,b){var c=0,d=0,e=0;if(!w[b+21|0]){bc(a,21);return-1}if(v[a+1396>>2]<=9){Gk(a)}d=v[a+1392>>2];c=u[(((d&1023)<<1)+b|0)+36>>1];a:{if((c|0)>=0){e=d;d=c&65535;c=w[d+v[b+8>>2]|0];v[a+1392>>2]=e>>>c;c=v[a+1396>>2]-c|0;v[a+1396>>2]=(c|0)>0?c:0;c=(c|0)>=0?d:-1;break a}c=Jl(a,b)}if(!((c|0)>=v[b+2092>>2]?w[b+23|0]:0)){if(!(!(v[a+1384>>2]?w[a+1376|0]:1)|(c|0)>=0)){bc(a,21)}return c}aa(7484,13048,1793,5711);L()}function P4(a){a=a|0;var b=0,c=0,d=0;v[23296]=0;Y(925,a|0);b=v[23296];v[23296]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+36>>2];v[23296]=0;c=+na(d|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,7712,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function N4(a){a=a|0;var b=0,c=0,d=0;v[23296]=0;Y(925,a|0);b=v[23296];v[23296]=0;a:{b:{if((b|0)!=1){b=v[a+28>>2];d=v[v[b>>2]+28>>2];v[23296]=0;c=+na(d|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,7660,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function w3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[23296]=0;b=Q(54,f|0,8118)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}e=P()|0;O()|0;yb(b);break b}Lk(a,b,2);c=kx(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=f+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function i3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!(e?d:0)){a=ba(8)|0;v[23296]=0;b=Q(54,f|0,8118)|0;c=v[23296];v[23296]=0;if((c|0)==1){break c}a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}e=P()|0;O()|0;yb(b);break b}Lk(a,b,2);c=mx(a,c,d,e,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=f+16|0;return c|0}e=P()|0;O()|0;ca(a|0)}S(e|0)}L()}function f5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;v[e+24>>2]=c;c=v[Tf(e+16|0,e+24|0)>>2];v[23296]=0;f=v[b+12>>2];v[e+8>>2]=v[b+8>>2];v[e+12>>2]=f;f=v[b+4>>2];v[e>>2]=v[b>>2];v[e+4>>2]=f;fa(894,a+8|0,e|0,c|0,d|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){a=FI(a);b=EI(a+88|0);c=DI(a+92|0);v[a>>2]=61368;v[b>>2]=61480;v[c>>2]=61560;te(e+24|0);jb=e+32|0;return a|0}a=P()|0;O()|0;te(e+24|0);S(a|0);L()}function Xw(a){var b=0,c=0,d=0;a:{b:{if(!v[a+1384>>2]){b=v[a+1380>>2];if((b|0)==-1){v[a+1388>>2]=v[a+1116>>2]-1;if(!as(a)){v[a+1384>>2]=1;return 0}if(!(t[a+1375|0]&1)){break b}b=v[a+1380>>2]}d=b+1|0;v[a+1380>>2]=d;c=w[(a+b|0)+1120|0];if((c|0)!=255){v[a+1388>>2]=b;v[a+1384>>2]=1}if(v[a+1116>>2]<=(d|0)){v[a+1380>>2]=-1}if(w[a+1376|0]){break a}t[a+1376|0]=c}return c}bc(a,32);return 0}aa(15575,13048,1564,5997);L()}function C8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;c=gf(a,c);ae(f,v[a+28>>2]);a:{b:{if(!c){d=-1;if(!hd(a,5)){break b}break a}d=v[c+8>>2]}g=v[a+28>>2];c:{if(!((d|0)!=4&(d|0)!=-1)){d=jb-16|0;jb=d;v[d+8>>2]=0;qp(g,d+8|0);z[b>>2]=z[d+8>>2];jb=d+16|0;break c}e=jb-32|0;jb=e;v[e+28>>2]=0;v[e+24>>2]=d;v[e+20>>2]=4;Cr(e+8|0,g,e+28|0,v[Ib(e+24|0,e+20|0)>>2]);v[b>>2]=0;jb=e+32|0}e=c}$e(a,e);jb=f+16|0}function bZ(a){a=a|0;if(w[467240]){return v[116809]}if(!w[467592]){a=467424;while(1){a=Kb(a)+12|0;if((a|0)!=467592){continue}break}t[467592]=1}jd(467424,5201);jd(467436,5208);jd(467448,5174);jd(467460,5182);jd(467472,5165);jd(467484,5215);jd(467496,5192);jd(467508,9650);jd(467520,9856);jd(467532,11152);jd(467544,12720);jd(467556,5464);jd(467568,10656);jd(467580,6548);t[467240]=1;v[116809]=467424;return 467424}function a2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-16|0;jb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;VI(a,c);a:{if(z[a+24>>2]==C(1)){break a}d=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;j=v[a+16>>2];k=v[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=Kh(k,j,b,i);z[f>>2]=z[a+24>>2]*z[f>>2];b=b+1|0;continue}}}jb=c+16|0}function pI(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((Eg(a)|0)>(b|0)){break d}}b=ba(8)|0;v[23296]=0;c=Q(54,c|0,10598)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}a=sc(b,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}jb=c+16|0;return(v[(a+B(b,872)|0)+1075080>>2]&134218752)!=0|0}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function W1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-32|0;jb=e;v[e+24>>2]=c;v[e+28>>2]=d;a:{a=gc(e+16|0,a,b);a=Os(3,v[a>>2],v[a+4>>2],e+24|0);if(a+1>>>0>=3){b=ba(8)|0;v[23296]=0;c=Q(54,e|0,7975)|0;a=v[23296];v[23296]=0;b:{if((a|0)!=1){a=sc(b,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=P()|0;O()|0;ca(b|0)}S(a|0);L()}jb=e+32|0;return a|0}L()}function PE(a,b,c,d,e,f,g){var h=0;v[23296]=0;Y(900,a|0);h=v[23296];v[23296]=0;a:{b:{if((h|0)!=1){h=v[a+24>>2];v[23296]=0;b=ja(g|0,h|0,b|0,c|0,d|0,e|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,f|0,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function maa(a){a=a|0;var b=0;a=Kb(a);v[23296]=0;R(45,a|0,4);b=v[23296];v[23296]=0;a:{b:{if((b|0)==1){break b}v[23296]=0;R(46,a|0,32);b=v[23296];v[23296]=0;if((b|0)==1){break b}v[23296]=0;R(46,a|0,10);b=v[23296];v[23296]=0;if((b|0)==1){break b}v[23296]=0;R(46,a|0,13);b=v[23296];v[23296]=0;if((b|0)==1){break b}v[23296]=0;R(46,a|0,9);b=v[23296];v[23296]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;yb(a);S(b|0);L()}}function gu(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;f=Lb(a,0);e=(w[f|0]&15)<<8|w[Lb(a,1)|0];c=0;a:{if(!e|(e|0)==4095){break a}while(1){c=108;if((d|0)==84){break a}b:{c=x[(d<<1)+32672>>1];if(c>>>0<=e>>>0){if(!d|(e|0)==(c|0)|(x[(d<<1)+32670>>1]-e|0)>=(e-c|0)){break b}c=d+24|0;break a}d=d+1|0;continue}break}c=d+25|0}t[b|0]=c;e=w[f|0]&16;d=Lb(a,2);t[b+1|0]=e|w[d|0]>>>4;t[b+3|0]=w[d|0]&15;g=b,h=w[Lb(a,3)|0],t[g+5|0]=h}function MW(a){a=a|0;var b=0;a=Kb(a);v[23296]=0;R(72,a|0,4);b=v[23296];v[23296]=0;a:{b:{if((b|0)==1){break b}v[23296]=0;R(50,a|0,32);b=v[23296];v[23296]=0;if((b|0)==1){break b}v[23296]=0;R(50,a|0,10);b=v[23296];v[23296]=0;if((b|0)==1){break b}v[23296]=0;R(50,a|0,13);b=v[23296];v[23296]=0;if((b|0)==1){break b}v[23296]=0;R(50,a|0,9);b=v[23296];v[23296]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;zb(a);S(b|0);L()}}function AB(a){a=a|0;var b=0,c=0,d=0;b=v[a>>2];if(b){nb[v[v[b>>2]+8>>2]](b);v[a>>2]=0}a=a+4|0;Hc(a);b=jb-32|0;jb=b;a:{b:{d=$o(a);c=ad(v[a>>2],v[a+4>>2]);c:{if(d>>>0<=c>>>0){break c}v[23296]=0;c=fa(860,b+8|0,c|0,c|0,Gb(a)|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){Ad(a,c);Al(c);break c}a=V(0)|0;O()|0;_(a|0)|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)==1){break b}}jb=b+32|0;break a}V(0)|0;O()|0;Ub();L()}}function h3(a,b){a=a|0;b=b|0;var c=0,d=0;v[23296]=0;Y(900,a|0);c=v[23296];v[23296]=0;d=1;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23296]=0;R(989,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,10759,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();d=0}return d|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function GE(a,b,c,d,e){var f=0,g=0,h=0;f=jb-160|0;jb=f;v[f+152>>2]=37;v[f+156>>2]=0;g=f+152|0;Br(g|1,10646,e,v[b+4>>2]);e=Bd();v[f>>2]=d;d=f+139|0;e=Lg(d,13,e,g,f)+d|0;g=Ti(d,e,b);h=f+16|0;bd(h,b);v[23296]=0;ia(1101,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=v[23296];v[23296]=0;a:{if((d|0)!=1){_b(f+16|0);a=zr(a,f+32|0,v[f+28>>2],v[f+24>>2],b,c);jb=f+160|0;break a}a=P()|0;O()|0;_b(f+16|0);S(a|0);L()}return a}function DO(a,b,c){a:{switch(b|0){case 0:qh(a,0,c);return;case 1:qh(a,1,c);return;case 2:qh(a,2,c);return;case 3:qh(a,3,c);return;case 4:qh(a,4,c);return;case 5:qh(a,5,c);return;case 6:kO(a,23552,c);return;case 7:kO(a,24576,c);return;case 8:qh(a,6,c);return;case 9:qh(a,7,c);return;case 10:qh(a,8,c);return;case 11:qh(a,9,c);return;case 12:qh(a,10,c);return;case 13:qh(a,11,c);return;default:break a}}Kb(a)}function sI(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{d:{if((b|0)>=0){a=v[a+32>>2];if((Eg(a)|0)>(b|0)){break d}}b=ba(8)|0;v[23296]=0;c=Q(54,c|0,10598)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}a=sc(b,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}jb=c+16|0;return+(+v[(a+B(b,872)|0)+1075740>>2]*.015625)}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function Zo(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=jb-16|0;jb=i;if(-18-b>>>0>=c>>>0){j=tc(a);k=-17;if(b>>>0<=2147483622){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=zi(v[Yc(i+12|0,i+8|0)>>2])+1|0}c=xc(k);if(e){He(c,j,e)}if(g){He(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){He((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){Jb(j)}yd(a,c);Af(a,k);b=a;a=h+(e+g|0)|0;Td(b,a);t[i+7|0]=0;sd(a+c|0,i+7|0);jb=i+16|0;return}of();L()}function Ut(a,b,c,d,e,f,g,h){var i=0,j=0,k=0,l=0;i=jb-16|0;jb=i;if(-18-b>>>0>=c>>>0){j=rd(a);k=-17;if(b>>>0<=2147483622){v[i+8>>2]=b<<1;v[i+12>>2]=b+c;k=zi(v[Yc(i+12|0,i+8|0)>>2])+1|0}c=xc(k);if(e){He(c,j,e)}if(g){He(c+e|0,h,g)}l=e+f|0;h=d-l|0;if((d|0)!=(l|0)){He((c+e|0)+g|0,(e+j|0)+f|0,h)}if((b|0)!=10){Jb(j)}yd(a,c);Af(a,k);b=a;a=h+(e+g|0)|0;Td(b,a);t[i+7|0]=0;sd(a+c|0,i+7|0);jb=i+16|0;return}of();L()}function qy(a,b){a=a|0;b=b|0;var c=C(0),d=0,e=0,f=0;t[a+1074368|0]=b;rM(a+1074332|0,b);f=a+946300|0;a=a+906300|0;while(1){if((a|0)!=(f|0)){b=v[a>>2];if(b){c=C(1);d=v[b+20>>2];if(d){c=C(C(w[d+26|0])*C(.10000000149011612))}c=c<C(.10000000149011612)?C(1):c;if(nb[v[v[b>>2]+136>>2]](b)|0){d=v[b+16>>2];e=d+1074332|0;c=C(C(c/z[e+8>>2])*C(C(y[d+480232>>2])/z[e+20>>2]))}z[b+4196>>2]=c}a=a+160|0;continue}break}}function c5(a){a=a|0;var b=0;v[23296]=0;Y(925,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){v[a+24>>2]=0;b=v[a+28>>2];if(b){nb[v[v[b>>2]+4>>2]](b)}v[a+28>>2]=0;b=v[a+20>>2];if(b){Jb(b);v[a+20>>2]=0}Jb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,5012,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Ym(a,b,c,d,e,f){var g=0;v[23296]=0;Y(900,a|0);g=v[23296];v[23296]=0;a:{b:{if((g|0)!=1){g=v[a+24>>2];v[23296]=0;b=fa(f|0,g|0,b|0,c|0,d|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,e|0,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();b=0}return b}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function v0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;while(1){a:{if((c|0)<=(f|0)){break a}g=v[a+28>>2];d=v[a+24>>2];if(g>>>0<=d>>>0){if(((i=a,j=Lf(t[b|0]),h=v[v[a>>2]+52>>2],nb[h](i|0,j|0)|0)|0)==-1){break a}f=f+1|0;b=b+1|0}else{v[e+12>>2]=g-d;v[e+8>>2]=c-f;g=d;d=v[td(e+12|0,e+8|0)>>2];He(g,b,d);v[a+24>>2]=d+v[a+24>>2];f=f+d|0;b=b+d|0}continue}break}jb=e+16|0;return f|0}function Vca(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{c=v[b+4>>2];if(!c){break a}f=a+480190|0;u[d>>1]=x[f>>1];u[d+14>>1]=c-1;c=x[Zc(d,d+14|0)>>1];while(1){if(!c){break a}Bb(d,v[b>>2],c);b:{if(Cb(v[v[d>>2]>>2],v[d+4>>2])){break b}if(eM(a,c&65535)){e=Vb(d,21473);Ec(((c<<5)+a|0)+946304|0,e);yb(e)}if(c>>>0<2){break b}e=x[f>>1];if((e|0)!=(c|0)){break b}u[f>>1]=e-1}c=c-1|0;continue}}jb=d+16|0}function F1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb-32|0;jb=e;a:{if(w[b+8|0]){f=v[b+12>>2];h=e,i=ad(f,v[b+16>>2])-c|0,v[h+28>>2]=i;v[e+24>>2]=v[d+4>>2];g=v[Ib(e+28|0,e+24|0)>>2];f=$g(Eb(f),c);c=$g($g(Eb(v[b+12>>2]),c),g);b=v[d>>2];ch(f,c,b);ic(a,b,g);break a}g=v[d+4>>2];d=v[d>>2];v[e+16>>2]=d;v[e+20>>2]=g;f=v[v[b>>2]+40>>2];v[e+8>>2]=d;v[e+12>>2]=g;nb[f|0](a,b,c,e+8|0)}jb=e+32|0}function Qe(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;o(+a);d=j(1)|0;j(0)|0;d=d&2147483647;a:{if(d>>>0<=1072243195){c=1;if(d>>>0<1044816030){break a}c=Xo(a,0);break a}c=a-a;if(d>>>0>=2146435072){break a}b:{switch(dF(a,b)&3){case 0:c=Xo(A[b>>3],A[b+8>>3]);break a;case 1:c=-Yo(A[b>>3],A[b+8>>3],1);break a;case 2:c=-Xo(A[b>>3],A[b+8>>3]);break a;default:break b}}c=Yo(A[b>>3],A[b+8>>3],1)}a=c;jb=b+16|0;return a}function IE(a,b,c,d,e){var f=0,g=0,h=0;f=jb-80|0;jb=f;v[f+72>>2]=37;v[f+76>>2]=0;g=f+72|0;Br(g|1,10646,e,v[b+4>>2]);e=Bd();v[f>>2]=d;d=f+59|0;e=Lg(d,13,e,g,f)+d|0;g=Ti(d,e,b);h=f+16|0;bd(h,b);v[23296]=0;ia(1098,d|0,g|0,e|0,f+32|0,f+28|0,f+24|0,h|0);d=v[23296];v[23296]=0;a:{if((d|0)!=1){_b(f+16|0);a=Jq(a,f+32|0,v[f+28>>2],v[f+24>>2],b,c);jb=f+80|0;break a}a=P()|0;O()|0;_b(f+16|0);S(a|0);L()}return a}function m3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[23296]=0;c=Q(54,e|0,8118)|0;b=v[23296];v[23296]=0;if((b|0)==1){break c}a=sc(a,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}Lk(a,b,1);c=mx(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function I_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-208|0;jb=a;f=Bd();v[a>>2]=e;g=a+176|0;i=Lg(g,20,f,9164,a);e=i+g|0;g=Ti(g,e,c);f=a+8|0;bd(f,c);v[23296]=0;f=T(1084,f|0)|0;h=v[23296];v[23296]=0;if((h|0)!=1){_b(a+8|0);h=f;f=a+16|0;cG(h,a+176|0,e,f);h=b;b=f+(i<<2)|0;b=zr(h,f,(e|0)==(g|0)?b:((g-a<<2)+a|0)-688|0,b,c,d);jb=a+208|0;return b|0}b=P()|0;O()|0;_b(a+8|0);S(b|0);L()}function A3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a:{b:{c:{if(!d){a=ba(8)|0;v[23296]=0;c=Q(54,e|0,8118)|0;b=v[23296];v[23296]=0;if((b|0)==1){break c}a=sc(a,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}Lk(a,b,1);c=kx(a,c,d,0,0,0);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=e+16|0;return c|0}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function Gs(a){var b=0,c=0,d=0;b=w[a+4266|0];z[a+4236>>2]=C(b>>>0)*C(.00390625);v[a+4228>>2]=(B(v[a+4232>>2],w[a+4264|0])+250>>>0)/500;z[a+4240>>2]=C(256-b|0)*C(.00390625);c=w[a+4267|0];b=w[a+4265|0];z[a+4244>>2]=C(B(c,b)|0)*C(152587890625e-16);d=c|-256;z[a+4256>>2]=C(B(d,b|-256)|0)*C(152587890625e-16);z[a+4252>>2]=C(B(b,d)|0)*C(152587890625e-16);z[a+4248>>2]=C(B(256-b|0,c)|0)*C(152587890625e-16)}function kt(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[b+40>>2]=0;v[b+44>>2]=0;f=b- -64|0;v[f>>2]=0;v[f+4>>2]=0;v[b+56>>2]=0;v[b+60>>2]=0;v[b+48>>2]=0;v[b+52>>2]=0;while(1){if((d|0)==1e4){a:{d=Eb(v[c>>2]);v[e+8>>2]=d;f=Eb(v[c+4>>2]);while(1){if(!Rb(d,f)){break a}g=d,h=nO(b,A[d>>3]),A[g>>3]=h;d=v[it(e+8|0)>>2];continue}}}else{nO(b,A[Re(v[c>>2],0)>>3]);d=d+1|0;continue}break}_j(a,c);jb=e+16|0}function iC(a,b){var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(!w[b+7|0]){while(1){if((d|0)==7){d=0;t[c+27|0]=0;t[c+28|0]=0;t[c+29|0]=0;t[c+30|0]=0;v[c+24>>2]=0;e=gc(c+8|0,c+24|0,7);md(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=7){break b}if(Pb(c+24|0,b,7)){break b}dd(a,7);d=1}jb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17284,8981,413,13012);L()}aa(17263,8981,411,13012);L()}return d}function c3(a,b){a=a|0;b=+b;var c=0;v[23296]=0;Y(900,a|0);c=v[23296];v[23296]=0;a:{b:{if((c|0)!=1){c=v[a+24>>2];v[23296]=0;b=+Ya(991,c|0,+b);c=v[23296];v[23296]=0;if((c|0)!=1){break b}}c=V(0)|0;O()|0;_(c|0)|0;v[23296]=0;X(887,7524,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();b=0}return+b}a=P()|0;O()|0;v[23296]=0;Z(17);c=v[23296];v[23296]=0;if((c|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function gI(a,b,c){a=a|0;b=b|0;c=+c;var d=0,e=0,f=0;d=jb-16|0;jb=d;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23296]=0;d=Q(54,d|0,10598)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}a=sc(b,d);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(d);break b}e=(v[a+32>>2]+B(b,872)|0)+1075766|0,f=Jz(c*32768),u[e>>1]=f;jb=d+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function Pea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;b=-1;a:{if(!Vf(a,8)){break a}b=jb-32|0;jb=b;v[b+24>>2]=0;v[b+28>>2]=0;d=gc(b+8|0,b+24|0,8);md(b+16|0,a,v[d>>2],v[d+4>>2]);b:{if(v[b+20>>2]!=8){break b}if(Pb(b+24|0,13979,8)){break b}dd(a,8);e=1}jb=b+32|0;b=0;if(!e){break a}b=-1;if(!Aj(a,c+8|0)){break a}b=0;if(!cc(v[c+12>>2])){break a}b=!(cc(v[c+8>>2])&-2139062144)}jb=c+16|0;return b|0}function oo(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+12>>2]=c;a:{if(!Ob(v[b>>2],v[b+8>>2],c)){break a}yc(f+12|0,65535);kg(a,x[f+12>>1]);c=Eb(v[a>>2]);v[f>>2]=c;h=Eb(v[a+4>>2]);while(1){if(!Rb(c,h)){break a}a=f+11|0;if(!og(b,a)){vg(a)}a=w[f+11|0];u[c>>1]=a;g=65535;b:{if((a|0)!=(d|0)){g=65534;if((a|0)!=(e|0)){break b}}u[c>>1]=g}c=v[Se(f)>>2];continue}}jb=f+16|0}function mr(a){var b=0,c=0;Rm(a,1,15270);v[23296]=0;b=ga(114)|0;c=v[23296];v[23296]=0;a:{if((c|0)==1){break a}v[a+12>>2]=b;v[23296]=0;b=ga(115)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}t[a+16|0]=b;v[23296]=0;b=ga(116)|0;c=v[23296];v[23296]=0;if((c|0)==1){break a}t[a+18|0]=0;t[a+17|0]=b;v[23296]=0;Y(117,a+20|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}return}b=P()|0;O()|0;zb(a);S(b|0);L()}function f9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-32|0;jb=d;Ze(d,2,a+6|0);e=d+16|0;Gc(e,d);Ec(b+492|0,e);f=b+236|0;g=c+1|0;yb(e);c=0;while(1){if((c|0)==128){v[b>>2]=(w[a+226|0]|w[a+227|0]<<8)<<5;Wx(a+180|0,b+48|0,0);Wx(a+228|0,b+88|0,2);Wx(a+276|0,b+68|0,1);if(!(w[a+324|0]|w[a+325|0]<<8)){Ez(f)}jb=d+32|0}else{h=dc(f,c),i=w[(a+c|0)+38|0]+g|0,u[h>>1]=i;c=c+1|0;continue}break}}function $ca(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=jb-16|0;jb=c;a=Bz(c,a);vP(v[a+4>>2],w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));v[a+4>>2]=v[a+4>>2]+4;lc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Gb(a);c=fg(d+8|0,Ug(a,wc(v[a>>2],v[a+4>>2])+1|0),wc(v[a>>2],v[a+4>>2]),c);vP(v[c+8>>2],w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24));v[c+8>>2]=v[c+8>>2]+4;Ad(a,c);eg(c);jb=d+32|0}function zM(a,b){var c=0,d=0,e=0,f=0;c=v[a>>2];v[a>>2]=b;if(c){d=jb-16|0;jb=d;b=Eb(v[c>>2]);v[d+8>>2]=b;f=Eb(v[c+4>>2]);while(1){a:{b:{if(Rb(b,f)){while(1){a=v[b>>2];e=v[a>>2];if(!e){break b}a=v[v[e>>2]+8>>2];v[23296]=0;Y(a|0,e|0);a=v[23296];v[23296]=0;if((a|0)!=1){continue}break}V(0)|0;O()|0;Ub();L()}a=vc(c);jb=d+16|0;break a}Tb(a+20|0);Tb(a+8|0);Jb(a);b=v[Ce(d+8|0)>>2];continue}break}Jb(a)}}function qE(a,b,c,d,e){var f=0,g=0;a:{f=jb-80|0;jb=f;lA(b);g=f+56|0;Cf(g,a,c);a=v[f+56>>2];c=f+8|0;Rf(c,e,ye(g),a);v[23296]=0;R(210,f+24|0,c|0);a=v[23296];v[23296]=0;b:{c:{if((a|0)!=1){v[23296]=0;U(11,f+40|0,d|0,f+24|0);a=v[23296];v[23296]=0;if((a|0)==1){break c}a=f+40|0;Hb(b,a);zb(a);yb(f+24|0);Pc(f+56|0);jb=f+80|0;break a}a=P()|0;O()|0;break b}a=P()|0;O()|0;yb(f+24|0)}Pc(f+56|0);S(a|0);L()}}function tea(a,b){a=a|0;b=b|0;var c=0,d=0;a:{a=Rz(a,b);v[23296]=0;c=Q(608,a+12|0,b+12|0)|0;d=v[23296];v[23296]=0;b:{c:{if((d|0)!=1){v[23296]=0;Q(609,a+24|0,b+24|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break c}c=v[b+40>>2];v[a+36>>2]=v[b+36>>2];v[a+40>>2]=c;u[a+52>>1]=x[b+52>>1];c=v[b+48>>2];v[a+44>>2]=v[b+44>>2];v[a+48>>2]=c;break a}b=P()|0;O()|0;break b}b=P()|0;O()|0;fc(c)}fc(a);S(b|0);L()}}function X3(a){a=a|0;var b=0,c=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23296]=0;b=T(967,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,7196,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();b=0}return b|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function rS(a){var b=0;a:{if(Pb(a,14120,3)|(w[a+3|0]-52&255)>>>0<252){break a}if(cc(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))+788>>>0<840){break a}if(cc(w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24))>>>0<52){break a}if(cc(w[a+24|0]|w[a+25|0]<<8|(w[a+26|0]<<16|w[a+27|0]<<24))-1>>>0<51){break a}b=cc(w[a+32|0]|w[a+33|0]<<8|(w[a+34|0]<<16|w[a+35|0]<<24))>>>0<4294967216}return b}function o2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-16|0;jb=c;a:{if(z[a+24>>2]==C(1)){break a}g=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=v[b+4>>2];j=v[b>>2];k=+z[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Pg(j,i,d,e);A[f>>3]=A[f>>3]*k;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;dJ(a,c);jb=c+16|0}function nd(a,b){var c=0,d=0,e=0,f=0,g=0;a:{e=xG(b);c=cn(a);if(e>>>0<=c>>>0){f=tc(a);d=f;c=e;if(c){b:{if((b|0)==(d|0)){break b}if(d-b>>>0>=c<<2>>>0){if(!c){break b}while(1){v[d>>2]=v[b>>2];d=d+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}break b}if(!c){break b}while(1){c=c-1|0;g=c<<2;v[g+d>>2]=v[b+g>>2];if(c){continue}break}}}Mh(a,e);yd((e<<2)+f|0,0);break a}d=a;a=Fb(a);iF(d,c,e-c|0,a,0,a,e,b)}}function j2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0;c=jb-16|0;jb=c;g=v[a+4>>2];v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;aJ(a,c);a:{if(z[a+24>>2]==C(1)){break a}d=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=e+g|0;j=v[a+12>>2];b=0;while(1)if((b|0)==(d|0)){e=e+1|0;continue b}else{f=Up(j,b,i);z[f>>2]=z[a+24>>2]*z[f>>2];b=b+1|0;continue}}}jb=c+16|0}function i2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-16|0;jb=c;a:{if(z[a+24>>2]==C(1)){break a}g=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=v[b+4>>2];j=v[b>>2];k=+z[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Pg(j,i,d,e);A[f>>3]=A[f>>3]*k;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;_I(a,c);jb=c+16|0}function hda(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;u[b+12>>1]=0;u[b+14>>1]=1;ug(b+14|0,x[v[v[a+24>>2]+8>>2]+12>>1]);e=b+12|0;d=jb-16|0;jb=d;c=x[b+14>>1];v[d+12>>2]=c;a:{if(Fm(a)>>>0>=c>>>0){g=v[a>>2];f=Nc(g,v[a+4>>2]);v[d+8>>2]=f;Ot(g,v[Ib(d+12|0,d+8|0)>>2],e);if(c>>>0>f>>>0){xo(a,c-f|0,e);break a}Nd(a,v[a>>2]+(c<<1)|0);break a}XO(a);Sp(a,yj(a,c));xo(a,c,e)}jb=d+16|0;jb=b+16|0}function f2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-16|0;jb=c;a:{if(z[a+24>>2]==C(1)){break a}g=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=v[b+4>>2];j=v[b>>2];k=+z[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Pg(j,i,d,e);A[f>>3]=A[f>>3]*k;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;YI(a,c);jb=c+16|0}function eR(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(!w[b+8|0]){while(1){if((d|0)==8){v[c+24>>2]=0;v[c+28>>2]=0;d=gc(c+8|0,c+24|0,8);nc(c+16|0,v[a>>2],v[a+8>>2],v[d>>2],v[d+4>>2]);d=0;b:{if(v[c+20>>2]!=8){break b}if(Pb(c+24|0,b,8)){break b}ac(a,8);d=1}jb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17284,8981,413,13012);L()}aa(17263,8981,411,13012);L()}return d|0}function $1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=jb-16|0;jb=c;a:{if(z[a+24>>2]==C(1)){break a}g=v[b+4>>2];h=v[b+8>>2];b:while(1){if((e|0)==(h|0)){break a}i=v[b+4>>2];j=v[b>>2];k=+z[a+24>>2];d=0;while(1)if((d|0)==(g|0)){e=e+1|0;continue b}else{f=Pg(j,i,d,e);A[f>>3]=A[f>>3]*k;d=d+1|0;continue}}}v[c+8>>2]=v[b+8>>2];d=v[b+4>>2];v[c>>2]=v[b>>2];v[c+4>>2]=d;TI(a,c);jb=c+16|0}function ti(a){var b=0,c=0;b=jb-16|0;jb=b;o(+a);c=j(1)|0;j(0)|0;c=c&2147483647;a:{if(c>>>0<=1072243195){if(c>>>0<1045430272){break a}a=Yo(a,0,0);break a}if(c>>>0>=2146435072){a=a-a;break a}b:{switch(dF(a,b)&3){case 0:a=Yo(A[b>>3],A[b+8>>3],1);break a;case 1:a=Xo(A[b>>3],A[b+8>>3]);break a;case 2:a=-Yo(A[b>>3],A[b+8>>3],1);break a;default:break b}}a=-Xo(A[b>>3],A[b+8>>3])}jb=b+16|0;return a}function i4(a){a=a|0;var b=0,c=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;a:{b:{if((b|0)!=1){b=v[a+24>>2];v[23296]=0;c=+na(958,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){break b}}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,7596,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();c=0}return+c}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function eV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[a>>2]=0;v[a+4>>2]=0;if(!Ob(v[b>>2],v[b+8>>2],c)){c=cf(b)}v[a>>2]=c;c=v[b>>2];a:{if(nb[v[v[c>>2]+16>>2]](c)|0){c=a;a=v[b>>2];e=c,f=(nb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0,v[e+4>>2]=f;break a}Li(a+8|0,v[a>>2]);c=v[a+8>>2];a=v[a+12>>2];if(uc(c,a)){break a}ke(d+8|0,c,a);nc(d,v[b>>2],v[b+8>>2],v[d+8>>2],v[d+12>>2])}jb=d+16|0}function S_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;a=jb-96|0;jb=a;f=Bd();v[a>>2]=e;g=a- -64|0;i=Lg(g,20,f,9164,a);e=i+g|0;g=Ti(g,e,c);f=a+8|0;bd(f,c);v[23296]=0;f=T(18,f|0)|0;h=v[23296];v[23296]=0;if((h|0)!=1){_b(a+8|0);h=f;f=a+16|0;gG(h,a- -64|0,e,f);h=b;b=f+i|0;b=Jq(h,f,(e|0)==(g|0)?b:((g-a|0)+a|0)-48|0,b,c,d);jb=a+96|0;return b|0}b=P()|0;O()|0;_b(a+8|0);S(b|0);L()}function R6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=li(a,b,c,d);v[a>>2]=45744;b=Qb(a+4208|0);v[a+4240>>2]=0;v[a+4244>>2]=0;c=v[c+24620>>2];v[a+4260>>2]=0;v[a+4256>>2]=c;v[a+4236>>2]=0;c=a+4228|0;v[c>>2]=1048576e3;v[c+4>>2]=1048576e3;v[a+4220>>2]=1056964608;v[a+4224>>2]=1056964608;v[23296]=0;R(851,a+44|0,2);c=v[23296];v[23296]=0;if((c|0)!=1){ki(a);return a|0}c=P()|0;O()|0;vc(b);uf(a);S(c|0);L()}function hG(a,b,c){var d=0,e=0,f=C(0),g=0,h=C(0);e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115772];v[115772]=0;Bd();d=jb-16|0;jb=d;rw(d,a,e+12|0,0);f=aF(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);jb=d+16|0;a=v[115772];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115772]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}jb=e+16|0;return f}function ex(a,b,c){var d=0,e=0;d=jb-32|0;jb=d;a:{if(w[a+20|0]){break a}b=b+c|0;b=b>>>0<c>>>0?-1:b;c=v[a+16>>2];if(b>>>0<=c>>>0){break a}b=NI(b,4096);MI(a,b-c|0);c=v[a+16>>2];b=gc(d+16|0,Lb(v[a+4>>2],c),b-c|0);c=v[v[a>>2]+44>>2];e=v[b+4>>2];v[d+8>>2]=v[b>>2];v[d+12>>2]=e;nb[c|0](d+24|0,a,d+8|0);v[a+16>>2]=v[a+16>>2]+v[d+28>>2];if(!(nb[v[v[a>>2]+40>>2]](a)|0)){break a}t[a+20|0]=1}jb=d+32|0}function zB(a,b,c){var d=0,e=0,f=0;d=v[c+16>>2];a:{if(!d){if(cC(c)){break a}d=v[c+16>>2]}f=v[c+20>>2];if(d-f>>>0<b>>>0){return nb[v[c+36>>2]](c,a,b)|0}b:{if(v[c+80>>2]<0){d=0;break b}e=b;while(1){d=e;if(!d){d=0;break b}e=d-1|0;if(w[e+a|0]!=10){continue}break}e=nb[v[c+36>>2]](c,a,d)|0;if(e>>>0<d>>>0){break a}a=a+d|0;b=b-d|0;f=v[c+20>>2]}qc(f,a,b);v[c+20>>2]=v[c+20>>2]+b;e=b+d|0}return e}function P8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-48|0;jb=d;a:{b:{e=wT(Jc(b),Fb(b),Jc(c),Fb(c));if((e|0)!=-1){f=d,g=Zd(b),v[f+16>>2]=g;f=d,g=Hi(d+16|0,e),v[f+24>>2]=g;f=d,g=Hi(d+24|0,1),v[f+32>>2]=g;c=Gf(d+40|0,d+32|0);f=d,g=oh(b),v[f>>2]=g;e=Gf(d+8|0,d);dL(b,v[c>>2],v[e>>2]);break b}if(!Fb(b)){break b}if(dT(Jc(b),Fb(b),Jc(c),Fb(c))){break b}Kb(a);break a}Sc(a,b)}jb=d+48|0}function OA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=c;c=0;a:{if(!b){break a}if(!Ob(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=3){d=jb-16|0;jb=d;if(Ob(v[a>>2],v[a+8>>2],b)){while(1){if((c|0)==4){c=v[d+12>>2]}else{t[d+11|0]=0;b:{if(b>>>0>c>>>0){og(a,d+11|0);e=t[d+11|0];g=e>>>31|0;break b}e=0-g|0}t[(d+12|0)+c|0]=e;c=c+1|0;continue}break}}jb=d+16|0;break a}c=qg(a);ac(a,b-4|0)}t[f|0]=c}function _ha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;ic(c+8|0,b,15);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0;t[b+14|0]=0}}function Xz(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+30|0]=0;t[a+31|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function LR(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+27|0]=0;t[a+28|0]=0;t[a+29|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function zga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;ic(c+8|0,b,14);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;if((d|0)!=(e|0)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0;t[b+12|0]=0;t[b+13|0]=0}}function fia(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(ih(1073741823)>>>0<=8191){Wc();L()}b=xc(32768);v[a>>2]=b;v[a+4>>2]=b;e=Gb(a),f=b+32768|0,v[e>>2]=f;b=jb-16|0;jb=b;v[b>>2]=a;c=v[a+4>>2];v[b+4>>2]=c;v[b+8>>2]=c+32768;c=v[b+4>>2];d=v[b+8>>2];while(1){if((c|0)==(d|0)){lc(b);jb=b+16|0}else{u[c>>1]=0;u[c+2>>1]=0;c=c+4|0;v[b+4>>2]=c;continue}break}return a|0}function X2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;b=jb-32|0;jb=b;a:{e=a;a=gc(b+24|0,c,d);a=Os(e,v[a>>2],v[a+4>>2],0);if(a+1>>>0>=3){a=ba(8)|0;v[23296]=0;b=Q(54,b+8|0,7975)|0;c=v[23296];v[23296]=0;b:{if((c|0)!=1){a=sc(a,b);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}c=P()|0;O()|0;yb(b);break b}c=P()|0;O()|0;ca(a|0)}S(c|0);L()}jb=b+32|0;return a|0}L()}function zI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;v[23296]=0;c=Q(54,c|0,7772)|0;d=v[23296];v[23296]=0;if((d|0)==1){break c}a=sc(a,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(c);break b}a=v[a+32>>2];e=a,f=Ie(65536/b),v[e+480244>>2]=f;yp(a);jb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function xI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{b:{c:{if(b<=0|b>4){a=ba(8)|0;v[23296]=0;c=Q(54,c|0,7793)|0;d=v[23296];v[23296]=0;if((d|0)==1){break c}a=sc(a,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(c);break b}a=v[a+32>>2];e=a,f=Ie(b*65536),v[e+480240>>2]=f;yp(a);jb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function fG(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{c:{if((a|0)!=(b|0)){g=v[115772];v[115772]=0;Bd();d=jb-16|0;jb=d;rw(d,a,e+12|0,1);f=uw(v[d>>2],v[d+4>>2],v[d+8>>2],v[d+12>>2]);jb=d+16|0;a=v[115772];if(!a){break c}if(v[e+12>>2]!=(b|0)){break b}h=f;if((a|0)!=68){break a}break b}v[c>>2]=4;break a}v[115772]=g;if(v[e+12>>2]==(b|0)){break a}}v[c>>2]=4;f=h}jb=e+16|0;return f}function Qca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;e=v[a+8>>2];j=v[a+12>>2];while(1){if(d){f=u[(v[b+12>>2]<<1)+i>>1];v[c>>2]=v[c>>2]+B(f,h);v[c+4>>2]=v[c+4>>2]+B(g,f);Sb(b+8|0,e,j);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function OE(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!d){a=ba(8)|0;v[23296]=0;c=Q(54,f|0,8118)|0;b=v[23296];v[23296]=0;if((b|0)==1){break c}a=sc(a,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}Lk(a,b,e);c=KE(a,c,e,d,59312,60084);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=f+16|0;return c}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function NE(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;a:{b:{c:{if(!d){a=ba(8)|0;v[23296]=0;c=Q(54,f|0,8118)|0;b=v[23296];v[23296]=0;if((b|0)==1){break c}a=sc(a,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}b=P()|0;O()|0;yb(c);break b}Lk(a,b,e);c=KE(a,c,e,d,58484,59256);A[a+16>>3]=A[a+16>>3]+ +(c>>>0)/+(b|0);jb=f+16|0;return c}b=P()|0;O()|0;ca(a|0)}S(b|0)}L()}function k8(a){a=a|0;var b=0,c=0;b=v[a+20>>2];v[b+148>>2]=-1;v[23296]=0;R(272,b+4|0,8);b=v[23296];v[23296]=0;if((b|0)!=1){b=v[a+4264>>2];c=v[v[a+20>>2]+4>>2];a=v[a+4260>>2];t[c|0]=a;t[c+1|0]=a>>>8;t[c+2|0]=a>>>16;t[c+3|0]=a>>>24;t[c+4|0]=b;t[c+5|0]=b>>>8;t[c+6|0]=b>>>16;t[c+7|0]=b>>>24;return}b=V(91780)|0;if((O()|0)==(ea(91780)|0)){_(b|0)|0;Hc(v[a+20>>2]+4|0);$();return}S(b|0);L()}function lI(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23296]=0;c=Q(54,c|0,10598)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}a=sc(b,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=v[a+32>>2]+B(b,872)|0;v[a+1075008>>2]=0;v[a+1075068>>2]=0;jb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function mia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;a:{e=Ee(a);b:{if(e>>>0>1){break b}c:{if(e){v[23296]=0;U(315,d|0,a|0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){pm(b,d);fc(d);break c}a=V(30320)|0;if((O()|0)!=(ea(30320)|0)){break a}_(a|0)|0;$();break b}if(!Ob(v[a>>2],v[a+8>>2],c)){break b}Ku(a,b,c)}f=ad(v[b>>2],v[b+4>>2])>>>0>=c>>>0}jb=d+16|0;return f|0}S(a|0);L()}function Ri(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(Yi(a,f+8|0)){break b}h=Ek(v[a>>2]);g=4;if(!lh(v[d+8>>2],64,h)){break b}b=en(d,h);while(1){c:{b=b-48|0;h=Hl(a);if(!ep(h,f+8|0)|(e|0)<2){break c}g=Ek(v[h>>2]);if(!lh(v[d+8>>2],64,g)){break a}e=e-1|0;b=en(d,g)+B(b,10)|0;continue}break}g=2;if(!Yi(h,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}jb=f+16|0;return b}function Rca(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;b=jb-16|0;jb=b;g=v[a+24>>2];h=v[a+20>>2];i=v[a+16>>2];e=v[a+4>>2];v[b+8>>2]=v[a>>2];v[b+12>>2]=e;e=v[a+8>>2];j=v[a+12>>2];while(1){if(d){f=t[v[b+12>>2]+i|0]<<8;v[c>>2]=v[c>>2]+B(f,h);v[c+4>>2]=v[c+4>>2]+B(g,f);Sb(b+8|0,e,j);c=c+8|0;d=d-1|0;continue}break}c=v[b+12>>2];v[a>>2]=v[b+8>>2];v[a+4>>2]=c;jb=b+16|0}function naa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-48|0;jb=d;a:{b:{e=TD(Jc(b),Fb(b),Jc(c),Fb(c));if((e|0)!=-1){f=d,g=Zd(b),v[f+32>>2]=g;c=Gf(d+40|0,d+32|0);f=d,g=Zd(b),v[f+8>>2]=g;f=d,g=Hi(d+8|0,e),v[f+16>>2]=g;e=Gf(d+24|0,d+16|0);dL(b,v[c>>2],v[e>>2]);break b}e=Fb(b);if(!e){break b}if((SD(Jc(b),Fb(b),Jc(c),Fb(c))|0)!=(e-1|0)){break b}Kb(a);break a}Sc(a,b)}jb=d+48|0}function hI(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23296]=0;c=Q(54,c|0,10598)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}a=sc(b,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}jb=c+16|0;return+(+(v[(v[a+32>>2]+B(b,872)|0)+1075684>>2]-128|0)*.0078125)}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function N0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a+32|0;Bq(c,b);v[a+44>>2]=0;b=v[a+48>>2];if(b&8){b=tc(c)+Fb(c)|0;v[a+44>>2]=b;d=tc(c);nn(a,d,d,b);b=v[a+48>>2]}a:{if(!(b&16)){break a}b=Fb(c);e=a,f=b+tc(c)|0,v[e+44>>2]=f;Bx(c,Tc(c));d=tc(c);Bw(a,d,Fb(c)+d|0);if(!(w[a+48|0]&3)){break a}while(1){if((b|0)<0){Pr(a,2147483647);b=b-2147483647|0;continue}break}if(!b){break a}Pr(a,b)}}function Ah(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(!w[b+4|0]){while(1){if((d|0)==4){d=0;v[c+28>>2]=0;e=gc(c+8|0,c+28|0,4);nc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=4){break b}if(Pb(c+28|0,b,4)){break b}ac(a,4);d=1}jb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17284,8981,413,13012);L()}aa(17263,8981,411,13012);L()}return d|0}function fI(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23296]=0;c=Q(54,c|0,10598)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}a=sc(b,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}jb=c+16|0;return+(+u[(v[a+32>>2]+B(b,872)|0)+1075766>>1]*30517578125e-15)}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function W3(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-32|0;jb=c;a:{e=a+36|0;b=v[e>>2];d=v[a+40>>2];b:{if(Rb(b,d)){Cc(c+24|0);break b}b=c+8|0;Cn(b,a);v[23296]=0;b=T(959,b|0)|0;d=v[23296];v[23296]=0;if((d|0)==1){break a}v[c+24>>2]=b;Wf(c+8|0);d=v[a+40>>2];b=v[a+36>>2]}if(!Rb(b,d)){e=v[c+24>>2];b=v[e>>2]}a=Bn(b,v[e+4>>2]);Ik(c+24|0);jb=c+32|0;return a|0}a=P()|0;O()|0;Wf(c+8|0);S(a|0);L()}function qfa(a){a=a|0;var b=0,c=0,d=0,e=0;e=jb-16|0;jb=e;b=xc(2500);c=jb-2496|0;jb=c;tQ(a,c,c+2496|0);a=0;while(1){if((a|0)==624){v[b+2496>>2]=0;a:{if(v[b>>2]<0){break a}a=1;while(1){if((a|0)!=624){d=a<<2;a=a+1|0;if(!v[b+d>>2]){continue}break a}break}v[b>>2]=-2147483648}jb=c+2496|0}else{d=a<<2;v[d+b>>2]=v[c+d>>2];a=a+1|0;continue}break}a=v[xf(e+8|0,b)>>2];jb=e+16|0;return a|0}function l5(a){a=a|0;var b=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){b=v[a+24>>2];if(b){Jb(ys(b))}v[a+24>>2]=0;b=v[a+20>>2];if(b){Jb(b);v[a+20>>2]=0}Jb(a);return}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,5039,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function h0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;while(1){a:{if((c|0)<=(g|0)){break a}d=v[a+24>>2];e=v[a+28>>2];if(d>>>0>=e>>>0){if((nb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){break a}g=g+1|0;b=b+4|0}else{v[f+12>>2]=e-d>>2;v[f+8>>2]=c-g;e=d;d=v[td(f+12|0,f+8|0)>>2];ei(e,b,d);e=d<<2;v[a+24>>2]=e+v[a+24>>2];g=g+d|0;b=b+e|0}continue}break}jb=f+16|0;return g|0}function HR(a,b){var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(!w[b+5|0]){while(1){if((d|0)==5){d=0;t[c+28|0]=0;v[c+24>>2]=0;e=gc(c+8|0,c+24|0,5);nc(c+16|0,v[a>>2],v[a+8>>2],v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=5){break b}if(Pb(c+24|0,b,5)){break b}ac(a,5);d=1}jb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17284,8981,413,13012);L()}aa(17263,8981,411,13012);L()}return d}function vI(a,b){a=a|0;b=+b;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{b:{c:{if(b<0|b>1){a=ba(8)|0;v[23296]=0;c=Q(54,c|0,11610)|0;d=v[23296];v[23296]=0;if((d|0)==1){break c}a=sc(a,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}d=P()|0;O()|0;yb(c);break b}e=v[a+32>>2]+1074456|0,f=Ie(b*256),v[e>>2]=f;jb=c+16|0;return}d=P()|0;O()|0;ca(a|0)}S(d|0)}L()}function t8(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;c=xc(64);v[23296]=0;e=T(788,c|0)|0;f=v[23296];v[23296]=0;a:{if((f|0)!=1){c=xf(d,e);e=v[c>>2];v[23296]=0;a=W(849,e|0,a|0,b|0)|0;b=v[23296];v[23296]=0;b:{c:{if((b|0)!=1){if((a|0)==1){break c}Cc(d+8|0);break b}a=P()|0;O()|0;ig(c);break a}Tf(d+8|0,c)}ig(c);jb=d+16|0;return v[d+8>>2]}a=P()|0;O()|0;Jb(c)}S(a|0);L()}function h5(a,b){a=a|0;b=b|0;var c=0;v[23296]=0;Y(900,a|0);c=v[23296];v[23296]=0;a:{b:{if((c|0)!=1){v[a+16>>2]=b;b=v[a+20>>2];if(!b){break b}Jb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,5621,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function pP(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a=Kb(a);d=Fb(b);v[23296]=0;R(45,a|0,d|0);d=v[23296];v[23296]=0;a:{if((d|0)!=1){e=c,f=$s(b),v[e+8>>2]=f;e=c,f=Ys(b),v[e>>2]=f;while(1){if(!Nh(c+8|0,c)){break a}b=w[v[c+8>>2]];v[23296]=0;R(46,a|0,((b|0)==13?10:b)<<24>>24);b=v[23296];v[23296]=0;if((b|0)!=1){Be(c+8|0);continue}break}}b=P()|0;O()|0;yb(a);S(b|0);L()}jb=c+16|0}function X7(a,b){a=a|0;b=b|0;var c=C(0);a:{switch(b|0){case 0:return C(z[a+4220>>2]);case 1:return C(z[a+4224>>2]);case 2:return C(z[a+4228>>2]);case 3:return C(w[a+4240|0]?C(1):C(0));case 4:return C(C(C(v[a+4232>>2])*C(.03125)));case 5:return C(w[a+4241|0]?C(1):C(0));case 6:return C(w[a+4242|0]?C(1):C(0));case 7:c=w[a+4244|0]?C(1):C(0);break;default:break a}}return C(c)}function Y6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=li(a,b,c,d);v[a>>2]=45372;b=a+4208|0;e=Db(b,0),f=1060320051,v[e>>2]=f;e=Db(b,1),f=1041865114,v[e>>2]=f;e=Db(b,2),f=1065353216,v[e>>2]=f;e=Db(b,3),f=1049951732,v[e>>2]=f;e=Db(b,4),f=1049951732,v[e>>2]=f;v[23296]=0;R(851,a+44|0,2);b=v[23296];v[23296]=0;if((b|0)!=1){ki(a);return a|0}b=P()|0;O()|0;uf(a);S(b|0);L()}function ox(a,b,c){var d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(c){il(a,c);d=jb-16|0;jb=d;e=Ph(d,a,c);c=v[e+4>>2];f=v[e+8>>2];while(1){if((c|0)==(f|0)){lc(e);jb=d+16|0}else{v[c>>2]=0;Cc(c);c=c+4|0;v[e+4>>2]=c;continue}break}}c=0;e=0;d=jb-16|0;jb=d;f=d+8|0;while(1){if(c>>>0<32){c=c+48|0;e=vM(b);continue}break}v[f>>2]=e;Nn(f);jb=d+16|0;v[a+12>>2]=v[f>>2];return a}function Cx(a){var b=C(0),c=C(0),d=0,e=C(0),f=0;b=C(y[v[a+16>>2]+24620>>2]);c=C(C(C(nb[v[v[a>>2]+204>>2]](a))*b)/C(1e3));d=a,e=C(C(c*C(nb[v[v[a>>2]+196>>2]](a)))*C(2048)),z[d+4248>>2]=e;d=a,f=Oh(C(C(c+C(2))*C(4096))),v[d+4256>>2]=f;c=C(nb[v[v[a>>2]+208>>2]](a));z[a+4252>>2]=c;b=C(c/b);if(!(nb[v[v[a>>2]+192>>2]](a)|0)){b=FK(C(b*C(3.1415927410125732)))}z[a+4244>>2]=b+b}function By(a,b,c,d){a:{if(v[a+1074392>>2]!=(c|0)){break a}b:{if(d){c=B(b,872)+a|0;v[c+1075688>>2]=0;d=c+1075e3|0;v[d>>2]=0;v[d+4>>2]=0;d=c+1075080|0;c=v[d>>2]|4096;v[d>>2]=c;break b}c=B(b,872)+a|0;v[c+1075680>>2]=0;c=v[c+1075080>>2]}d=B(b,872)+a|0;v[d+1075080>>2]=c|2097152;Ul(a,b,255,0);if(!(w[d+1075081|0]&2)){break a}a=v[a+1298300>>2];if(!xd(a)){break a}jj(a,b,0)}}function B1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(c){if(ih(357913941)>>>0<c>>>0){Wc();L()}d=_D(c);v[a>>2]=d;v[a+4>>2]=d;f=Gb(a),g=d+B(c,12)|0,v[f>>2]=g;e=Hd(b,c);d=jb-16|0;jb=d;c=At(d,a,c);v[23296]=0;U(1032,b|0,e|0,c+4|0);b=v[23296];v[23296]=0;a:{if((b|0)!=1){lc(c);jb=d+16|0;break a}a=P()|0;O()|0;lc(c);S(a|0);L()}}return a|0}function Kl(a){if((a|0)>=0){if(a>>>0<=16383){if(a>>>0<=15){return t[a+71520|0]}if(a>>>0<=511){return t[(a>>>5|0)+71520|0]+5|0}return t[(a>>>10|0)+71520|0]+10|0}if(a>>>0<=16777215){if(a>>>0<=524287){return t[(a>>>15|0)+71520|0]+15|0}return t[(a>>>20|0)+71520|0]+20|0}if(a>>>0<=536870911){return t[(a>>>25|0)+71520|0]+25|0}a=t[(a>>>30|0)+71520|0]+30|0}else{a=0}return a}function w2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;a:{b:{if((Oj(w[a+140|0])|0)!=1){break b}if((uJ(a)|0)!=(b|0)){break b}d=a+120|0;ns(w[d+20|0]);b=jb-16|0;jb=b;v[b+8>>2]=c+8;a=jb-16|0;jb=a;e=v[14175];v[a+8>>2]=v[14174];v[a+12>>2]=e;e=v[14173];v[a>>2]=v[14172];v[a+4>>2]=e;nb[v[jp(a,Oj(w[d+20|0]))>>2]](b+8|0,d);jb=a+16|0;jb=b+16|0;break a}tJ(a,1,b)}jb=c+16|0}function k5(a){a=a|0;var b=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;a:{b:{if((b|0)!=1){v[a+16>>2]=0;b=v[a+20>>2];if(!b){break b}Jb(b);v[a+20>>2]=0;return}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,8818,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$()}return}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function JE(a,b,c){var d=0;d=jb-16|0;jb=d;a:{b:{c:{if(b>>>0>=256){b=ba(8)|0;v[23296]=0;c=Q(54,d|0,10598)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}a=sc(b,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}a=(v[a+32>>2]+B(b,872)|0)+1075080|0;v[a>>2]=v[a>>2]|c;jb=d+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function GB(a,b){var c=0,d=0;b=!v[a+24>>2]|b;v[a+16>>2]=b;if(b&v[a+20>>2]){a=jb-16|0;jb=a;c=ba(16)|0;b=jb-16|0;jb=b;if(!w[463712]){t[463712]=1}gc(b+8|0,1,92872);d=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=d;jb=b+16|0;b=v[a+12>>2];a=v[a+8>>2];v[23296]=0;a=YE(1058,c,8845,a,b);b=v[23296];v[23296]=0;if((b|0)!=1){ha(a|0,77204,1059);L()}a=P()|0;O()|0;ca(c|0);S(a|0);L()}}function AI(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b-513>>>0<=4294966814){b=ba(8)|0;v[23296]=0;c=Q(54,c|0,9265)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}a=sc(b,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}v[v[a+32>>2]+1074420>>2]=B(b,1e4);jb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function Qi(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;v[f+8>>2]=b;b=0;g=6;a:{b:{if(Kj(a,f+8|0)){break b}g=4;h=Dk(v[a>>2]);if(!Ck(d,64,h)){break b}b=dn(d,h);while(1){c:{b=b-48|0;h=on(a);if(!Qr(h,f+8|0)|(e|0)<2){break c}g=Dk(v[h>>2]);if(!Ck(d,64,g)){break a}e=e-1|0;b=dn(d,g)+B(b,10)|0;continue}break}g=2;if(!Kj(h,f+8|0)){break a}}v[c>>2]=v[c>>2]|g}jb=f+16|0;return b}function JC(a){var b=0,c=0,d=0,e=0,f=0;a:{b:{if(Pb(a,11012,2)){if(Pb(a,13621,2)){break a}if(w[a+110|0]<=64){break b}break a}if(w[a+110|0]>64){break a}}if(t[a+112|0]<0|w[a+111|0]>128){break a}while(1){d=(b|0)==128;if(d){break a}c=a+b|0;e=t[c+113|0];if((e|0)<-2){break a}f=w[c+241|0];if(!f&(e|0)>=0|f>>>0>15){break a}b=b+1|0;if(w[c+369|0]<64){continue}break}}return d}function Ar(a,b,c){var d=0,e=0;if(c&2048){t[a|0]=43;a=a+1|0}if(c&1024){t[a|0]=35;a=a+1|0}d=c&260;if((d|0)!=260){t[a|0]=46;t[a+1|0]=42;a=a+2|0}c=c&16384;while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}a:{b:{if((d|0)!=256){if((d|0)!=4){break b}b=c?70:102;break a}b=c?69:101;break a}b=c?65:97;if((d|0)==260){break a}b=c?71:103}t[a|0]=b;return(d|0)!=260}function qV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;c=-1;a:{if(!Vf(a,7)){break a}c=0;if(!iC(a,11632)){break a}c=jb-16|0;jb=c;fC(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){eC(d)}c=-1;if(!e){break a}c=0;if(!hC(w[d+1|0])){break a}c=Ge(a,b,gC(d),mb)}jb=d+16|0;return c|0}function i5(a){a=a|0;var b=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;a:{b:{if((b|0)!=1){a=v[a+20>>2];if(!a){break b}return Xf(a)|0}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,12033,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();return 0}return Xf(21473)|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Zga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;c=gf(a,c);ae(f,v[a+28>>2]);a:{b:{if(!c){d=-1;if(!hd(a,5)){break b}break a}d=v[c+8>>2]}e=v[a+28>>2];c:{d:{switch(d+1|0){case 0:case 2:d=jb-32|0;jb=d;t[d+24|0]=0;Xi(d+8|0,d+24|0);ln(d+16|0,e,v[d+8>>2],v[d+12>>2]);t[b|0]=w[d+24|0];jb=d+32|0;break c;default:break d}}TS(e,b,d)}e=c}$e(a,e);jb=f+16|0}function _L(a,b){var c=0,d=0,e=0,f=0;a:{if(x[a+480188>>1]<=b>>>0){break a}b:{c:{c=B(b,872)+a|0;d=w[c+1075783|0];switch(d-31|0){case 1:break b;case 0:break c;default:break a}}if(!(w[a+480209|0]&16)){break a}}e=a+1074376|0;f=(d|0)==32;c=t[c+1075785|0];d:{if((c|0)>=0){d=pe(a+901692|0,w[(B(b,872)+a|0)+1075836|0]);break d}d=pe(a+902204|0,c&127)}rN(a,e,b,f,d,c&255)}}function iaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=b;c=jb-16|0;jb=c;d=xc(223888);v[23296]=0;b=Q(755,d|0,b+1074376|0)|0;e=v[23296];v[23296]=0;a:{if((e|0)!=1){b=v[xf(c+8|0,b)>>2];jb=c+16|0;break a}a=P()|0;O()|0;Jb(d);S(a|0);L()}v[a+4>>2]=b;b=Qb(a+8|0);v[23296]=0;Y(536,a|0);c=v[23296];v[23296]=0;if((c|0)!=1){return a|0}c=P()|0;O()|0;je(b);hN(a+4|0);S(c|0);L()}function Yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=Qb(a);a=Eb(v[b>>2]);v[d+24>>2]=a;b=Eb(v[b+4>>2]);a:{while(1){if(Rb(a,b)){yi(d,v[a>>2],v[a+4>>2]);if((cc(v[d>>2])|0)==(c|0)){to(d,a);v[23296]=0;R(338,e|0,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break a}Ab(d)}a=v[rm(d+24|0)>>2];continue}break}jb=d+32|0;return}a=P()|0;O()|0;Ab(d);ld(e);S(a|0);L()}function P3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;v[23296]=0;Y(900,a|0);f=v[23296];v[23296]=0;if((f|0)!=1){return vx(v[v[a+24>>2]+24>>2],b,c,d,e)|0}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,12276,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function CI(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{b:{c:{if(b-65536>>>0<=4294901760){b=ba(8)|0;v[23296]=0;c=Q(54,c|0,5809)|0;a=v[23296];v[23296]=0;if((a|0)==1){break c}a=sc(b,c);v[23296]=0;U(107,a|0,61592,904);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(c);break b}v[v[a+32>>2]+1074416>>2]=b;jb=c+16|0;return}a=P()|0;O()|0;ca(b|0)}S(a|0)}L()}function Tn(a,b,c,d){a:{if(v[a+480180>>2]==4){if(c){t[b+810|0]=w[b+810|0]&15|c<<4;break a}c=w[b+810|0]>>>4|0;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]+((c&255)<<2)|0;v[b+688>>2]=(c|0)<256?c:256;if(!(t[a+480180|0]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function mG(a,b,c,d){var e=0,f=0,g=0;e=jb-16|0;jb=e;a:{if((a|0)!=(b|0)){g=v[115772];v[115772]=0;Bd();d=nG(a,e+12|0,d);a=mb;f=v[115772];b:{if(f){if(v[e+12>>2]!=(b|0)){break b}if((f|0)!=68){break a}v[c>>2]=4;a=!!d&(a|0)>=0|(a|0)>0;d=a?-1:0;a=a?2147483647:-2147483648;break a}v[115772]=g;if(v[e+12>>2]==(b|0)){break a}}}v[c>>2]=4;d=0;a=0}jb=e+16|0;mb=a;return d}function oV(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=jb-32|0;jb=e;Mu(e+8|0,c);c=w[d|0];v[23296]=0;R(231,e+20|0,c|0);c=v[23296];v[23296]=0;b:{c:{if((c|0)!=1){pk(e,e+8|0);v[23296]=0;X(102,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23296];v[23296]=0;if((a|0)==1){break c}Ch(e+8|0);jb=e+32|0;break a}a=P()|0;O()|0;zb(e+8|0);break b}a=P()|0;O()|0;Ch(e+8|0)}S(a|0);L()}}function _3(a){a=a|0;var b=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){a=v[v[a+24>>2]+24>>2];return lj(Zb(v[a+484360>>2],w[a+484376|0]))|0}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,6846,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function vt(a,b){var c=0,d=0;if(a-268435457>>>0>=4026531840){a=a+208|0;Sia(b,0,a,0);a=mb?0:B(a,b)}else{a=0}a:{if(!a){break a}v[23296]=0;b=T(703,a|0)|0;c=v[23296];v[23296]=0;b:{c:{if((c|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;Z(17);c=v[23296];v[23296]=0;b=0;if((c|0)==1){break c}}break b}V(0)|0;O()|0;Ub();L()}if(!b){break a}d=Xb(b,0,a)- -64|0}return d}function Z3(a){a=a|0;var b=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){a=v[v[a+24>>2]+24>>2];return ht(v[a+484344>>2],v[a+484348>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,6914,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Vz(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=Qb(a);a=Eb(v[b>>2]);v[d+24>>2]=a;b=Eb(v[b+4>>2]);a:{while(1){if(Rb(a,b)){yi(d,v[a>>2],v[a+4>>2]);if(v[d>>2]==(c|0)){to(d,a);v[23296]=0;R(338,e|0,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break a}Ab(d)}a=v[rm(d+24|0)>>2];continue}break}jb=d+32|0;return}a=P()|0;O()|0;Ab(d);ld(e);S(a|0);L()}function ap(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;d=e+8|0;bd(d,b);v[23296]=0;b=T(1085,d|0)|0;d=v[23296];v[23296]=0;a:{if((d|0)==1){break a}v[23296]=0;d=T(1094,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break a}v[c>>2]=d;v[23296]=0;R(1095,a|0,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break a}_b(e+8|0);jb=e+16|0;return}a=P()|0;O()|0;_b(e+8|0);S(a|0);L()}function BQ(a,b){var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(!w[b+4|0]){while(1){if((d|0)==4){d=0;v[c+28>>2]=0;e=gc(c+8|0,c+28|0,4);md(c+16|0,a,v[e>>2],v[e+4>>2]);b:{if(v[c+20>>2]!=4){break b}if(Pb(c+28|0,b,4)){break b}dd(a,4);d=1}jb=c+32|0;break a}e=b+d|0;d=d+1|0;if(w[e|0]){continue}break}aa(17284,8981,413,13012);L()}aa(17263,8981,411,13012);L()}return d}function A$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;e=v[a+84>>2];f=v[e>>2];d=v[e+4>>2];h=v[a+28>>2];g=v[a+20>>2]-h|0;g=d>>>0<g>>>0?d:g;if(g){qc(f,h,g);f=g+v[e>>2]|0;v[e>>2]=f;d=v[e+4>>2]-g|0;v[e+4>>2]=d}d=c>>>0>d>>>0?d:c;if(d){qc(f,b,d);f=d+v[e>>2]|0;v[e>>2]=f;v[e+4>>2]=v[e+4>>2]-d}t[f|0]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;return c|0}function lL(a,b){var c=0,d=0,e=0,f=0,g=0,h=C(0);c=jb-16|0;jb=c;d=0;a:{if(!Kg(v[v[a>>2]-12>>2]+a|0)){break a}v[c+12>>2]=0;bk(a,c+12|0);e=v[c+12>>2];d=0;if(e>>>0>65535){break a}Qj(b,e);while(1){if((f|0)==(e|0)){d=Kg(v[v[a>>2]-12>>2]+a|0)}else{v[c+8>>2]=0;qp(a,c+8|0);g=Db(v[b>>2],f),h=z[c+8>>2],z[g>>2]=h;f=f+1|0;continue}break}}a=d;jb=c+16|0;return a}function dp(a,b,c){var d=0,e=0,f=0;e=jb-16|0;jb=e;d=e+8|0;bd(d,b);v[23296]=0;b=T(1067,d|0)|0;d=v[23296];v[23296]=0;a:{if((d|0)==1){break a}v[23296]=0;d=T(1080,b|0)|0;f=v[23296];v[23296]=0;if((f|0)==1){break a}t[c|0]=d;v[23296]=0;R(1081,a|0,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break a}_b(e+8|0);jb=e+16|0;return}a=P()|0;O()|0;_b(e+8|0);S(a|0);L()}function K6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;b=PK(a,b,c,d,e^1);v[b>>2]=45972;a=b+4208|0;f=Db(a,0),g=1056964608,v[f>>2]=g;f=Db(a,1),g=1065353216,v[f>>2]=g;f=Db(a,2),g=1020054733,v[f>>2]=g;f=Db(a,3),g=1065353216,v[f>>2]=g;f=Db(a,4),g=1056964608,v[f>>2]=g;f=Db(a,5),g=1048406533,v[f>>2]=g;f=Db(a,6),g=1056964608,v[f>>2]=g;return b|0}function mT(a){var b=0,c=0,d=0;a:{if(Pb(a+60|0,15361,4)|(w[a+32|0]|w[a+33|0]<<8)>>>0>256|(w[a+49|0]<32|(w[a+36|0]|w[a+37|0]<<8)>>>0>255)){break a}if(t[a+51|0]<4|w[a+50|0]>64){break a}b=a+576|0;a=a- -64|0;while(1){if((a|0)==(b|0)){d=c;break a}b:{switch(w[a+15|0]){case 0:case 1:c=1;break;case 2:break b;default:break a}}a=a+16|0;continue}}return d&1}function haa(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=jb-16|0;jb=c;v[c>>2]=a;a=v[a+4>>2];v[c+4>>2]=a;v[c+8>>2]=a+32;YM(v[c+4>>2],b);v[c+4>>2]=v[c+4>>2]+32;lc(c);jb=c+16|0;return}d=jb-32|0;jb=d;c=Gb(a);c=st(d+8|0,Pp(a,gg(v[a>>2],v[a+4>>2])+1|0),gg(v[a>>2],v[a+4>>2]),c);YM(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;Ad(a,c);KP(c);jb=d+32|0}function Tfa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=jb-32|0;jb=e;vq(e+8|0,c);v[23296]=0;R(526,e+20|0,d|0);c=v[23296];v[23296]=0;b:{c:{if((c|0)!=1){pk(e,e+8|0);v[23296]=0;X(282,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23296];v[23296]=0;if((a|0)==1){break c}QR(e+8|0);jb=e+32|0;break a}a=P()|0;O()|0;yb(e+8|0);break b}a=P()|0;O()|0;QR(e+8|0)}S(a|0);L()}}function I5(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-32|0;jb=b;a=Qb(a);v[23296]=0;Y(890,b+16|0);c=v[23296];v[23296]=0;a:{b:{if((c|0)!=1){c=Eb(v[b+16>>2]);d=Eb(v[b+20>>2]);e=v[hc(b+8|0,a)>>2];v[23296]=0;U(891,c|0,d|0,e|0);c=v[23296];v[23296]=0;if((c|0)==1){break b}vc(b+16|0);jb=b+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;vc(b+16|0)}Me(a);S(c|0);L()}function G9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;u[a>>1]=0;c=Qb(a+4|0);d=Qb(a+16|0);v[a+36>>2]=0;e=Kb(a+40|0);f=hg(a+52|0);Hc(c);u[a+28>>1]=65472;v[23296]=0;v[b+12>>2]=1065353216;R(792,c|0,b+12|0);g=v[23296];v[23296]=0;if((g|0)!=1){v[a+32>>2]=0;u[a+30>>1]=0;Hc(d);jb=b+16|0;return a|0}a=P()|0;O()|0;WS(f);zb(e);vc(d);vc(c);S(a|0);L()}function kX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=jb-32|0;jb=e;Vm(e+8|0,c);v[23296]=0;R(101,e+20|0,d|0);c=v[23296];v[23296]=0;b:{c:{if((c|0)!=1){pk(e,e+8|0);v[23296]=0;X(102,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23296];v[23296]=0;if((a|0)==1){break c}Ch(e+8|0);jb=e+32|0;break a}a=P()|0;O()|0;zb(e+8|0);break b}a=P()|0;O()|0;Ch(e+8|0)}S(a|0);L()}}function g3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[23296]=0;Y(900,a|0);d=v[23296];v[23296]=0;if((d|0)!=1){v[a+16>>2]=0;v[a+12>>2]=c;v[a+8>>2]=b;return}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,12897,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Cu(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=jb-32|0;jb=e;OB(e+8|0,c);v[23296]=0;R(101,e+20|0,d|0);c=v[23296];v[23296]=0;b:{c:{if((c|0)!=1){pk(e,e+8|0);v[23296]=0;X(102,a|0,b|0,v[e>>2],v[e+4>>2]);a=v[23296];v[23296]=0;if((a|0)==1){break c}Ch(e+8|0);jb=e+32|0;break a}a=P()|0;O()|0;zb(e+8|0);break b}a=P()|0;O()|0;Ch(e+8|0)}S(a|0);L()}}function Ts(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=jb-16|0;jb=e;a:{if(!b){break a}Bb(e+8|0,a+1074312|0,73);j=Cb(v[v[e+8>>2]>>2],v[e+12>>2])?c- -64|0:c;c=120;h=gj(a);k=h^-1;f=1;while(1){if(!c){break a}l=c;c=c>>>1|0;i=f+c|0;g=Rg(a,i,j,d);if(!(g>>>0>b>>>0&k)&(!(!g|h)|b>>>0<=g>>>0)){continue}f=i+1|0;c=(c^-1)+l|0;continue}}jb=e+16|0;return f}function Sn(a,b,c,d){a:{if(v[a+480180>>2]==4){d=w[b+810|0];if(c){t[b+810|0]=d&240|c;break a}c=d&15;break a}if(d){if(c){t[b+834|0]=c;break a}c=w[b+834|0];break a}if(c){t[b+810|0]=c;break a}c=w[b+810|0]}b:{if(!(t[b+851|0]&1)){break b}c=v[b+688>>2]-((c&255)<<2)|0;v[b+688>>2]=(c|0)>0?c:0;if(!(t[a+480180|0]&1)){break b}v[b+88>>2]=v[b+88>>2]|2097152}}function cw(a,b,c,d){t[a+53|0]=1;a:{if(v[a+4>>2]!=(c|0)){break a}t[a+52|0]=1;c=v[a+16>>2];b:{if(!c){v[a+36>>2]=1;v[a+24>>2]=d;v[a+16>>2]=b;if((d|0)!=1){break a}if(v[a+48>>2]==1){break b}break a}if((b|0)==(c|0)){c=v[a+24>>2];if((c|0)==2){v[a+24>>2]=d;c=d}if(v[a+48>>2]!=1){break a}if((c|0)==1){break b}break a}v[a+36>>2]=v[a+36>>2]+1}t[a+54|0]=1}}function Gu(a,b,c,d){var e=0,f=0;a:{e=w[a|0];f=w[c|0];b:{if(!(w[d|0]|((e|0)!=11|(f-5&255)>>>0>1))){t[a|0]=(f|0)==5?7:6;break b}if(!(w[b|0]|((f|0)!=11|(e-5&255)>>>0>1))){t[a|0]=(e|0)==5?7:6;t[b|0]=w[d|0];break b}if(!((e|0)!=10|(f|0)!=20|w[d|0]!=159)){t[a|0]=42;break b}if(w[b|0]!=159|(f|0)!=10|(e|0)!=20){break a}t[a|0]=42;t[b|0]=w[d|0]}t[c|0]=0}}function LI(a){var b=0,c=0,d=0,e=0,f=0,g=0;a:{b=v[a>>2];b:{if(!b){break b}c=v[a+8>>2];if(!c){break b}a=v[a+12>>2];if(!a){break b}e=nb[a|0](b)|0;d=mb;if((d|0)<0){break b}if((nb[c|0](b,0,0,0)|0)<0){break a}if((nb[c|0](b,0,0,2)|0)<0){break a}f=nb[a|0](b)|0;a=mb;nb[c|0](b,e,d,0)|0;if((a|0)<0){break b}g=Vy(f,a)}return g}nb[c|0](b,e,d,0)|0;return 0}function xea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=d+11|0;WQ(a,c);if(Pb(c,13428,4)){a=1}else{WQ(a,d+11|0);t[b|0]=1;a=0}c=jb-16|0;jb=c;a:{b:{a=(d+11|0)+a|0;c:{if(!a){a=0;break c}b=Vb(c,a);v[23296]=0;a=T(606,b|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break b}yb(b)}jb=c+16|0;break a}a=P()|0;O()|0;yb(b);S(a|0);L()}jb=d+16|0;return a|0}function qk(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;v[f+8>>2]=a;v[f+12>>2]=b;h=v[a+8>>2]+120|0;ns(w[h+20|0]);g=jb-16|0;jb=g;v[g+8>>2]=f+8;e=jb-16|0;jb=e;i=v[d+4>>2];v[e+8>>2]=v[d>>2];v[e+12>>2]=i;d=v[c+4>>2];v[e>>2]=v[c>>2];v[e+4>>2]=d;nb[v[jp(e,Oj(w[h+20|0]))>>2]](g+8|0,h);jb=e+16|0;jb=g+16|0;v[a+4>>2]=v[a+4>>2]+v[b+8>>2];jb=f+16|0}function Waa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=jb-32|0;jb=d;HA(d+8|0,c);v[23296]=0;R(409,d+20|0,43212);c=v[23296];v[23296]=0;b:{c:{if((c|0)!=1){pk(d,d+8|0);v[23296]=0;X(102,a|0,b|0,v[d>>2],v[d+4>>2]);a=v[23296];v[23296]=0;if((a|0)==1){break c}Ch(d+8|0);jb=d+32|0;break a}a=P()|0;O()|0;zb(d+8|0);break b}a=P()|0;O()|0;Ch(d+8|0)}S(a|0);L()}}function Rha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-112|0;jb=d;c=jb-16|0;jb=c;f=d+8|0;BT(c+8|0,f);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(g|0);if(!e){AT(f)}c=-1;a:{if(!e){break a}c=0;if(!DT(d+8|0)){break a}c=Ge(a,b,CT(w[d+55|0]|w[d+56|0]<<8),mb)}jb=d+112|0;return c|0}function Q$(a){a=a|0;a:{v[23296]=0;T(1061,465976)|0;a=v[23296];v[23296]=0;b:{if((a|0)==1){break b}v[23296]=0;T(1061,466312)|0;a=v[23296];v[23296]=0;if((a|0)==1){break b}v[23296]=0;T(1062,466060)|0;a=v[23296];v[23296]=0;if((a|0)==1){break b}v[23296]=0;T(1062,466396)|0;a=v[23296];v[23296]=0;if((a|0)==1){break b}break a}V(0)|0;O()|0;Ub();L()}}function y7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=li(a,b,c,d);v[a>>2]=44880;c=Qb(a+4208|0);v[a+4220>>2]=0;v[a+4224>>2]=1056964608;b=a+4228|0;t[b+4|0]=0;t[b+5|0]=4;t[b|0]=69;t[b+1|0]=99;t[b+2|0]=104;t[b+3|0]=111;t[b+6|0]=1;v[23296]=0;R(851,a+44|0,2);b=v[23296];v[23296]=0;if((b|0)!=1){ki(a);Cs(a);return a|0}b=P()|0;O()|0;vc(c);uf(a);S(b|0);L()}function IV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-512|0;jb=d;c=jb-16|0;jb=c;f=d+8|0;HC(c+8|0,f);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(g|0);if(!e){GC(f)}c=-1;a:{if(!e){break a}c=0;if(!JC(d+8|0)){break a}c=Ge(a,b,IC(w[d+118|0],w[d+119|0]),mb)}jb=d+512|0;return c|0}function TX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;e=jb+-64|0;jb=e;d=1;a:{if(Jg(a,b,0)){break a}d=0;if(!b){break a}b=Fy(b,91388,91436);d=0;if(!b){break a}d=e+8|0;Xb(d|4,0,52);v[e+56>>2]=1;v[e+20>>2]=-1;v[e+16>>2]=a;v[e+8>>2]=b;nb[v[v[b>>2]+28>>2]](b,d,v[c>>2],1);a=v[e+32>>2];if((a|0)==1){v[c>>2]=v[e+24>>2]}d=(a|0)==1}jb=e- -64|0;return d|0}function IN(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;i=v[d+20>>2];h=v[d+52>>2];g=!h|e;t[f+15|0]=g;a:{if(!g|(b|0)!=2){break a}g=c&65535;c=0;while(1){if((c|0)==(g|0)){break a}v[(B(c,872)+d|0)+1380>>2]=0;c=c+1|0;continue}}v[d+24>>2]=0;v[d+16>>2]=0;v[d+20>>2]=0;v[d+48>>2]=h;u[d+72>>1]=x[d+74>>1];nt(a,i>>>0>1&e&(b|0)==1,f+15|0);jb=f+16|0}function $2(a,b){a=a|0;b=b|0;var c=0;v[23296]=0;Y(900,a|0);c=v[23296];v[23296]=0;if((c|0)!=1){v[v[v[a+24>>2]+24>>2]+480272>>2]=b;return 1}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,5745,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function ny(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;e=pi(b,c);a:{if(e>>>0<=$o(a)>>>0){f=c;g=v[a>>2];h=ad(g,v[a+4>>2]);i=h>>>0>=e>>>0;if(!i){v[d+12>>2]=b;v[d+12>>2]=v[d+12>>2]+h;f=v[d+12>>2]}b=Ji(b,f,g);if(!i){_t(a,f,c,e-ad(v[a>>2],v[a+4>>2])|0);break a}Nd(a,b);break a}gB(a);pl(a,zl(a,e));_t(a,b,c,e)}jb=d+16|0}function gz(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+23|0]=0;t[a+24|0]=0;t[a+25|0]=0;t[a+26|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function iW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;f=v[b+16>>2];a:{if(f>>>0<=c>>>0){ic(a,v[d>>2],0);break a}g=v[b+12>>2];b=v[b+4>>2];v[e+20>>2]=v[d+4>>2];v[e+16>>2]=f-c;ic(e+24|0,v[d>>2],v[Ib(e+20|0,e+16|0)>>2]);d=v[v[b>>2]+28>>2];f=v[e+28>>2];v[e+8>>2]=v[e+24>>2];v[e+12>>2]=f;nb[d|0](a,b,c+g|0,e+8|0)}jb=e+32|0}function f3(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[23296]=0;Y(900,a|0);d=v[23296];v[23296]=0;if((d|0)!=1){v[a+4>>2]=c;v[a>>2]=b?b:881;return}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,12927,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function LG(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;e=b+16|0;a:{while(1){d=v[a+36>>2];c=b+8|0;f=nb[v[v[d>>2]+20>>2]](d,v[a+40>>2],c,e,b+4|0)|0;d=-1;g=c;c=v[b+4>>2]-c|0;if((fk(g,1,c,v[a+32>>2])|0)!=(c|0)){break a}b:{switch(f-1|0){case 1:break a;case 0:continue;default:break b}}break}d=As(v[a+32>>2])?-1:0}jb=b+16|0;return d|0}function Dj(a,b){a:{if((b|0)>=1024){a=a*898846567431158e293;if(b>>>0<2047){b=b-1023|0;break a}a=a*898846567431158e293;b=((b|0)<3069?b:3069)-2046|0;break a}if((b|0)>-1023){break a}a=a*2004168360008973e-307;if(b>>>0>4294965304){b=b+969|0;break a}a=a*2004168360008973e-307;b=((b|0)>-2960?b:-2960)+1938|0}l(0,0);l(1,b+1023<<20);return a*+n()}function AY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;while(1){a:{if((c|0)==(d|0)|e>>>0<=h>>>0){break a}f=1;g=jb-16|0;jb=g;k=bi(g+8|0,v[a+8>>2]);i=Jr(0,c,d-c|0,b?b:466956);ai(k);jb=g+16|0;b:{switch(i+2|0){default:f=i;break;case 0:case 1:break a;case 2:break b}}h=h+1|0;j=f+j|0;c=c+f|0;continue}break}return j|0}function uo(a,b,c,d,e){var f=0,g=0,h=0;g=jb-16|0;jb=g;a:{b:{while(1){f=h&255;if(f>>>0>3){break b}if(!Dq(b,c,f>>>0>1)){ah(b,d);ah(c,e);h=h+1|0;continue}break}t[g+15|0]=0;nt(a,0,g+15|0);break a}h=g+8|0;f=w[b|0];if(Bi(f)>>>0>Bi(w[d|0])>>>0){ah(b,d);ah(c,e);f=w[b|0]}d=nt(h,f,c);t[b|0]=0;t[c|0]=0;b=x[d>>1];t[a|0]=b;t[a+1|0]=b>>>8}jb=g+16|0}function Vd(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;Lm(b);f=xf(e+8|0,b);a:{d=a+8|0;b=v[d>>2];if(wc(b,v[a+12>>2])>>>0<=c>>>0){v[23296]=0;R(1158,d|0,c+1|0);a=v[23296];v[23296]=0;if((a|0)==1){break a}b=v[d>>2]}a=Db(b,c);b=v[a>>2];if(b){Pm(b);a=Db(v[d>>2],c)}g=a,h=de(f),v[g>>2]=h;DF(f);jb=e+16|0;return}a=P()|0;O()|0;DF(f);S(a|0);L()}function P1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=jb-16|0;jb=e;g=v[d+4>>2];ex(b,c,g);f=v[b+16>>2];a:{if(f>>>0<=c>>>0){ic(a,v[d>>2],0);break a}v[e+12>>2]=f-c;v[e+8>>2]=g;d=v[d>>2];f=v[Ib(e+12|0,e+8|0)>>2];lq(e,d,g,0,f);h=v[e>>2];i=v[e+4>>2];ch($g(Eb(v[b+4>>2]),c),$g($g(Eb(v[b+4>>2]),c),i),h);lq(a,d,g,0,f)}jb=e+16|0}function vfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb+-64|0;jb=c;b=-1;a:{if(!(nb[v[v[a>>2]+32>>2]](a,0,1084)|0)){break a}al(a,1080);d=c+60|0;PR(a,d);e=d;d=OR(c+40|0);b=0;if(!NR(e,d)){break a}al(a,20);b=1;while(1){if((b&65535)>>>0>=32){b=y[d+4>>2]>=f>>>0}else{e=c+8|0;MR(a,e);b=b+1|0;f=kA(e)+f|0;continue}break}}jb=c- -64|0;return b|0}function j4(a){a=a|0;var b=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){return y[v[v[a+24>>2]+24>>2]+1074420>>2]/1e4|0}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,9232,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function iL(a){var b=0,c=0,d=0;c=jb-32|0;jb=c;a:{d=Ox(a);b=zj(v[a>>2],v[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}v[23296]=0;b=fa(855,c+8|0,b|0,b|0,Gb(a)|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){Ad(a,b);fL(b);break b}a=V(0)|0;O()|0;_(a|0)|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)==1){break a}}jb=c+32|0;return}V(0)|0;O()|0;Ub();L()}function hL(a){var b=0,c=0,d=0;c=jb-32|0;jb=c;a:{d=ui(a);b=wc(v[a>>2],v[a+4>>2]);b:{if(d>>>0<=b>>>0){break b}v[23296]=0;b=fa(856,c+8|0,b|0,b|0,Gb(a)|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){Ad(a,b);eg(b);break b}a=V(0)|0;O()|0;_(a|0)|0;v[23296]=0;Z(17);a=v[23296];v[23296]=0;if((a|0)==1){break a}}jb=c+32|0;return}V(0)|0;O()|0;Ub();L()}function gC(a){var b=0,c=0,d=0,e=0,f=0;d=w[a+9|0]|w[a+10|0]<<8;c=Sia(w[a+3|0],0,18,0);d=d+c|0;b=mb;b=c>>>0>d>>>0?b+1|0:b;c=d;d=b;f=c;c=w[a+6|0]|w[a+7|0]<<8;b=c>>>31|0;e=c<<1;c=f+e|0;b=b+d|0;b=c>>>0<e>>>0?b+1|0:b;d=b;a=w[a+4|0]|w[a+5|0]<<8;b=a>>>30|0;e=a<<2;c=e+c|0;a=b+d|0;a=c>>>0<e>>>0?a+1|0:a;b=c+3|0;a=b>>>0<3?a+1|0:a;mb=a;return b}function Py(a,b,c){var d=0,e=0,f=0;d=Kb(a);a=Fb(b);v[23296]=0;R(47,d|0,a|0);a=v[23296];v[23296]=0;if((a|0)!=1){a:{while(1){if(Fb(b)>>>0>e>>>0){a=65533;f=t[Yf(b,e)|0];if((f|0)>=-96){a=v[((f&255)<<2)+c>>2]}v[23296]=0;R(48,d|0,a|0);a=v[23296];v[23296]=0;if((a|0)==1){break a}e=e+1|0;continue}break}return}}a=P()|0;O()|0;Kc(d);S(a|0);L()}function A1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;a:{if(!(c&1024)){break a}f=e,g=Ii(b),v[f+8>>2]=g;c=tl(v[b+4>>2],w[b+11|0]);b:{if(!c){break b}if(w[rd(b)|0]!=(lf(43)&255)){if(w[rd(b)|0]!=(lf(45)&255)){break b}}d=d+1|0;$I(e+8|0)}if(c>>>0>=d>>>0){break a}BI(b,v[Gf(e,e+8|0)>>2],d-c|0,lf(48))}Sc(a,b);jb=e+16|0}function zq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=Eb(v[b>>2]);g=Eb(v[b+4>>2]);e=jb-16|0;jb=e;v[e+8>>2]=d;while(1){a:{if(!Rb(d,g)){break a}f=jb-16|0;jb=f;yi(f+8|0,v[d>>2],v[d+4>>2]);h=cc(v[f+8>>2]);jb=f+16|0;if((c|0)==(h|0)){break a}d=v[rm(e+8|0)>>2];continue}break}jb=e+16|0;if(uc(d,Eb(v[b+4>>2]))){Bh(a);return}to(a,d)}function s9(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;t[b+23|0]=0;t[b+24|0]=0;t[b+25|0]=0;t[b+26|0]=0;t[b+27|0]=0;t[b+28|0]=0;t[b+29|0]=0;t[b+30|0]=0;v[b+16>>2]=0;v[b+20>>2]=0;c=gc(b,b+16|0,15);nc(b+8|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);c=0;a:{if(v[b+12>>2]!=15){break a}if(Pb(b+16|0,8443,15)){break a}ac(a,15);c=1}jb=b+32|0;return c|0}function lR(a){var b=0,c=0,d=0,e=0,f=0;e=w[a+28|0]|w[a+29|0]<<8;b=Sia(w[a+30|0],0,37,0);c=mb;d=b;b=Sia(w[a+24|0]|w[a+25|0]<<8,0,192,0);d=d+b|0;c=mb+c|0;c=b>>>0>d>>>0?c+1|0:c;b=c;f=e;a=w[a+26|0];c=a>>>26|0;e=d;d=a<<6;e=e+d|0;a=b+c|0;a=d>>>0>e>>>0?a+1|0:a;b=e;c=f+b|0;a=b>>>0>c>>>0?a+1|0:a;b=c+192|0;a=b>>>0<192?a+1|0:a;mb=a;return b}function Yga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;f=jb-16|0;jb=f;c=gf(a,c);ae(f,v[a+28>>2]);a:{if(!c){e=0;if(hd(a,5)){break a}}h=v[a+28>>2];g=jb-16|0;jb=g;e=Kb(g);v[23296]=0;fa(404,b|0,h|0,e|0,d|0)|0;b=v[23296];v[23296]=0;b:{if((b|0)!=1){zb(e);jb=g+16|0;break b}a=P()|0;O()|0;zb(e);S(a|0);L()}e=c}$e(a,e);jb=f+16|0}function E1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=0;a:{if(!v[b+28>>2]){break a}e=0;if((nb[v[b+32>>2]](v[b+24>>2],c,0,0)|0)<0){break a}f=v[d+4>>2];c=v[d>>2];while(1){b:{if(!f){break b}e=nb[v[b+28>>2]](v[b+24>>2],c,f)|0;if(!e){break b}f=f-e|0;c=c+e|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}break}e=g}ic(a,v[d>>2],e)}function QU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;ic(c+8|0,b,10);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0}return a|0}function Jp(a){var b=0,c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Eb(v[a>>2]);e=a;f=Eb(v[a+4>>2]);a=jb-16|0;jb=a;v[a+8>>2]=d;while(1){if(Rb(d,f)){b=b+A[d>>3];d=v[it(a+8|0)>>2];continue}break}jb=a+16|0;a=Eb(v[e>>2]);v[c+8>>2]=a;b=-b;e=Eb(v[e+4>>2]);while(1){if(Rb(a,e)){b=b+A[a>>3];A[a>>3]=b;a=v[it(c+8|0)>>2];continue}else{jb=c+16|0}break}}function AK(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[v[a+16>>2]+24620>>2]/5|0;b=Ic(b,b>>31);v[a+4272>>2]=b;v[23296]=0;v[c+12>>2]=0;U(857,a+4256|0,b<<1,c+12|0);b=v[23296];v[23296]=0;a:{if((b|0)==1){b=V(91780)|0;if((O()|0)!=(ea(91780)|0)){break a}_(b|0)|0;v[a+4272>>2]=0;$()}v[a+4276>>2]=0;v[a+4268>>2]=0;jb=c+16|0;return}S(b|0);L()}function pd(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;hm(a);v[a+16>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=0;v[a+4>>2]=0;u[a+32>>1]=64;v[a+24>>2]=8363;v[a+28>>2]=16777344;v[a+36>>2]=0;t[a+39|0]=0;t[a+40|0]=0;t[a+41|0]=0;t[a+42|0]=0;d=x[a+34>>1]&-25151;u[a+34>>1]=(b|0)==4?d|32:d;b=Vb(c,21473);ze(a+43|0,b);yb(b);RP(a);jb=c+16|0}function j6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=li(a,b,c,d);v[a+4272>>2]=1065353216;v[a>>2]=46992;b=a+4208|0;e=Db(b,0),f=1056880300,v[e>>2]=f;e=Db(b,1),f=1050733080,v[e>>2]=f;e=Db(b,2),f=1056964608,v[e>>2]=f;v[23296]=0;R(851,a+44|0,2);b=v[23296];v[23296]=0;if((b|0)!=1){ki(a);return a|0}b=P()|0;O()|0;uf(a);S(b|0);L()}function c6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=li(a,b,c,d);v[a>>2]=47224;b=a+4208|0;e=Db(b,0),f=1065353216,v[e>>2]=f;e=Db(b,1),f=1065353216,v[e>>2]=f;e=Db(b,2),f=1051372203,v[e>>2]=f;e=Db(b,3),f=0,v[e>>2]=f;v[23296]=0;R(851,a+44|0,2);b=v[23296];v[23296]=0;if((b|0)!=1){ki(a);return a|0}b=P()|0;O()|0;uf(a);S(b|0);L()}function d5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;v[f+8>>2]=d;d=v[Tf(f,f+8|0)>>2];v[23296]=0;ja(898,a+8|0,b|0,c|0,d|0,e|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){a=FI(a);b=EI(a+88|0);c=DI(a+92|0);v[a>>2]=61368;v[b>>2]=61480;v[c>>2]=61560;te(f+8|0);jb=f+16|0;return a|0}a=P()|0;O()|0;te(f+8|0);S(a|0);L()}function VL(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;a:{b:{while(1){v[e+12>>2]=b;v[e+8>>2]=d;if(y[Ib(e+12|0,e+8|0)>>2]<=f>>>0){break b}g=xp(t[Lb(a,f)|0]);h=xp(t[Lb(c,f)|0]);if((g|0)!=(h|0)){a=g>>>0<h>>>0?-1:1;break a}f=f+1|0;if(g){continue}break}a=0;break a}a=0;if((b|0)==(d|0)){break a}a=b>>>0<d>>>0?-1:1}jb=e+16|0;return a}function RI(a){a=a|0;var b=0,c=0,d=0,e=0,f=0,g=0;b=v[a>>2];a:{if(!b){break a}c=v[a+8>>2];if(!c){break a}d=v[a+12>>2];if(!d){break a}e=nb[d|0](b)|0;a=mb;f=a;if((a|0)<0){break a}a=0;b:{if((nb[c|0](b,0,0,0)|0)<0){break b}a=0;if((nb[c|0](b,0,0,2)|0)<0){break b}nb[d|0](b)|0;a=mb;a=(a|0)>0|(a|0)>=0}g=a;nb[c|0](b,e,f,0)|0}return g|0}function tf(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;a:{if(y[b+8>>2]<c>>>0){v[23296]=0;X(1023,17201,9012,392,6342);a=v[23296];v[23296]=0;if((a|0)==1){break a}L()}v[d+8>>2]=v[b+8>>2];e=v[b+4>>2];v[d>>2]=v[b>>2];v[d+4>>2]=e;b=v[d+4>>2];v[a>>2]=v[d>>2];v[a+4>>2]=b;v[a+8>>2]=v[d+8>>2];v[a+12>>2]=c;jb=d+16|0;return}V(0)|0;O()|0;Ub();L()}function nga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb+-64|0;jb=d;c=jb-16|0;jb=c;f=d+8|0;pS(c+8|0,f);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(g|0);if(!e){oS(f)}c=-1;a:{if(!e){break a}c=0;if(!rS(d+8|0)){break a}c=Ge(a,b,qS(d+8|0),mb)}jb=d- -64|0;return c|0}function Sw(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;g=jb-240|0;jb=g;v[g>>2]=a;h=1;a:{if((c|0)<2){break a}e=a;while(1){e=e-4|0;i=c-2|0;f=e-v[(i<<2)+d>>2]|0;if((nb[b|0](a,f)|0)>=0){if((nb[b|0](a,e)|0)>=0){break a}}j=f;f=(nb[b|0](f,e)|0)>=0;e=f?j:e;v[(h<<2)+g>>2]=e;h=h+1|0;c=f?c-1|0:i;if((c|0)>1){continue}break}}HH(g,h);jb=g+240|0}function Ql(a,b,c,d,e,f,g){var h=0,i=0,j=0,k=0;h=jb-16|0;jb=h;i=-17;if(-17-b>>>0>=c>>>0){j=tc(a);if(b>>>0<=2147483622){v[h+8>>2]=b<<1;v[h+12>>2]=b+c;i=zi(v[Yc(h+12|0,h+8|0)>>2])+1|0}c=xc(i);if(e){He(c,j,e)}k=e+f|0;if((k|0)!=(d|0)){He((c+e|0)+g|0,(e+j|0)+f|0,d-k|0)}if((b|0)!=10){Jb(j)}yd(a,c);Af(a,i);jb=h+16|0;return}of();L()}function N8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,52)+e;b=v[d>>2];a:{while(1){if(v[d+4>>2]==(b|0)){break a}v[23296]=0;R(830,b|0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){b=v[d>>2]+52|0;v[d>>2]=b;continue}break}a=P()|0;O()|0;Id(d);S(a|0);L()}Id(d);jb=d+16|0}function GV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;d=jb-48|0;jb=d;c=jb-16|0;jb=c;f=d+8|0;AC(c+8|0,f);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(g|0);if(!e){zC(f)}c=-1;a:{if(!e){break a}c=0;if(!CC(d+8|0)){break a}c=Ge(a,b,BC(w[d+43|0]),mb)}jb=d+48|0;return c|0}function wE(a,b,c,d,e){var f=0;a:{f=jb-32|0;jb=f;Qo(f+8|0,c);v[23296]=0;R(e|0,f+20|0,d|0);c=v[23296];v[23296]=0;b:{c:{if((c|0)!=1){pk(f,f+8|0);v[23296]=0;X(102,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23296];v[23296]=0;if((a|0)==1){break c}Ch(f+8|0);jb=f+32|0;break a}a=P()|0;O()|0;zb(f+8|0);break b}a=P()|0;O()|0;Ch(f+8|0)}S(a|0);L()}}function tE(a,b,c,d,e){var f=0;a:{f=jb-32|0;jb=f;ET(f+8|0,c);v[23296]=0;R(e|0,f+20|0,d|0);c=v[23296];v[23296]=0;b:{c:{if((c|0)!=1){pk(f,f+8|0);v[23296]=0;X(102,a|0,b|0,v[f>>2],v[f+4>>2]);a=v[23296];v[23296]=0;if((a|0)==1){break c}Ch(f+8|0);jb=f+32|0;break a}a=P()|0;O()|0;zb(f+8|0);break b}a=P()|0;O()|0;Ch(f+8|0)}S(a|0);L()}}function fS(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;e=re(b,c);a:{if(e>>>0<=ui(a)>>>0){f=c;g=v[a>>2];h=wc(g,v[a+4>>2]);i=h>>>0>=e>>>0;if(!i){v[d+12>>2]=b;v[d+12>>2]=v[d+12>>2]+(h<<2);f=v[d+12>>2]}b=Ji(b,f,g);if(!i){qA(a,f,c,e-wc(v[a>>2],v[a+4>>2])|0);break a}Nd(a,b);break a}pA(a);il(a,Ug(a,e));qA(a,b,c,e)}jb=d+16|0}function SF(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;i=v[b>>2];h=v[a>>2];e=v[kc(a)>>2]==1106;f=v[c>>2]-h|0;g=f<<1;f=f>>>0<2147483647?g?g:4:-1;g=Yr(e?0:h,f);if(g){if(!e){de(a)}v[d+4>>2]=1071;e=le(d+8|0,g,d+4|0);a=PF(a,e);Qc(e);v[b>>2]=v[a>>2]+(i-h|0);v[c>>2]=v[a>>2]+(f&-4);jb=d+16|0;return}pw();L()}function Jha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-576|0;jb=d;c=jb-16|0;jb=c;kT(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){jT(d)}c=-1;a:{if(!e){break a}c=0;if(!mT(d)){break a}c=Ge(a,b,lT(x[d+34>>1],x[d+36>>1]),mb)}jb=d+576|0;return c|0}function jha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a>>2];d=ad(e,v[a+4>>2]);if(d>>>0<b>>>0){e=jb-32|0;jb=e;b=b-d|0;d=v[Gb(a)>>2];f=v[a+4>>2];a:{if(b>>>0<=d-f>>>0){Do(a,b,c);break a}d=Gb(a);d=Bl(e+8|0,zl(a,ad(v[a>>2],f)+b|0),ad(v[a>>2],v[a+4>>2]),d);KS(d,b,c);Ad(a,d);Al(d)}jb=e+32|0;return}if(b>>>0<d>>>0){Nd(a,b+e|0)}}function I9(a){a=a|0;var b=0,c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;if(!xd(v[a+1298300>>2])){d=v[a+24620>>2];e=jb-16|0;jb=e;b=xc(536);v[23296]=0;d=Q(787,b|0,d|0)|0;f=v[23296];v[23296]=0;a:{if((f|0)!=1){b=v[xf(e+8|0,d)>>2];jb=e+16|0;break a}a=P()|0;O()|0;Jb(b);S(a|0);L()}v[c+8>>2]=b;b=a+1298300|0;a=c+8|0;yM(b,de(a));uy(a)}jb=c+16|0}function u2(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;a:{if(!(c&1024)){break a}f=e,g=Zd(b),v[f+8>>2]=g;b:{if(!Fb(b)){break b}if(w[Oc(b,0)|0]!=(lf(43)&255)){if(w[Oc(b,0)|0]!=(lf(45)&255)){break b}}d=d+1|0;$I(e+8|0)}c=Fb(b);if(c>>>0>=d>>>0){break a}hx(b,v[Gf(e,e+8|0)>>2],d-c|0,lf(48))}Sc(a,b);jb=e+16|0}function c0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=v[a+44>>2];c=v[a+24>>2];if(e>>>0<c>>>0){v[a+44>>2]=c;e=c}f=v[a+8>>2];c=v[a+12>>2];d=-1;a:{if(f>>>0>=c>>>0){break a}if(uc(b,-1)){nn(a,f,c-1|0,e);return Aw(b)|0}g=An(b);if(!(v[a+48>>2]&16)){d=-1;if(!uc(g,t[c-1|0])){break a}}nn(a,f,c-1|0,e);t[v[a+12>>2]]=g;d=b}return d|0}function RL(a,b){var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;gc(d+8|0,rd(b),Cd(v[b+4>>2],w[b+11|0]));b=v[d+8>>2];e=v[d+12>>2];c=jb-16|0;jb=c;f=Cd(v[a+4>>2],w[a+11|0]);v[c+12>>2]=f;v[c+8>>2]=e;g=Ib(c+12|0,c+8|0);a=Tl(rd(a),b,v[g>>2]);a:{if(a){break a}a=-1;if(e>>>0>f>>>0){break a}a=e>>>0<f>>>0}jb=c+16|0;jb=d+16|0;return a>>>31|0}function KC(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(b>>>0<3){if(!b){break a}if(!Ob(v[a>>2],v[a+8>>2],b)){break a}while(1)if((d|0)==2){d=x[c+14>>1];break a}else{t[c+13|0]=0;f=(c+14|0)+d|0;if(b>>>0>d>>>0){og(a,c+13|0);e=w[c+13|0]}else{e=0}t[f|0]=e;d=d+1|0;continue}}aa(11081,8981,136,14045);L()}jb=c+16|0;return d&65535}function yha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=c;a:{e=Ob(v[b>>2],v[b+8>>2],c<<2);if(!e){break a}yc(d+12|0,65535);kg(a,x[d+12>>1]);c=Eb(v[a>>2]);v[d>>2]=c;a=Eb(v[a+4>>2]);while(1){if(!Rb(c,a)){break a}f=d+8|0;if(!Ho(b,f)){tm(f)}u[c>>1]=v[d+8>>2];c=v[Se(d)>>2];continue}}jb=d+16|0;return e|0}function qW(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-32|0;jb=f;v[f+28>>2]=c;v[f+24>>2]=b;v[f+20>>2]=d;v[f+16>>2]=e;v[23296]=0;X(161,f|0,f+24|0,f+20|0,f+16|0);b=v[23296];v[23296]=0;if((b|0)!=1){b=f+8|0;pv(b,v[f>>2],v[f+4>>2]);rg(a,b);ee(b);ee(f);ee(f+24|0);jb=f+32|0;return}a=P()|0;O()|0;ee(f+24|0);S(a|0);L()}function oaa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;b=Rh(d,b);v[23296]=0;U(752,d+16|0,b|0,c|0);e=v[23296];v[23296]=0;a:{b:{if((e|0)!=1){v[23296]=0;U(55,a|0,d+16|0,c|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}yb(d+16|0);yb(b);jb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;yb(d+16|0)}yb(b);S(c|0);L()}function KF(a,b,c,d,e){var f=0,g=0,h=0,i=0;f=jb-16|0;jb=f;g=1073741807;if(1073741807-b>>>0>=c>>>0){h=tc(a);if(b>>>0<=536870886){v[f+8>>2]=b<<1;v[f+12>>2]=b+c;g=El(v[Yc(f+12|0,f+8|0)>>2])+1|0}c=ri(g);if(e){ei(c,h,e)}if((d|0)!=(e|0)){i=e<<2;ei(c+i|0,h+i|0,d-e|0)}if((b|0)!=1){Jb(h)}yd(a,c);Af(a,g);jb=f+16|0;return}of();L()}function vK(a){var b=C(0),c=0,d=C(0);b=z[a+4224>>2];z[a+4260>>2]=K(C(C(1)-C(b*b)));t[a+4264|0]=z[a+4236>>2]>C(.5);d=C(v[a+4256>>2]<<1>>>0);b=C(z[a+4228>>2]*d);a:{if(b<C(4294967296)&b>=C(0)){c=~~b>>>0;break a}c=0}v[a+4248>>2]=c;c=a+4252|0;b=C(z[a+4232>>2]*d);b:{if(b<C(4294967296)&b>=C(0)){a=~~b>>>0;break b}a=0}v[c>>2]=a}function v7(a){a=a|0;var b=0,c=0,d=0,e=0;c=jb-16|0;jb=c;v[v[a+20>>2]+148>>2]=-1;wo(c+8|0,a+4228|0);d=v[a+20>>2];e=v[c+12>>2];b=v[c+8>>2];v[23296]=0;U(869,d+4|0,b|0,Lb(b,e)|0);b=v[23296];v[23296]=0;a:{if((b|0)==1){b=V(91780)|0;if((O()|0)!=(ea(91780)|0)){break a}_(b|0)|0;Hc(v[a+20>>2]+4|0);$()}jb=c+16|0;return}S(b|0);L()}function p_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,i=0;d=jb-16|0;jb=d;i=v[b>>2];h=v[a>>2];e=v[kc(a)>>2]==1106;f=v[c>>2]-h|0;g=f<<1;f=f>>>0<2147483647?g?g:1:-1;g=Yr(e?0:h,f);if(g){if(!e){de(a)}v[d+4>>2]=1071;e=le(d+8|0,g,d+4|0);a=PF(a,e);Qc(e);v[b>>2]=v[a>>2]+(i-h|0);v[c>>2]=f+v[a>>2];jb=d+16|0;return}pw();L()}function a4(a){a=a|0;var b=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){return Eg(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,7039,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Y3(a){a=a|0;var b=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){return us(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,7398,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function VU(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-1968|0;jb=e;c=jb-16|0;jb=c;f=e+8|0;MB(c+8|0,f);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(d|0)){dd(a,v[c+12>>2])}jb=c+16|0;d=(d|0)==(g|0);if(!d){LB(f)}c=-1;a:{if(!d){break a}c=0;if(!NB(e+8|0)){break a}c=Ge(a,b,1024,0)}jb=e+1968|0;return c|0}function RB(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=jb-16|0;jb=c;a=Fi(c,a,1);Di(v[a+4>>2],x[b>>1]);v[a+4>>2]=v[a+4>>2]+2;lc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Gb(a);c=xj(d+8|0,yj(a,Nc(v[a>>2],v[a+4>>2])+1|0),Nc(v[a>>2],v[a+4>>2]),c);Di(v[c+8>>2],x[b>>1]);v[c+8>>2]=v[c+8>>2]+2;Ad(a,c);Gi(c);jb=d+32|0}function A8(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=jb-16|0;jb=c;a=Ph(c,a,1);Ks(v[a+4>>2],z[b>>2]);v[a+4>>2]=v[a+4>>2]+4;lc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Gb(a);c=fg(d+8|0,Ug(a,wc(v[a>>2],v[a+4>>2])+1|0),wc(v[a>>2],v[a+4>>2]),c);Ks(v[c+8>>2],z[b>>2]);v[c+8>>2]=v[c+8>>2]+4;Ad(a,c);eg(c);jb=d+32|0}function $3(a){a=a|0;var b=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){return vs(v[v[a+24>>2]+24>>2])|0}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,6748,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function p4(a){a=a|0;var b=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){return+kM(v[v[a+24>>2]+24>>2])}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,10041,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function lj(a){var b=0,c=0,d=0,e=0,f=0;b=v[a+4>>2];if(uc(v[a>>2],b)){a=0}else{b=qj(b);e=qj(v[a>>2]);c=jb-16|0;jb=c;v[c+8>>2]=b;while(1){a:{if(!Ag(b,e)){break a}d=jb-16|0;jb=d;v[d+8>>2]=b;f=UO(d+8|0);jb=d+16|0;if(x[v[f>>2]>>1]!=65535){break a}b=v[UO(c+8|0)>>2];continue}break}jb=c+16|0;a=vB(Eb(v[a>>2]),b)}return a&65535}function Wv(a,b,c){var d=0;v[23296]=0;Y(900,a|0);d=v[23296];v[23296]=0;if((d|0)!=1){return v[v[v[a+24>>2]+24>>2]+c>>2]}c=V(0)|0;O()|0;_(c|0)|0;v[23296]=0;X(887,b|0,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function RE(a,b,c){var d=0;v[23296]=0;Y(900,a|0);d=v[23296];v[23296]=0;if((d|0)!=1){return x[v[v[a+24>>2]+24>>2]+c>>1]}c=V(0)|0;O()|0;_(c|0)|0;v[23296]=0;X(887,b|0,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function LW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;b=Sm(d,b);v[23296]=0;U(142,d+16|0,b|0,c|0);e=v[23296];v[23296]=0;a:{b:{if((e|0)!=1){v[23296]=0;U(4,a|0,d+16|0,c|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}zb(d+16|0);zb(b);jb=d+32|0;return}c=P()|0;O()|0;break a}c=P()|0;O()|0;zb(d+16|0)}zb(b);S(c|0);L()}function K7(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=33;e=v[a>>2];f=v[a+8>>2];c=v[Ib(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=cf(a)}e=d+8|0;BA(e,b);f=gc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);BA(e,b);Xb(v[d+8>>2]+c|0,0,33-c|0);ac(a,v[d+28>>2]);jb=d+32|0;return c|0}function Zf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;d=a;f=jb-16|0;jb=f;a:{e=pi(b,c);if(e>>>0<4294967280){b:{if(xq(e)){xe(d,e);break b}g=zi(e)+1|0;h=xc(g);yd(d,h);Af(d,g);Td(d,e);d=h}while(1){if((b|0)!=(c|0)){sd(d,b);d=d+1|0;b=b+1|0;continue}break}t[f+15|0]=0;sd(d,f+15|0);jb=f+16|0;break a}of();L()}return a|0}function T9(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;t[d+15|0]=b;b=w[a+11|0];a:{b:{c:{if(!Uf(b)){c=10;b=Lf(b);if((b|0)==10){break c}xe(a,b+1|0);c=a;break a}b=v[a+4>>2];c=fB(v[a+8>>2])-1|0;if((b|0)!=(c|0)){break b}}ry(a,c,1,c,c,0);b=c}c=v[a>>2];Td(a,b+1|0)}a=b+c|0;sd(a,d+15|0);t[d+14|0]=0;sd(a+1|0,d+14|0);jb=d+16|0}function PI(a){var b=0,c=0,d=0,e=0;b=jb-32|0;jb=b;if(!w[a+20|0]){while(1){if(!(nb[v[v[a>>2]+40>>2]](a)|0)){MI(a,65536);c=gc(b+16|0,Lb(v[a+4>>2],v[a+16>>2]),65536);d=v[v[a>>2]+44>>2];e=v[c+4>>2];v[b+8>>2]=v[c>>2];v[b+12>>2]=e;nb[d|0](b+24|0,a,b+8|0);v[a+16>>2]=v[a+16>>2]+v[b+28>>2];continue}break}t[a+20|0]=1}jb=b+32|0}function MX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(Jg(a,v[b+8>>2],e)){bw(b,c,d);return}a:{if(!Jg(a,v[b>>2],e)){break a}if(!(v[b+16>>2]!=(c|0)&v[b+20>>2]!=(c|0))){if((d|0)!=1){break a}v[b+32>>2]=1;return}v[b+20>>2]=c;v[b+32>>2]=d;v[b+40>>2]=v[b+40>>2]+1;if(!(v[b+36>>2]!=1|v[b+24>>2]!=2)){t[b+54|0]=1}v[b+44>>2]=4}}function EO(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;if(w[a+534|0]){while(1){d=c&65535;if(d>>>0>=256){t[a+534|0]=0}else{jj(a,d,1);c=c+1|0;continue}break}}t[b+15|0]=0;Yh(a+8|0,18,b+15|0);Ot(a+26|0,18,29034);t[b+14|0]=255;Yh(a+62|0,256,b+14|0);Tg(v[a>>2],v[a+4>>2],65535,261,1);Tg(v[a>>2],v[a+4>>2],65535,260,0);jb=b+16|0}function ms(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;a:{if(!(c&32)){break a}g=d,h=Zd(b),v[g+8>>2]=h;g=d,h=oh(b),v[g>>2]=h;while(1){if(!Nh(d+8|0,d)){break a}c=v[d+8>>2];f=lf(97);e=t[c|0];b:{if((f|0)>(e|0)){break b}if((lf(122)|0)<(e|0)){break b}g=c,h=(lf(65)-f|0)+e|0,t[g|0]=h}Be(d+8|0);continue}}Sc(a,b);jb=d+16|0}function fs(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;a:{if(!(c&32)){break a}g=d,h=Ii(b),v[g+8>>2]=h;g=d,h=jv(b),v[g>>2]=h;while(1){if(!Nh(d+8|0,d)){break a}c=v[d+8>>2];f=lf(97);e=t[c|0];b:{if((f|0)>(e|0)){break b}if((lf(122)|0)<(e|0)){break b}g=c,h=(lf(65)-f|0)+e|0,t[g|0]=h}Be(d+8|0);continue}}Sc(a,b);jb=d+16|0}function LC(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(b>>>0<5){if(!b){break a}if(!Ob(v[a>>2],v[a+8>>2],b)){break a}while(1)if((d|0)==4){d=v[c+12>>2];break a}else{t[c+11|0]=0;f=(c+12|0)+d|0;if(b>>>0>d>>>0){og(a,c+11|0);e=w[c+11|0]}else{e=0}t[f|0]=e;d=d+1|0;continue}}aa(11081,8981,136,14045);L()}jb=c+16|0;return d}function qga(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c>>2]=v[a+8>>2];d=v[a+8>>2];v[c+8>>2]=a+8;v[c+4>>2]=B(b,20)+d;b=v[c>>2];a:{while(1){if(v[c+4>>2]==(b|0)){break a}v[23296]=0;Y(216,b|0);a=v[23296];v[23296]=0;if((a|0)!=1){b=v[c>>2]+20|0;v[c>>2]=b;continue}break}a=P()|0;O()|0;Id(c);S(a|0);L()}Id(c);jb=c+16|0}function oia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;e=jb-32|0;jb=e;c=jb-16|0;jb=c;f=e+8|0;YB(c+8|0,f);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(d|0)){dd(a,v[c+12>>2])}jb=c+16|0;d=(d|0)==(g|0);if(!d){Eu(f)}c=-1;a:{if(!d){break a}c=0;if(!NT(e+8|0)){break a}c=Ge(a,b,72,0)}jb=e+32|0;return c|0}function mN(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;f=-2147483648;f=!c|!(t[c+15|0]&1)?f:v[c+8>>2];a:{b:{if(!(!d|!(w[d+34|0]&32))){f=x[d+28>>1];break b}if((f|0)==-2147483648){break a}}Mp(b,f,a);Bb(e+8|0,a+1074312|0,10);if(!Cb(v[v[e+8>>2]>>2],v[e+12>>2])|v[a+480208>>2]&16384){break a}v[b+88>>2]=v[b+88>>2]&-257}jb=e+16|0}function nea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-608|0;jb=d;c=jb-16|0;jb=c;JQ(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){IQ(d)}c=-1;a:{if(!e){break a}c=0;if(!LQ(d)){break a}c=Ge(a,b,KQ(x[d+34>>1]),mb)}jb=d+608|0;return c|0}function _x(a,b,c){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;c=F(c,.999);h=c*3.141592653589793;i=jt(b);while(1){if((e|0)!=32768){f=((e<<12^-1)&28672)+(e>>>3|0)|0;if((f|0)!=16384){d=+(f-16384|0)*.000244140625;g=h*d;d=ti(g)*jt(K(d*d*-.0625+1)*b)/(i*g)}else{d=1}j=a,k=Jz(c*d*32768),u[j>>1]=k;e=e+1|0;a=a+2|0;continue}break}}function PQ(a){var b=0,c=0;a:{if(Pb(a,3868,4)|w[a+63|0]!=26){break a}b=w[a+65|0];if(w[a+66|0]|(b|0)!=16&(b|0)!=1|(w[a+64|0]&3|(w[a+78|0]|w[a+79|0]<<8)>>>0>127)){break a}if((w[a+80|0]|w[a+81|0]<<8)>>>0>127){break a}b=a+80|0;a=a+78|0;a=rl(w[a|0]|w[a+1|0]<<8,w[b|0]|w[b+1|0]<<8)?b:a;c=(w[a|0]|w[a+1|0]<<8)!=0}return c}function O3(a){a=a|0;var b=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){return+A[v[a+24>>2]+16>>3]}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,7560,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return 0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function I3(a){a=a|0;var b=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){return v[v[a+24>>2]+8>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,10789,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Zca(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=4896;e=v[a>>2];f=v[a+8>>2];c=v[Ib(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=cf(a)}e=d+8|0;EA(e,b);f=gc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);EA(e,b);Xb(v[d+8>>2]+c|0,0,4896-c|0);ac(a,v[d+28>>2]);jb=d+32|0}function Yda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{d=jb-32|0;jb=d;e=jb-16|0;jb=e;f=e,g=Mb(c&65535),u[f+14>>1]=g;c=d+16|0;rJ(c,e+14|0);jb=e+16|0;Xi(d+8|0,c);v[23296]=0;X(102,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23296];v[23296]=0;if((a|0)!=1){ec(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;ec(d+16|0);S(a|0);L()}}function LQ(a){var b=0;a:{if(Pb(a+44|0,14002,4)|w[a+28|0]!=26|(w[a+40|0]|w[a+41|0]<<8|w[a+30|0]>2)){break a}if(((w[a+38|0]|w[a+39|0]<<8)-33&65535)>>>0<65504|((w[a+32|0]|w[a+33|0]<<8)-257&65535)>>>0<65280|((w[a+34|0]|w[a+35|0]<<8)-256&65535)>>>0<65281){break a}b=((w[a+36|0]|w[a+37|0]<<8)-1&65535)>>>0<128}return b}function fda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=263;e=v[a>>2];f=v[a+8>>2];c=v[Ib(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=cf(a)}e=d+8|0;sP(e,b);f=gc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);sP(e,b);Xb(v[d+8>>2]+c|0,0,263-c|0);ac(a,v[d+28>>2]);jb=d+32|0}function Rx(a,b){var c=0,d=0,e=0,f=0,g=0,h=0;d=jb-16|0;jb=d;h=x[b>>1];c=Wd(a);e=kc(a);f=jb-16|0;jb=f;while(1){if(c){g=Js(x[c+16>>1],h);e=g?e:c;c=v[(g?c+4|0:c)>>2];continue}break}c=v[hc(f+8|0,e)>>2];jb=f+16|0;a:{if(Rb(c,Jf(a))){if(!Js(x[b>>1],x[vd(c)>>1])){break a}}c=Jf(a)}a=v[hc(d+8|0,c)>>2];jb=d+16|0;return a}function Lea(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=jb-16|0;jb=c;a=Qu(c,a,1);dR(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+20;lc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Gb(a);c=bB(d+8|0,cB(a,Df(v[a>>2],v[a+4>>2])+1|0),Df(v[a>>2],v[a+4>>2]),c);dR(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;aB(a,c);fu(c);jb=d+32|0}function iU(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=jb-16|0;jb=c;a=$T(c,a,1);_T(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+48;lc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Gb(a);c=YT(d+8|0,ZT(a,nq(v[a>>2],v[a+4>>2])+1|0),nq(v[a>>2],v[a+4>>2]),c);_T(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+48;XT(a,c);WT(c);jb=d+32|0}function gy(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;f=v[b+656>>2];e=0;a:{if(!f){break a}f=Vu(f,c);e=a+1074312|0;Bb(d+8|0,e,31);a=0;if(!Cb(v[v[d+8>>2]>>2],v[d+12>>2])){Bb(d,e,93);a=Cb(v[v[d>>2]>>2],v[d+4>>2])^1}if(!(t[WL(b,c)+6|0]&1)){e=0;if(!(t[f+12|0]&1)|a){break a}}e=uc(v[f>>2],v[f+4>>2])^1}jb=d+16|0;return e}function YZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a:{if(!Ve(f)){b=v[f+4>>2];v[a>>2]=v[f>>2];v[a+4>>2]=b;v[a+8>>2]=v[f+8>>2];break a}d=v[f>>2];b:{c:{c=v[f+4>>2];d:{if(Hr(c)){xe(a,c);break d}if(c>>>0>=1073741808){break c}e=El(c)+1|0;b=ri(e);yd(a,b);Af(a,e);Td(a,c);a=b}ei(a,d,c+1|0);break b}of();L()}}}function Xaa(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=jb-16|0;jb=c;a=Dz(c,a,1);pz(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+32;lc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Gb(a);c=st(d+8|0,Pp(a,gg(v[a>>2],v[a+4>>2])+1|0),gg(v[a>>2],v[a+4>>2]),c);pz(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+32;MO(a,c);oz(c);jb=d+32|0}function Uha(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=jb-16|0;jb=c;a=Qu(c,a,1);dB(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+20;lc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Gb(a);c=bB(d+8|0,cB(a,Df(v[a>>2],v[a+4>>2])+1|0),Df(v[a>>2],v[a+4>>2]),c);dB(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+20;aB(a,c);fu(c);jb=d+32|0}function iga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=22;e=v[a>>2];f=v[a+8>>2];c=v[Ib(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=cf(a)}e=d+8|0;iu(e,b);f=gc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);iu(e,b);Xb(v[d+8>>2]+c|0,0,22-c|0);ac(a,v[d+28>>2]);jb=d+32|0}function gga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=40;e=v[a>>2];f=v[a+8>>2];c=v[Ib(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=cf(a)}e=d+8|0;rA(e,b);f=gc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);rA(e,b);Xb(v[d+8>>2]+c|0,0,40-c|0);ac(a,v[d+28>>2]);jb=d+32|0}function W2(a,b){a=a|0;b=b|0;var c=0,d=0;a=Kb(a);c=Fb(b);v[23296]=0;R(72,a|0,c|0);c=v[23296];v[23296]=0;if((c|0)!=1){a:{b:{while(1){if(Fb(b)>>>0<=d>>>0){break b}c=t[Yf(b,d)|0];v[23296]=0;R(50,a|0,lf(c)|0);c=v[23296];v[23296]=0;if((c|0)!=1){d=d+1|0;continue}break}break a}return}}b=P()|0;O()|0;zb(a);S(b|0);L()}function Uda(a,b){a=a|0;b=b|0;var c=0,d=0;if(v[a+4>>2]!=v[Gb(a)>>2]){c=jb-16|0;jb=c;a=Ev(c,a);Nz(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;lc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Gb(a);c=ok(d+8|0,Tm(a,wd(v[a>>2],v[a+4>>2])+1|0),wd(v[a>>2],v[a+4>>2]),c);Nz(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;gQ(a,c);fQ(c);jb=d+32|0}function ON(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=jb-16|0;jb=c;a=At(c,a,1);So(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;lc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Gb(a);c=ok(d+8|0,Tm(a,wd(v[a>>2],v[a+4>>2])+1|0),wd(v[a>>2],v[a+4>>2]),c);So(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;nr(a,c);NN(c);jb=d+32|0}function B_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-32|0;jb=g;h=v[20511];v[g+24>>2]=v[20510];v[g+28>>2]=h;h=v[20509];v[g+16>>2]=v[20508];v[g+20>>2]=h;h=v[20507];v[g+8>>2]=v[20506];v[g+12>>2]=h;h=v[20505];v[g>>2]=v[20504];v[g+4>>2]=h;h=a;a=g+32|0;b=Ij(h,b,c,d,e,f,g,a);jb=a;return b|0}function uV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=65;e=v[a>>2];f=v[a+8>>2];c=v[Ib(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=cf(a)}e=d+8|0;Ou(e,b);f=gc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);Ou(e,b);Xb(v[d+8>>2]+c|0,0,65-c|0);ac(a,v[d+28>>2]);jb=d+32|0}function rf(a,b,c,d){var e=0,f=0,g=0;a:{if(!Fb(a)|(c-b|0)<5){break a}Fr(b,c);e=c-4|0;c=Jc(a);g=c+Fb(a)|0;b:{while(1){c:{a=t[c|0];f=a-127|0;if(b>>>0>=e>>>0){break c}if((a|0)!=v[b>>2]&(f&255)>>>0>=130){break b}b=b+4|0;c=((g-c|0)>1)+c|0;continue}break}if((f&255)>>>0<130|a>>>0>v[e>>2]-1>>>0){break a}}v[d>>2]=4}}function Vea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-1120|0;jb=d;c=jb-16|0;jb=c;iR(c+8|0,d+8|0);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!kR(d+8|0)){break a}c=Ge(a,b,jR(v[d+1112>>2]),mb)}jb=d+1120|0;return c|0}function Fp(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;t[d+15|0]=b;a:{b:{c:{if(!Ve(a)){c=10;b=w[a+11|0];if((b|0)==10){break c}xe(a,b+1|0);c=a;break a}c=ml(a);b=v[a+4>>2];c=c-1|0;if((b|0)!=(c|0)){break b}}Ql(a,c,1,c,c,0,0);b=c}c=v[a>>2];Td(a,b+1|0)}a=b+c|0;sd(a,d+15|0);t[d+14|0]=0;sd(a+1|0,d+14|0);jb=d+16|0}function tK(a){var b=0,c=C(0),d=0,e=0;e=v[v[a+16>>2]+24620>>2];b=jb-16|0;jb=b;v[b+12>>2]=0;v[b+8>>2]=1065353216;c=Qh(C(z[Xp(a+4208|0,b+12|0,b+8|0)>>2]*C(999)));a:{if(c<C(4294967296)&c>=C(0)){d=~~c>>>0;break a}d=0}jb=b+16|0;b=(e>>>0)/(d+1>>>0)|0;b=b>>>0>2?b:2;v[a+4216>>2]=b;v[a+4220>>2]=b>>>1;yc(a+4224|0,b)}function aX(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=jb-16|0;jb=c;a=Ev(c,a);So(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+12;lc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Gb(a);c=ok(d+8|0,Tm(a,wd(v[a>>2],v[a+4>>2])+1|0),wd(v[a>>2],v[a+4>>2]),c);So(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+12;nr(a,c);Dv(c);jb=d+32|0}function WV(a,b){a=a|0;b=b|0;var c=0,d=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=jb-16|0;jb=c;a=sD(c,a);mv(v[a+4>>2],b);v[a+4>>2]=v[a+4>>2]+36;lc(a);jb=c+16|0;return}d=jb-32|0;jb=d;c=Gb(a);c=qD(d+8|0,rD(a,$q(v[a>>2],v[a+4>>2])+1|0),$q(v[a>>2],v[a+4>>2]),c);mv(v[c+8>>2],b);v[c+8>>2]=v[c+8>>2]+36;pD(a,c);ov(c);jb=d+32|0}function Pha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-224|0;jb=d;c=jb-16|0;jb=c;sT(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;c=-1;a:{if((e|0)!=(f|0)){break a}c=0;if(!uT(d)){break a}c=Ge(a,b,tT(w[d+216|0],w[d+217|0]),mb)}jb=d+224|0;return c|0}function ry(a,b,c,d,e,f){var g=0,h=0,i=0;g=jb-16|0;jb=g;h=-17;if(-17-b>>>0>=c>>>0){i=rd(a);if(b>>>0<=2147483622){v[g+8>>2]=b<<1;v[g+12>>2]=b+c;h=zi(v[Yc(g+12|0,g+8|0)>>2])+1|0}c=xc(h);if(e){He(c,i,e)}if((d|0)!=(e|0)){He((c+e|0)+f|0,e+i|0,d-e|0)}if((b|0)!=10){Jb(i)}yd(a,c);Af(a,h);jb=g+16|0;return}of();L()}function aea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb+-64|0;jb=d;c=jb-16|0;jb=c;qu(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){ku(d)}c=-1;a:{if(!e){break a}c=0;if(!oQ(d)){break a}c=Ge(a,b,nQ(d),mb)}jb=d- -64|0;return c|0}function aL(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[a+4232>>2];b=(b>>>1)+(b>>>6)|0;v[a+4220>>2]=b;v[23296]=0;v[c+12>>2]=0;U(857,a+4208|0,b<<1,c+12|0);b=v[23296];v[23296]=0;a:{if((b|0)==1){b=V(91780)|0;if((O()|0)!=(ea(91780)|0)){break a}_(b|0)|0;v[a+4220>>2]=0;$()}v[a+4224>>2]=0;jb=c+16|0;return}S(b|0);L()}function L1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0;a:{if(w[b+40|0]){break a}if(!v[b+28>>2]){t[b+40|0]=1;break a}d=v[c+4>>2];f=v[c>>2];while(1){b:{if(d){e=nb[v[b+28>>2]](v[b+24>>2],f,d)|0;if(e){break b}t[b+40|0]=1}d=g;break a}d=d-e|0;f=e+f|0;g=e+g|0;h=g>>>0<e>>>0?h+1|0:h;continue}}ic(a,v[c>>2],d)}function sl(a,b,c,d,e){var f=0;a:{if(c>>>0>255){break a}b:{switch(d-2|0){case 0:d=B(c,872)+b|0;f=aN(v[d+720>>2],v[d+1272>>2],e);if((f+5&255)>>>0>5){break a}return $M(a,b,c,e);case 1:break b;default:break a}}f=$M(a,b,c,e);if((f+5&255)>>>0>5){break a}a=B(c,872)+b|0;f=aN(v[a+720>>2],v[a+1272>>2],e)}return f}function rB(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=jb-32|0;jb=f;v[f+8>>2]=c;g=f,h=cf(b),v[g+28>>2]=h;c=f+8|0;Cf(c,b,v[Ib(c,f+28|0)>>2]);b=ye(c);v[23296]=0;da(224,a|0,b|0,v[f+8>>2],d|0,e|0);a=v[23296];v[23296]=0;if((a|0)!=1){Pc(f+8|0);jb=f+32|0;return}a=P()|0;O()|0;Pc(f+8|0);S(a|0);L()}function j5(a){a=a|0;var b=0;v[23296]=0;Y(900,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){return v[a+16>>2]}b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,5651,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)!=1){$();return-1}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function Fs(a){var b=0,c=0,d=0;b=Lj(+z[a+4228>>2]*8)*.25+-.25;A[a+4248>>3]=b;if(w[a+4240|0]){if(b>45e-5){c=lp(b)/.6931471805599453;b=c-H(c);d=c-b;c=0;a:{if(b<.2075187496394219){break a}c=.4150374992788438;if(b<.5){break a}c=b<.792481250360578?.5849625007211562:1}b=Lj(d+c)*.5}else{b=0}A[a+4248>>3]=b}Es(a)}function Dha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-192|0;jb=d;c=jb-16|0;jb=c;Aq(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){eT(d)}c=-1;a:{if(!e){break a}c=0;if(!gT(d)){break a}c=Ge(a,b,fT(d),mb)}jb=d+192|0;return c|0}function D4(a){a=a|0;var b=0;v[23296]=0;Y(925,a|0);b=v[23296];v[23296]=0;a:{if((b|0)==1){b=V(0)|0;O()|0;_(b|0)|0;v[23296]=0;X(887,11832,a|0,0,0);a=v[23296];v[23296]=0;if((a|0)==1){break a}$();a=0}return a|0}a=P()|0;O()|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;if((b|0)!=1){S(a|0);L()}V(0)|0;O()|0;Ub();L()}function o0(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Kb(a);d=Cd(v[b+4>>2],w[b+11|0]);e=Cd(v[c+4>>2],w[c+11|0]);b=rd(b);v[23296]=0;X(90,a|0,b|0,d|0,d+e|0);b=v[23296];v[23296]=0;a:{if((b|0)!=1){b=rd(c);v[23296]=0;W(91,a|0,b|0,e|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;zb(a);S(b|0);L()}}function Tx(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;v[d>>2]=a;a=v[a+4>>2];v[d+4>>2]=a;v[d+8>>2]=a+B(b,52);b=v[d+4>>2];a=v[d+8>>2];a:{while(1){if((a|0)==(b|0)){break a}v[23296]=0;R(830,b|0,c|0);e=v[23296];v[23296]=0;if((e|0)!=1){b=b+52|0;v[d+4>>2]=b;continue}break}a=P()|0;O()|0;lc(d);S(a|0);L()}lc(d);jb=d+16|0}function NU(a){a=a|0;var b=0,c=0,d=0;c=jb-32|0;jb=c;b=255;a:{if(kj(v[a>>2],v[a+4>>2])>>>0<=49){b=tz(c,v[a+12>>2]);v[23296]=0;R(276,a|0,b|0);d=v[23296];v[23296]=0;if((d|0)==1){break a}Yk(b);Ai(a,kj(v[a>>2],v[a+4>>2])-1&255);b=kj(v[a>>2],v[a+4>>2])-1|0}jb=c+32|0;return b&255}a=P()|0;O()|0;Yk(b);S(a|0);L()}function Im(a,b,c,d){var e=0,f=0,g=0,h=0,i=0;a:{if(v[c>>2]|v[d>>2]){while(1){if((b|0)==(f|0)){break a}e=v[d>>2];g=v[c>>2];h=c,i=g-id((id(0-g|0,31)&255)+g|0,8)|0,v[h>>2]=i;h=d,i=v[d>>2]-id(e+(id(0-e|0,31)&255)|0,8)|0,v[h>>2]=i;e=(f<<3)+a|0;v[e>>2]=v[c>>2];v[e+4>>2]=v[d>>2];f=f+1|0;continue}}Xb(a,0,b<<3)}}function jda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-80|0;jb=d;c=jb-16|0;jb=c;HS(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){FA(d)}c=-1;a:{if(!e){break a}c=0;if(!zP(d)){break a}c=Ge(a,b,yP(d),mb)}jb=d+80|0;return c|0}function bu(a){var b=0,c=0;b=v[a+76>>2];if(!((b|0)>=0&(!b|v[115780]!=(b&-1073741825)))){b=v[a+4>>2];if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;return w[b|0]}return yw(a)}b=v[a+76>>2];v[a+76>>2]=b?b:1073741823;c=a+76|0;b=v[a+4>>2];a:{if((b|0)!=v[a+8>>2]){v[a+4>>2]=b+1;a=w[b|0];break a}a=yw(a)}v[c>>2]=0;return a}function W5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;bd(a,b);v[23296]=0;U(65,d+8|0,b|0,c|0);e=v[23296];v[23296]=0;a:{if((e|0)==1){break a}_b(d+8|0);b=v[b+24>>2];if(b){v[23296]=0;U(66,d|0,b|0,c|0);b=v[23296];v[23296]=0;if((b|0)==1){break a}_b(d)}jb=d+16|0;return}b=P()|0;O()|0;_b(a);S(b|0);L()}function Mk(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;sx(c,b);v[23296]=0;R(1004,c+16|0,c|0);b=v[23296];v[23296]=0;a:{b:{if((b|0)!=1){v[23296]=0;U(1005,a|0,0,c+16|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}Kc(c+16|0);zb(c);jb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Kc(c+16|0)}zb(c);S(b|0);L()}function LU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=c;a:{if(!Ob(v[b>>2],v[b+8>>2],c<<1)){break a}yc(d+12|0,65535);kg(a,x[d+12>>1]);c=Eb(v[a>>2]);v[d>>2]=c;a=Eb(v[a+4>>2]);while(1){if(!Rb(c,a)){break a}Iu(b,d+8|0);e=c,f=Mb(x[d+8>>1]),u[e>>1]=f;c=v[Se(d)>>2];continue}}jb=d+16|0}function Dia(a,b){a=a|0;b=b|0;var c=0;ru(a,b);Of(b);a=w[b+3|0];a:{if((a|0)!=9){if((a|0)!=19){break a}a=w[b+5|0];c=a&240;if((c|0)!=128){if((c|0)!=64){if((c|0)!=48){break a}t[b+3|0]=45;t[b+5|0]=a&15;return}if((a|0)!=64){break a}t[b+3|0]=0;t[b|0]=254;return}t[b+3|0]=20;t[b+5|0]=a&15|160;return}t[b+3|0]=0}}function CY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;v[e>>2]=c;a=ew(f+12|0,0,v[a+8>>2]);b=2;a:{if(a+1>>>0<2){break a}c=a-1|0;b=1;if(c>>>0>d-v[e>>2]>>>0){break a}b=f+12|0;while(1){if(c){a=w[b|0];d=v[e>>2];v[e>>2]=d+1;t[d|0]=a;c=c-1|0;b=b+1|0;continue}break}b=0}jb=f+16|0;return b|0}function C1(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-32|0;jb=f;v[f+28>>2]=e;v[f+24>>2]=d;Og(f+16|0,b,c);b=rg(f+8|0,f+24|0);c=v[b+4>>2];b=v[b>>2];v[23296]=0;wg(157,a,v[f+16>>2],v[f+20>>2],b,c);a=v[23296];v[23296]=0;if((a|0)!=1){ee(f+24|0);jb=f+32|0;return}a=P()|0;O()|0;ee(f+24|0);S(a|0);L()}function Br(a,b,c,d){var e=0;a:{if(!(d&2048)){break a}e=d&74;if(!c|((e|0)==8|(e|0)==64)){break a}t[a|0]=43;a=a+1|0}if(d&512){t[a|0]=35;a=a+1|0}while(1){e=w[b|0];if(e){t[a|0]=e;a=a+1|0;b=b+1|0;continue}break}e=d&74;b=111;b:{if((e|0)==64){break b}b=d&16384?88:120;if((e|0)==8){break b}b=c?100:117}t[a|0]=b}function q8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=li(a,b,c,d);v[a>>2]=43836;b=Qb(a+4208|0);v[a+4228>>2]=0;v[a+4220>>2]=0;v[a+4224>>2]=0;v[a+4232>>2]=v[c+24620>>2];CU(a+4260|0,80,150,80,255);v[23296]=0;R(851,a+44|0,2);c=v[23296];v[23296]=0;if((c|0)!=1){ki(a);return a|0}c=P()|0;O()|0;vc(b);uf(a);S(c|0);L()}function jfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-128|0;jb=d;c=jb-16|0;jb=c;uR(c+8|0,d);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;e=(e|0)==(f|0);if(!e){tR(d)}c=-1;a:{if(!e){break a}c=0;if(!vR(d)){break a}c=Ge(a,b,256,0)}jb=d+128|0;return c|0}function aaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=qc(a,b,614);e=c+616|0;a=0;while(1){d=B(a,872);Bp(d+e|0,(b+d|0)+616|0);a=a+1|0;if((a|0)!=256){continue}break}a=Rz(c+223848|0,b+223848|0);v[23296]=0;Q(756,c+223860|0,b+223860|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){return c|0}b=P()|0;O()|0;fc(a);S(b|0);L()}function Cga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=Eb(v[b>>2]);g=Eb(v[b+4>>2]);e=jb-16|0;jb=e;v[e+8>>2]=d;while(1){a:{if(!Rb(d,g)){break a}f=jb-16|0;jb=f;MS(f+8|0,d);jb=f+16|0;if(x[f+8>>1]==(c|0)){break a}d=v[rm(e+8|0)>>2];continue}break}jb=e+16|0;if(uc(d,Eb(v[b+4>>2]))){Bh(a);return}to(a,d)}function GL(a){var b=0,c=0;a:{if(Pb(a,14036,4)){break a}b=w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24);if((b|0)!=-1095062050&(b|0)!=-1346458146){break a}b=w[a+16|0]|w[a+17|0]<<8|(w[a+18|0]<<16|w[a+19|0]<<24);if(!b){break a}c=(b+24|0)==(w[a+8|0]|w[a+9|0]<<8|(w[a+10|0]<<16|w[a+11|0]<<24))}return c}function eq(a){var b=0,c=0;b=jb-32|0;jb=b;v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;c=a+288|0;zz(c,c+512|0,b);v[b+24>>2]=0;v[b+28>>2]=0;v[b+16>>2]=0;v[b+20>>2]=0;v[b+8>>2]=0;v[b+12>>2]=0;v[b>>2]=0;v[b+4>>2]=0;a=a+800|0;zz(a,XP(a),b);jb=b+32|0}function Ov(a,b,c,d,e){var f=0,g=0;g=c-b|0;a:{if((e|0)>=(g|0)){e=B(32-E(d|1)|0,1233)>>12;f=61;if((g|0)<(e+(y[(e<<2)+25600>>2]<=d>>>0)|0)){break a}}b:{if(d>>>0<=99999999){c=Lw(b,d);break b}c=d;d=(d>>>0)/1e8|0;e=c+B(d,-1e8)|0;c=(e>>>0)/1e4|0;c=Zi(Zi(vH(b,d),c),e+B(c,-1e4)|0)}f=0}v[a+4>>2]=f;v[a>>2]=c}function n7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=6){c=Sd(c,C(0));a:{b:{switch(b-3|0){case 0:c=Qh(c);if(c==z[Db(a+4208|0,3)>>2]){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 1:break b;default:break a}}c=C(Qh(C(c*C(4)))*C(.25))}d=Db(a+4208|0,b),e=c,z[d>>2]=e;Cx(a)}}function I6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=6){c=Sd(c,C(0));a:{b:{switch(b-1|0){case 0:c=Qh(c);if(c==z[Db(a+4208|0,1)>>2]){break a}v[a+4236>>2]=0;z[a+4240>>2]=C(c*C(.5))+C(.5);break a;case 3:break b;default:break a}}c=C(Qh(C(c*C(4)))*C(.25))}d=Db(a+4208|0,b),e=c,z[d>>2]=e;Cx(a)}}function uf(a){a=a|0;var b=0,c=0;v[a>>2]=44304;b=v[a+12>>2];if(v[b>>2]==(a|0)){v[b>>2]=v[a+4>>2]}b=v[a+20>>2];if(b){v[b>>2]=0;v[a+20>>2]=0}b=v[a+4>>2];if(b){v[b+8>>2]=v[a+8>>2]}c=v[a+8>>2];if(c){v[c+4>>2]=b}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+16>>2];v[b+946300>>2]=v[b+946300>>2]-1;UK(a+44|0);return a|0}function HN(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=v[b+48>>2]+1|0;v[b+52>>2]=e;a:{if(y[$b(v[a+484344>>2],x[b+70>>1])+12>>2]>e>>>0){break a}if(!c){u[b+74>>1]=x[b+72>>1]+1}v[b+52>>2]=0;Bb(d+8|0,a+1074312|0,63);if(!Cb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}a=v[b+56>>2];v[b+56>>2]=0;v[b+52>>2]=a}jb=d+16|0}function Xl(a,b,c){var d=0,e=0;a=Kb(a);d=Fb(b);v[23296]=0;R(47,a|0,d|0);d=v[23296];v[23296]=0;if((d|0)!=1){a:{while(1){if(Fb(b)>>>0>e>>>0){d=v[(w[Yf(b,e)|0]<<2)+c>>2];v[23296]=0;R(48,a|0,d|0);d=v[23296];v[23296]=0;if((d|0)==1){break a}e=e+1|0;continue}break}return}}b=P()|0;O()|0;Kc(a);S(b|0);L()}function VK(a){a=a|0;var b=0,c=0,d=0;b=A[a+4264>>3]*+y[v[a+16>>2]+1074376>>2];a:{if(D(b)<0x8000000000000000){d=~~b>>>0;c=D(b)>=1?~~(b>0?F(H(b*2.3283064365386963e-10),4294967295):I((b-+(~~b>>>0>>>0))*2.3283064365386963e-10))>>>0:0;break a}c=-2147483648}A[a+4256>>3]=b-(+(d>>>0)+ +(c|0)*4294967296)}function OX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;if(Jg(a,v[b+8>>2],0)){$v(b,c,d);return}e=v[a+12>>2];f=a+16|0;fF(v[f>>2],v[a+20>>2],b,c,d);a=a+24|0;e=(e<<3)+f|0;a:{if(a>>>0>=e>>>0){break a}while(1){fF(v[a>>2],v[a+4>>2],b,c,d);if(w[b+54|0]){break a}a=a+8|0;if(e>>>0>a>>>0){continue}break}}}function N2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);c=hh(v[b+4>>2],v[b+8>>2]);if(c){mO(a,c);d=v[b+4>>2];e=v[b+8>>2];b=jb-16|0;jb=b;a=To(b,a,c);v[23296]=0;U(1006,d|0,e|0,a+4|0);c=v[23296];v[23296]=0;a:{if((c|0)!=1){lc(a);jb=b+16|0;break a}b=P()|0;O()|0;lc(a);S(b|0);L()}}}function qO(a,b,c){var d=0,e=0,f=0,g=0;if(c==0){e=a;b=ts(b);o(0);a=j(1)|0;f=j(0)|0;o(+c);d=j(1)|0;j(0)|0;l(0,f|0);l(1,a&2147483647|d&-2147483648);Wk(e,b,+n());return}a:{if(!af(b)){break a}d=D(c)<N;if(b<0){c=d?c:1;break a}if(d){break a}Wk(a,b,af(c)?M:c);return}b=ts(b);g=ti(c);Wk(a,b*Qe(c),g*b)}function Mg(a,b){var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;a:{if(!b){b=0;break a}c=b>>31;e=(c^b)-c|0;c=E(e);vf(d,e,0,0,0,c+81|0);e=0+v[d+8>>2]|0;c=(v[d+12>>2]^65536)+(16414-c<<16)|0;c=e>>>0<f>>>0?c+1|0:c;f=b&-2147483648|c;c=v[d+4>>2];b=v[d>>2]}v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=e;v[a+12>>2]=f;jb=d+16|0}function Kha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;v[d+8>>2]=c;v[d+12>>2]=-1;if((c|0)!=-1){f=d,g=Fb(a),v[f>>2]=g;e=v[Ib(d+12|0,d)>>2];v[d+4>>2]=e;a=Tl(Jc(a),b,v[Ib(d+4|0,d+8|0)>>2]);a:{if(a){break a}a=-1;if(c>>>0>e>>>0){break a}a=c>>>0<e>>>0}jb=d+16|0;return a|0}mm();L()}function jB(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;v[e+8>>2]=c;f=e,g=cf(b),v[f+28>>2]=g;c=e+8|0;Cf(c,b,v[Ib(c,e+28|0)>>2]);b=ye(c);v[23296]=0;X(323,a|0,b|0,v[e+8>>2],d|0);a=v[23296];v[23296]=0;if((a|0)!=1){Pc(e+8|0);jb=e+32|0;return}a=P()|0;O()|0;Pc(e+8|0);S(a|0);L()}function WX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;a:{e=v[b>>2];if(xd(e)){if(!De(c)){ZJ(c,17588);e=v[b>>2]}b=v[b+4>>2];nb[v[v[b>>2]+24>>2]](d,b,e);v[23296]=0;Q(753,c|0,d|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break a}yb(d)}Sc(a,c);jb=d+16|0;return}a=P()|0;O()|0;yb(d);S(a|0);L()}function QB(a,b,c){var d=0,e=0,f=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+8>>2]=192;e=v[a>>2];f=v[a+8>>2];c=v[Ib(d+28|0,d+8|0)>>2];if(!Ob(e,f,c)){c=cf(a)}e=d+8|0;Aq(e,b);f=gc(d+16|0,v[d+8>>2],c);nc(d,v[a>>2],v[a+8>>2],v[f>>2],v[f+4>>2]);Aq(e,b);Xb(v[d+8>>2]+c|0,0,192-c|0);ac(a,v[d+28>>2]);jb=d+32|0}function lS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;a=hg(a);b=b+236|0;e=hq(b);a:{while(1){if((b|0)!=(e|0)){d=x[b>>1];u[c+14>>1]=d;if(d){v[23296]=0;U(488,c|0,a|0,c+14|0);d=v[23296];v[23296]=0;if((d|0)==1){break a}}b=b+2|0;continue}break}jb=c+16|0;return}b=P()|0;O()|0;uA(a);S(b|0);L()}function kL(a,b){var c=0,d=0,e=0,f=0,g=C(0);c=jb-16|0;jb=c;if(Kg(v[v[a>>2]-12>>2]+a|0)){u[c+14>>1]=0;Kf(a,c+14|0);e=x[c+14>>1];Qj(b,e);while(1){if((d|0)!=(e|0)){v[c+8>>2]=0;qp(a,c+8|0);f=Db(v[b>>2],d),g=z[c+8>>2],z[f>>2]=g;d=d+1|0;continue}break}d=Kg(v[v[a>>2]-12>>2]+a|0)}jb=c+16|0;return d}function TP(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=jb-16|0;jb=e;v[e+12>>2]=6553600;i=e,j=cc(b),v[i+8>>2]=j;f=+(d>>>0)/6553600;g=e+12|0;b=e+8|0;h=jq(f*+y[Ib(g,b)>>2]);v[e+8>>2]=6553600;i=e,j=cc(c),v[i+4>>2]=j;i=e,j=jq(f*+y[Ib(b,e+4|0)>>2]),v[i+12>>2]=j;v[e+8>>2]=d-h;co(a,h,Ib(b,g));jb=e+16|0}function FJ(a,b){var c=0;c=jb-32|0;jb=c;gi(c,b);v[23296]=0;U(1008,c+16|0,0,c|0);b=v[23296];v[23296]=0;a:{b:{if((b|0)!=1){v[23296]=0;R(1009,a|0,c+16|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}Kc(c+16|0);yb(c);jb=c+32|0;return}b=P()|0;O()|0;break a}b=P()|0;O()|0;Kc(c+16|0)}yb(c);S(b|0);L()}function zv(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+22|0]=0;t[a+23|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function rw(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-160|0;jb=e;v[e+60>>2]=b;v[e+20>>2]=b;v[e+24>>2]=-1;f=e+16|0;ci(f,0,0);FG(e,f,d,1);d=v[e+8>>2];f=v[e+12>>2];g=v[e>>2];h=v[e+4>>2];if(c){v[c>>2]=((v[e+20>>2]+v[e+136>>2]|0)-v[e+60>>2]|0)+b}v[a+8>>2]=d;v[a+12>>2]=f;v[a>>2]=g;v[a+4>>2]=h;jb=e+160|0}function FT(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+14|0]=0;t[a+15|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+20|0]=0;t[a+21|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function yy(a,b,c){var d=0;d=v[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=w[b+813|0];if(c){t[b+813|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}Rj(a,b,b+700|0,c<<2,0)}}function uK(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[a+4256>>2];v[a+4240>>2]=b<<1;v[23296]=0;v[c+12>>2]=0;U(857,a+4208|0,b<<2,c+12|0);b=v[23296];v[23296]=0;a:{if((b|0)==1){b=V(91780)|0;if((O()|0)!=(ea(91780)|0)){break a}_(b|0)|0;v[a+4240>>2]=0;$()}v[a+4244>>2]=0;jb=c+16|0;return}S(b|0);L()}function bp(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;bd(d,a);v[23296]=0;a=T(1084,d|0)|0;d=v[23296];v[23296]=0;a:{b:{if((d|0)==1){break b}v[23296]=0;X(1096,a|0,81808,81834,b|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}_b(c+8|0);jb=c+16|0;break a}a=P()|0;O()|0;_b(c+8|0);S(a|0);L()}return b}function bD(a,b,c){var d=0,e=0,f=0,g=0,h=0;d=v[a+92>>2];e=v[a+96>>2];if(d|e){while(1){if((c|0)==(g|0)){v[a+96>>2]=e;v[a+92>>2]=d}else{f=(g<<3)+b|0;h=v[f>>2];d=d-id((id(0-d|0,31)&255)+d|0,8)|0;v[f>>2]=h+d;h=v[f+4>>2];e=e-id((id(0-e|0,31)&255)+e|0,8)|0;v[f+4>>2]=h+e;g=g+1|0;continue}break}}}function _9(a,b){a=a|0;b=b|0;var c=0,d=0;if(Rd(w[b+24|0])){a=hg(a);c=qj(v[b>>2]);d=yf(b);v[23296]=0;U(759,a|0,c|0,d|0);c=v[23296];v[23296]=0;a:{b:{if((c|0)==1){break b}v[23296]=0;Q(758,a+12|0,b+12|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;fN(a);S(b|0);L()}t[a+24|0]=1}}function Lga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;Nf(b);v[d+12>>2]=0;a:{if(!bk(a,d+12|0)){break a}f=c;c=v[d+12>>2];if(f>>>0<c>>>0){break a}while(1){if((c|0)==(e|0)){e=1;break a}t[d+11|0]=0;if(Jh(a,d+11|0)){Fp(b,t[d+11|0]);e=e+1|0;continue}break}e=0}jb=d+16|0;return e|0}function v_(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;c=jb-128|0;jb=c;v[c+12>>2]=c+116;d=v[a+8>>2];a=c+16|0;VF(d,a,c+12|0,e,f,g);e=v[c+12>>2];d=jb-16|0;jb=d;v[d+8>>2]=b;while(1){if((a|0)!=(e|0)){eH(d+8|0,t[a|0]);a=a+1|0;continue}break}jb=d+16|0;jb=c+128|0;return v[d+8>>2]}function Yaa(a,b){a=a|0;b=b|0;var c=0;a:{v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);c=Nc(v[b>>2],v[b+4>>2]);if(c){Sp(a,c);NO(a,v[b>>2],v[b+4>>2],c)}v[23296]=0;Q(3,a+12|0,b+12|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){v[a+24>>2]=v[b+24>>2];u[a+28>>1]=x[b+28>>1];break a}b=P()|0;O()|0;ud(a);S(b|0);L()}}function Ny(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0,k=0;f=jb-16|0;jb=f;g=v[b+480180>>2];a:{if(g&64671904){b=w[(d&15)+43744|0];t[a+2|0]=0;u[a>>1]=b;break a}Bb(f+8|0,b+1074312|0,66);h=a;a=(c&255)==4&(g|0)==4;b=(d&255)<<a<<4;ko(h,(i=Cb(v[v[f+8>>2]>>2],v[f+12>>2])?0:b,j=b,k=e,k?i:j),a)}jb=f+16|0}function OM(a,b,c){var d=0;d=v[a+480180>>2];a:{if((d|0)!=1048576){if((d|0)!=4){break a}d=w[b+814|0];if(c){t[b+814|0]=d&15|c<<4;break a}c=(d&240)>>>4|0;break a}if(c){t[b+813|0]=c;break a}c=w[b+813|0]}b:{if(!(t[b+851|0]&1)|!v[b+700>>2]){break b}c=c&255;if(!c){break b}Rj(a,b,b+700|0,c,0)}}function dS(a,b,c){var d=0,e=0,f=0;f=jb-16|0;jb=f;e=Fb(a);d=Tc(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=tc(a);if(e){rj(c+d|0,d,e);b=(b>>>0>=d>>>0?d+e>>>0>b>>>0?c:0:0)+b|0}b=rj(d,b,c);c=c+e|0;Mh(a,c);t[f+15|0]=0;sd(b+c|0,f+15|0);break a}Zo(a,d,(c+e|0)-d|0,e,0,0,c,b)}jb=f+16|0;return a}function Ul(a,b,c,d){var e=0,f=0;a:{f=v[(B(b,872)+a|0)+1075648>>2];if(!f){break a}if(!nj(w[f+31|0])){break a}e=w[f+34|0];if((e-1&255)>>>0>249){break a}e=v[(B(e,160)+a|0)+906140>>2];if(!e){break a}nb[v[v[e>>2]+92>>2]](e,f,c,d,b);if(c>>>0>250){break a}u[(B(b,872)+a|0)+1075834>>1]=65535}}function Oz(a,b,c,d,e){var f=0;a:{f=v[a>>2];if(!Ud(f,v[a+20>>2])|c>>>0>=f>>>0|f-c>>>0<d>>>0){break a}hm(b);b=go(b,a);v[b+20>>2]=0;v[b>>2]=d;if(!Bg(b)){break a}if(v[a>>2]!=(d|0)){Yq(b+68|0)}qc(v[b+20>>2],v[a+20>>2]+c|0,d);v[b+8>>2]=e?d:0;v[b+4>>2]=0;u[b+34>>1]=x[b+34>>1]&65533|(e?2:0)}}function t9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb+-64|0;jb=d;Nf(b);e=d+40|0;Cf(e,a,c);a=v[d+40>>2];c=d+8|0;Rf(c,1,ye(e),a);v[23296]=0;R(210,d+24|0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){a=d+24|0;Bc(b,a);yb(a);Pc(d+40|0);jb=d- -64|0;break a}a=P()|0;O()|0;Pc(d+40|0);S(a|0);L()}}function q1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=a+60|0;d=xs(c);v[a>>2]=76952;v[d>>2]=76972;v[a+60>>2]=77012;v[a>>2]=76992;v[a+4>>2]=0;e=c;c=a+8|0;Dn(e,c);v[a>>2]=76952;v[d>>2]=76972;v[23296]=0;Q(80,c|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){return a|0}a=P()|0;O()|0;Fk(d);S(a|0);L()}function pL(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=b;a:{if(ui(a)>>>0>=b>>>0){f=v[a>>2];e=wc(f,v[a+4>>2]);v[d+8>>2]=e;oL(f,v[Ib(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Sx(a,b-e|0,c);break a}Nd(a,v[a>>2]+(b<<2)|0);break a}pA(a);il(a,Ug(a,b));Sx(a,b,c)}jb=d+16|0}function XC(a,b,c,d){var e=0,f=0,g=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;e=d;d=v[a+1068>>2];u[e+(d<<1)>>1]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;f=a,g=Gd(x[v[a+1060>>2]+34>>1])+d|0,v[f+1068>>2]=g;v[a+1072>>2]=v[a+1072>>2]-1}function Saa(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-32|0;jb=e;v[e+24>>2]=d;c=gf(a,c);ae(e+8|0,v[a+28>>2]);f=a;a:{if(!c){d=0;if(hd(a,5)){break a}}d=v[a+28>>2];a=0;tC(b,v[e+24>>2]);while(1){if(y[e+24>>2]>a>>>0){LO(d,dc(v[b>>2],a));a=a+1|0;continue}break}d=c}$e(f,d);jb=e+32|0}function SI(a,b,c,d,e){var f=0;a:{if((e|0)==10){GJ(a,b,c,d);break a}f=d>>>0<e>>>0?1:B(e,e)>>>0>d>>>0?2:3;if((f|0)>(c-b|0)){v[a+4>>2]=61;v[a>>2]=c;break a}c=b+f|0;b=c;while(1){f=d&255;d=(f|0)/(e|0)|0;b=b-1|0;t[b|0]=w[(f-B(d,e)|0)+4856|0];if(d&255){continue}break}v[a+4>>2]=0;v[a>>2]=c}}function QG(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;a=ss(a);v[a+32>>2]=b;v[a>>2]=77492;b=d+8|0;Or(b,a);v[23296]=0;b=T(1063,b|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){_b(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;f=a,g=mn(b),t[f+44|0]=g;jb=d+16|0;return}b=P()|0;O()|0;_b(d+8|0);En(a);S(b|0);L()}function OG(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;a=dH(a);v[a+32>>2]=b;v[a>>2]=77860;b=d+8|0;Or(b,a);v[23296]=0;b=T(1064,b|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){_b(d+8|0);v[a+40>>2]=c;v[a+36>>2]=b;f=a,g=mn(b),t[f+44|0]=g;jb=d+16|0;return}b=P()|0;O()|0;_b(d+8|0);Rr(a);S(b|0);L()}function kV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;a:{if(!Ob(v[b>>2],v[b+8>>2],c<<1)){break a}yc(d+12|0,65535);kg(a,x[d+12>>1]);c=Eb(v[a>>2]);v[d>>2]=c;a=Eb(v[a+4>>2]);while(1){if(!Rb(c,a)){break a}Iu(b,d+8|0);u[c>>1]=x[d+8>>1];c=v[Se(d)>>2];continue}}jb=d+16|0}function Kp(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;a:{e=Xk(a,b);if((e|0)==255){break a}g=v[a>>2];if(Vj(g)){break a}f=Hd(a+318|0,e);e=CO(e);if(h=1,i=t[Lb(f,10)|0]&1,j=d,j?h:i){Tg(g,v[a+4>>2],b,e- -64|0,BO(c,w[Lb(f,2)|0]))}if(d){break a}Tg(v[a>>2],v[a+4>>2],b,e+67|0,BO(c,w[Lb(f,3)|0]))}}function $S(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=jb+-64|0;jb=c;d=c+40|0;Cf(d,a,32);a=v[c+40>>2];e=c+8|0;Rf(e,2,ye(d),a);v[23296]=0;R(210,c+24|0,e|0);a=v[23296];v[23296]=0;if((a|0)!=1){Em(c,b);a=c+24|0;nl(c,a);yb(a);Pc(c+40|0);jb=c- -64|0;break a}a=P()|0;O()|0;Pc(c+40|0);S(a|0);L()}}function uJ(a){var b=0,c=0,d=0,e=0;d=jb-16|0;jb=d;b=a+120|0;ns(w[b+20|0]);c=jb-16|0;jb=c;v[c+8>>2]=d+8;a=jb-16|0;jb=a;e=v[14171];v[a+8>>2]=v[14170];v[a+12>>2]=e;e=v[14169];v[a>>2]=v[14168];v[a+4>>2]=e;b=nb[v[jp(a,Oj(w[b+20|0]))>>2]](c+8|0,b)|0;jb=a+16|0;jb=c+16|0;jb=d+16|0;return b}function Rc(a,b,c){var d=0,e=0;d=b^-2147483648;e=a;b=c&31;if((c&63)>>>0>=32){a=0;b=d>>>b|0}else{a=d>>>b|0;b=((1<<b)-1&d)<<32-b|e>>>b}d=c&31;if((c&63)>>>0>=32){c=0;d=-2147483648>>>d|0}else{c=-2147483648>>>d|0;d=((1<<d)-1&-2147483648)<<32-d}e=b-d|0;mb=a-(c+(b>>>0<d>>>0)|0)|0;return e}function Ir(a,b,c,d){var e=0,f=0;e=jb-160|0;jb=e;f=-1;v[e+148>>2]=b?b-1|0:0;a=b?a:e+158|0;v[e+144>>2]=a;e=Xb(e,0,144);v[e+76>>2]=-1;v[e+36>>2]=1066;v[e+80>>2]=-1;v[e+44>>2]=e+159;v[e+84>>2]=e+144;a:{if((b|0)<0){v[115772]=61;break a}t[a|0]=0;f=BH(e,c,d,1040,1041)}jb=e+160|0;return f}function sv(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;v[f+12>>2]=e;v[f+8>>2]=d;Og(f,b,c);v[23296]=0;Qa(159,a|0,v[f>>2],v[f+4>>2]);b=v[23296];v[23296]=0;if((b|0)!=1){v[a+8>>2]=0;b=f+8|0;rg(a+12|0,b);ee(b);jb=f+16|0;return a|0}a=P()|0;O()|0;ee(f+8|0);S(a|0);L()}function hK(a,b,c){t[a+12|0]=0;v[c>>2]=0;v[b>>2]=0;v[a+28>>2]=0;v[a+32>>2]=0;u[a+24>>1]=0;v[a+36>>2]=0;v[a+40>>2]=0;v[a+44>>2]=0;v[a+48>>2]=0;gK(a+60|0);gK(a+52|0);zp(a+49956|0);zp(a+58148|0);zp(a+66340|0);zp(a+74532|0);Xb(a+228|0,0,32768);Xb(a+32996|0,0,512);Xb(a+33508|0,0,16384)}function Dl(a,b){v[a>>2]=0;v[a+4>>2]=0;v[a+20>>2]=0;u[a+16>>1]=65535;v[a+8>>2]=0;v[a+12>>2]=0;v[a+24>>2]=11;v[a+28>>2]=b;Qb(a+32|0);Qb(a+44|0);v[a+72>>2]=0;v[a+76>>2]=0;v[a+64>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;v[a+80>>2]=0;v[a+84>>2]=0;v[a+88>>2]=0;v[a+92>>2]=0;v[a+96>>2]=0;return a}function XB(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;Nf(b);e=d+40|0;Cf(e,a,c);a=v[d+40>>2];f=d+8|0;Rf(f,3,ye(e),a);v[23296]=0;R(210,d+24|0,f|0);e=v[23296];v[23296]=0;if((e|0)!=1){e=b;b=d+24|0;Bc(e,b);yb(b);Pc(d+40|0);jb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Pc(d+40|0);S(a|0);L()}function Si(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=d;g=bi(e+8|0,b);b=jb-16|0;jb=b;d=v[e+12>>2];v[b+12>>2]=d;v[b+8>>2]=d;f=-1;d=Ir(0,0,c,d);a:{if((d|0)<0){break a}h=a;d=d+1|0;a=Jd(d);v[h>>2]=a;if(!a){break a}f=Ir(a,d,c,v[b+12>>2])}jb=b+16|0;ai(g);jb=e+16|0;return f}function Caa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=b;a:{if($o(a)>>>0>=b>>>0){f=v[a>>2];e=ad(f,v[a+4>>2]);v[d+8>>2]=e;Yh(f,v[Ib(d+12|0,d+8|0)>>2],c);if(b>>>0>e>>>0){Do(a,b-e|0,c);break a}Nd(a,v[a>>2]+b|0);break a}gB(a);pl(a,zl(a,b));Do(a,b,c)}jb=d+16|0}function uha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb+-64|0;jb=d;e=d+40|0;Cf(e,a,c);a=v[d+40>>2];c=d+8|0;Rf(c,2,ye(e),a);v[23296]=0;R(210,d+24|0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){a=d+24|0;wm(b,a);yb(a);Pc(d+40|0);jb=d- -64|0;break a}a=P()|0;O()|0;Pc(d+40|0);S(a|0);L()}}function Qh(a){var b=C(0),c=0,d=0;c=(p(a),j(2));d=c>>>23&255;if(d>>>0<=149){if(d>>>0<=125){return C(a*C(0))}a=(c|0)>=0?a:C(-a);b=C(C(C(a+C(8388608))+C(-8388608))-a);a:{if(b>C(.5)){a=C(C(a+b)+C(-1));break a}a=C(a+b);if(!(b<=C(-.5))){break a}a=C(a+C(1))}a=(c|0)>=0?a:C(-a)}return a}function q9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb+-64|0;jb=d;e=d+40|0;Cf(e,a,c);a=v[d+40>>2];c=d+8|0;Rf(c,1,ye(e),a);v[23296]=0;R(210,d+24|0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){a=d+24|0;ze(b,a);yb(a);Pc(d+40|0);jb=d- -64|0;break a}a=P()|0;O()|0;Pc(d+40|0);S(a|0);L()}}function nU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb+-64|0;jb=d;e=d+40|0;Cf(e,a,c);a=v[d+40>>2];c=d+8|0;Rf(c,2,ye(e),a);v[23296]=0;R(210,d+24|0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){a=d+24|0;Ec(b,a);yb(a);Pc(d+40|0);jb=d- -64|0;break a}a=P()|0;O()|0;Pc(d+40|0);S(a|0);L()}}function dP(a,b){var c=0,d=0,e=0,f=0;c=jb-96|0;jb=c;tQ(b,c,c+96|0);b=0;while(1){if((b|0)==12){v[a+104>>2]=0;v[a+96>>2]=!(v[a+88>>2]|v[a+92>>2]);v[a+100>>2]=0;jb=c+96|0}else{d=b<<3;e=d+a|0;f=c+d|0;d=v[f+4>>2];v[e>>2]=v[f>>2];v[e+4>>2]=d&65535;b=b+1|0;continue}break}v[a+112>>2]=0}function Kq(a,b,c,d,e){var f=0,g=0,h=0,i=0,j=0;f=jb-16|0;jb=f;v[f+12>>2]=c;c=f+12|0;yc(c,256);yc(c,65535);h=x[f+12>>1];kg(a,h);c=0;while(1){if((c|0)==(h|0)){jb=f+16|0}else{g=w[b+c|0];i=kl(v[a>>2],v[a+4>>2],c),j=(d|0)==(g|0)?-1:(e|0)==(g|0)?-2:g,u[i>>1]=j;c=c+1|0;continue}break}}function xJ(a,b,c){var d=0,e=0;while(1){a:{if((a|0)!=(b|0)){e=v[a>>2];d=Ef(e);b:{c:{if((Fb(c)|0)==(d|0)){v[23296]=0;d=W(347,c|0,e|0,d|0)|0;e=v[23296];v[23296]=0;if((e|0)==1){break c}d=!d}else{d=0}break b}V(0)|0;O()|0;Ub();L()}if(!d){break a}}else{a=b}return a}a=a+8|0;continue}}function hS(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;v[e+12>>2]=a;a:{if(!(!c|b)){a=Ie(+(B(a,d)>>>0)*.25*1e4);break a}if(!(!a|!b)){yc(e+12|0,10);a=B(w[v[e+12>>2]+26640|0],1e4);break a}f=+(a>>>0);if(a-1>>>0<=9){a=Ie(733.8401379310345/f*1e4);break a}a=Ie(f/.264*1e4)}jb=e+16|0;return a}function dt(a,b){var c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;ve(d+8|0,b);b=v[d+8>>2];e=v[d+12>>2];c=jb-16|0;jb=c;f=Fb(a);v[c+12>>2]=f;v[c+8>>2]=e;g=Ib(c+12|0,c+8|0);a=Tl(Jc(a),b,v[g>>2]);a:{if(a){break a}a=-1;if(e>>>0>f>>>0){break a}a=e>>>0<f>>>0}jb=c+16|0;jb=d+16|0;return a>>>31|0}function WC(a,b,c,d){var e=0,f=0;b=v[a+1076>>2]+((b&c?0-(c<<1)|0:0)+b|0)|0;v[a+1076>>2]=b;c=b+v[a+1080>>2]|0;v[a+1080>>2]=c;t[v[a+1068>>2]+d|0]=w[a+1084|0]?c:b;v[a+1064>>2]=v[a+1064>>2]+1;e=a,f=v[a+1068>>2]+Gd(x[v[a+1060>>2]+34>>1])|0,v[e+1068>>2]=f;v[a+1072>>2]=v[a+1072>>2]-1}function paa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=jb+-64|0;jb=c;d=c+40|0;Cf(d,a,32);a=v[c+40>>2];e=c+8|0;Rf(e,1,ye(d),a);v[23296]=0;R(210,c+24|0,e|0);a=v[23296];v[23296]=0;if((a|0)!=1){a=c+24|0;Ec(b,a);yb(a);Pc(c+40|0);jb=c- -64|0;break a}a=P()|0;O()|0;Pc(c+40|0);S(a|0);L()}}function nl(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;d=Jc(b);e=c,f=Fb(b),v[e+12>>2]=f;v[c+8>>2]=v[a+4>>2]-1;ch(d,d+v[Ib(c+12|0,c+8|0)>>2]|0,v[a>>2]);d=v[a>>2];e=c,f=Fb(b),v[e+12>>2]=f;a=v[a+4>>2];v[c+8>>2]=a-1;b=v[Ib(c+12|0,c+8|0)>>2];t[c+7|0]=0;Pl(b+d|0,a+d|0,c+7|0);jb=c+16|0}function Te(a){var b=0,c=0;b=jb-32|0;jb=b;t[b+8|0]=0;v[b>>2]=0;v[b+4>>2]=4194432;EC(b+9|0);v[a>>2]=v[b>>2];c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;c=v[b+16>>2];v[a+12>>2]=v[b+12>>2];v[a+16>>2]=c;c=v[b+24>>2];v[a+20>>2]=v[b+20>>2];v[a+24>>2]=c;t[a+28|0]=w[b+28|0];jb=b+32|0}function qea(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-160|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;OQ(c+8|0,e);f=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(f|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(f|0)==(g|0);if(!a){NQ(e)}if(a){d=PQ(b+8|0)}jb=b+160|0;return d|0}function j8(a,b){a=a|0;b=b|0;var c=0;a:{b:{c=v[a+20>>2];b=v[c+4>>2];if((ad(b,v[c+8>>2])|0)!=8){break b}if(Pb(b,9458,4)){break b}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4264>>2]=c;break a}Mx(a,a)}Gs(a)}function Naa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;a=JP(d,a+8|0,b);b=v[a>>2];a:{while(1){if(v[a+4>>2]==(b|0)){break a}v[23296]=0;R(706,b|0,c|0);b=v[23296];v[23296]=0;if((b|0)!=1){b=v[a>>2]+32|0;v[a>>2]=b;continue}break}b=P()|0;O()|0;Id(a);S(b|0);L()}Id(a);jb=d+16|0}function Hia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-624|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;pU(c+8|0,e);f=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(f|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(f|0)==(g|0);if(!a){oU(e)}if(a){d=qU(b+8|0)}jb=b+624|0;return d|0}function vR(a){var b=0;a:{if(Pb(a,15331,4)|((w[a+8|0]|w[a+9|0]<<8)-768&65535)>>>0<65280|(((w[a+112|0]|w[a+113|0]<<8)-65&65535)>>>0<65472|(w[a+106|0]|w[a+107|0]<<8)>>>0>256)){break a}if((w[a+122|0]|w[a+123|0]<<8)>>>0>255){break a}b=(w[a+124|0]|w[a+125|0]<<8)>>>0<4e3}return b}function _B(a,b,c){var d=0,e=0,f=0;d=jb+-64|0;jb=d;e=d+40|0;Cf(e,a,c);a=v[d+40>>2];f=d+8|0;Rf(f,3,ye(e),a);v[23296]=0;R(210,d+24|0,f|0);e=v[23296];v[23296]=0;if((e|0)!=1){e=b;b=d+24|0;Ec(e,b);yb(b);Pc(d+40|0);jb=d- -64|0;return!c|(a|0)!=0}a=P()|0;O()|0;Pc(d+40|0);S(a|0);L()}function Qv(a,b,c,d,e){var f=0,g=0;a:{f=jb+-64|0;jb=f;g=f+40|0;Cf(g,a,e);a=v[f+40>>2];e=f+8|0;Rf(e,d,ye(g),a);v[23296]=0;R(210,f+24|0,e|0);a=v[23296];v[23296]=0;if((a|0)!=1){gc(f,b,c);a=f+24|0;nl(f,a);yb(a);Pc(f+40|0);jb=f- -64|0;break a}a=P()|0;O()|0;Pc(f+40|0);S(a|0);L()}}function QK(a){a=a|0;var b=0,c=0;c=jb-16|0;jb=c;b=v[v[a+16>>2]+1074404>>2];v[23296]=0;v[c+12>>2]=0;U(857,a+4208|0,B(b,254)|0,c+12|0);b=v[23296];v[23296]=0;a:{if((b|0)==1){b=V(91780)|0;if((O()|0)!=(ea(91780)|0)){break a}_(b|0)|0;$()}v[a+4220>>2]=0;jb=c+16|0;return}S(b|0);L()}function uU(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;v[d+12>>2]=b;c=jb-16|0;jb=c;v[c+12>>2]=153391689;v[c+8>>2]=2147483647;e=Ib(c+12|0,c+8|0);jb=c+16|0;c=b;b=v[e>>2];if(c>>>0<=b>>>0){a=wB(a);if(a>>>0<b>>>1>>>0){v[d+8>>2]=a<<1;b=v[Yc(d+8|0,d+12|0)>>2]}jb=d+16|0;return b}Wc();L()}function eia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-32|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;iu(c+8|0,e);f=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(f|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(f|0)==(g|0);if(!a){FT(e)}if(a){d=GT(b+8|0)}jb=b+32|0;return d|0}function dT(a,b,c,d){var e=0,f=0,g=0;if(!b|!d){a=-1}else{e=a;f=e+b|0;d=c+d|0;while(1){a:{b=c;b:{if((e|0)!=(f|0)){while(1){if((b|0)==(d|0)){break b}g=t[b|0];b=b+1|0;if(!uc(t[e|0],g)){continue}break}b=e}else{b=f}break a}e=e+1|0;continue}break}a=(b|0)==(f|0)?-1:b-a|0}return a}function Nga(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c+8>>2]=b;a:{if(wc(v[a>>2],v[a+4>>2])>>>0>511){break a}if(!xd(b)){break a}v[23296]=0;R(434,a|0,c+8|0);a=v[23296];v[23296]=0;d=b;if((a|0)!=1){break a}a=P()|0;O()|0;ig(c+8|0);S(a|0);L()}ig(c+8|0);jb=c+16|0;return d|0}function Fga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;d=-1;c=jb-16|0;jb=c;e=b+8|0;zu(c+8|0,e);f=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);g=v[c+4>>2];if((g|0)==(f|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(f|0)==(g|0);if(!a){AS(e)}if(a){d=BS(b+8|0)}jb=b+16|0;return d|0}function bS(a,b){var c=0,d=0;a:{c=v[b>>2];d=v[b+20>>2];if(!Ud(c,d)){break a}if(v[a+20>>2]==(d|0)){v[a+20>>2]=0;c=v[b>>2]}yc(a,c);c=x[a+34>>1]&-2|u[b+34>>1]&1;u[a+34>>1]=c;u[a+34>>1]=c&65471|x[b+34>>1]&64;if(!Bg(a)){break a}qc(v[a+20>>2],v[b+20>>2],uj(v[a>>2],x[a+34>>1]))}}function ZT(a,b){var c=0,d=0,e=0;d=jb-16|0;jb=d;v[d+12>>2]=b;c=jb-16|0;jb=c;v[c+12>>2]=89478485;v[c+8>>2]=2147483647;e=Ib(c+12|0,c+8|0);jb=c+16|0;c=b;b=v[e>>2];if(c>>>0<=b>>>0){a=VT(a);if(a>>>0<b>>>1>>>0){v[d+8>>2]=a<<1;b=v[Yc(d+8|0,d+12|0)>>2]}jb=d+16|0;return b}Wc();L()}function ND(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-32|0;jb=e;g=v[b+8>>2];f=v[b>>2];Og(e+16|0,c,d);c=v[v[f>>2]+28>>2];d=v[e+20>>2];v[e+8>>2]=v[e+16>>2];v[e+12>>2]=d;nb[c|0](e+24|0,f,g,e+8|0);Og(a,v[e+24>>2],v[e+28>>2]);v[b+8>>2]=v[b+8>>2]+v[a+4>>2];jb=e+32|0}function CB(a,b){var c=0,d=0;a:{b:{a=a-12|0;c:{if(a>>>0>31){break c}d=1<<a;c=1;if(d&-2145904587){break a}if(d&65792){break b}if((a|0)!=7){break c}b=b&240;c=1;if(!b|(b|0)==96|(b|0)==224){break a}}return 0}b=(b&240)-96|0;c=0;if(b>>>0>=144){break a}c=297>>>(b>>>4)&1}return c}function z$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0,h=0;h=(e-d|0)+b|0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=t[b|0];g=t[d|0];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+1|0;b=b+1|0;continue}}break}a=(c|0)!=(h|0)}return a|0}function sn(a,b,c){var d=0,e=0,f=0;a:{if(!b){d=a;break a}while(1){d=Via(a,b,10,0);f=mb;e=Sia(d,f,246,0)+a|0;c=c-1|0;t[c|0]=e|48;e=b>>>0>9;a=d;b=f;if(e){continue}break}}if(d){while(1){c=c-1|0;a=(d>>>0)/10|0;t[c|0]=B(a,246)+d|48;b=d>>>0>9;d=a;if(b){continue}break}}return c}function F2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;Cn(c,a);if(v[b>>2]){Hc(b);a=v[b>>2];Lt(b);Jb(a);d=Gb(b),e=0,v[d>>2]=e;v[b>>2]=0;v[b+4>>2]=0}v[b>>2]=v[c>>2];v[b+4>>2]=v[c+4>>2];a=Gb(c);d=Gb(b),e=v[a>>2],v[d>>2]=e;v[a>>2]=0;v[c>>2]=0;v[c+4>>2]=0;Wf(c);jb=c+16|0}function Bh(a){var b=0,c=0,d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;b=jb-16|0;jb=b;v[b+4>>2]=1;f=b,g=xc(16),v[f+8>>2]=g;c=Ko(v[b+8>>2]);v[c>>2]=42728;f=Nm(zc(c)),g=42860,v[f>>2]=g;c=d+8|0;e=Mo(b);Lo(c,zc(e),e);Om(b);jb=b+16|0;rg(a,c);ee(c);jb=d+16|0;v[a+8>>2]=0;$d(a+12|0);return a}function ge(a){var b=0,c=0,d=0;o(+a);b=j(1)|0;j(0)|0;d=b>>>20&2047;if(d>>>0<=1074){if(d>>>0<=1021){return a*0}a=(b|0)>0|(b|0)>=0?a:-a;c=a+4503599627370496+-4503599627370496-a;a:{if(c>.5){a=a+c+-1;break a}a=a+c;if(!(c<=-.5)){break a}a=a+1}a=(b|0)>0|(b|0)>=0?a:-a}return a}function Z1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;v[d+24>>2]=c;a:{while(1){if((a|0)==(b|0)){break a}c=Vb(d+8|0,v[a>>2]);v[23296]=0;Q(1024,d+24|0,c|0)|0;e=v[23296];v[23296]=0;if((e|0)!=1){yb(c);a=a+4|0;continue}break}a=P()|0;O()|0;yb(c);S(a|0);L()}jb=d+32|0}function an(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;a:{if(!b){b=0;break a}d=b;b=E(b);vf(c,d,0,0,0,b+81|0);e=16414-b<<16;b=0;d=b+v[c+8>>2]|0;e=e+(v[c+12>>2]^65536)|0;e=b>>>0>d>>>0?e+1|0:e;f=d;d=v[c>>2];b=v[c+4>>2]}v[a>>2]=d;v[a+4>>2]=b;v[a+8>>2]=f;v[a+12>>2]=e;jb=c+16|0}function KO(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;a:{e=jb-16|0;jb=e;b:{c:{if((b|0)==(c|0)){b=a;a=Jc(d);Zf(b,a,Fb(d)+a|0);break c}DO(e,c,d);v[23296]=0;U(43,a|0,b|0,e|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}Kc(e)}jb=e+16|0;break a}a=P()|0;O()|0;Kc(e);S(a|0);L()}}function J7(a){a=a|0;var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=4104;a=0;d=v[b+8>>2];a:{if(d>>>0<4096){break a}c=v[b+12>>2];e=c+7&-8;c=e-c|0;if(c>>>0>d-4096>>>0){break a}v[b+12>>2]=e;v[b+8>>2]=d-c;a=e}if(!a){aa(6014,8916,88,7318);L()}jb=b+16|0;return a|0}function Cs(a){var b=0,c=0,d=C(0);b=a+4232|0;c=w[b|0];if(c>>>0>=5){t[b|0]=0;c=0}if(t[a+4233|0]<0){t[a+4233|0]=127}b=t[a+4234|0];if((b|0)<0){t[a+4234|0]=127;b=127}a:{if((c|0)==3){d=C(C(1)-me(C(2),C(-C((b&255)+1|0))));break a}d=me(C(2),C(-C((b&255)>>>0)))}z[a+4224>>2]=d}function AU(a){var b=0,c=0,d=0,e=0,f=0,g=0;b=jb-16|0;jb=b;f=Lb(a,31),g=0,t[f|0]=g;t[b+15|0]=0;c=mi(a,ao(a),b+15|0);t[b+14|0]=0;c=pi(a,c);Pl(c+a|0,ao(a),b+14|0);while(1){if((c|0)!=(d|0)){e=Lb(a,d);if((w[e|0]-127&255)>>>0<=160){t[e|0]=32}d=d+1|0;continue}break}jb=b+16|0}function yW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+12>>2]=c;v[d+8>>2]=b;b=jb-16|0;jb=b;v[b+4>>2]=1;e=b,f=xc(24),v[e+8>>2]=f;c=Ko(v[b+8>>2]);v[c>>2]=61060;JD(zc(c),v[d+8>>2],v[d+12>>2]);c=Mo(b);Lo(d,zc(c),c);Om(b);jb=b+16|0;rg(a,d);ee(d);jb=d+16|0}function qQ(a){var b=0,c=0,d=0,e=0;c=jb-16|0;jb=c;b=Eb(v[a>>2]);v[c+8>>2]=b;e=Eb(v[a+4>>2]);while(1){a:{d=Rb(b,e);if(!d){break a}a=x[b>>1];b:{if(!((a|0)!=255&(a|0)!=99)){u[b>>1]=65535;break b}if(a>>>0>63){break a}}b=v[Se(c+8|0)>>2];continue}break}jb=c+16|0;return d^1}function OD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=jb-16|0;jb=d;b:{c:{if(!b){b=a;a=rd(c);Zf(b,a,Cd(v[c+4>>2],w[c+11|0])+a|0);break c}qM(d,c);v[23296]=0;U(43,a|0,b|0,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}Kc(d)}jb=d+16|0;break a}a=P()|0;O()|0;Kc(d);S(a|0);L()}}function xh(a,b){var c=0,d=0,e=0;a:{if(!(b?1:t[a+480180|0]&1)){break a}e=v[a+24616>>2]&524288;b=0;while(1){if((b|0)==127){break a}c=(b<<5)+a|0;u[c+480286>>1]=64;d=c+480280|0;v[d>>2]=v[d>>2]&-257;d=c+480284|0;c=(b&3)-1>>>0<2;u[d>>1]=e?c<<8:c?192:64;b=b+1|0;continue}}}function sj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=Eb(v[b>>2]);f=Eb(v[b+4>>2]);e=jb-16|0;jb=e;v[e+8>>2]=d;while(1){a:{if(!Rb(d,f)){break a}if(aU(c,v[d>>2],v[d+4>>2])){break a}d=v[rm(e+8|0)>>2];continue}break}jb=e+16|0;if(uc(d,Eb(v[b+4>>2]))){Bh(a);return}to(a,d)}function qz(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;a=Dz(d,a,b);b=v[a+4>>2];e=v[a+8>>2];a:{while(1){if((b|0)==(e|0)){break a}v[23296]=0;R(706,b|0,c|0);f=v[23296];v[23296]=0;if((f|0)!=1){b=b+32|0;v[a+4>>2]=b;continue}break}b=P()|0;O()|0;lc(a);S(b|0);L()}lc(a);jb=d+16|0}function eU(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;t[d+15|0]=1;t[d+14|0]=a>>>2;a=w[ef(d+15|0,d+14|0)|0];e=b>>>0<2|a>>>0<15;if(!e){t[d+13|0]=1;t[d+12|0]=(((a+b|0)-2&65535)>>>0)/((b-1&65535)>>>0);a=w[ef(d+13|0,d+12|0)|0]}jb=d+16|0;return(c?a<<4|(e?15:0):a&15|(e?-16:0))&255}function Yo(a,b,c){var d=0,e=0,f=0;d=a*a;f=d*(d*d)*(d*1.58969099521155e-10+-2.5050760253406863e-8)+(d*(d*27557313707070068e-22+-.0001984126982985795)+.00833333333332249);e=d*a;if(!c){return e*(d*f+-.16666666666666632)+a}return a-(d*(b*.5-f*e)-b+e*.16666666666666632)}function Wr(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=ba(16)|0;if(!w[468945]){t[468945]=1}a=gc(c+8|0,a,93176);c=v[a+4>>2];a=v[a>>2];v[23296]=0;a=fa(1042,d|0,a|0,c|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){ha(a|0,91088,1043);L()}a=P()|0;O()|0;ca(d|0);S(a|0);L()}function UC(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;bd(d,a);v[23296]=0;a=T(18,d|0)|0;d=v[23296];v[23296]=0;a:{if((d|0)==1){break a}v[23296]=0;a=Q(19,a|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break a}_b(c+8|0);jb=c+16|0;return a}a=P()|0;O()|0;_b(c+8|0);S(a|0);L()}function Raa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;f=gf(a,c);ae(e,v[a+28>>2]);a:{b:{if(!f){c=-1;if(!hd(a,5)){break b}break a}c=v[f+8>>2]}d=v[a+28>>2];c:{d:{switch(c+1|0){case 0:case 2:di(d,b);break c;default:break d}}TS(d,b,c)}d=f}$e(a,d);jb=e+16|0}function RC(a,b,c){var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=v[a+4>>2];f=e+b|0;v[a+4>>2]=f;a:{b:{if(!e){g=f-1|0;break b}g=f-1|0;if((g^e-1)>>>0>31){break b}a=v[a>>2];break a}a=v[a>>2];v[a+((f>>>0<33?0:g>>>5|0)<<2)>>2]=0}Co(d+8|0,a,e);bv(v[d+8>>2],v[d+12>>2],b,c);jb=d+16|0}function H$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if(((f=a,g=Lf(t[b|0]),e=v[v[a>>2]+52>>2],nb[e](f|0,g|0)|0)|0)==-1){return d|0}else{b=b+1|0;d=d+1|0;continue}}}c=fk(b,1,c,v[a+32>>2])}return c|0}function AE(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=c;c=e+12|0;yc(c,d);yc(c,65535);f=x[e+12>>1];kg(a,f);c=0;while(1){if((c|0)==(f|0)){jb=e+16|0}else{d=w[b+c|0];g=kl(v[a>>2],v[a+4>>2],c),h=(d|0)==255?-1:(d|0)==254?-2:d,u[g>>1]=h;c=c+1|0;continue}break}}function A7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;v[a+4>>2]=b;v[a>>2]=0;b=mt(a+8|0,d);v[23296]=0;Q(867,a+20|0,c|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){v[a+32>>2]=0;v[a+36>>2]=0;t[a+42|0]=0;t[a+40|0]=0;t[a+41|0]=w[a+41|0]&224|25;return a|0}a=P()|0;O()|0;Tb(b);S(a|0);L()}function wJ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a=Kb(a);d=Ef(b);e=Fb(c);v[23296]=0;X(1013,a|0,b|0,d|0,d+e|0);b=v[23296];v[23296]=0;a:{if((b|0)!=1){b=Jc(c);v[23296]=0;W(1014,a|0,b|0,e|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break a}}b=P()|0;O()|0;yb(a);S(b|0);L()}}function GA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;d=lm(a);e=Cd(v[a+4>>2],w[a+11|0]);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=rd(a);He(d+e|0,b,c);b=c+e|0;au(a,b);t[f+15|0]=0;sd(b+d|0,f+15|0);break a}Ut(a,d,(c+e|0)-d|0,e,e,0,c,b)}jb=f+16|0;return a|0}function d0(a){a=a|0;var b=0,c=0,d=0;c=v[a+44>>2];b=v[a+24>>2];if(c>>>0<b>>>0){v[a+44>>2]=b;c=b}d=-1;a:{if(!(w[a+48|0]&8)){break a}b=v[a+16>>2];if(b>>>0<c>>>0){nn(a,v[a+8>>2],v[a+12>>2],c);b=v[a+16>>2]}a=v[a+12>>2];if(a>>>0>=b>>>0){break a}d=Lf(t[a|0])}return d|0}function Lr(a,b){var c=0,d=0,e=0;d=-1;a:{if((a|0)==-1){break a}e=v[b+76>>2]>=0;b:{c=v[b+4>>2];c:{if(!c){Jw(b);c=v[b+4>>2];if(!c){break c}}if(v[b+44>>2]-8>>>0<c>>>0){break b}}if(!e){break a}return-1}c=c-1|0;v[b+4>>2]=c;t[c|0]=a;v[b>>2]=v[b>>2]&-17;d=a&255}return d}function uE(a,b,c,d){var e=0,f=0;a:{e=jb+-64|0;jb=e;f=e+40|0;Cf(f,a,d);a=v[e+40>>2];d=e+8|0;Rf(d,c,ye(f),a);v[23296]=0;R(210,e+24|0,d|0);a=v[23296];v[23296]=0;if((a|0)!=1){a=e+24|0;ze(b,a);yb(a);Pc(e+40|0);jb=e- -64|0;break a}a=P()|0;O()|0;Pc(e+40|0);S(a|0);L()}}function C6(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;a=li(a,b,c,d);v[a>>2]=46468;b=a+4208|0;e=Db(b,0),f=1017370378,v[e>>2]=f;e=Db(b,1),f=0,v[e>>2]=f;v[23296]=0;R(851,a+44|0,2);b=v[23296];v[23296]=0;if((b|0)!=1){ki(a);return a|0}b=P()|0;O()|0;uf(a);S(b|0);L()}function fT(a){var b=0,c=0,d=0,e=0;d=w[a+32|0]|w[a+33|0]<<8;e=w[a+38|0]|w[a+39|0]<<8;c=w[a+34|0]|w[a+35|0]<<8;b=c+(w[a+36|0]|w[a+37|0]<<8)|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;a=a<<2|b>>>30;c=b<<2;b=d+c|0;a=b>>>0<c>>>0?a+1|0:a;mb=a;return b}function U1(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;a:{c=jb-16|0;jb=c;v[c+4>>2]=1;e=c,f=xc(52),v[e+8>>2]=f;d=v[c+8>>2];v[23296]=0;Q(1031,d|0,b|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){b=a;a=Mo(c);Lo(b,zc(a),a);Om(c);jb=c+16|0;break a}a=P()|0;O()|0;Om(c);S(a|0);L()}}function Paa(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-48|0;jb=c;t[c+40|0]=b;b=c+40|0;Nq(c+16|0,b);d=v[c+16>>2];Nq(c+8|0,b);b=Zf(c+24|0,d,v[c+8>>2]+1|0);v[23296]=0;Q(709,a|0,b|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){yb(b);jb=c+48|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function L8(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-48|0;jb=c;u[c+40>>1]=b;b=c+40|0;ql(c+16|0,b);d=v[c+16>>2];ql(c+8|0,b);b=Zf(c+24|0,d,v[c+8>>2]+2|0);v[23296]=0;Q(709,a|0,b|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){yb(b);jb=c+48|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function BU(a,b,c){var d=0,e=0;d=jb+-64|0;jb=d;Nf(b);e=d+40|0;Cf(e,a,c);a=v[d+40>>2];c=d+8|0;Rf(c,2,ye(e),a);v[23296]=0;R(210,d+24|0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){a=d+24|0;Bc(b,a);yb(a);Pc(d+40|0);jb=d- -64|0;return}a=P()|0;O()|0;Pc(d+40|0);S(a|0);L()}function qC(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;a=Qu(c,a,b);b=v[a+4>>2];d=v[a+8>>2];a:{while(1){if((b|0)==(d|0)){break a}v[23296]=0;Y(216,b|0);e=v[23296];v[23296]=0;if((e|0)!=1){b=b+20|0;v[a+4>>2]=b;continue}break}b=P()|0;O()|0;lc(a);S(b|0);L()}lc(a);jb=c+16|0}function Gk(a){var b=0,c=0;a:{b=v[a+1396>>2];if((b|0)>24){break a}if(!b){v[a+1392>>2]=0}while(1){if(w[a+1376|0]?0:v[a+1384>>2]){break a}c=bs(a);if((c|0)==-1){break a}b=v[a+1396>>2];v[a+1396>>2]=b+8;v[a+1392>>2]=v[a+1392>>2]+(c<<b);if((b|0)<17){continue}break}}}function Bj(a,b){var c=0,d=0,e=0,f=0,g=0;g=v[a+8>>2];while(1){if((b|0)!=(e|0)){d=v[a>>2];if(d){c=v[a+4>>2]}else{v[a>>2]=8;c=g;d=v[a+12>>2];if((c|0)!=(d|0)){c=d-1|0;v[a+12>>2]=c}d=8;c=w[c|0]}v[a>>2]=d-1;v[a+4>>2]=c>>>1;f=c&1|f<<1;e=e+1|0;continue}break}return f}function gA(a,b,c){var d=0,e=0,f=0,g=0,h=0;e=jb-1024|0;jb=e;d=jb-16|0;jb=d;dA(d+8|0,e);f=v[d+12>>2];nc(d,v[a>>2],v[a+8>>2],v[d+8>>2],v[d+12>>2]);g=v[d+4>>2];if((g|0)==(f|0)){ac(a,v[d+12>>2])}jb=d+16|0;if((f|0)==(g|0)){h=eA(e,c)>>>0<=b>>>0}jb=e+1024|0;return h}function _da(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-208|0;jb=b;d=-1;c=jb-16|0;jb=c;lQ(c+8|0,b);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(e|0)==(f|0);if(!a){kQ(b)}if(a){d=mQ(b)}jb=b+208|0;return d|0}function Ub(){var a=0;a=v[23295];v[23296]=0;Z(a|0);a=v[23296];v[23296]=0;a:{if((a|0)!=1){v[23296]=0;Z(1174);a=v[23296];v[23296]=0;if((a|0)!=1){break a}}a=V(0)|0;O()|0;_(a|0)|0;v[23296]=0;Z(1174);a=v[23296];v[23296]=0;if((a|0)!=1){break a}V(0)|0;O()|0;Ub()}L()}function Mha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-160|0;jb=b;d=-1;c=jb-16|0;jb=c;pT(c+8|0,b);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(e|0)==(f|0);if(!a){oT(b)}if(a){d=qT(b)}jb=b+160|0;return d|0}function sG(a,b,c){var d=0,e=0,f=0,g=0;d=a;a:{e=re(b,c);if(e>>>0<1073741808){b:{if(Hr(e)){xe(d,e);break b}f=El(e)+1|0;g=ri(f);yd(d,g);Af(d,f);Td(d,e);d=g}while(1){if((b|0)!=(c|0)){yd(d,v[b>>2]);d=d+4|0;b=b+4|0;continue}break}yd(d,0);break a}of();L()}return a}function g8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0),f=0,g=C(0);d=jb-16|0;jb=d;f=d,g=C(C(nb[v[v[a>>2]+48>>2]](a,b))+c),z[f+12>>2]=g;c=C(0);e=z[d+12>>2];a:{if(!(e<C(0))){c=C(1);if(!(e>C(1))){break a}}z[d+12>>2]=c}nb[v[v[a>>2]+44>>2]](a,b,z[d+12>>2]);jb=d+16|0}function bz(a,b,c,d){var e=0,f=0,g=0;e=Wd(a);a:{if(e){f=kc(a);while(1){a=e;e=x[a+16>>1];g=v[a+20>>2];if(Vk(c,d,e,g)){f=a;e=v[a>>2];if(e){continue}break a}if(!Vk(e,g,c,d)){break a}f=a+4|0;e=v[a+4>>2];if(e){continue}break}break a}a=kc(a);f=a}v[b>>2]=a;return f}function VO(a,b){var c=0,d=0;v[a+4>>2]=b;v[a>>2]=93192;v[a+20>>2]=0;v[a+24>>2]=0;c=(b>>>5|0)+((b&31)!=0)|0;v[a+12>>2]=c;d=(b>>>0)/(c>>>0)|0;v[a+8>>2]=d;v[a+32>>2]=d>>>0<31?-1>>>31-d|0:-1;v[a+28>>2]=b>>>0<c>>>0?0:-1>>>32-d|0;v[a+16>>2]=(B(c,d)-b|0)+c;return a}function MM(a,b,c,d){var e=0,f=0,g=0;t[c+851|0]=w[c+851|0]|64;e=a?w[c+813|0]:0;g=(d|0)<0?e:0-e|0;f=(+(a>>>0)+1)*+(d|0)/+(b>>>0);a:{if(D(f)<2147483648){e=~~f;break a}e=-2147483648}v[c+852>>2]=g+(e+v[c+852>>2]|0);b=(a+1|0)==(b|0)?d:e;a=b>>31;t[c+813|0]=(a^b)-a}function wW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;f=v[b+8>>2];a:{if(f>>>0<=c>>>0){c=v[d>>2];b=0;break a}v[e+12>>2]=f-c;v[e+8>>2]=v[d+4>>2];c=v[b+4>>2]+c|0;f=c;b=v[Ib(e+12|0,e+8|0)>>2];g=c+b|0;c=v[d>>2];Ji(f,g,c)}ic(a,c,b);jb=e+16|0}function Jk(a,b,c){var d=0,e=0,f=0,g=0;e=jb-16|0;jb=e;v[e+8>>2]=c;while(1){a:{if((a|0)!=(b|0)){c=jb-16|0;jb=c;d=rc(c+8|0,v[a>>2]);f=v[d>>2];g=v[d+4>>2];d=v[e+8>>2];d=Mc(f,g,v[d>>2],v[d+4>>2]);jb=c+16|0;if(!d){break a}b=a}jb=e+16|0;return b}a=a+8|0;continue}}function Dy(a,b,c,d){var e=0,f=0,g=0;e=Wd(a);a:{if(e){f=kc(a);while(1){a=e;e=w[a+16|0];g=v[a+20>>2];if(Ln(c,d,e,g)){f=a;e=v[a>>2];if(e){continue}break a}if(!Ln(e,g,c,d)){break a}f=a+4|0;e=v[a+4>>2];if(e){continue}break}break a}a=kc(a);f=a}v[b>>2]=a;return f}function Jga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;Nf(b);t[c+15|0]=0;a:{if(!Jh(a,c+15|0)){break a}f=w[c+15|0];d=1;while(1){if((e&255)==(f|0)){break a}t[c+14|0]=0;if(Jh(a,c+14|0)){Fp(b,t[c+14|0]);e=e+1|0;continue}break}d=0}jb=c+16|0;return d|0}function DV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;b=jb-48|0;jb=b;d=-1;c=jb-16|0;jb=c;wC(c+8|0,b);e=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);f=v[c+4>>2];if((f|0)==(e|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(e|0)==(f|0);if(!a){vC(b)}if(a){d=xC(b)}jb=b+48|0;return d|0}function w$(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;a:{while(1){if((d|0)!=(e|0)){a=-1;if((b|0)==(c|0)){break a}f=v[b>>2];g=v[d>>2];if((f|0)<(g|0)){break a}if((f|0)>(g|0)){return 1}else{d=d+4|0;b=b+4|0;continue}}break}a=(b|0)!=(c|0)}return a|0}function aC(a,b,c){var d=0,e=0;d=jb+-64|0;jb=d;e=d+40|0;Cf(e,a,c);a=v[d+40>>2];c=d+8|0;Rf(c,3,ye(e),a);v[23296]=0;R(210,d+24|0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){a=d+24|0;wm(b,a);yb(a);Pc(d+40|0);jb=d- -64|0;return}a=P()|0;O()|0;Pc(d+40|0);S(a|0);L()}function Je(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=a;e=jb-16|0;jb=e;a:{if(b>>>0<4294967280){b:{if(xq(b)){xe(d,b);break b}f=zi(b)+1|0;g=xc(f);yd(d,g);Af(d,f);Td(d,b);d=g}c=qq(d,b,c);t[e+15|0]=0;sd(b+c|0,e+15|0);jb=e+16|0;break a}of();L()}return a|0}function z_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;bd(g,d);v[23296]=0;b=T(1084,g|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){_b(g);YF(a,f+24|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;_b(g);S(a|0);L()}function y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;bd(g,d);v[23296]=0;b=T(1084,g|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){_b(g);XF(a,f+16|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;_b(g);S(a|0);L()}function Jw(a){var b=0,c=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;if(v[a+20>>2]!=v[a+28>>2]){nb[v[a+36>>2]](a,0,0)|0}v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;b=v[a>>2];if(b&4){v[a>>2]=b|32;return-1}c=v[a+44>>2]+v[a+48>>2]|0;v[a+8>>2]=c;v[a+4>>2]=c;return b<<27>>31}function gU(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=0;a:{if(!a){break a}b:{c:{if(a>>>0<=15){if(b>>>0<2|c){break c}break b}if(b>>>0>1){break b}}e=a|-16;break a}t[d+15|0]=1;t[d+14|0]=(a>>>0)/((b-1&255)>>>0);e=w[ef(d+15|0,d+14|0)|0]}a=e;jb=d+16|0;return a&255}function Nea(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;a:{if(!Ob(v[b>>2],v[b+8>>2],8)){u[c>>1]=0;b=4;while(1){if(b){d=w[c|0]|w[c+1|0]<<8;t[a|0]=d;t[a+1|0]=d>>>8;b=b-1|0;a=a+2|0;continue}break}break a}Km(c+8|0,a);qd(c,b,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function F_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;bd(g,d);v[23296]=0;b=T(18,g|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){_b(g);$F(a,f+24|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;_b(g);S(a|0);L()}function E_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0;g=jb-16|0;jb=g;v[g+8>>2]=b;bd(g,d);v[23296]=0;b=T(18,g|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){_b(g);_F(a,f+16|0,g+8|0,c,e,b);jb=g+16|0;return v[g+8>>2]}a=P()|0;O()|0;_b(g);S(a|0);L()}function xA(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nS(a,b);$c(a,cc(w[b+8|0]|w[b+9|0]<<8|(w[b+10|0]<<16|w[b+11|0]<<24))+504|0);mS(a,d);a:{b=cc(w[b+32|0]|w[b+33|0]<<8|(w[b+34|0]<<16|w[b+35|0]<<24));if(!b){break a}if(!$c(a,b)){break a}zA(a,c);return}Xb(c,0,80)}function r2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=v[b+8>>2];e=v[b+4>>2];f=v[b>>2];a=0;a:while(1){b:{b=0;if((a|0)==(e|0)){break b}while(1)if((b|0)==(d|0)){a=a+1|0;continue a}else{c=v[(a<<2)+f>>2]+(b<<3)|0;v[c>>2]=0;v[c+4>>2]=0;b=b+1|0;continue}}break}}function J9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{b:{if((b|0)!=437){if((b|0)==1252){break b}d=0;if((b|0)==65001){break a}c:{if((b|0)!=28591){if((b|0)==28605){break c}if((b|0)!=20127){break b}d=1;break a}d=2;break a}d=3;break a}d=5;break a}d=8}cD(a,d,c)}function G1(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;if(!w[a+8|0]){Li(a+12|0,v[a+4>>2]);ke(b+24|0,v[a+12>>2],v[a+16>>2]);c=v[v[a>>2]+40>>2];d=v[b+28>>2];v[b+8>>2]=v[b+24>>2];v[b+12>>2]=d;nb[c|0](b+16|0,a,0,b+8|0);t[a+8|0]=1}jb=b+32|0;return v[a+12>>2]}function Ef(a){var b=0,c=0,d=0;b=a;a:{if(b&3){while(1){if(!w[b|0]){break a}b=b+1|0;if(b&3){continue}break}}while(1){c=b;b=b+4|0;d=v[c>>2];if(!((d^-1)&d-16843009&-2139062144)){continue}break}while(1){b=c;c=b+1|0;if(w[b|0]){continue}break}}return b-a|0}function u7(a,b){a=a|0;b=b|0;var c=0,d=0;b=jb-16|0;jb=b;a:{b:{d=v[a+20>>2];c=v[d+4>>2];if((ad(c,v[d+8>>2])|0)!=7){break b}if(Pb(c,9458,4)){break b}c=Eb(c);d=Eb(v[v[a+20>>2]+8>>2]);wo(b+8|0,a+4228|0);ch(c,d,v[b+8>>2]);break a}Mx(a,a)}Cs(a);jb=b+16|0}function $E(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;v[b>>2]=0;t[c+15|0]=0;Jh(a,c+15|0);d=w[c+15|0];e=d>>>2|0;f=d&3;d=0;while(1){v[b>>2]=e;if((d|0)==(f|0)){jb=c+16|0}else{t[c+15|0]=0;Jh(a,c+15|0);d=d+1|0;e=v[b>>2]|w[c+15|0]<<(d<<3)-2;continue}break}}function mQ(a){var b=0;a:{if(Pb(a,14834,4)){break a}if(Mb(w[a+4|0]|w[a+5|0]<<8)>>>0>2|w[a+6|0]>128){break a}if(Mb(w[a+200|0]|w[a+201|0]<<8)>>>0>3999){break a}if(!Mb(w[a+140|0]|w[a+141|0]<<8)){break a}b=(Mb(w[a+148|0]|w[a+149|0]<<8)|0)==50}return b}function cD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=jb-16|0;jb=d;b:{c:{if(!b){b=a;a=Jc(c);Zf(b,a,Fb(c)+a|0);break c}DO(d,b,c);v[23296]=0;R(49,a|0,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}Kc(d)}jb=d+16|0;break a}a=P()|0;O()|0;Kc(d);S(a|0);L()}}function vr(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;f=jb-16|0;jb=f;d=Tc(a);e=Fb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=tc(a);He(d+e|0,b,c);b=c+e|0;Mh(a,b);t[f+15|0]=0;sd(b+d|0,f+15|0);break a}Zo(a,d,(c+e|0)-d|0,e,e,0,c,b)}jb=f+16|0;return a|0}function aG(a,b,c){var d=0,e=0,f=0;d=a;a:{if(b>>>0<1073741808){b:{if(Hr(b)){xe(d,b);break b}e=El(b)+1|0;f=ri(e);yd(d,f);Af(d,e);Td(d,b);d=f}e=b;f=d;while(1){v[f>>2]=c;f=f+4|0;e=e-1|0;if(e){continue}break}yd((b<<2)+d|0,0);break a}of();L()}return a}function CH(a,b){var c=0,d=0,e=0;o(+a);d=j(1)|0;e=j(0)|0;c=d>>>20&2047;if((c|0)!=2047){if(!c){if(a==0){c=0}else{a=CH(a*0x10000000000000000,b);c=v[b>>2]+-64|0}v[b>>2]=c;return a}v[b>>2]=c-1022;l(0,e|0);l(1,d&-2146435073|1071644672);a=+n()}return a}function baa(a,b){a=a|0;b=b|0;var c=0,d=0;a:{b:{c:{if(!Ve(a)){c=1;d=w[a+11|0];if((d|0)==1){break c}xe(a,d+1|0);c=a;break a}c=ml(a)-1|0;d=v[a+4>>2];if((c|0)!=(d|0)){break b}}KF(a,c,1,c,c);d=c}c=v[a>>2];Td(a,d+1|0)}a=(d<<2)+c|0;yd(a,b);yd(a+4|0,0)}function x_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=jb-16|0;jb=a;v[a+8>>2]=b;bd(a,d);v[23296]=0;b=T(1084,a|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){_b(a);WF(f+20|0,a+8|0,c,e,b);jb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;_b(a);S(b|0);L()}function lha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;HA(e,c);Xi(d+8|0,e);v[23296]=0;X(102,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23296];v[23296]=0;if((a|0)!=1){ec(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;ec(d+16|0);S(a|0);L()}}function hha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;Qo(e,c);Xi(d+8|0,e);v[23296]=0;X(102,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23296];v[23296]=0;if((a|0)!=1){ec(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;ec(d+16|0);S(a|0);L()}}function efa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;op(e,c);Xi(d+8|0,e);v[23296]=0;X(282,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23296];v[23296]=0;if((a|0)!=1){Tb(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;Tb(d+16|0);S(a|0);L()}}function ZD(a,b,c,d){var e=0,f=0,g=0;a:{if((c|0)==(d|0)){break a}b:{d=d-c|0;if((d|0)>(b-a|0)){break b}f=1-d|0;g=w[c|0];while(1){e=b-a|0;if((d|0)>(e|0)){break b}a=_p(a,f+e|0,g);if(!a){break b}if(!Tl(a,c,d)){break a}a=a+1|0;continue}}a=b}return a}function TO(a,b,c){var d=0,e=0,f=0,g=0;f=v[b+4>>2];e=b+4|0;Op(v[a>>2],c,e);g=v[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){Di(v[d>>2],x[c>>1]);v[d>>2]=v[d>>2]+2;c=c+2|0;continue}break}oc(a,e);oc(a+4|0,d);oc(Gb(a),zc(b));v[b>>2]=v[b+4>>2];return f}function Oia(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;vq(e,c);Xi(d+8|0,e);v[23296]=0;X(282,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23296];v[23296]=0;if((a|0)!=1){Tb(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;Tb(d+16|0);S(a|0);L()}}function LA(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Qb(a+8|0);v[23296]=0;d=T(190,b|0)|0;e=v[23296];v[23296]=0;b:{if((e|0)==1){break b}v[23296]=0;U(232,a|0,b|0,d|0);a=v[23296];v[23296]=0;if((a|0)==1){break b}break a}a=P()|0;O()|0;fc(c);S(a|0);L()}}function jU(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;OB(e,c);Xi(d+8|0,e);v[23296]=0;X(102,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23296];v[23296]=0;if((a|0)!=1){ec(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;ec(d+16|0);S(a|0);L()}}function W8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;f=gf(a,c);ae(e,v[a+28>>2]);a:{b:{if(!f){c=-1;if(!hd(a,5)){break b}break a}c=v[f+8>>2]}d=v[a+28>>2];c:{if(!((c|0)!=4&(c|0)!=-1)){bk(d,b);break c}YG(d,b,c)}d=f}$e(a,d);jb=e+16|0}function UD(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;Vm(e,c);Xi(d+8|0,e);v[23296]=0;X(102,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23296];v[23296]=0;if((a|0)!=1){ec(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;ec(d+16|0);S(a|0);L()}}function IT(a,b,c){var d=0,e=0,f=0,g=0;f=v[b+4>>2];e=b+4|0;Op(v[a>>2],c,e);g=v[a+4>>2];d=b+8|0;while(1){if((c|0)!=(g|0)){Hj(v[d>>2],w[c|0]);v[d>>2]=v[d>>2]+1;c=c+1|0;continue}break}oc(a,e);oc(a+4|0,d);oc(Gb(a),zc(b));v[b>>2]=v[b+4>>2];return f}function BV(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;a:{d=jb-32|0;jb=d;e=d+16|0;Mu(e,c);Xi(d+8|0,e);v[23296]=0;X(102,a|0,b|0,v[d+8>>2],v[d+12>>2]);a=v[23296];v[23296]=0;if((a|0)!=1){ec(d+16|0);jb=d+32|0;break a}a=P()|0;O()|0;ec(d+16|0);S(a|0);L()}}function uD(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+18|0]=0;t[a+19|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function rO(a){var b=0,c=0,d=0,e=0,f=0;b=jb-16|0;jb=b;c=a;d=v[a>>2];f=hh(d,v[a+4>>2]);a=Eb(d);v[b+8>>2]=a;e=+(f>>>0);c=Eb(v[c+4>>2]);while(1){if(Rb(a,c)){A[a>>3]=A[a>>3]/e;A[a+8>>3]=A[a+8>>3]/e;a=v[eo(b+8|0)>>2];continue}else{jb=b+16|0}break}}function VB(a){var b=0,c=0,d=0,e=0;b=w[a+2|0];c=b+(w[a+5|0]|w[a+6|0]<<8)|0;d=b>>>0>c>>>0?1:d;b=c;c=b<<1;b=d<<1|b>>>31;a=w[a+3|0]|w[a+4|0]<<8;d=a>>>30|0;e=c;c=a<<2;e=e+c|0;a=b+d|0;a=c>>>0>e>>>0?a+1|0:a;b=e+47|0;a=b>>>0<47?a+1|0:a;mb=a;return b}function D_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;a=jb-16|0;jb=a;v[a+8>>2]=b;bd(a,d);v[23296]=0;b=T(18,a|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){_b(a);ZF(f+20|0,a+8|0,c,e,b);jb=a+16|0;return v[a+8>>2]}b=P()|0;O()|0;_b(a);S(b|0);L()}function fA(a,b,c){var d=0;d=jb-16|0;jb=d;u[d+12>>1]=c;u[d+14>>1]=b;b=Eb(v[a>>2]);c=Eb(v[a+4>>2]);a=jb-16|0;jb=a;v[a+8>>2]=b;while(1){if(Rb(b,c)){if(x[b>>1]==x[d+14>>1]){u[b>>1]=x[d+12>>1]}b=v[Se(a+8|0)>>2];continue}break}jb=a+16|0;jb=d+16|0}function Xo(a,b){var c=0,d=0,e=0,f=0;c=a*a;d=c*.5;e=1-d;f=1-e-d;d=c*c;return e+(f+(c*(c*(c*(c*2480158728947673e-20+-.001388888888887411)+.0416666666666666)+d*d*(c*(c*-11359647557788195e-27+2.087572321298175e-9)+-2.7557314351390663e-7))-a*b))}function AN(a,b){var c=0,d=0;d=jb-16|0;jb=d;c=v[a+104>>2];a:{if(!c){break a}c=v[c>>2];if(!c){break a}v[a+76>>2]=c;v[a+88>>2]=v[a+88>>2]&-131|128;v[d+12>>2]=b<<8;v[d+8>>2]=c-1;b=c+(v[Ib(d+12|0,d+8|0)>>2]^-1)|0;v[a>>2]=0;v[a+4>>2]=b}jb=d+16|0}function tG(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;g=hc(e+8|0,v[v[b>>2]-12>>2]+b|0),h=b,v[g+4>>2]=h;f=c;Bk(v[e+12>>2],c,d);b=jb-16|0;jb=b;v[b+12>>2]=v[v[e+12>>2]+4>>2];v[b+8>>2]=0;c=v[Ne(b+8|0,b+12|0)>>2];jb=b+16|0;ic(a,f,c);jb=e+16|0}function dD(a){var b=0,c=0;a:{if(Pb(a,14021,4)){break a}if(Pb(a+8|0,13942,4)){break a}b=cc(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24));if(!b){break a}c=(cc(w[a+12|0]|w[a+13|0]<<8|(w[a+14|0]<<16|w[a+15|0]<<24))|0)!=0&b>>>0>27}return c}function BK(a,b,c){var d=0,e=0;if(C(D(a))<C(0x8000000000000000)){d=~~a>>>0}else{d=0}e=d&-2147483648;d=e?0-d|0:d;while(1){if(!((d|0)<0|(b|0)<=0)){b=b-1|0;d=d<<1;continue}break}b=(d>>>31|0)+b<<31-c|(d&2147483647)>>>c;return C((e?b^-1|e:b)|0)}function vE(a,b,c,d){var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;v[e+12>>2]=c;c=e+12|0;yc(c,d);yc(c,65535);d=x[e+12>>1];kg(a,d);c=0;while(1){if((c|0)==(d|0)){jb=e+16|0}else{f=w[b+c|0];g=kl(v[a>>2],v[a+4>>2],c),h=f,u[g>>1]=h;c=c+1|0;continue}break}}function uda(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;u[b+28>>1]=0;v[b+24>>2]=0;c=gc(b+8|0,b+24|0,6);nc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=6){break a}if(Pb(b+24|0,3856,6)){break a}ac(a,6);d=1}jb=b+32|0;return d|0}function uQ(a){var b=0,c=0;a:{if(w[a+29|0]!=2){break a}b=w[a+28|0];if((b|0)!=26&(b|0)!=2|w[a+30|0]!=2){break a}b=w[a+31|0];if(b>>>0>21|!(1<<b&3146753)|w[a+33|0]>64){break a}b=w[a+34|0];if(b>>>0>=65&(b|0)!=88){break a}c=rQ(a+20|0)}return c}function ce(a,b){var c=0,d=0;c=v[a+4>>2];d=c+b|0;v[a+4>>2]=d;if(v[a+8>>2]>=(d|0)){d=v[a>>2]+(c>>3)|0;a=c&7;c=w[d|0]&255>>>a;a=a+b|0;b=0;while(1){if((a|0)>=9){a=a-8|0;b=c<<a|b;c=w[d+1|0];d=d+1|0;continue}break}a=c>>>8-a|b}else{a=0}return a}function RN(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+3|0]|w[b+4|0]<<8|(w[b+5|0]<<16|w[b+6|0]<<24);t[a+3|0]=b;t[a+4|0]=b>>>8;t[a+5|0]=b>>>16;t[a+6|0]=b>>>24}function L2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-32|0;jb=d;Mk(d,c);c=d+16|0;v[c>>2]=b;Sc(c+4|0,d);v[23296]=0;R(1007,a+4|0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){qs(d+16|0);yb(d);jb=d+32|0;return}a=P()|0;O()|0;qs(d+16|0);yb(d);S(a|0);L()}function Cf(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=Qb(a+8|0);v[23296]=0;U(232,a|0,b|0,c|0);c=v[23296];v[23296]=0;a:{if((c|0)!=1){a=v[a>>2];v[23296]=0;Q(176,b|0,a|0)|0;a=v[23296];v[23296]=0;if((a|0)!=1){break a}}a=P()|0;O()|0;fc(d);S(a|0);L()}}function Aha(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;t[b+30|0]=0;u[b+28>>1]=0;c=gc(b+8|0,b+28|0,3);nc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=3){break a}if(Pb(b+28|0,14593,3)){break a}ac(a,3);d=1}jb=b+32|0;return d|0}function ria(a,b){a=a|0;b=b|0;var c=0;b=jb-32|0;jb=b;c=-1;a:{if(!mB(a,b+16|0)){break a}c=0;if(!ST(b+16|0)){break a}if(!Pb(b+16|0,14007,4)){c=-1;if(!dd(a,4)){break a}}c=-1;if(!Aj(a,b+8|0)){break a}c=!Pb(b+8|0,13983,4)}jb=b+32|0;return c|0}function Yv(a,b){var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;u[b>>1]=0;t[c+15|0]=0;Jh(a,c+15|0);d=w[c+15|0];e=d>>>1|0;f=d&1;d=0;while(1){u[b>>1]=e;if(d>>>0>=f>>>0){jb=c+16|0}else{t[c+15|0]=0;Jh(a,c+15|0);e=x[b>>1]|w[c+15|0]<<7;d=1;continue}break}}function jN(a,b){var c=0,d=0;a:{if(!(w[a+89|0]&16)){break a}c=v[a+656>>2];if(!c){break a}c=v[c>>2];b:{if(c){d=a;a=v[a+696>>2]-(c<<1)|0;a=(a|0)>0?a:0;v[d+696>>2]=a;a=(B(a,v[b>>2])|0)/65536|0;break b}if(v[a+696>>2]){break a}a=0}v[b>>2]=a}}function aH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;if(d>>>0<4294967280){a:{if(xq(d)){xe(a,c);break a}f=zi(d)+1|0;d=xc(f);yd(a,d);Af(a,f);Td(a,c);a=d}a=He(a,b,c);t[e+15|0]=0;sd(a+c|0,e+15|0);jb=e+16|0;return}of();L()}function Vv(a,b,c,d,e,f){var g=0;g=jb-16|0;jb=g;v[g+12>>2]=e;v[g+8>>2]=d;d=rg(g,g+8|0);e=v[d+4>>2];d=v[d>>2];v[23296]=0;a=wg(f,a,b,c,d,e);b=v[23296];v[23296]=0;if((b|0)!=1){ee(g+8|0);jb=g+16|0;return a}a=P()|0;O()|0;ee(g+8|0);S(a|0);L()}function zia(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;kv(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;if((d|0)!=(e|0)){t[b+2|0]=0;t[b|0]=0;t[b+1|0]=0}}function zN(a,b){var c=0,d=0;a:{if(!(t[a+851|0]&1)){break a}c=v[a+104>>2];if(!c){break a}d=v[c>>2];if(!d){break a}v[a+76>>2]=d;v[a>>2]=0;v[a+4>>2]=d-1;c=v[a+88>>2];v[a+88>>2]=b?c|134:c&-135|128;if(!b){break a}v[a+84>>2]=d;v[a+80>>2]=0}}function ci(a,b,c){var d=0,e=0,f=0,g=0;v[a+112>>2]=b;v[a+116>>2]=c;e=v[a+4>>2];d=v[a+44>>2]-e|0;v[a+120>>2]=d;v[a+124>>2]=d>>31;d=a;a=v[a+8>>2];f=a-e|0;g=f>>31;if(!(!(b|c)|((c|0)>=(g|0)&b>>>0>=f>>>0|(c|0)>(g|0)))){a=b+e|0}v[d+104>>2]=a}function IM(a,b){a=EM(a);EM(a+368680|0);if(b){DM(a,1);return}if(!w[462056]){IM(93352,1);t[462056]=1}Wn(224464,29e4,a+131112|0);Wn(29e4,355536,a+196648|0);Wn(355536,421072,a+262184|0);Wn(93376,224464,a+24|0);qc(a+327720|0,421072,40960)}function uN(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=c&15;if(e){t[b+824|0]=e}c=c&240;if(c){t[b+823|0]=c>>>4}v[b+88>>2]=v[b+88>>2]|131072;Bb(d+8|0,a+1074312|0,80);if(!(!e|!Cb(v[v[d+8>>2]>>2],v[d+12>>2]))){t[b+824|0]=w[b+824|0]<<2}jb=d+16|0}function s2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=v[b+8>>2];d=v[b+4>>2];e=v[b>>2];a=0;a:while(1){b:{b=0;if((a|0)==(d|0)){break b}while(1)if((b|0)==(c|0)){a=a+1|0;continue a}else{f=Up(e,a,b),g=0,v[f>>2]=g;b=b+1|0;continue}}break}}function Pga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=jb-16|0;jb=c;while(1){a:{d=v[a>>2];if(wc(d,v[a+4>>2])>>>0>e>>>0){Sm(c,v[Db(d,e)>>2]+40|0);d=bq(c,b);zb(c);if(!d){break a}f=v[Db(v[a>>2],e)>>2]}jb=c+16|0;return f|0}e=e+1|0;continue}}function vha(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;EA(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){Xb(b,0,4896)}return a|0}function vO(a,b){var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(b){mO(a,b);d=jb-16|0;jb=d;c=To(d,a,b);b=v[c+4>>2];e=v[c+8>>2];while(1){if((b|0)==(e|0)){lc(c);jb=d+16|0}else{Wk(b,0,0);b=b+16|0;v[c+4>>2]=b;continue}break}}return a}function q7(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(v[b+4>>2]!=8){break a}b=v[b>>2];if(Pb(b,9458,4)){break a}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4228>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4232>>2]=c;Cs(a)}}function a8(a,b,c){a=a|0;b=b|0;c=c|0;a:{if(v[b+4>>2]!=8){break a}b=v[b>>2];if(Pb(b,9458,4)){break a}c=w[b+4|0]|w[b+5|0]<<8|(w[b+6|0]<<16|w[b+7|0]<<24);v[a+4260>>2]=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);v[a+4264>>2]=c;Gs(a)}}function Ti(a,b,c){c=v[c+4>>2]&176;if((c|0)==32){return b}a:{if((c|0)!=16){break a}b:{c:{c=w[a|0];switch(c-43|0){case 0:case 2:break c;default:break b}}return a+1|0}if((c|0)!=48|(b-a|0)<2|(w[a+1|0]|32)!=120){break a}a=a+2|0}return a}function oda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-32|0;jb=d;e=pf(v[b>>2],v[b+4>>2]);c=FP(d+8|0,c);v[23296]=0;X(678,a|0,b|0,e-1&65535,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){Le(c);jb=d+32|0;return}a=P()|0;O()|0;Le(c);S(a|0);L()}function O$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{if(!w[a+44|0]){c=(c|0)>0?c:0;while(1){if((c|0)==(d|0)){break a}if((nb[v[v[a>>2]+52>>2]](a,v[b>>2])|0)==-1){return d|0}else{b=b+4|0;d=d+1|0;continue}}}c=fk(b,4,c,v[a+32>>2])}return c|0}function fM(a){var b=0,c=0,d=0;c=jb-544|0;jb=c;a:{if(!(w[a+480210|0]&128)|!v[a+24668>>2]){break a}d=a+1298224|0;b=a+1074992|0;a=Gz(c,v[a+24620>>2]);while(1){if((b|0)==(d|0)){break a}qc(b+112|0,a,538);b=b+872|0;continue}}jb=c+544|0}function Gz(a,b){var c=0,d=0,e=0,f=0;u[a+24>>1]=0;v[a+20>>2]=0;c=3546895/+(b>>>0);d=c*.25;a:{if(D(d)<2147483648){b=~~d;break a}b=-2147483648}v[a+16>>2]=b;v[a>>2]=0;v[a+4>>2]=0;e=a,f=UP(c-+(b<<2)),v[e+8>>2]=f;v[a+12>>2]=mb;return a}function Ey(a,b,c){var d=0,e=0;d=Wd(a);a:{if(d){e=kc(a);while(1){a=d;d=w[a+16|0];if(Mn(c,d)){e=a;d=v[a>>2];if(d){continue}break a}if(!Mn(d,c)){break a}e=a+4|0;d=v[a+4>>2];if(d){continue}break}break a}a=kc(a);e=a}v[b>>2]=a;return e}function zV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;Ou(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){Xb(b,0,65)}return a|0}function WD(){var a=0,b=0,c=0;b=jb-16|0;jb=b;a=Vb(b,15023);a:{if(!Fb(a)){break a}c=1;if((tg(a,14489)|0)!=-1){break a}if((tg(a,16618)|0)!=-1){break a}if((tg(a,13555)|0)!=-1){break a}c=(tg(a,13598)|0)!=-1}yb(a);jb=b+16|0;return c|0}function QD(a){var b=0;if(!(Pb(a,13199,8)|(w[a+8|0]|w[a+9|0]<<8)!=14|(!(w[a+12|0]|w[a+13|0]<<8)|(w[a+14|0]|w[a+15|0]<<8|(w[a+16|0]<<16|w[a+17|0]<<24))<=0))){b=(w[a+18|0]|w[a+19|0]<<8|(w[a+20|0]<<16|w[a+21|0]<<24))>>>0>23}return b}function Eea(a,b){a=a|0;b=b|0;var c=0;b=jb-32|0;jb=b;c=-1;a:{if(!mB(a,b+16|0)){break a}c=0;if(!ZQ(b+16|0)){break a}c=-1;if(!Aj(a,b+8|0)){break a}c=0;if(!v[b+12>>2]){break a}a=v[b+8>>2];c=(a&2139062143)==(a|0)}jb=b+32|0;return c|0}function fR(a,b,c){var d=0,e=0,f=0,g=0;while(1){if((b|0)!=(c|0)){e=v[a+4>>2];f=e>>>8|0;d=v[a>>2];e=(e&255)<<24|d>>>8;d=(((d^w[b|0])&255)<<3)+21496|0;g=v[d>>2];d=v[d+4>>2]^f;v[a>>2]=e^g;v[a+4>>2]=d;b=b+1|0;continue}break}return a}function bia(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Ob(v[a>>2],v[a+8>>2],64);a:{if(!d){a=0;while(1){if((a|0)!=32){Iq((a<<1)+b|0);a=a+1|0;continue}break}break a}qu(c+8|0,b);qd(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;return d|0}function _U(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Ob(v[a>>2],v[a+8>>2],120);a:{if(!d){a=0;while(1){if((a|0)!=120){vg(a+b|0);a=a+1|0;continue}break}break a}ic(c+8|0,b,120);qd(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;return d|0}function $f(a,b){var c=0,d=0,e=0,f=0;d=x[a+22>>1];e=d+x[a+20>>1]|0;c=x[a+24>>1]<<17;while(1){if((d|0)==(e|0)){a=(c|0)/32768|0}else{f=c;c=((d&127)<<2)+a|0;c=f-B(v[Db(b,x[c+28>>1])>>2],u[c+26>>1])|0;d=d+1|0;continue}break}return a}function qB(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;e=v[a>>2];f=ik(e,v[a+4>>2]);while(1){a:{c=d&65535;if(c>>>0>=f>>>0){break a}c=Pf(e,c);if(!Rb(v[c>>2],v[c+4>>2])){break a}d=d+1|0;continue}break}return(bh(a,d&65535,b)?d:-1)&65535}function ni(a){var b=0,c=0,d=0,e=0;e=Ee(a);c=e&63;a:{if(!(e&64)){break a}b=6;while(1){d=Ee(a);c=(d&127)<<b|c;if(!(d&128)){break a}d=b>>>0<25;b=b+7|0;if(d){continue}break}}a=e>>>7|0;b=a?-2147483648:c;return a?(c|0)>=0?0-c|0:b:b}function lfa(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;u[b+30>>1]=0;c=gc(b+8|0,b+30|0,2);nc(b+16|0,v[a>>2],v[a+8>>2],v[c>>2],v[c+4>>2]);a:{if(v[b+20>>2]!=2){break a}if(Pb(b+30|0,13463,2)){break a}ac(a,2);d=1}jb=b+32|0;return d|0}function UL(a,b,c){var d=0,e=0,f=0,g=0,h=0;g=c;h=c>>31;c=0;while(1){if((b|0)!=(c|0)){d=v[a>>2];e=v[a+4>>2];f=(d+e|0)/2|0;d=d-e|0;d=Ic(Tia(Sia(d,d>>31,g,h),mb,256,0),mb);v[a+4>>2]=f-d;v[a>>2]=d+f;c=c+1|0;a=a+8|0;continue}break}}function Cq(a){var b=0,c=0,d=0,e=0;c=jb-16|0;jb=c;b=jb-16|0;jb=b;Nq(b+8|0,c+15|0);d=v[b+12>>2];md(b,a,v[b+8>>2],v[b+12>>2]);e=v[b+4>>2];if((e|0)==(d|0)){dd(a,v[b+12>>2])}jb=b+16|0;jb=c+16|0;return((d|0)==(e|0)?w[c+15|0]:0)&255}function su(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;f=jb-16|0;jb=f;if(b){e=Tc(a);d=Fb(a);g=d+b|0;if(e-d>>>0<b>>>0){Ql(a,e,g-e|0,d,d,0,0)}e=d;d=tc(a);qq(e+d|0,b,c);Mh(a,g);t[f+15|0]=0;sd(d+g|0,f+15|0)}jb=f+16|0;return a|0}function rga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;BA(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){CA(b)}return a|0}function Tia(a,b,c,d){var e=0,f=0,g=0,h=0;f=b^d;g=f>>31;e=b>>31;a=a^e;h=a-e|0;e=(b^e)-((a>>>0<e>>>0)+e|0)|0;a=d>>31;b=c^a;f=f>>31;a=Via(h,e,b-a|0,(a^d)-((a>>>0>b>>>0)+a|0)|0)^f;b=a-f|0;mb=(g^mb)-((a>>>0<f>>>0)+g|0)|0;return b}function Laa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;yO(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){gz(b)}return a|0}function FN(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;a:{if(!c){break a}v[b+40>>2]=c;if(!c|v[a+480180>>2]!=256){break a}v[d+12>>2]=c>>>4;v[d+8>>2]=1;e=b,f=v[Yc(d+12|0,d+8|0)>>2],v[e+40>>2]=f;e=b,f=Qz(c&255),v[e+44>>2]=f}jb=d+16|0}function uC(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;wC(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){vC(b)}return a|0}function qd(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0;e=jb-16|0;jb=e;g=v[b+8>>2];f=v[b>>2];v[e+8>>2]=c;v[e+12>>2]=d;h=v[v[f>>2]+28>>2];v[e>>2]=c;v[e+4>>2]=d;nb[h|0](a,f,g,e);v[b+8>>2]=v[b+8>>2]+v[a+4>>2];jb=e+16|0}function Lu(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;fC(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){eC(b)}return a|0}function Gt(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;_Q(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){$Q(b)}return a|0}function Wz(a,b){var c=0,d=0,e=0,f=0;c=a<<8;d=c&16711680;c=e;e=a<<24|d;f=c;d=b<<24|a>>>8;c=b<<8|a>>>24;a=f|(((b&255)<<24|a>>>8)&-16777216|((b&16777215)<<8|a>>>24)&16711680|(b>>>8&65280|b>>>24));mb=e|(d&65280|c&255);return a}function Ps(a,b){var c=0;a:{b:{c:{switch(b-2|0){default:c=43820;if((b|0)==16777216){break a}if((b|0)!=32){break b}c=43672;break a;case 2:c=43668;break a;case 1:break b;case 0:break c}}c=43664;break a}c=43660}v[a>>2]=v[c>>2]}function Kd(a,b){var c=0,d=0,e=0,f=0,g=0;d=x[a+22>>1];g=d+x[a+20>>1]|0;c=d;while(1){a:{if((c|0)!=(g|0)){e=((c&127)<<2)+a|0;f=x[e+28>>1]+b|0;u[e+28>>1]=f;if((f&65535)>>>0<2048){break a}u[a+20>>1]=c-d}return}c=c+1|0;continue}}function aE(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;d=jb-16|0;jb=d;c=lm(a);e=Cd(v[a+4>>2],w[a+11|0]);f=e+1|0;if((c|0)==(e|0)){ry(a,c,f-c|0,c,c,0)}c=rd(a);qq(c+e|0,1,b);au(a,f);t[d+15|0]=0;sd(c+f|0,d+15|0);jb=d+16|0;return a|0}function Ip(a,b,c){var d=0,e=0,f=0,g=0,h=0;f=131072/(A[b-8>>3]-A[a>>3]);b=0;while(1){if((b|0)!=2048){d=-ge(f*A[Re(a,b)>>3]);a:{if(D(d)<2147483648){e=~~d;break a}e=-2147483648}g=Db(c,b),h=e,v[g>>2]=h;b=b+1|0;continue}break}}function Bha(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[a+480180>>2]=b;Mz(c,fq(a));d=v[c+12>>2];b=a+1074320|0;v[b>>2]=v[c+8>>2];v[b+4>>2]=d;b=v[c+4>>2];v[a+1074312>>2]=v[c>>2];v[a+1074316>>2]=b;Ps(a+8|0,fq(a));jb=c+16|0}function zE(a,b,c,d,e){var f=0;f=jb-32|0;jb=f;v[f+24>>2]=a;v[f+28>>2]=b;v[f+16>>2]=d;v[f+20>>2]=e;v[f+8>>2]=c;v[f+12>>2]=0;a=PB(f+24|0,f+8|0);b=f+16|0;a=eE(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?a:b;jb=f+32|0;return v[a>>2]}function yN(a,b,c,d){var e=0;a=Xc(Rn(a,x[c+70>>1],v[c+48>>2],b,0)-32768|0);a:{if(!d){break a}d=Rk(c)-v[c+16>>2]|0;if((d|0)<2){break a}e=a;a=u[(B(b,872)+c|0)+1390>>1];a=Xc(((e-a|0)/(d|0)|0)+a|0)}u[(B(b,872)+c|0)+1390>>1]=a}function nJ(a,b){var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(b){pl(a,b);d=jb-16|0;jb=d;b=uk(d,a,b);c=v[b+4>>2];e=v[b+8>>2];while(1){if((c|0)==(e|0)){lc(b);jb=d+16|0}else{c=c+1|0;v[b+4>>2]=c;continue}break}}return a}function Yea(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Ob(v[a>>2],v[a+8>>2],6);a:{if(!d){a=0;while(1){if((a|0)!=6){vg(a+b|0);a=a+1|0;continue}break}break a}eB(c+8|0,b);qd(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;return d|0}function Ft(a,b){var c=0,d=0,e=0;if(v[a>>2]){zU(a);c=v[a>>2];wB(a);Jb(c);d=Gb(a),e=0,v[d>>2]=e;v[a>>2]=0;v[a+4>>2]=0}v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Gb(b);d=Gb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0}function wQ(a,b,c){var d=0;d=jb-16|0;jb=d;t[d+15|0]=a;a=0;if(!(c>>>0<25|b>>>0<25|(b>>>0>108|b>>>0>=c>>>0)|c>>>0>108)){t[d+14|0]=(x[(b<<1)+32622>>1]-x[(c<<1)+32622>>1]|0)/5;a=w[Wb(d+15|0,d+14|0)|0]}jb=d+16|0;return a&255}function nZ(a){a=a|0;if(w[467280]){return v[116819]}if(!w[468440]){a=468416;while(1){a=Kb(a)+12|0;if((a|0)!=468440){continue}break}t[468440]=1}nd(468416,88592);nd(468428,88604);t[467280]=1;v[116819]=468416;return 468416}function dN(a,b){var c=0,d=0,e=0,f=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];d=Gb(a);c=kc(a);a:{if(!v[d>>2]){v[a>>2]=c;break a}v[v[c>>2]+8>>2]=c;c=kc(b);v[b>>2]=c;v[c>>2]=0;e=Gb(b),f=0,v[e>>2]=f}return a}function bs(a){var b=0;a:{b=w[a+1376|0];b:{if(!b){b=-1;if(v[a+1384>>2]){break b}if(!Xw(a)){break b}b=w[a+1376|0];if(!b){break a}}t[a+1376|0]=b-1;v[a+1400>>2]=v[a+1400>>2]+1;b=Pe(a)}return b}aa(15532,13048,1578,5390);L()}function $Y(a){a=a|0;if(w[467272]){return v[116817]}if(!w[468408]){a=468384;while(1){a=Kb(a)+12|0;if((a|0)!=468408){continue}break}t[468408]=1}jd(468384,13705);jd(468396,13684);t[467272]=1;v[116817]=468384;return 468384}function vS(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+17|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function ls(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0;c=jb-16|0;jb=c;d=v[b>>2];b=wc(d,v[b+4>>2]);a=0;while(1){if((a|0)==(b|0)){jb=c+16|0}else{v[c+8>>2]=0;e=Cc(c+8|0);f=Db(d,a),g=v[e>>2],v[f>>2]=g;a=a+1|0;continue}break}}function k7(a){a=a|0;var b=0;nb[v[v[a>>2]+128>>2]](a);Cx(a);v[a+4236>>2]=0;t[a+4202|0]=1;b=nb[v[v[a>>2]+192>>2]](a)|0;v[a+4328>>2]=0;v[a+4312>>2]=0;z[a+4240>>2]=b?C(.5):C(1);b=v[a+4256>>2];v[a+4324>>2]=b;v[a+4320>>2]=b}function Gga(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;d=jb-16|0;jb=d;c=-1;a:{if(!Aj(a,d+8|0)){break a}e=v[d+12>>2];c=0;if(!(v[d+8>>2]==(Am(8880)|0)&e>>>0>255&e>>>0<260)){break a}c=Ge(a,b,e>>>0<259?80:76,0)}jb=d+16|0;return c|0}function Fj(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;ic(d+8|0,b,c);e=v[d+12>>2];nc(d,v[a>>2],v[a+8>>2],v[d+8>>2],v[d+12>>2]);f=v[d+4>>2];if((f|0)==(e|0)){ac(a,v[d+12>>2])}jb=d+16|0;a=(e|0)==(f|0);if(!a){Xb(b,0,c)}return a}function $M(a,b,c,d){var e=0,f=0;e=v[(B(c,872)+b|0)+704>>2];a:{if(!(!(e&134218752)|(d|0)!=1)|e&67108864){break a}b=x[(B(c,872)+b|0)+1402>>1];b=(b?b-1|0:c)&65535;if(b>>>0>126){break a}f=w[((b<<5)+a|0)+480288|0]}return f}function Zx(a,b,c,d,e){var f=0,g=0,h=0;f=jb-16|0;jb=f;a:{if(!c){a=ed(v[a>>2],b);A[a+8>>3]=e;A[a>>3]=d;break a}g=c>>>1|0;Zx(a,b,g,d,e);h=ed(v[a>>2],c);oi(f,d,e,A[h>>3],A[h+8>>3]);Zx(a,b|c,g,A[f>>3],A[f+8>>3])}jb=f+16|0}function Mp(a,b,c){var d=0;d=jb-16|0;jb=d;Bb(d+8|0,c+1074312|0,102);a:{if(!Cb(v[v[d+8>>2]>>2],v[d+12>>2])){break a}c=x[a+692>>1]+1|0;u[a+784>>1]=c;if(!(t[a+89|0]&1)){break a}u[a+784>>1]=c|32768}v[a+692>>2]=b;jb=d+16|0}function GO(a,b){a:{if(w[a+76|0]==(b|0)){break a}t[a+76|0]=b;if(b){b=0;if(x[a+24>>1]==15){u[a+20>>1]=0;b=1}v[a+8>>2]=0;v[a+16>>2]=b;return}b:{switch(v[a+16>>2]+1|0){case 0:case 4:break a;default:break b}}v[a+16>>2]=3}}function nz(a,b,c){var d=0;a:{switch(c+1|0){case 0:case 3:LO(a,b);return;default:break a}}d=jb-32|0;jb=d;v[d+28>>2]=c;u[d+24>>1]=0;v[d+12>>2]=2;Cr(d+16|0,a,d+24|0,v[Ib(d+28|0,d+12|0)>>2]);u[b>>1]=x[d+24>>1];jb=d+32|0}function gT(a){var b=0;a:{b:{if(Pb(a,13682,4)){if(Pb(a,16099,4)){break a}if((w[a+34|0]|w[a+35|0]<<8)>>>0<=255){break b}break a}if((w[a+34|0]|w[a+35|0]<<8)>>>0>255){break a}}b=(w[a+36|0]|w[a+37|0]<<8)>>>0<4e3}return b}function Sia(a,b,c,d){var e=0,f=0,g=0,h=0,i=0,j=0;e=c>>>16|0;f=a>>>16|0;j=B(e,f);g=c&65535;h=a&65535;i=B(g,h);f=(i>>>16|0)+B(f,g)|0;e=(f&65535)+B(e,h)|0;mb=(B(b,c)+j|0)+B(a,d)+(f>>>16)+(e>>>16)|0;return i&65535|e<<16}function gL(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;If(a+12|0,d);if(b){if(b>>>0>=2097152){jg();L()}d=xc(b<<11)}else{d=0}v[a>>2]=d;c=d+(c<<11)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+(b<<11)|0,v[e>>2]=f;return a|0}function Vw(a){var b=0;a:{b:{while(1){if(v[a+1380>>2]!=-1){break b}b=0;if(!as(a)){break a}if(!(t[a+1375|0]&1)){continue}break}bc(a,32);return 0}v[a+1396>>2]=0;v[a+1400>>2]=0;v[a+1384>>2]=0;t[a+1376|0]=0;b=1}return b}function Oy(a,b,c){var d=0,e=0;e=x[a+480192>>1];a:{if(e){if(!Uc(b)|c>>>0>e>>>0){break a}c=v[((c<<2)+a|0)+900380>>2];if(!c){break a}d=x[dc(c+236|0,b-1|0)>>1];break a}d=c}return(x[a+480190>>1]<(d&65535)>>>0?0:d)&65535}function HH(a,b){var c=0,d=0,e=0;c=jb-256|0;jb=c;if((b|0)>=2){v[(b<<2)+a>>2]=c;qc(c,v[a>>2],4);while(1){e=(d<<2)+a|0;d=d+1|0;qc(v[e>>2],v[(d<<2)+a>>2],4);v[e>>2]=v[e>>2]+4;if((b|0)!=(d|0)){continue}break}}jb=c+256|0}function nO(a,b){var c=0,d=0,e=0,f=0;e=A[a+48>>3];c=A[a+40>>3];A[a+48>>3]=c;f=A[a+64>>3];d=A[a+56>>3];A[a+64>>3]=d;A[a+40>>3]=b;b=e*A[a+16>>3]+(A[a>>3]*b+c*A[a+8>>3])-d*A[a+24>>3]-f*A[a+32>>3];A[a+56>>3]=b;return b}function Jo(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;if(c>>>0<4294967280){a:{if(xq(c)){xe(a,c);break a}e=zi(c)+1|0;f=xc(e);yd(a,f);Af(a,e);Td(a,c);a=f}a=He(a,b,c);t[d+15|0]=0;sd(a+c|0,d+15|0);jb=d+16|0;return}of();L()}function un(a,b){var c=0,d=0,e=0;c=a*a;d=c*a;e=c*c;a=d*e*(e*(c*.009465647849436732+.002974357433599673)+(c*.024528318116654728+.05338123784456704))+(d*(c*.13339200271297674+.3333313950307914)+a);return C(b?-1/a:a)}function iP(a){var b=0;b=u[a+784>>1];if(b){v[a+692>>2]=(b&32767)-1;if((b|0)<0){v[a+88>>2]=v[a+88>>2]|256}u[a+784>>1]=0}b=w[a+795|0];if(b){t[a+795|0]=0;t[a+838|0]=b-1}b=w[a+796|0];if(b){t[a+796|0]=0;t[a+837|0]=b-1}}function g_(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=cn(a);e=Fb(a);a:{if(d-e>>>0>=c>>>0){if(!c){break a}d=tc(a);ei(d+(e<<2)|0,b,c);b=c+e|0;Mh(a,b);yd(d+(b<<2)|0,0);return a|0}iF(a,d,(c+e|0)-d|0,e,e,0,c,b)}return a|0}function Bp(a,b){a=qc(a,b,88);v[a+88>>2]=v[b+88>>2];qc(a+92|0,b+92|0,576);v[a+668>>2]=v[b+668>>2];qc(a+672|0,b+672|0,52);Hy(a+724|0,b+724|0);Hy(a+732|0,b+732|0);Hy(a+740|0,b+740|0);qc(a+748|0,b+748|0,123);return a}function Sl(a,b){var c=C(0),d=0,e=0;c=C(1);d=u[a+28>>1];a:{if((d|0)>(b|0)){break a}e=v[a+4>>2];if((wc(e,v[a+8>>2])+d<<16)-65536>>16<(b|0)){break a}c=z[Db(e,b-d|0)>>2];c=c<=C(10000000036274937e-31)?C(1):c}return c}function PS(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;v[d>>2]=v[a+8>>2];e=v[a+8>>2];v[d+8>>2]=a+8;v[d+4>>2]=B(b,6)+e;b=v[d>>2];while(1){if(v[d+4>>2]!=(b|0)){Xt(b,c);b=v[d>>2]+6|0;v[d>>2]=b;continue}break}Id(d);jb=d+16|0}function Faa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=Qb(a);d=hg(a+12|0);t[a+32|0]=c;v[a+28>>2]=0;v[a+24>>2]=b;v[23296]=0;R(718,a|0,1);b=v[23296];v[23296]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;gO(d);lO(a);S(b|0);L()}function nS(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;pS(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){oS(b)}return a}function lk(a){yc(a+16|0,v[a>>2]);yc(a+8|0,v[a>>2]);if(y[a+12>>2]>=y[a+16>>2]){v[a+12>>2]=0;v[a+16>>2]=0;u[a+34>>1]=x[a+34>>1]&65511}if(y[a+4>>2]>=y[a+8>>2]){v[a+4>>2]=0;v[a+8>>2]=0;u[a+34>>1]=x[a+34>>1]&65529}}function YO(a,b,c,d){var e=0;e=jb-16|0;jb=e;a=Fi(e,a,d);d=jb-16|0;jb=d;v[d+8>>2]=b;while(1){if(Rb(b,c)){Di(v[a+4>>2],x[b>>1]);b=Se(d+8|0);v[a+4>>2]=v[a+4>>2]+2;b=v[b>>2];continue}break}jb=d+16|0;lc(a);jb=e+16|0}function MC(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Ob(v[a>>2],v[a+8>>2],1)){break b}t[c+15|0]=0;og(a,c+15|0);d=t[c+15|0]}jb=c+16|0;a=d;break a}aa(11081,8981,136,14045);L()}return a}function $A(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;vT(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){xT(b)}return a}function xaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(Yy(a)>>>0<b>>>0){if(ih(613566756)>>>0<b>>>0){break a}d=Gb(a);e=a;a=UN(c+8|0,b,Xy(v[a>>2],v[a+4>>2]),d);TN(e,a);SN(a)}jb=c+32|0;return}Wc();L()}function w9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(ui(a)>>>0<b>>>0){if(ih(1073741823)>>>0<b>>>0){break a}d=Gb(a);e=a;a=fg(c+8|0,b,wc(v[a>>2],v[a+4>>2]),d);Ad(e,a);eg(a)}jb=c+32|0;return}Wc();L()}function jy(a,b){var c=0,d=0;c=v[b+4>>2];v[a+24648>>2]=v[b>>2];v[a+24652>>2]=c;d=v[b+20>>2];c=a+24664|0;v[c>>2]=v[b+16>>2];v[c+4>>2]=d;d=v[b+12>>2];c=a+24656|0;v[c>>2]=v[b+8>>2];v[c+4>>2]=d;$L(a+24648|0);fM(a)}function iS(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(Fm(a)>>>0<b>>>0){if(ih(2147483647)>>>0<b>>>0){break a}d=Gb(a);e=a;a=xj(c+8|0,b,Nc(v[a>>2],v[a+4>>2]),d);Ad(e,a);Gi(a)}jb=c+32|0;return}Wc();L()}function XG(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];a:{if(!c){break a}d=v[c+24>>2];b:{if((d|0)==v[c+28>>2]){b=nb[v[v[c>>2]+52>>2]](c,b)|0;break b}v[c+24>>2]=d+4;v[d>>2]=b}if(!pn(b)){break a}v[a>>2]=0}return a|0}function Vda(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(Ej(a)>>>0<b>>>0){if(ih(357913941)>>>0<b>>>0){break a}d=Gb(a);e=a;a=ok(c+8|0,b,wd(v[a>>2],v[a+4>>2]),d);gQ(e,a);fQ(a)}jb=c+32|0;return}Wc();L()}function It(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;nR(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;if((d|0)!=(e|0)){Xz(b)}}function Gaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);c=Hg(v[b>>2],v[b+4>>2]);if(c){ez(a,c);d=jb-16|0;jb=d;e=v[b>>2];f=v[b+4>>2];b=ar(d,a,c);Zt(e,f,b+4|0);lc(b);jb=d+16|0}return a|0}function Eaa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(Qm(a)>>>0<b>>>0){if(ih(536870911)>>>0<b>>>0){break a}d=Gb(a);e=a;a=cr(c+8|0,b,Hg(v[a>>2],v[a+4>>2]),d);Ad(e,a);br(a)}jb=c+32|0;return}Wc();L()}function y9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if(Ej(a)>>>0<b>>>0){if(ih(357913941)>>>0<b>>>0){break a}d=Gb(a);e=a;a=ok(c+8|0,b,wd(v[a>>2],v[a+4>>2]),d);nr(e,a);NN(a)}jb=c+32|0;return}Wc();L()}function pD(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-36|0;mv(v[d>>2]-36|0,c);v[d>>2]=v[d>>2]-36;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Gb(a),zc(b));v[b>>2]=v[b+4>>2]}function p9(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;a:{if(!Aj(a,b+8|0)){break a}c=0;if(!KL(v[b+8>>2],v[b+12>>2])){break a}a=yQ(a,b);if(!a){tm(b)}c=-1;if(!a){break a}c=JL(v[b>>2])}a=c;jb=b+16|0;return a|0}function nr(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-12|0;So(v[d>>2]-12|0,c);v[d>>2]=v[d>>2]-12;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Gb(a),zc(b));v[b>>2]=v[b+4>>2]}function aB(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-20|0;dB(v[d>>2]-20|0,c);v[d>>2]=v[d>>2]-20;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Gb(a),zc(b));v[b>>2]=v[b+4>>2]}function Taa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;c=gf(a,c);ae(e,v[a+28>>2]);a:{b:{if(!c){d=-1;if(!hd(a,5)){break b}break a}d=v[c+8>>2]}nz(v[a+28>>2],b,d);f=c}a=$e(a,f);jb=e+16|0;return a|0}function S7(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;a=Pj(a);if(a){d=v[b+4>>2];b=v[b>>2];v[c+8>>2]=b;v[c+12>>2]=d;e=v[v[a>>2]+72>>2];v[c>>2]=b;v[c+4>>2]=d;a=nb[e|0](a,c)|0}else{a=1}jb=c+16|0;return a|0}function Rm(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;a:{if(c){Vb(d,c);break a}Kb(d)}v[23296]=0;U(11,a|0,b|0,d|0);a=v[23296];v[23296]=0;if((a|0)!=1){yb(d);jb=d+16|0;return}a=P()|0;O()|0;yb(d);S(a|0);L()}function MO(a,b){var c=0,d=0,e=0;e=v[a>>2];c=v[a+4>>2];d=b+4|0;while(1){if((c|0)!=(e|0)){c=c-32|0;pz(v[d>>2]-32|0,c);v[d>>2]=v[d>>2]-32;continue}break}oc(a,d);oc(a+4|0,b+8|0);oc(Gb(a),zc(b));v[b>>2]=v[b+4>>2]}function $v(a,b,c){var d=0;d=v[a+16>>2];if(!d){v[a+36>>2]=1;v[a+24>>2]=c;v[a+16>>2]=b;return}a:{if((b|0)==(d|0)){if(v[a+24>>2]!=2){break a}v[a+24>>2]=c;return}t[a+54|0]=1;v[a+24>>2]=2;v[a+36>>2]=v[a+36>>2]+1}}function ly(a,b){var c=0;c=v[b+24>>2];v[a+24628>>2]=c?c>>>0<512?c:512:1;a:{if(!(v[b+16>>2]!=v[a+24620>>2]|v[b+20>>2]!=v[a+24624>>2])){c=0;if(v[b+12>>2]==v[a+24616>>2]){break a}}c=1}qc(a+24604|0,b,40);aM(a,c)}function eA(a,b){var c=0,d=0,e=0,f=0;d=b?224:240;e=GD(a);a:while(1){if((a|0)!=(e|0)){f=vd(a);b=a;while(1)if((b|0)==(f|0)){a=a+16|0;continue a}else{c=((w[Lb(b,0)|0]&d)!=0)+c|0;b=b+4|0;continue}}break}return c}function Y8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;f=jb-16|0;jb=f;c=gf(a,c);ae(f,v[a+28>>2]);a:{b:{if(!c){e=-1;if(!hd(a,5)){break b}break a}e=v[c+8>>2]}nb[d|0](v[a+28>>2],b,e);g=c}$e(a,g);jb=f+16|0}function VV(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-48|0;jb=c;d=-1;a:{if(!eD(a,c+8|0)){break a}d=0;if(!dD(c+8|0)){break a}if(b){a=v[b>>2];if(!v[b+4>>2]&a>>>0<cc(v[c+12>>2])-8>>>0){break a}}d=1}jb=c+48|0;return d|0}function UP(a){a=a*4294967296;if(D(a)<0x8000000000000000){mb=D(a)>=1?~~(a>0?F(H(a*2.3283064365386963e-10),4294967295):I((a-+(~~a>>>0>>>0))*2.3283064365386963e-10))>>>0:0;return~~a>>>0}mb=-2147483648;return 0}function Fv(a,b,c){var d=0,e=0;d=rd(a);a=Cd(v[a+4>>2],w[a+11|0]);e=rd(b);b=Cd(v[b+4>>2],w[b+11|0]);a:{if(a>>>0>=c>>>0){if(!b){break a}a=a+d|0;b=ZD(c+d|0,a,e,b+e|0);c=(a|0)==(b|0)?-1:b-d|0}else{c=-1}}return c}function zd(a,b){var c=0,d=0;c=jb-16|0;jb=c;a:{if(b>>>0<2){b:{if(!b){break b}if(!Ob(v[a>>2],v[a+8>>2],1)){break b}t[c+15|0]=0;og(a,c+15|0);d=w[c+15|0]}jb=c+16|0;break a}aa(11081,8981,136,14045);L()}return d}function YM(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+28>>2];v[a+24>>2]=v[b+24>>2];v[a+28>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function P9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;b=(b-a|0)/160|0;while(1){if((b|0)>0){b=b-1|0;v[a>>2]=v[c>>2];d=a+4|0;if((d|0)!=(c+4|0)){ny(d,v[c+4>>2],v[c+8>>2])}qc(a+16|0,c+16|0,144);a=a+160|0;continue}break}}function Ns(a){var b=0;v[23296]=0;a=T(765,a|0)|0;b=v[23296];v[23296]=0;a:{if((b|0)==1){a=V(0)|0;O()|0;_(a|0)|0;v[23296]=0;Z(17);b=v[23296];v[23296]=0;a=0;if((b|0)==1){break a}}return a}V(0)|0;O()|0;Ub();L()}function Eu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+16|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function O0(a,b){a=a|0;b=b|0;var c=0;a=ss(a);v[a>>2]=76272;c=Kb(a+32|0);v[a+44>>2]=0;v[a+48>>2]=8;v[23296]=0;R(81,a|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;yb(c);En(a);S(b|0);L()}function Mi(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;ic(d+8|0,b,c);e=v[d+12>>2];nc(d,v[a>>2],v[a+8>>2],v[d+8>>2],v[d+12>>2]);f=v[d+4>>2];if((f|0)==(e|0)){ac(a,v[d+12>>2])}jb=d+16|0;if((e|0)!=(f|0)){Xb(b,0,c)}}function vba(a){a=a|0;var b=0;b=jb-16|0;jb=b;a:{if(gq(a,10157)){wJ(b,17392,a);a=Jc(b);v[23296]=0;R(40,44,a|0);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;yb(b);S(a|0);L()}jb=b+16|0;return}L()}function mz(a){var b=0,c=0,d=0;b=x[a+20>>1];u[a+28>>1]=x[a+22>>1]<<1|(w[v[a+16>>2]+3842|0]?b>>>9|0:b>>>8&1);b=0;while(1){if((b|0)!=4){c=(b<<2)+a|0;d=v[c>>2];if(d){_n(d);HO(v[c>>2])}b=b+1|0;continue}break}}function Pda(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;em(a,b);b=Eb(v[a>>2]);v[c+8>>2]=b;a=Eb(v[a+4>>2]);while(1){if(Rb(b,a)){d=w[b|0]+(d&255)|0;t[b|0]=d;b=v[Be(c+8|0)>>2];continue}else{jb=c+16|0}break}}function Kaa(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],27)){a=0;while(1){if((a|0)!=27){vg(a+b|0);a=a+1|0;continue}break}break a}yO(c+8|0,b);qd(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function J2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;FJ(d,c);a=v[a+1298464>>2];v[23296]=0;U(353,a|0,b|0,d|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(d);jb=d+16|0;return}a=P()|0;O()|0;zb(d);S(a|0);L()}function Fk(a){a=a|0;var b=0;v[a>>2]=77468;v[23296]=0;R(69,a|0,0);b=v[23296];v[23296]=0;if((b|0)!=1){_b(a+28|0);Jb(v[a+32>>2]);Jb(v[a+36>>2]);Jb(v[a+48>>2]);Jb(v[a+60>>2]);return a|0}V(0)|0;O()|0;Ub();L()}function Eia(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],64)){a=0;while(1){if((a|0)!=64){vg(a+b|0);a=a+1|0;continue}break}break a}qu(c+8|0,b);qd(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function sf(a,b,c,d,e){var f=0;f=jb-256|0;jb=f;if(!(e&73728|(c|0)<=(d|0))){d=c-d|0;c=d>>>0<256;Xb(f,b&255,c?d:256);if(!c){while(1){hf(a,f,256);d=d-256|0;if(d>>>0>255){continue}break}}hf(a,f,d)}jb=f+256|0}function qR(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],32)){a=0;while(1){if((a|0)!=32){vg(a+b|0);a=a+1|0;continue}break}break a}nR(c+8|0,b);qd(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function v6(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0;f=jb-16|0;jb=f;b=Ic(Tia(Sia(d,d>>31,b,0),mb,1e3,0),mb);v[a+16>>2]=0;v[a+12>>2]=b+c;sK(a,e);b=v[a+12>>2];v[f+12>>2]=0;pL(a,b,f+12|0);jb=f+16|0}function tS(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;eB(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)|0}function qT(a){var b=0;a:{if(Pb(a,3873,4)|w[a+68|0]!=13|(w[a+69|0]!=10|w[a+70|0]!=26)){break a}if(Pb(a+71|0,13543,4)|w[a+75|0]!=1|w[a+76|0]){break a}b=((w[a+116|0]|w[a+117|0]<<8)-1&65535)>>>0<9}return b}function lda(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;if((b|0)>=0){d=2147483647;a=rt(a);if(a>>>0<=1073741822){v[c+12>>2]=a<<1;v[c+8>>2]=b+31&-32;d=v[Yc(c+12|0,c+8|0)>>2]}jb=c+16|0;return d|0}Wc();L()}function be(a,b){var c=0,d=0,e=0;b=b+7&-8;v[a+8>>2]=b+v[a+8>>2];d=v[a+80>>2];a:{if(d){c=b;b=v[a+88>>2];e=c+b|0;c=0;if((e|0)>v[a+92>>2]){break a}v[a+88>>2]=e;return b+d|0}if(!b){return 0}c=Jd(b)}return c}function Xh(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;Km(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)|0}function Rfa(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],2)){a=0;while(1){if((a|0)!=2){vg(a+b|0);a=a+1|0;continue}break}break a}ql(c+8|0,b);qd(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function F5(a,b){a=a|0;b=b|0;var c=0,d=0;a:{c=v[b+52>>2];if(c&16){d=v[b+48>>2];c=v[b+28>>2];if(d>>>0<c>>>0){v[b+48>>2]=c;d=c}Zf(a,v[b+24>>2],d);break a}if(c&8){Zf(a,v[b+12>>2],v[b+20>>2]);break a}Kb(a)}}function gn(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-32|0;jb=c;a:{if($o(a)>>>0<b>>>0){if(ih(-1)>>>0<b>>>0){break a}d=Gb(a);e=a;a=Bl(c+8|0,b,ad(v[a>>2],v[a+4>>2]),d);Ad(e,a);Al(a)}jb=c+32|0;return}Wc();L()}function VF(a,b,c,d,e,f){var g=0,h=0,i=0;g=jb-16|0;jb=g;t[g+15|0]=0;t[g+14|0]=f;t[g+13|0]=e;t[g+12|0]=37;if(f){ah(g+13|0,g+14|0)}h=c,i=(cb(b|0,ad(b,v[c>>2])|0,g+12|0,d|0,a|0)|0)+b|0,v[h>>2]=i;jb=g+16|0}function Qfa(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(b){if(ih(1073741823)>>>0<b>>>0){Wc();L()}c=QC(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=(b<<2)+c|0,v[d>>2]=e;DA(a,b)}return a|0}function Hf(a){var b=0,c=0,d=0,e=0;b=jb-16|0;jb=b;c=2;if(a>>>0>=2){v[b+12>>2]=a>>>1;v[b+8>>2]=a^-1;d=b,e=v[Ib(b+12|0,b+8|0)>>2]+a|0,v[d+12>>2]=e;v[b+8>>2]=-1;c=v[Ib(b+12|0,b+8|0)>>2]}jb=b+16|0;return c}function BB(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],8)){a=0;while(1){if((a|0)!=8){vg(a+b|0);a=a+1|0;continue}break}break a}Km(c+8|0,b);qd(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function xV(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(b){if(ih(214748364)>>>0<b>>>0){Wc();L()}c=nC(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=B(b,20)+c|0,v[d>>2]=e;qC(a,b)}return a|0}function rR(a,b){a=a|0;b=b|0;var c=0,d=0;d=v[a>>2];c=65535;a:{if(!oe(d,v[a+4>>2],b)){break a}d=qB(a,v[Pf(d,b)+12>>2]);c=65535;if((d|0)==65535){break a}c=v[a>>2];a=Pf(c,b);BL(Pf(c,d),a);c=d}return c|0}function nX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;d=jb-16|0;jb=d;f=v[v[b>>2]+20>>2];e=v[c+12>>2];v[d+8>>2]=v[c+8>>2];v[d+12>>2]=e;e=v[c+4>>2];v[d>>2]=v[c>>2];v[d+4>>2]=e;nb[f|0](a,b,d,8);jb=d+16|0}function Qg(a,b){var c=0,d=0,e=0;c=Fb(a);a:{if((c|0)!=(Fb(b)|0)){break a}d=Jc(a);b=Jc(b);if(!Ve(a)){while(1){e=!c;if(!c|w[d|0]!=w[b|0]){break a}b=b+1|0;d=d+1|0;c=c-1|0;continue}}e=!Tl(d,b,c)}return e}function yP(a){var b=0,c=0,d=0;d=w[a+64|0]|w[a+65|0]<<8;b=w[a+70|0]|w[a+71|0]<<8;a=b+(w[a+72|0]|w[a+73|0]<<8)|0;c=a>>>0<b>>>0?1:c;b=a;a=c<<2|a>>>30;b=b<<2;c=d+b|0;a=c>>>0<b>>>0?a+1|0:a;mb=a;return c}function iM(a){var b=0,c=0;c=a+946300|0;a=a+906300|0;while(1){if((a|0)!=(c|0)){b=v[a>>2];a:{if(!b){break a}if(!(nb[v[v[b>>2]+116>>2]](b)|0)){break a}nb[v[v[b>>2]+96>>2]](b)}a=a+160|0;continue}break}}function eK(a){var b=0,c=0,d=C(0);if(!a){return C(1)}if((a|0)>=-99999){b=+(a|0)*3.321928094887362/2e3;c=b+.5;a:{if(D(c)<2147483648){a=~~c;break a}a=-2147483648}d=C(Lj(b-+(a|0)))}else{d=C(0)}return d}function bX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=Cd(v[b+4>>2],w[b+11|0]);if(d>>>0<c>>>0){mm();L()}b=rd(b);v[e+8>>2]=d-c;Jo(a,b+c|0,v[Ib(e+12|0,e+8|0)>>2]);jb=e+16|0}function JB(a,b){var c=0;c=jb-16|0;jb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],512)){a=0;while(1){if((a|0)!=128){tm((a<<2)+b|0);a=a+1|0;continue}break}break a}xu(c+8|0,b);qd(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function GQ(a){var b=0,c=0,d=0;d=w[a+32|0]|w[a+33|0]<<8;b=w[a+34|0]|w[a+35|0]<<8;a=b+(w[a+36|0]|w[a+37|0]<<8)|0;c=a>>>0<b>>>0?1:c;b=a;a=c<<1|a>>>31;b=b<<1;c=d+b|0;a=c>>>0<b>>>0?a+1|0:a;mb=a;return c}function C7(a){a=a|0;var b=0,c=0,d=0;b=jb-32|0;jb=b;a:{if(ui(a)>>>0<=12){if(ih(1073741823)>>>0<=12){break a}c=Gb(a);d=a;a=fg(b+8|0,13,wc(v[a>>2],v[a+4>>2]),c);Ad(d,a);eg(a)}jb=b+32|0;return}Wc();L()}function Su(a,b){var c=0;c=jb-16|0;jb=c;a:{if(!Ob(v[a>>2],v[a+8>>2],256)){a=0;while(1){if((a|0)!=256){vg(a+b|0);a=a+1|0;continue}break}break a}ic(c+8|0,b,256);qd(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function ER(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;KR(c+8|0,b);d=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;if((d|0)!=(e|0)){LR(b)}}function uT(a){var b=0,c=0,d=0;a:{if(Pb(a,21462,11)){break a}c=a+215|0;a=a+63|0;while(1){b=(a|0)==(c|0);if(b|w[a+16|0]>3|w[a+17|0]>3){break a}d=a;a=a+19|0;if(w[d+18|0]<16){continue}break}}return b}function pO(a,b,c,d,e,f){v[a+40>>2]=0;v[a+44>>2]=0;A[a+32>>3]=f;A[a+24>>3]=e;A[a+16>>3]=d;A[a+8>>3]=c;A[a>>3]=b;v[a+48>>2]=0;v[a+52>>2]=0;v[a+56>>2]=0;v[a+60>>2]=0;a=a- -64|0;v[a>>2]=0;v[a+4>>2]=0}function Ld(a,b){var c=0,d=0,e=0;d=x[a+24>>1];if((d|0)!=(b&65535)){c=x[a+22>>1]-1&127;u[a+22>>1]=c;e=x[a+20>>1];if(e>>>0<=127){u[a+20>>1]=e+1}c=(c<<2)+a|0;u[c+26>>1]=b-d;u[c+28>>1]=0;u[a+24>>1]=b}}function DJ(){var a=0,b=0,c=0,d=0;a=jb-16|0;jb=a;b=xc(1298472);v[23296]=0;c=T(1011,b|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){b=v[xf(a+8|0,c)>>2];jb=a+16|0;return b|0}a=P()|0;O()|0;Jb(b);S(a|0);L()}function bj(a){var b=0;b=32767;a:{if(a>=C(32766.5)){break a}b=32768;if(a<=C(-32767.5)){break a}a=C(a+C(.5));b:{if(C(D(a))<C(2147483648)){b=~~a;break b}b=-2147483648}b=b+(b>>15)|0}return b<<16>>16}function Pv(a,b,c,d){var e=0,f=0,g=0;e=b+4|0;g=c;f=v[a>>2];c=v[a+4>>2]-f|0;d=v[e>>2]+B(g,(c|0)/(d|0)|0)|0;v[e>>2]=d;if((c|0)>0){qc(d,f,c)}oc(a,e);oc(a+4|0,b+8|0);oc(Gb(a),zc(b));v[b>>2]=v[b+4>>2]}function zH(a){var b=0,c=0,d=0;d=v[a>>2];while(1){c=t[d|0];if(Mj(c)){d=d+1|0;v[a>>2]=d;if(b>>>0<=214748364){c=c-48|0;b=B(b,10);b=(c|0)>(2147483647-b|0)?-1:c+b|0}else{b=-1}continue}break}return b}function vQ(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;vT(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){xT(b)}return a}function mu(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a+12|0]=0;t[a+13|0]=0;t[a+14|0]=0;t[a+15|0]=0}function mU(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;pu(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){tB(b)}return a}function mB(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;lB(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){RT(b)}return a}function eD(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;Xq(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){Yq(b)}return a}function cR(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;_Q(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){$Q(b)}return a}function U2(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;FJ(c,b);a=v[a+1298464>>2];v[23296]=0;U(353,a|0,1,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){zb(c);jb=c+16|0;return}a=P()|0;O()|0;zb(c);S(a|0);L()}function RD(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;PD(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){zv(b)}return a}function MR(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;KR(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){LR(b)}return a}function D8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=jb-16|0;jb=e;c=gf(a,c);ae(e,v[a+28>>2]);a:{b:{if(!c){d=-1;if(!hd(a,5)){break b}break a}d=v[c+8>>2]}nz(v[a+28>>2],b,d);f=c}$e(a,f);jb=e+16|0}function Aj(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;Km(c+8|0,b);d=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);e=v[c+4>>2];if((e|0)==(d|0)){dd(a,v[c+12>>2])}jb=c+16|0;a=(d|0)==(e|0);if(!a){ul(b)}return a}function oB(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=1;v[c+8>>2]=a>>>4;b=Yb(128/(B(v[Ne(c+12|0,c+8|0)>>2],b)|0)|0,1,15);t[c+7|0]=1;t[c+6|0]=a&15;a=w[ef(c+7|0,c+6|0)|0];jb=c+16|0;return a|b<<4&240}function SO(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;t[a+16|0]=0;c=tz(b,v[a+12>>2]);v[23296]=0;R(705,a|0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){Yk(c);jb=b+32|0;return}a=P()|0;O()|0;Yk(c);S(a|0);L()}function Bu(a,b,c){var d=0;a=(a&65535)>>>B(c,3)|0;d=a>>>2&1|w[b+12|0]&-8;t[b+12|0]=d|a<<1&6;if(!(!(a>>>9-(c<<1)&1)|(a&3)!=1)){a=w[b+13|0]|w[b+14|0]<<8;t[b+15|0]=a;t[b+16|0]=a>>>8;t[b+12|0]=d|4}}function zh(a,b){var c=0;c=v[a>>2];a=Pd(b);b=v[c+8>>2];if(wc(b,v[c+12>>2])>>>0>a>>>0){c=v[Db(b,a)>>2]!=0}else{c=0}if(!c){a=Ll(ba(4)|0);v[a>>2]=92236;ha(a|0,92372,1055);L()}return v[Db(b,a)>>2]}function dK(a,b){var c=0,d=0,e=0,f=0;if(a>C(.9999989867210388)){d=0}else{a=C(a*a);c=+a;e=32768/(1-c);f=c;c=Qe(31415.926535897932/+b);d=bm(e*(1-(f*c+K(+C(a+a)*(1-c)-+C(a*a)*(1-c*c)))))}return d}function aT(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;Kf(a,d+14|0);e=x[d+14>>1];oM(b,e);c=0;while(1){if((c|0)==(e|0)){oy(b);jb=d+16|0}else{bk(a,Db(v[b>>2],c));c=c+1|0;continue}break}}function aR(a){var b=0,c=0,d=0,e=0;mb=0;d=w[a+4|0];e=w[a+92|0];c=w[a+94|0]|w[a+95|0]<<8;b=c+w[a+93|0]|0;a=0;a=b>>>0<c>>>0?1:a;c=b;b=e+b|0;a=b>>>0<c>>>0?a+1|0:a;c=b<<2;b=d+c|0;b=b-96|0;return b}function aI(a,b){var c=0,d=0,e=0,f=C(0),g=C(0),h=0;b=(b|0)>0?b:0;h=a+2304|0;while(1){if((b|0)!=(d|0)){c=d<<2;e=c+a|0;f=z[e>>2];c=c+h|0;g=z[c>>2];z[e>>2]=f+g;z[c>>2]=f-g;d=d+1|0;continue}break}}function my(a,b){var c=0;a=$P(a,b);t[a+12|0]=w[b+12|0];c=w[b+13|0]|w[b+14|0]<<8|(w[b+15|0]<<16|w[b+16|0]<<24);t[a+13|0]=c;t[a+14|0]=c>>>8;t[a+15|0]=c>>>16;t[a+16|0]=c>>>24;t[a+17|0]=w[b+17|0]}function mg(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb+-64|0;jb=c;d=Ux(c+8|0,a);v[23296]=0;U(189,a|0,b|0,d|0);a=v[23296];v[23296]=0;if((a|0)!=1){Pk(d);jb=c- -64|0;return}a=P()|0;O()|0;Pk(d);S(a|0);L()}function yj(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=ih(2147483647);if(d>>>0<=b>>>0){a=Fm(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}Wc();L()}function sr(a,b,c,d,e,f){var g=0,h=0;If(a+12|0,d);if(b){if(b>>>0>=f>>>0){jg();L()}d=xc(B(b,e))}else{d=0}v[a>>2]=d;c=d+B(c,e)|0;v[a+8>>2]=c;v[a+4>>2]=c;g=zc(a),h=d+B(b,e)|0,v[g>>2]=h;return a}function kP(a,b){var c=0;c=w[a+800|0];a:{if(c){break a}c=xi(w[a+797|0]-u[a+770>>1]|0);if(!b|(c<<24)-16777216>>24<0){break a}a=v[a+656>>2];if(!a){break a}c=w[Lb(a+108|0,c-1|0)|0]}return c&255}function jj(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;a:{d=Xk(a,b);if((d|0)==255){break a}Uj(a,b);Kp(a,b,0,0);if(!c){break a}e=dc(a+26|0,d),f=65535,u[e>>1]=f;a=Lb(a+62|0,b);t[a|0]=w[a|0]|128}}function jF(a){a=a|0;var b=0,c=0,d=0;v[a>>2]=82056;d=a+8|0;while(1){b=v[a+8>>2];if(wc(b,v[a+12>>2])>>>0>c>>>0){b=v[Db(b,c)>>2];if(b){Pm(b)}c=c+1|0;continue}break}yb(a+152|0);GF(d);return a|0}function Ug(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=ih(1073741823);if(d>>>0<=b>>>0){a=ui(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}Wc();L()}function yn(a){var b=0,c=0;b=jb-16|0;jb=b;a:{if(!qJ(w[a+20|0])){v[23296]=0;R(1016,b+8|0,a|0);c=v[23296];v[23296]=0;if((c|0)==1){break a}}t[a+20|0]=255;jb=b+16|0;return}V(0)|0;O()|0;Ub();L()}function rD(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=ih(119304647);if(d>>>0<=b>>>0){a=nv(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}Wc();L()}function pR(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=(lp(b)+-4.8737671609324025)*(a&32768?28.85390081777927:34.624680981335125),A[d+8>>3]=e;MN(c+8|0,127);a=io(A[c+8>>3]);jb=c+16|0;return a}function jA(a,b,c,d){var e=0,f=0,g=0;e=jb-16|0;jb=e;f=v[b+12>>2];v[e+8>>2]=c;v[e+12>>2]=d;g=v[v[b>>2]+28>>2];v[e>>2]=c;v[e+4>>2]=d;nb[g|0](a,b,f,e);v[b+12>>2]=v[b+12>>2]+v[a+4>>2];jb=e+16|0}function dr(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=ih(536870911);if(d>>>0<=b>>>0){a=Qm(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}Wc();L()}function cB(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=ih(214748364);if(d>>>0<=b>>>0){a=pC(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}Wc();L()}function Tm(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=ih(357913941);if(d>>>0<=b>>>0){a=Ej(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}Wc();L()}function Pp(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=ih(134217727);if(d>>>0<=b>>>0){a=ho(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}Wc();L()}function Jv(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=ih(268435455);if(d>>>0<=b>>>0){a=or(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}Wc();L()}function IA(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=ih(715827882);if(d>>>0<=b>>>0){a=lu(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}Wc();L()}function yu(a,b){var c=0,d=0;c=jb-16|0;jb=c;wo(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function xL(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=ih(82595524);if(d>>>0<=b>>>0){a=Qs(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}Wc();L()}function wt(a){var b=0;a:{if(Pb(a,13443,4)|w[a+4|0]){break a}if(Mb(w[a+6|0]|w[a+7|0]<<8)>>>0>1){break a}if(Mb(w[a+12|0]|w[a+13|0]<<8)){break a}b=(Mb(w[a+16|0]|w[a+17|0]<<8)|0)==20}return b}function og(a,b){var c=0,d=0;c=jb-16|0;jb=c;Nq(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function nD(a,b){var c=0,d=0;c=jb-16|0;jb=c;PD(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function hR(a,b){var c=0,d=0;c=jb-16|0;jb=c;rA(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function fD(a,b){var c=0,d=0;c=jb-16|0;jb=c;Xq(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function eh(a,b,c){a:{if(b>>>0<=c>>>0){a=ba(8)|0;v[23296]=0;b=T(181,a|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return w[a+c|0]}ha(b|0,25912,156);L()}function cU(a,b){var c=0,d=0;c=jb-16|0;jb=c;Nu(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function cC(a){var b=0;b=v[a+72>>2];v[a+72>>2]=b-1|b;b=v[a>>2];if(b&8){v[a>>2]=b|32;return-1}v[a+4>>2]=0;v[a+8>>2]=0;b=v[a+44>>2];v[a+28>>2]=b;v[a+20>>2]=b;v[a+16>>2]=b+v[a+48>>2];return 0}function _M(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;a=ar(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){lc(a);jb=d+16|0}else{ZM(b,v[c>>2],v[c+4>>2]);b=b+8|0;v[a+4>>2]=b;continue}break}}function ZB(a,b){var c=0,d=0;c=jb-16|0;jb=c;YB(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function Uv(a,b,c){var d=0;d=jb-16|0;jb=d;ic(d+8|0,b,c);b=v[d+12>>2];nc(d,v[a>>2],v[a+8>>2],v[d+8>>2],v[d+12>>2]);c=v[d+4>>2];if((b|0)==(c|0)){ac(a,v[d+12>>2])}jb=d+16|0;return(b|0)==(c|0)}function Uq(a,b){var c=0,d=0;c=jb-16|0;jb=c;ql(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function UT(a,b){var c=0,d=0;c=jb-16|0;jb=c;pu(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function PT(a,b){var c=0,d=0;c=jb-16|0;jb=c;qu(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function OT(a,b){var c=0,d=0;c=jb-16|0;jb=c;lB(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function IS(a,b){var c=0,d=0;c=jb-16|0;jb=c;HS(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function Ho(a,b){var c=0,d=0;c=jb-16|0;jb=c;Dh(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function E9(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0,g=0;d=jb-16|0;jb=d;e=x[a+28>>1];u[d+8>>1]=e;f=d,g=(wc(v[a+4>>2],v[a+8>>2])+e|0)-1|0,u[f+10>>1]=g;a=sL(a,b,c,d+8|0);jb=d+16|0;return a|0}function DR(a,b){var c=0,d=0;c=jb-16|0;jb=c;CR(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function DG(a,b,c,d){a:{if(!a){break a}b:{switch(b+2|0){case 0:t[a|0]=c;return;case 1:u[a>>1]=c;return;case 2:case 3:v[a>>2]=c;return;case 5:break b;default:break a}}v[a>>2]=c;v[a+4>>2]=d}}function Au(a,b){var c=0,d=0;c=jb-16|0;jb=c;zu(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){ac(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function yx(a,b,c,d,e,f,g,h,i){var j=0;j=jb-16|0;jb=j;yg(j,b,c,d,e,f,g,h,i^-2147483648);d=v[j>>2];c=v[j+4>>2];b=v[j+12>>2];v[a+8>>2]=v[j+8>>2];v[a+12>>2]=b;v[a>>2]=d;v[a+4>>2]=c;jb=j+16|0}function Uz(a,b){var c=0,d=0;d=jb-32|0;jb=d;c=Gb(a);c=fg(d+8|0,Ug(a,wc(v[a>>2],v[a+4>>2])+1|0),wc(v[a>>2],v[a+4>>2]),c);Qp(v[c+8>>2],v[b>>2]);v[c+8>>2]=v[c+8>>2]+4;Ad(a,c);eg(c);jb=d+32|0}function Nw(a,b,c){b=(b+9|0)%12|0;a=((b<<24>>24)/-10<<24>>24)+a|0;return(((((((a|0)/4|0)+c|0)+B(a,365)|0)+((a|0)/-100|0)|0)+((a|0)/400|0)|0)+((B(b,20054016)+327680>>16)/10<<16>>16)|0)-1|0}function rP(a){var b=0,c=0;a:{b:{c=a&240;if((c|0)!=192){if((c|0)==240){break b}b=3;if((c|0)!=208){break a}}b=2;break a}a=a+15&255;b=1;if(a>>>0>2){break a}b=131842>>>(a<<3)|0}return b&255}function bn(a,b){var c=0,d=0,e=0;a:{c=xG(b);if(c>>>0<1073741808){b:{if(Hr(c)){xe(a,c);break b}d=El(c)+1|0;e=ri(d);yd(a,e);Af(a,d);Td(a,c);a=e}ei(a,b,c);yd((c<<2)+a|0,0);break a}of();L()}}function LF(a,b){var c=0,d=0;d=jb-32|0;jb=d;c=Gb(a);c=Bl(d+8|0,zl(a,ad(v[a>>2],v[a+4>>2])+1|0),ad(v[a>>2],v[a+4>>2]),c);Hj(v[c+8>>2],w[b|0]);v[c+8>>2]=v[c+8>>2]+1;Ad(a,c);Al(c);jb=d+32|0}function fj(a,b){var c=0,d=0;c=w[a|0];d=w[b|0];a:{if(!c|(d|0)!=(c|0)){break a}while(1){d=w[b+1|0];c=w[a+1|0];if(!c){break a}b=b+1|0;a=a+1|0;if((c|0)==(d|0)){continue}break}}return c-d|0}function RS(a,b,c,d){var e=0;e=jb-16|0;jb=e;v[e+12>>2]=b;v[e+8>>2]=d;c=Tl(a,c,v[Ib(e+12|0,e+8|0)>>2]);a:{if(c){break a}c=0;if((b|0)==(d|0)){break a}c=b>>>0<d>>>0?-1:1}jb=e+16|0;return c}function Hb(a,b){var c=0,d=0;c=jb-16|0;jb=c;if(Uf(w[a+11|0])){Jb(v[a>>2])}d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;v[a+8>>2]=v[b+8>>2];xe(b,0);t[c+15|0]=0;sd(b,c+15|0);jb=c+16|0;return a}function B$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0;e=v[a+84>>2];d=c+256|0;f=Yt(e,0,d);d=f?f-e|0:d;c=c>>>0>d>>>0?d:c;qc(b,e,c);b=e+d|0;v[a+84>>2]=b;v[a+8>>2]=b;v[a+4>>2]=c+e;return c|0}function Hx(a){var b=0,c=0,d=0;A[a+4272>>3]=A[a+4280>>3];c=a;d=a+4296|0;a=0;while(1){if(a>>>0<32){a=a+15|0;b=Nn(d)|b<<15;continue}break}A[c+4280>>3]=C(C(b|0)*C(-4.656612873077393e-10))}function H_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-16|0;jb=g;v[g+8>>2]=624576549;v[g+12>>2]=1394948685;h=a;a=g+16|0;b=Jj(h,b,c,d,e,f,g+8|0,a);jb=a;return b|0}function G5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;a=XJ(f,b,c,d,0,0,0,0,e);jb=f+16|0;return a|0}function y2(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=v[14179];v[c+8>>2]=v[14178];v[c+12>>2]=d;d=v[14177];v[c>>2]=v[14176];v[c+4>>2]=d;nb[v[jp(c,Oj(w[b+20|0]))>>2]](a,b);jb=c+16|0}function sha(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Ob(v[a>>2],v[a+8>>2],12);a:{if(!d){t[c|0]=0;Yh(b,12,c);break a}lB(c+8|0,b);qd(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;return d|0}function is(a){var b=0,c=0,d=0;c=1;while(1){if(c){c=0;b=v[a+4>>2];d=((b<<2)+($u(v[a>>2],1)^270549120)|0)+2019860093|0;v[a>>2]=d;b=b+B($u(d,16),5)|0;v[a+4>>2]=b;continue}break}return b}function zl(a,b){var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=b;d=b;b=ih(-1);if(d>>>0<=b>>>0){a=$o(a);if(a>>>0<b>>>1>>>0){v[c+8>>2]=a<<1;b=v[Yc(c+8|0,c+12|0)>>2]}jb=c+16|0;return b}Wc();L()}function Oh(a){var b=0;a=Qh(a);b=2147483647;a:{if(a>=C(2147483648)){break a}b=-2147483648;if(a<=C(-2147483648)){break a}b=~~a;if(C(D(a))<C(2147483648)){break a}b=-2147483648}return b}function ys(a){var b=0;b=v[a+24>>2];v[23296]=0;Y(766,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){Me(a+68|0);Wf(a+36|0);os(a+32|0);dj(a+24|0);cj(a+4|0);return te(a)}V(0)|0;O()|0;Ub();L()}function xha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;DS(b,c);c=Ob(v[a>>2],v[a+8>>2],c<<2);if(c){CS(d+8|0,v[b>>2],v[b+4>>2]);qd(d,a,v[d+8>>2],v[d+12>>2])}jb=d+16|0;return c|0}function x8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;e=jb-16|0;jb=e;f=1;g=v[c>>2];if(g>>>0<ad(a,b)>>>0){a=$m(e,Lb(a,g),x[c+12>>1]);b=aw(d,a);Tb(a);f=b^1}jb=e+16|0;return f|0}function tda(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Ob(v[a>>2],v[a+8>>2],4);a:{if(!d){t[c|0]=0;kD(b,4,c);break a}Dh(c+8|0,b);qd(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;return d|0}function fg(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;If(a+12|0,d);if(b){d=ri(b)}else{d=0}v[a>>2]=d;c=d+(c<<2)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+(b<<2)|0,v[e>>2]=f;return a|0}function bK(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=d|0;e=e|0;var f=0,g=0;f=jb-16|0;jb=f;v[f+8>>2]=v[a+8>>2];g=v[a+4>>2];v[f>>2]=v[a>>2];v[f+4>>2]=g;c=aK(f,b,c,d,e,0,0,0,0);jb=f+16|0;return+c}function sW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=nb[v[v[a>>2]+24>>2]](a)|0;if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Ib(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}function nM(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;lM(c,b+80|0);v[23296]=0;U(11,a|0,0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){yb(c);jb=c+16|0;return}a=P()|0;O()|0;yb(c);S(a|0);L()}function cz(a){var b=0,c=0;b=v[a>>2];c=v[b>>2];a:{if(!c){while(1){c=sh(b);b=v[b+8>>2];if(c){continue}break}break a}while(1){b=c;c=v[b+4>>2];if(c){continue}break}}v[a>>2]=b;return a}function EW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;zD(b,c);c=Ob(v[a>>2],v[a+8>>2],c<<3);if(c){yD(d+8|0,v[b>>2],v[b+4>>2]);qd(d,a,v[d+8>>2],v[d+12>>2])}jb=d+16|0;return c|0}function Cv(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;d=Fb(b);if(d>>>0<c>>>0){mm();L()}b=Jc(b);v[e+8>>2]=d-c;Jo(a,b+c|0,v[Ib(e+12|0,e+8|0)>>2]);jb=e+16|0}function wda(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;_P(b,c);if(Ob(v[a>>2],v[a+8>>2],c<<8)){c=v[b>>2];ic(d+8|0,c,rh(c,v[b+4>>2])<<8);qd(d,a,v[d+8>>2],v[d+12>>2])}jb=d+16|0}function DW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d=!b|(b>>>0>d>>>0|a>>>0>=d>>>0|d-a>>>0<b>>>0);a:{if(d){break a}a=a+b|0;if(ad(v[c>>2],v[c+4>>2])>>>0>=a>>>0){break a}Li(c,a)}return!d|0}function CN(a,b,c,d){a:{if((a|0)!=67108864){break a}a=B(d,872)+c|0;v[a+704>>2]=v[a+704>>2]&-129;a=d^1;if(a>>>0>=(b&65535)>>>0){break a}a=B(a,872)+c|0;v[a+704>>2]=v[a+704>>2]&-129}}function xo(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;a=Fi(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){lc(a);jb=d+16|0}else{Di(b,x[c>>1]);b=b+2|0;v[a+4>>2]=b;continue}break}}function rC(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;a=Ph(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){lc(a);jb=d+16|0}else{Qp(b,v[c>>2]);b=b+4|0;v[a+4>>2]=b;continue}break}}function ne(a,b){var c=0;a:{c=Ef(b);if((c|0)==(Fb(a)|0)){v[23296]=0;a=W(347,a|0,b|0,c|0)|0;b=v[23296];v[23296]=0;if((b|0)==1){break a}a=!a}else{a=0}return a}V(0)|0;O()|0;Ub();L()}function Sx(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;a=Ph(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){lc(a);jb=d+16|0}else{Ks(b,z[c>>2]);b=b+4|0;v[a+4>>2]=b;continue}break}}function MS(a,b){var c=0;c=w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24);t[a|0]=c;t[a+1|0]=c>>>8;t[a+2|0]=c>>>16;t[a+3|0]=c>>>24;b=w[b+4|0]|w[b+5|0]<<8;t[a+4|0]=b;t[a+5|0]=b>>>8}function xC(a){var b=0,c=0;a:{if(Pb(a,14017,3)){break a}b=w[a+3|0];b:{if(b>>>0<=7){if((b|0)==1){break b}break a}if(b>>>0>14){break a}}c=(w[a+40|0]-1&255)>>>0<32|b>>>0<9}return c}function wY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];if(a>>>0<=127){a=v[(a<<2)+82128>>2]}else{a=0}v[d>>2]=a;d=d+4|0;b=b+4|0;continue}break}return c|0}function kha(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;v[c+24>>2]=0;v[c+28>>2]=0;v[c+16>>2]=0;v[c+20>>2]=0;v[c+8>>2]=0;v[c+12>>2]=0;v[c>>2]=0;v[c+4>>2]=0;$S(b,c);_S(a,c);jb=c+32|0}function fga(){var a=0,b=0,c=0;a=jb-16|0;jb=a;b=xc(1);v[23296]=0;Z(31);c=v[23296];v[23296]=0;if((c|0)!=1){b=v[xf(a+8|0,b)>>2];jb=a+16|0;return b|0}a=P()|0;O()|0;Jb(b);S(a|0);L()}function _j(a,b){var c=0,d=0,e=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Gb(b);d=Gb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function Xga(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;c=gf(a,c);ae(e,v[a+28>>2]);a:{if(!c){f=0;if(hd(a,5)){break a}}ZS(v[a+28>>2],b,d,0);f=c}$e(a,f);jb=e+16|0}function Do(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;a=uk(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){lc(a);jb=d+16|0}else{Hj(b,w[c|0]);b=b+1|0;v[a+4>>2]=b;continue}break}}function Bc(a,b){var c=0,d=0;c=jb-16|0;jb=c;if(Ve(a)){Jb(v[a>>2])}d=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=d;v[a+8>>2]=v[b+8>>2];xe(b,0);t[c+15|0]=0;sd(b,c+15|0);jb=c+16|0;return a}function $e(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!b){b=1;if(hd(a,5)){break a}ae(c,v[a+28>>2])}v[a>>2]=v[a>>2]|134217728;v[a+20>>2]=v[a+20>>2]+1;b=0}jb=c+16|0;return b|0}function p6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);if(b>>>0<=12){c=Sd(c,C(0));d=a+4208|0;if((b|0)==12){c=C(Qh(C(c*C(3)))/C(3));b=12}e=Db(d,b),f=c,z[e>>2]=f;t[a+5046|0]=1}}function js(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;v[b+12>>2]=12;while(1){v[b+8>>2]=32;if(y[Ib(b+12|0,b+8|0)>>2]<=c>>>0){jb=b+16|0}else{c=c+15|0;d=Nn(a)&4095;continue}break}return d}function cX(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;OD(b,0,a);v[23296]=0;a=T(113,b|0)|0;c=v[23296];v[23296]=0;if((c|0)!=1){yb(b);jb=b+16|0;return a|0}a=P()|0;O()|0;yb(b);S(a|0);L()}function b9(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-32|0;jb=d;c=-1;a:{if(!RD(a,d+8|0)){break a}c=0;if(!GL(d+8|0)|(v[d+16>>2]!=v[b>>2]|v[b+4>>2]?b:0)){break a}c=1}jb=d+32|0;return c|0}function aO(a,b,c,d){var e=0,f=0;e=jb-16|0;jb=e;while(1){if(c){f=Vk(x[c+16>>1],v[c+20>>2],a,b);d=f?d:c;c=v[(f?c+4|0:c)>>2];continue}break}a=v[hc(e+8|0,d)>>2];jb=e+16|0;return a}function YD(a){var b=0;a:{b:{if(a>>>0>=18285141){if(a>>>0>18350591){break b}b=1;if((a|0)!=18350080){break a}}return 0}b=0;if((a|0)==18350592){break a}b=(a&-256)!=(a|0)}return b}function lE(a,b,c){var d=0;a:{if(!a){a=ba(8)|0;v[23296]=0;c=T(c|0,a|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){break a}b=P()|0;O()|0;ca(a|0);S(b|0);L()}return}ha(c|0,b|0,904);L()}function aia(a,b){a=a|0;b=b|0;if(!OT(a,b)){t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b+6|0]=0;t[b+7|0]=0;t[b+8|0]=0;t[b+9|0]=0;t[b+10|0]=0;t[b+11|0]=0}}function N1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;ex(a,b,c);c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Ib(d+8|0,d+12|0)>>2]}jb=d+16|0;return c|0}function Lv(a,b,c,d,e){var f=0;a:{f=Ns(4332);if(f){v[23296]=0;ja(e|0,f|0,a|0,b|0,c|0,d|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break a}}return f}a=P()|0;O()|0;Jb(f);S(a|0);L()}function XL(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;while(1){v[b+12>>2]=7;v[b+8>>2]=32;if(y[Ib(b+12|0,b+8|0)>>2]<=c>>>0){jb=b+16|0}else{c=c+15|0;d=Nn(a)&127;continue}break}return d}function Sda(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;b=-1;a:{if(!Aj(a,c+8|0)){break a}b=0;if(!aQ(c+8|0)){break a}b=-1;if(!Vf(a,4)){break a}b=zQ(a)>>>31|0}jb=c+16|0;return b|0}function G8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=jb-16|0;jb=e;c=gf(a,c);ae(e,v[a+28>>2]);a:{if(!c){f=0;if(hd(a,5)){break a}}mL(d,v[a+28>>2],b);f=c}$e(a,f);jb=e+16|0}function $X(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;nb[v[v[a>>2]+12>>2]](d+8|0,a,b);a=v[d+8>>2];b=v[c>>2];a=uc(v[d+12>>2],v[c+4>>2])&(a|0)==(b|0);jb=d+16|0;return a|0}function rq(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a>>2];d=v[a+4>>2];if(Nc(c,d)>>>0>b>>>0){a=v[a+24>>2];b=kl(c,d,b);a=oe(v[a+484344>>2],v[a+484348>>2],x[b>>1])}else{a=0}return a|0}function fp(a){var b=0,c=0;b=v[23217];c=a+3&-4;a=b+c|0;a:{if(a>>>0<=b>>>0?c:0){break a}if(Mw()>>>0<a>>>0){if(!(xa(a|0)|0)){break a}}v[23217]=a;return b}v[115772]=48;return-1}function Z9(a,b){a=a|0;b=b|0;var c=0;a=hg(a);c=qj(v[b>>2]);b=yf(b);v[23296]=0;U(760,a|0,c|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;gN(a);S(b|0);L()}function yQ(a,b){var c=0,d=0;c=jb-16|0;jb=c;Dh(c+8|0,b);b=v[c+12>>2];md(c,a,v[c+8>>2],v[c+12>>2]);d=v[c+4>>2];if((b|0)==(d|0)){dd(a,v[c+12>>2])}jb=c+16|0;return(b|0)==(d|0)}function wea(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+8>>2]=b;while(1){if(Rb(b,c)){v[d+4>>2]=v[b>>2];iA(a,d+4|0);b=v[Ce(d+8|0)>>2];continue}else{jb=d+16|0}break}}function pg(a,b,c,d){var e=0;a=((b|0)/8|0)+a|0;e=eh(v[d>>2],v[d+4>>2],a);return((eh(v[d>>2],v[d+4>>2],a+1|0)<<8|e<<16|eh(v[d>>2],v[d+4>>2],a+2|0))<<(b&7)&16777215)>>>24-c|0}function MA(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;a=oq(d,a,b);b=v[a+4>>2];e=v[a+8>>2];while(1){if((b|0)==(e|0)){lc(a);jb=d+16|0}else{Xt(b,c);b=b+6|0;v[a+4>>2]=b;continue}break}}function Ku(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;Li(b,c);if(Ob(v[a>>2],v[a+8>>2],c)){c=v[b>>2];ic(d+8|0,c,ad(c,v[b+4>>2]));qd(d,a,v[d+8>>2],v[d+12>>2])}jb=d+16|0}function GT(a){var b=0;a:{if(Pb(a,16536,4)){break a}if(cc(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))-257>>>0<4294967053){break a}b=!Mb(w[a+8|0]|w[a+9|0]<<8)}return b}function Jh(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;t[c+24|0]=0;Xi(c+8|0,c+24|0);ln(c+16|0,a,v[c+8>>2],v[c+12>>2]);a=v[c+20>>2];t[b|0]=w[c+24|0];jb=c+32|0;return(a|0)==1|0}function Bl(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;If(a+12|0,d);if(b){d=xc(b)}else{d=0}v[a>>2]=d;c=c+d|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=b+d|0,v[e>>2]=f;return a|0}function xD(a,b,c){var d=0,e=0;a:{b:{if(xq(c)){xe(a,c);break b}if(c>>>0>=4294967280){break a}d=zi(c)+1|0;e=xc(d);yd(a,e);Af(a,d);Td(a,c);a=e}He(a,b,c+1|0);return}of();L()}function uY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a:{while(1){if((c|0)==(d|0)){break a}a=v[c>>2];if(!(a>>>0>127|!(v[(a<<2)+82128>>2]&b))){c=c+4|0;continue}break}d=c}return d|0}function Ye(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;v[d+8>>2]=c;v[d+4>>2]=31;e=d,f=yU(b,c),v[e+12>>2]=f;c=b;b=xB(d+4|0);ch(c,c+b|0,a);e=Lb(a,b),f=0,t[e|0]=f;AU(a);jb=d+16|0}function Aia(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Km(c+8|0,b);b=v[c+12>>2];nc(c,v[a>>2],v[a+8>>2],v[c+8>>2],v[c+12>>2]);if((b|0)==v[c+4>>2]){ac(a,v[c+12>>2])}jb=c+16|0}function zha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;a:{if(a){nb[v[v[a>>2]+8>>2]](a,b,c);break a}if((b|0)>=6){break a}tM(d,9055,10750,140,42);dE(d,b,c)}jb=d+16|0}function tW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=nb[v[v[a>>2]+24>>2]](a)|0;a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function kaa(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Ob(v[a>>2],v[a+8>>2],16);a:{if(!d){jC(b);break a}Nu(c+8|0,b);qd(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;return d|0}function Il(a){a=a<<8&16711680|a<<24|(a>>>8&65280|a>>>24);a=a>>>4&252645135|(a&252645135)<<4;a=a>>>2&858993459|(a&858993459)<<2;return a>>>1&1431655765|(a&1431655765)<<1}function Dfa(){var a=0,b=0,c=0;a=jb-16|0;jb=a;b=Vb(a,10157);v[23296]=0;Y(35,b|0);c=v[23296];v[23296]=0;if((c|0)!=1){yb(b);jb=a+16|0;return}a=P()|0;O()|0;yb(b);S(a|0);L()}function wP(a,b){var c=0,d=0;c=jb-16|0;jb=c;a=Ph(c,a,b);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){lc(a);jb=c+16|0}else{uP(b);b=b+4|0;v[a+4>>2]=b;continue}break}}function vY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){a:{if((c|0)!=(d|0)){a=v[c>>2];if(a>>>0>127|!(v[(a<<2)+82128>>2]&b)){break a}}else{c=d}return c|0}c=c+4|0;continue}}function mC(a,b){var c=0,d=0;c=jb-16|0;jb=c;a=Fi(c,a,b);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){lc(a);jb=c+16|0}else{lC(b);b=b+2|0;v[a+4>>2]=b;continue}break}}function kE(a,b){var c=0,d=0;c=jb-16|0;jb=c;a=uk(c,a,b);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){lc(a);jb=c+16|0}else{vg(b);b=b+1|0;v[a+4>>2]=b;continue}break}}function FF(a,b){var c=0,d=0;c=jb-16|0;jb=c;a=Ph(c,a,b);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){lc(a);jb=c+16|0}else{CF(b);b=b+4|0;v[a+4>>2]=b;continue}break}}function DA(a,b){var c=0,d=0;c=jb-16|0;jb=c;a=Ph(c,a,b);b=v[a+4>>2];d=v[a+8>>2];while(1){if((b|0)==(d|0)){lc(a);jb=c+16|0}else{tm(b);b=b+4|0;v[a+4>>2]=b;continue}break}}function no(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=Ob(v[a>>2],v[a+8>>2],4);a:{if(!d){FS(b);break a}Dh(c+8|0,b);qd(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0;return d|0}function bI(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&240)!=240&(b&254)!=226|!(b&6)){break a}a=w[a+2|0];if((a&240)==240){break a}c=(a&12)!=12}return c}function Ht(a){var b=0,c=0,d=0,e=0;while(1){a:{if((b|0)==32){e=c;break a}d=w[a+b|0];if((d-1&255)>>>0<31|((c^1)&1?0:d)){break a}b=b+1|0;c=!d|c;continue}break}return e&1}function cea(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-48|0;jb=c;d=-1;a:{if(!vQ(a,c)){break a}d=0;if(!uQ(c)){break a}d=Ge(a,b,sQ(w[c+31|0],w[c+33|0]),mb)}jb=c+48|0;return d|0}function afa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;zD(b,c);if(Ob(v[a>>2],v[a+8>>2],c<<3)){yD(d+8|0,v[b>>2],v[b+4>>2]);qd(d,a,v[d+8>>2],v[d+12>>2])}jb=d+16|0}function V8(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;c=gf(a,c);ae(d,v[a+28>>2]);a:{if(!c){e=0;if(hd(a,5)){break a}}aT(v[a+28>>2],b,a);e=c}$e(a,e);jb=d+16|0}function DC(a,b,c){var d=0;d=jb-16|0;jb=d;a=Eo(d,a+8|0,b);b=v[a>>2];while(1){if((b|0)!=v[a+4>>2]){Di(b,x[c>>1]);b=v[a>>2]+2|0;v[a>>2]=b;continue}break}Id(a);jb=d+16|0}function yA(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;DS(b,c);if(Ob(v[a>>2],v[a+8>>2],c<<2)){CS(d+8|0,v[b>>2],v[b+4>>2]);qd(d,a,v[d+8>>2],v[d+12>>2])}jb=d+16|0}function wl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;a:{c=Ef(b);d=lm(a);if(c>>>0<=d>>>0){PA(a,rj(rd(a),b,c),c);break a}e=a;a=Cd(v[a+4>>2],w[a+11|0]);Ut(e,d,c-d|0,a,0,a,c,b)}}function m5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=a;a=b+28|0;d=kp(d,a);PJ(a,c);v[23296]=0;R(69,b|0,1);a=v[23296];v[23296]=0;if((a|0)==1){a=P()|0;O()|0;_b(d);S(a|0);L()}}function gW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=v[a+16>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Ib(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}function Uj(a,b){var c=0,d=0,e=0;a:{c=Xk(a,b);if((c|0)==255){break a}if(Vj(v[a>>2])){break a}d=Lb(a+8|0,c);e=w[d|0]&223;t[d|0]=e;Tg(v[a>>2],v[a+4>>2],b,lt(c)|176,e)}}function Maa(a,b){a=a|0;b=b|0;a=Cc(a);t[a+534|0]=0;v[a+4>>2]=0;v[23296]=0;R(711,a|0,b|0);b=v[23296];v[23296]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;jm(a);S(b|0);L()}function KS(a,b,c){var d=0;d=jb-16|0;jb=d;a=Kv(d,a+8|0,b);b=v[a>>2];while(1){if((b|0)!=v[a+4>>2]){Hj(b,w[c|0]);b=v[a>>2]+1|0;v[a>>2]=b;continue}break}Id(a);jb=d+16|0}function Efa(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a:{d=Qb(a+8|0);v[23296]=0;U(232,a|0,b|0,c|0);a=v[23296];v[23296]=0;if((a|0)!=1){break a}a=P()|0;O()|0;fc(d);S(a|0);L()}}function uW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;c=0;a=v[a+8>>2];if(a>>>0>b>>>0){v[d+8>>2]=a-b;c=v[Ib(d+12|0,d+8|0)>>2]}jb=d+16|0;return c|0}function qP(a){var b=0,c=0;a:{if(w[a|0]!=255){break a}b=w[a+1|0];if((b&224)!=224|(b&24)==8|!(b&6)){break a}a=w[a+2|0];if((a&12)==12){break a}c=(a&240)!=240}return c}function iA(a,b){a=a|0;b=b|0;var c=0;if(y[a+4>>2]<y[Gb(a)>>2]){c=jb-16|0;jb=c;a=Ph(c,a,1);Qp(v[a+4>>2],v[b>>2]);v[a+4>>2]=v[a+4>>2]+4;lc(a);jb=c+16|0;return}Uz(a,b)}function VS(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;b=kc(b);a=th(a,xc(32),uh(d+8|0,b));b=v[a>>2]+16|0;u[b>>1]=x[v[c>>2]>>1];Kb(b+4|0);e=kc(a),f=1,t[e+4|0]=f;jb=d+16|0}function O1(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;ex(a,b,c);a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function E0(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=jb-16|0;jb=e;a=Qw(Ta(v[a+60>>2],b|0,c|0,d&255,e+8|0)|0);jb=e+16|0;mb=a?-1:v[e+12>>2];return(a?-1:v[e+8>>2])|0}function A_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=nb[v[v[a+8>>2]+20>>2]](a+8|0)|0;b=tc(a);return Ij(g,h,c,d,e,f,b,b+(Fb(a)<<2)|0)|0}function hH(a,b){var c=0,d=0,e=0,f=0;c=v[a+24>>2];if((c|0)==v[a+28>>2]){return e=a,f=Lf(b),d=v[v[a>>2]+52>>2],nb[d](e|0,f|0)|0}v[a+24>>2]=c+1;t[c|0]=b;return Lf(b)}function _aa(a,b){a=a|0;b=b|0;a=Qb(a);t[a+16|0]=0;v[a+12>>2]=b;v[23296]=0;Y(704,a|0);b=v[23296];v[23296]=0;if((b|0)!=1){return a|0}b=P()|0;O()|0;rz(a);S(b|0);L()}
function Xha(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Ob(v[b>>2],v[b+8>>2],6)){t[c|0]=0;Yh(a,6,c);break a}eB(c+8|0,a);qd(c,b,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function Oe(a,b){var c=0;c=v[a>>2];v[a>>2]=b;a:{if(c){a=v[kc(a)>>2];v[23296]=0;Y(a|0,c|0);a=v[23296];v[23296]=0;if((a|0)==1){break a}}return}V(0)|0;O()|0;Ub();L()}function LP(a){v[a>>2]=0;v[a+4>>2]=0;v[a+88>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;Gz(a+112|0,48e3);v[a+668>>2]=0;Fz(a+724|0);Fz(a+732|0);Fz(a+740|0);Th(a+788|0);return a}function Fea(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Ob(v[b>>2],v[b+8>>2],5)){t[c|0]=0;Yh(a,5,c);break a}zu(c+8|0,a);qd(c,b,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function zm(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Ob(v[b>>2],v[b+8>>2],4)){t[c|0]=0;Yh(a,4,c);break a}Dh(c+8|0,a);qd(c,b,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function xB(a){var b=0,c=0;a:{c=Db(a,3);if((c|0)==(a|0)){break a}b=a;while(1){b=b+4|0;if((c|0)==(b|0)){break a}a=aq(v[b>>2],v[a>>2])?b:a;continue}}return v[a>>2]}function Sm(a,b){a=a|0;b=b|0;var c=0;if(!Uf(w[b+11|0])){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return a|0}xD(a,v[b>>2],v[b+4>>2]);return a|0}function Np(a){v[a+8>>2]=0;v[a+12>>2]=0;v[a>>2]=128;v[a+4>>2]=256;v[a+32>>2]=363;v[a+36>>2]=952;v[a+16>>2]=48e3;v[a+20>>2]=2;v[a+24>>2]=128;v[a+28>>2]=0;return a}function JX(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;v[d+12>>2]=v[c>>2];a=nb[v[v[a>>2]+16>>2]](a,b,d+12|0)|0;if(a){v[c>>2]=v[d+12>>2]}jb=d+16|0;return a|0}function BD(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;v[f+12>>2]=e;v[f+8>>2]=d;v[f+4>>2]=c;v[f>>2]=b;a=rg(a,f);v[a+8>>2]=0;b=a+12|0;a=f+8|0;rg(b,a);ee(a);ee(f);jb=f+16|0}function vM(a){var b=0,c=0,d=0;b=v[a+112>>2];if((b|0)>=11){c=378;while(1){if(c|d){uM(a);b=c;c=b-1|0;d=d-!b|0;continue}break}b=0}v[a+112>>2]=b+1;a=uM(a);return a}function tP(a,b){var c=0;c=v[a+4>>2];a:{if((b|0)>=0){b=b+c|0;c=v[a>>2]+(b>>>3&536870908)|0;break a}b=b+c|0;c=v[a>>2]+((b-31|0)/32<<2)|0}v[a>>2]=c;v[a+4>>2]=b&31}function bk(a,b){var c=0;c=jb-32|0;jb=c;v[c+24>>2]=0;Hv(c+8|0,c+24|0);ln(c+16|0,a,v[c+8>>2],v[c+12>>2]);a=v[c+20>>2];v[b>>2]=v[c+24>>2];jb=c+32|0;return(a|0)==4}function Zp(a){var b=0,c=0,d=0,e=0;b=v[a+4>>2];c=v[b>>2];v[a+4>>2]=c;if(c){Ml(c,a)}v[b+8>>2]=v[a+8>>2];d=v[a+8>>2]+(sh(a)?0:4)|0,e=b,v[d>>2]=e;v[b>>2]=a;Ml(a,b)}function Yp(a){var b=0,c=0,d=0,e=0;b=v[a>>2];c=v[b+4>>2];v[a>>2]=c;if(c){Ml(c,a)}v[b+8>>2]=v[a+8>>2];d=v[a+8>>2]+(sh(a)?0:4)|0,e=b,v[d>>2]=e;v[b+4>>2]=a;Ml(a,b)}function Xea(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-80|0;jb=d;c=-1;a:{if(!mU(a,d+8|0)){break a}c=0;if(!mR(d+8|0)){break a}c=Ge(a,b,lR(d+8|0),mb)}jb=d+80|0;return c|0}function TD(a,b,c,d){var e=0,f=0;e=-1;a:{if(!b){break a}f=a+b|0;b=a;while(1){if((b|0)==(f|0)){break a}if(_p(c,d,w[b|0])){b=b+1|0;continue}break}e=b-a|0}return e}function Ki(a,b,c,d,e){a:{e=Ns(e);if(e){v[23296]=0;fa(d|0,e|0,a|0,b|0,c|0)|0;a=v[23296];v[23296]=0;if((a|0)==1){break a}}return e}a=P()|0;O()|0;Jb(e);S(a|0);L()}function D9(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=jb-16|0;jb=c;d=c,e=wi(b),v[d+12>>2]=e;v[c+8>>2]=0;d=a,e=v[wj(c+12|0,c+8|0,43824)>>2],v[d+36>>2]=e;rp(a);jb=c+16|0}function as(a){var b=0;a:{if((Pe(a)|0)!=79){break a}if((Pe(a)|0)!=103){break a}if((Pe(a)|0)!=103){break a}b=(Pe(a)|0)==83}if(!b){bc(a,30);return 0}return WH(a)}function Ru(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;a:{if(!Ob(v[b>>2],v[b+8>>2],2)){t[c|0]=0;kC(a,c);break a}ql(c+8|0,a);qd(c,b,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function MI(a,b){var c=0,d=0;d=a+4|0;c=ad(v[d>>2],v[a+8>>2]);a=v[a+16>>2]+b|0;if(c>>>0<a>>>0){a:{if(c){b=Hf(c);if(a>>>0<=b>>>0){break a}}b=NI(a,65536)}Li(d,b)}}function G_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=a;h=b;a=nb[v[v[a+8>>2]+20>>2]](a+8|0)|0;b=Jc(a);return Jj(g,h,c,d,e,f,b,Fb(a)+b|0)|0}function lT(a,b){var c=0;c=Sia(b&65535,0,384,0);b=a&65535;a=b>>>30|0;b=b<<2;c=c+b|0;a=a+mb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+256|0;a=b>>>0<256?a+1|0:a;mb=a;return b}function iV(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=-1;if(og(a,c+8|0)){v[c+4>>2]=w[c+8|0];d=_B(a,b,v[Ib(c+4|0,c+12|0)>>2])}jb=c+16|0;return d|0}function dC(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;v[c+12>>2]=-1;if(og(a,c+8|0)){v[c+4>>2]=w[c+8|0];d=XB(a,b,v[Ib(c+4|0,c+12|0)>>2])}jb=c+16|0;return d|0}function am(a){var b=0;b=2147483647;a:{if(a>=2147483647){break a}b=-2147483648;if(a<=-2147483648){break a}if(D(a)<2147483648){return~~a}b=-2147483648}return b}function W7(a){a=a|0;var b=0,c=0,d=0;b=jb-16|0;jb=b;XK(b+8|0,a,0);c=v[b+12>>2];if(c){a=v[a+20>>2];v[a+148>>2]=-1;d=a+4|0;a=v[b+8>>2];ny(d,a,Lb(a,c))}jb=b+16|0}function Sd(a,b){var c=0,d=0,e=C(0);c=jb-16|0;jb=c;v[c+8>>2]=1065353216;z[c+12>>2]=b;d=c,e=wf(a),z[d+4>>2]=e;a=z[Xp(c+4|0,c+12|0,c+8|0)>>2];jb=c+16|0;return a}function NT(a){var b=0;if(!(Pb(a,17667,8)|w[a+8|0]>1|((w[a+9|0]-1&255)>>>0>7|(w[a+10|0]|w[a+11|0]<<8)>>>0>4096))){b=(w[a+12|0]|w[a+13|0]<<8)>>>0<4097}return b}function EJ(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;c=v[b+20>>2];v[a+16>>2]=v[b+16>>2];v[a+20>>2]=c;c=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=c}function u$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=v[b>>2]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+4|0;continue}break}return a|0}function ok(a,b,c,d){var e=0,f=0;If(a+12|0,d);if(b){d=_D(b)}else{d=0}v[a>>2]=d;c=d+B(c,12)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+B(b,12)|0,v[e>>2]=f;return a}function md(a,b,c,d){var e=0,f=0,g=0;e=jb-16|0;jb=e;f=v[b+12>>2];v[e+8>>2]=c;v[e+12>>2]=d;g=v[v[b>>2]+28>>2];v[e>>2]=c;v[e+4>>2]=d;nb[g|0](a,b,f,e);jb=e+16|0}function mD(a){var b=0;if(!(Pb(a,15346,4)|(w[a+4|0]-16&255)>>>0<249|((w[a+5|0]-16&255)>>>0<249|(w[a+6|0]-16&255)>>>0<249))){b=(w[a+7|0]-9&255)>>>0<7}return b}function lK(a){a=a|0;var b=0;v[a+4240>>2]=0;v[a+4244>>2]=0;b=a+4264|0;v[b>>2]=0;v[b+4>>2]=0;b=a+4256|0;v[b>>2]=0;v[b+4>>2]=0;a=a+4248|0;v[a>>2]=0;v[a+4>>2]=0}function bB(a,b,c,d){var e=0,f=0;If(a+12|0,d);if(b){d=nC(b)}else{d=0}v[a>>2]=d;c=d+B(c,20)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+B(b,20)|0,v[e>>2]=f;return a}function Jz(a){var b=0;a=ge(a);b=32767;a:{if(a>=32767){break a}b=32768;if(a<=-32768){break a}b=~~a;if(D(a)<2147483648){break a}b=-2147483648}return b<<16>>16}function x$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=0;while(1){if((b|0)!=(c|0)){a=t[b|0]+(a<<4)|0;d=a&-268435456;a=(d|d>>>24)^a;b=b+1|0;continue}break}return a|0}function rda(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-48|0;jb=d;c=-1;a:{if(!vQ(a,d)){break a}c=0;if(!HP(d)){break a}c=Ge(a,b,GP(w[d+47|0]),mb)}jb=d+48|0;return c|0}function lA(a){var b=0,c=0;b=jb-16|0;jb=b;a:{if(Uf(w[a+11|0])){c=v[a>>2];t[b+15|0]=0;sd(c,b+15|0);Td(a,0);break a}t[b+14|0]=0;sd(a,b+14|0);xe(a,0)}jb=b+16|0}function ac(a,b){a=a|0;b=b|0;var c=0;c=Ob(v[a>>2],v[a+8>>2],b);a:{if(c){b=v[a+8>>2]+b|0;break a}b=v[a>>2];b=nb[v[v[b>>2]+24>>2]](b)|0}v[a+8>>2]=b;return c|0}function Tv(a,b,c,d){var e=0;e=ba(8)|0;v[23296]=0;a=Q(d|0,e|0,a|0)|0;d=v[23296];v[23296]=0;if((d|0)!=1){ha(a|0,c|0,b|0);L()}a=P()|0;O()|0;ca(e|0);S(a|0);L()}function MQ(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;while(1){if((b|0)==(c|0)){jb=d+16|0}else{v[d+12>>2]=v[b>>2];iA(a,d+12|0);b=b+4|0;continue}break}}function M2(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;while(1){if((a|0)!=(b|0)){d=v[c>>2];v[d>>2]=v[a>>2];Rh(d+4|0,a+4|0);v[c>>2]=v[c>>2]+16;a=a+16|0;continue}break}}function xj(a,b,c,d){var e=0,f=0;If(a+12|0,d);if(b){d=TC(b)}else{d=0}v[a>>2]=d;c=d+(c<<1)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+(b<<1)|0,v[e>>2]=f;return a}function xc(a){a=a|0;var b=0;a=a?a:1;a:{while(1){b=Jd(a);if(b){break a}b=v[117237];if(b){nb[b|0]();continue}break}ha(Nl(ba(4)|0)|0,91780,25);L()}return b|0}function st(a,b,c,d){var e=0,f=0;If(a+12|0,d);if(b){d=IP(b)}else{d=0}v[a>>2]=d;c=d+(c<<5)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+(b<<5)|0,v[e>>2]=f;return a}function cr(a,b,c,d){var e=0,f=0;If(a+12|0,d);if(b){d=wD(b)}else{d=0}v[a>>2]=d;c=d+(c<<3)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+(b<<3)|0,v[e>>2]=f;return a}function aA(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+8>>2]=a;c=c&65535;while(1){if(!(!Rb(a,b)|(c|0)==x[a>>1])){a=v[Se(d+8|0)>>2];continue}break}jb=d+16|0;return a}function Vs(a,b){var c=0,d=0,e=C(0);c=jb-16|0;jb=c;z[c+12>>2]=b;v[c+8>>2]=0;v[c+4>>2]=1065353216;d=a,e=z[Xp(c+12|0,c+8|0,c+4|0)>>2],z[d+144>>2]=e;jb=c+16|0}function QS(a,b,c,d){var e=0,f=0;If(a+12|0,d);if(b){d=LS(b)}else{d=0}v[a>>2]=d;c=d+B(c,6)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+B(b,6)|0,v[e>>2]=f;return a}function Iv(a,b,c,d){var e=0,f=0;If(a+12|0,d);if(b){d=fE(b)}else{d=0}v[a>>2]=d;c=d+(c<<4)|0;v[a+8>>2]=c;v[a+4>>2]=c;e=zc(a),f=d+(b<<4)|0,v[e>>2]=f;return a}function CM(){var a=0,b=0,c=0,d=0;a=jb-16|0;jb=a;b=a+8|0;while(1){if(c>>>0<32){c=c+48|0;d=sy(93224);continue}break}v[b>>2]=d;Nn(b);jb=a+16|0;return v[b>>2]}function t1(a,b,c){a=a|0;b=b|0;c=c|0;a:{a=Rh(a,b);v[23296]=0;Q(53,a+12|0,c|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){break a}b=P()|0;O()|0;yb(a);S(b|0);L()}}function np(a,b){var c=0,d=0;a:{if(!a){break a}c=Sia(a,0,b,0);d=mb;if((a|b)>>>0<65536){break a}c=d?-1:c}a=Jd(c);if(!(!a|!(w[a-4|0]&3))){Xb(a,0,c)}return a}function lD(a,b){a=a|0;b=b|0;var c=0,d=0;c=a;a=v[b>>2];d=(nb[v[v[a>>2]+20>>2]](a)|0)+v[b+8>>2]|0;a=v[b>>2];gc(c,d,(nb[v[v[a>>2]+24>>2]](a)|0)-v[b+8>>2]|0)}function hW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+16>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function ej(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;A[a>>3]=A[a>>3]-c;A[a+8>>3]=A[a+8>>3]-d}function SD(a,b,c,d){var e=0;if(!d){return-1}b=a+b|0;e=-1;a:{while(1){if((a|0)==(b|0)){break a}b=b-1|0;if(!_p(c,d,w[b|0])){continue}break}e=b-a|0}return e}function DU(a,b,c){var d=0;b=b-a>>2;while(1){if((b|0)>0){d=v[c>>2];t[a|0]=d;t[a+1|0]=d>>>8;t[a+2|0]=d>>>16;t[a+3|0]=d>>>24;b=b-1|0;a=a+4|0;continue}break}}function $h(a){var b=0,c=0;b=a*a;c=b*a;return C(c*(b*b)*(b*2718311493989822e-21+-.00019839334836096632)+(c*(b*.008333329385889463+-.16666666641626524)+a))}function vW(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;a=v[a+8>>2];a:{if(!c){d=1;if((a|0)==(b|0)){break a}}d=0;if(a>>>0<=b>>>0){break a}d=a-b>>>0>=c>>>0}return d|0}function _w(a,b){var c=0;while(1){c=(b|0)<120?b:120;a=C(a*C(z[((c&3)<<2)+64640>>2]*C(1073741824>>>(c>>2)|0)));b=b-c|0;if((b|0)>0){continue}break}return a}function YG(a,b,c){var d=0;d=jb-32|0;jb=d;v[d+28>>2]=c;v[d+24>>2]=0;v[d+12>>2]=4;Cr(d+16|0,a,d+24|0,v[Ib(d+28|0,d+12|0)>>2]);v[b>>2]=v[d+24>>2];jb=d+32|0}function Rh(a,b){a=a|0;b=b|0;var c=0;if(!Ve(b)){c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];return a|0}xD(a,v[b>>2],v[b+4>>2]);return a|0}function vn(a,b){var c=0,d=0;b=b+7&-8;d=v[a+80>>2];a:{if(d){b=v[a+92>>2]-b|0;c=0;if((b|0)<v[a+88>>2]){break a}v[a+92>>2]=b;return b+d|0}c=Jd(b)}return c}function e6(a){a=a|0;var b=0,c=C(0);t[a+4202|0]=1;b=a,c=Ty(C(C(C(C(y[v[a+16>>2]+24620>>2])/C(3))+C(-80))/C(15920)),C(0),C(1)),z[b+4272>>2]=c;mK(a);lK(a)}function Xg(a){var b=0,c=0;b=v[a>>2];c=v[b+4>>2];a:{if(!c){while(1){if(!sh(b)){b=v[b+8>>2];continue}break}b=v[b+8>>2];break a}b=eS(c)}v[a>>2]=b;return a}function Pb(a,b,c){var d=0,e=0;a:{while(1){d=w[a|0];e=w[b|0];if((d|0)!=(e|0)){break a}b=b+1|0;a=a+1|0;c=c-1|0;if(c){continue}break}return 0}return d-e|0}function xl(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;ec(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Ej(a);Jb(b)}}function pm(a,b){var c=0,d=0,e=0;gB(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Gb(b);d=Gb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function oD(a){a=a|0;var b=0;a=Kb(a);v[23296]=0;T(162,a+12|0)|0;b=v[23296];v[23296]=0;if((b|0)!=1){Cc(a+32|0);return a|0}b=P()|0;O()|0;zb(a);S(b|0);L()}function nx(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;qs(b);continue}break}v[a+4>>2]=c;b=v[a>>2];or(a);Jb(b)}}function nY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=v[b>>2];t[e|0]=a>>>0<128?a:d;e=e+1|0;b=b+4|0;continue}break}return c|0}function XR(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-24|0;Ab(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Lt(a);Jb(b)}}function XQ(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-56|0;Et(b);continue}break}v[a+4>>2]=c;b=v[a>>2];VQ(a);Jb(b)}}function Us(a,b,c){var d=0;a:{if(b&134218752){break a}if(!Sj(c)){break a}b=w[c+34|0];if((b+5&255)>>>0<6){break a}d=v[(B(b,160)+a|0)+906140>>2]}return d}function Me(a){var b=0,c=0;if(v[a>>2]){c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;Tb(b);continue}break}v[a+4>>2]=c;b=v[a>>2];Ej(a);Jb(b)}}function M$(a,b){a=a|0;b=b|0;var c=0,d=0;b=vw(b);v[a+36>>2]=b;c=a,d=Ig(b),v[c+44>>2]=d;c=a,d=mn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Kr(5524);L()}}function F$(a,b){a=a|0;b=b|0;var c=0,d=0;b=zw(b);v[a+36>>2]=b;c=a,d=Ig(b),v[c+44>>2]=d;c=a,d=mn(v[a+36>>2]),t[c+53|0]=d;if(v[a+44>>2]>=9){Kr(5524);L()}}function $c(a,b){a=a|0;b=b|0;var c=0,d=0;a:{if(y[a+8>>2]<b>>>0){d=v[a>>2];c=0;if(nb[v[v[d>>2]+24>>2]](d)>>>0<b>>>0){break a}}v[a+8>>2]=b;c=1}return c|0}function $P(a,b){var c=0,d=0,e=0;pA(a);v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];c=Gb(b);d=Gb(a),e=v[c>>2],v[d>>2]=e;v[c>>2]=0;v[b>>2]=0;v[b+4>>2]=0;return a}function tT(a,b){var c=0;c=Sia(b&255,0,9,0);b=a&255;a=b>>>31|0;b=b<<1;c=c+b|0;a=a+mb|0;a=b>>>0>c>>>0?a+1|0:a;b=c+11|0;a=b>>>0<11?a+1|0:a;mb=a;return b}function TS(a,b,c){var d=0;d=jb-32|0;jb=d;v[d+28>>2]=c;t[d+24|0]=0;v[d+12>>2]=1;Cr(d+16|0,a,d+24|0,v[Ib(d+28|0,d+12|0)>>2]);t[b|0]=w[d+24|0];jb=d+32|0}function E3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=jb-32|0;jb=h;i=h+8|0;HI(i,b,c,d,e,f,g);Sc(a,h+20|0);Zl(i);jb=h+32|0}function Dn(a,b){v[a+20>>2]=0;v[a+24>>2]=b;v[a+12>>2]=0;v[a+4>>2]=4098;v[a+8>>2]=6;v[a+16>>2]=!b;Xb(a+32|0,0,40);nH(a+28|0);v[a+72>>2]=0;v[a+76>>2]=-1}function wN(a,b,c){var d=0,e=0;v[b+56>>2]=0;d=b,e=Rn(a,x[b+70>>1],v[b+48>>2],c,0),u[d+68>>1]=e;if(!(!(w[a+480180|0]&5)|v[b+60>>2]==-1)){v[b+60>>2]=0}}function lv(a,b){var c=0;c=jb-16|0;jb=c;a:{if(!Ob(v[b>>2],v[b+8>>2],3)){t[c|0]=0;Yh(a,3,c);break a}kv(c+8|0,a);qd(c,b,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function jea(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-96|0;jb=d;c=-1;a:{if(!cR(a,d)){break a}c=0;if(!HQ(d)){break a}c=Ge(a,b,GQ(d),mb)}jb=d+96|0;return c|0}function fv(a,b,c,d,e){var f=0;while(1){if((d|0)!=(f|0)){z[b>>2]=C(v[a>>2])*e;z[c>>2]=C(v[a+4>>2])*e;f=f+1|0;c=c+4|0;a=a+8|0;b=b+4|0;continue}break}}function fY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;while(1){if((b|0)!=(c|0)){a=t[b|0];t[e|0]=(a|0)<0?d:a;e=e+1|0;b=b+1|0;continue}break}return c|0}function Nf(a){var b=0,c=0;b=jb-16|0;jb=b;a:{if(Ve(a)){c=v[a>>2];t[b+15|0]=0;sd(c,b+15|0);Td(a,0);break a}t[b+14|0]=0;sd(a,b+14|0);xe(a,0)}jb=b+16|0}function Jea(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-96|0;jb=d;c=-1;a:{if(!cR(a,d)){break a}c=0;if(!bR(d)){break a}c=Ge(a,b,aR(d),mb)}jb=d+96|0;return c|0}function vL(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-52|0;v[a+8>>2]=b;Pk(b);continue}break}c=v[a>>2];if(c){zc(a);Jb(c)}}function rU(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-28|0;v[a+8>>2]=b;Md(b);continue}break}c=v[a>>2];if(c){zc(a);Jb(c)}}function oz(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-32|0;v[a+8>>2]=b;Yk(b);continue}break}c=v[a>>2];if(c){Ro(a);Jb(c)}}function ov(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-36|0;v[a+8>>2]=b;_q(b);continue}break}c=v[a>>2];if(c){zc(a);Jb(c)}}function kM(a){if(w[a+480224|0]==2){return+y[a+1074420>>2]/1e4}return+y[a+24620>>2]/(+y[a+1074404>>2]*+(B(v[a+1074408>>2],v[a+1074416>>2])>>>0))*60}function fu(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-20|0;v[a+8>>2]=b;Ab(b);continue}break}c=v[a>>2];if(c){zc(a);Jb(c)}}function UQ(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-56|0;v[a+8>>2]=b;Et(b);continue}break}c=v[a>>2];if(c){zc(a);Jb(c)}}function SX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Jg(a,v[b+8>>2],f)){cw(b,c,d,e);return}a=v[a+8>>2];nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)}function NN(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;Tb(b);continue}break}c=v[a>>2];if(c){Ro(a);Jb(c)}}function Dv(a){var b=0,c=0;c=v[a+4>>2];while(1){b=v[a+8>>2];if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;ec(b);continue}break}c=v[a>>2];if(c){Ro(a);Jb(c)}}function $J(a,b){a=a|0;b=b|0;var c=0,d=0;d=jb-16|0;jb=d;c=HJ(xc(12));v[c+8>>2]=b;v[c+4>>2]=a;v[c>>2]=48972;a=v[xf(d+8|0,c)>>2];jb=d+16|0;return a|0}function kz(a,b,c){var d=0,e=0,f=0;d=Xk(a,b);if((d|0)!=255){e=dc(a+26|0,d),f=c,u[e>>1]=f;a=a+62|0;e=Lb(a,b),f=255,t[e|0]=f;e=Lb(a,c),f=d,t[e|0]=f}}function ip(a,b){var c=0;a:{if(!bI(b)|(w[b+1|0]^w[a+1|0])>>>0>1){break a}b=w[b+2|0];a=w[a+2|0];if((b^a)&12){break a}c=!(b&240)^(a&240)!=0}return c}function bF(a){var b=0,c=0;c=a>>>23&255;b=0;a:{if(c>>>0<127){break a}b=2;if(c>>>0>150){break a}c=1<<150-c;b=0;if(c-1&a){break a}b=a&c?1:2}return b}function Vx(a,b,c,d){var e=0;e=jb-16|0;jb=e;a=oq(e,a,d);c=c-b|0;if((c|0)>0){qc(v[a+4>>2],b,c);v[a+4>>2]=v[a+4>>2]+B((c>>>0)/6|0,6)}lc(a);jb=e+16|0}function Uia(a,b,c){var d=0;d=b>>31;a=a^d;Qia(a-d|0,(b^d)-((a>>>0<d>>>0)+d|0)|0,c,0);mb=lb;a=d^kb;b=a-d|0;mb=(d^mb)-((a>>>0<d>>>0)+d|0)|0;return b}function S$(a,b){a=a|0;b=b|0;var c=0,d=0;c=v[a+40>>2];while(1){if(c){c=c-1|0;d=c<<2;nb[v[v[a+32>>2]+d>>2]](b,a,v[d+v[a+36>>2]>>2]);continue}break}}function RT(a){t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0;t[a+11|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function AO(a){var b=0,c=0,d=0;d=w[a+26|0];b=d+27|0;while(1){if((c|0)==(d|0)){a=b&65535}else{b=w[(a+c|0)+27|0]+b|0;c=c+1|0;continue}break}return a}function eC(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0;t[a+7|0]=0;t[a+8|0]=0;t[a+9|0]=0;t[a+10|0]=0}function B4(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0;h=jb-32|0;jb=h;i=h+8|0;HI(i,b,c,d,e,f,g);Sc(a,i);Zl(i);jb=h+32|0}function A6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0,f=C(0);if(b>>>0<=1){c=Sd(c,C(0));if((b|0)==1){d=1;c=Qh(c)}e=Db(a+4208|0,d),f=c,z[e>>2]=f;tK(a)}}function yw(a){var b=0,c=0;b=jb-16|0;jb=b;c=-1;a:{if(Jw(a)){break a}if((nb[v[a+32>>2]](a,b+15|0,1)|0)!=1){break a}c=w[b+15|0]}jb=b+16|0;return c}function nL(a){var b=0;b=jb-16|0;jb=b;z[b+12>>2]=D(a);v[b+8>>2]=646978941;v[b+4>>2]=1259902592;a=z[Xp(b+12|0,b+8|0,b+4|0)>>2];jb=b+16|0;return a}function nH(a){var b=0,c=0;v[23296]=0;c=ga(1044)|0;b=v[23296];v[23296]=0;if((b|0)!=1){b=a;a=v[c>>2];v[b>>2]=a;Lm(a);return}V(0)|0;O()|0;Ub();L()}function Kf(a,b){a=a|0;b=b|0;var c=0;c=jb-32|0;jb=c;u[c+24>>1]=0;pk(c+8|0,c+24|0);ln(c+16|0,a,v[c+8>>2],v[c+12>>2]);u[b>>1]=x[c+24>>1];jb=c+32|0}function pN(a,b){t[a+840|0]=b;t[a+812|0]=b;t[a+811|0]=b;t[a+809|0]=b;t[a+807|0]=b;t[a+806|0]=b;t[a+833|0]=b;t[a+826|0]=b>>>4;t[a+827|0]=b<<2&60}function iQ(a){a=a|0;var b=0,c=0;u[a+34>>1]=0;b=jb-16|0;jb=b;t[b+15|0]=0;c=a+43|0;Pl(c,c+22|0,b+15|0);jb=b+16|0;v[a+20>>2]=0;pd(a,0);return a|0}function fk(a,b,c,d){var e=0;e=B(b,c);a:{if(v[d+76>>2]<0){a=zB(a,e,d);break a}a=zB(a,e,d)}if((e|0)==(a|0)){return b?c:0}return(a>>>0)/(b>>>0)|0}function aj(a,b,c){if(a>>>0<b>>>0){qc(a,b,c);return}if(c){a=a+c|0;b=b+c|0;while(1){a=a-1|0;b=b-1|0;t[a|0]=w[b|0];c=c-1|0;if(c){continue}break}}}function Rz(a,b){a=a|0;b=b|0;var c=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);c=ad(v[b>>2],v[b+4>>2]);if(c){pl(a,c);_t(a,v[b>>2],v[b+4>>2],c)}return a|0}function R8(a,b){a=a|0;b=b|0;var c=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);c=wc(v[b>>2],v[b+4>>2]);if(c){il(a,c);qA(a,v[b>>2],v[b+4>>2],c)}return a|0}function nc(a,b,c,d,e){var f=0,g=0;f=jb-16|0;jb=f;v[f+8>>2]=d;v[f+12>>2]=e;g=v[v[b>>2]+28>>2];v[f>>2]=d;v[f+4>>2]=e;nb[g|0](a,b,c,f);jb=f+16|0}function gj(a){var b=0,c=0;b=jb-16|0;jb=b;Bb(b+8|0,a+1074312|0,7);if(Cb(v[v[b+8>>2]>>2],v[b+12>>2])){c=om(v[a+480180>>2])^1}jb=b+16|0;return c}function dfa(a,b){a=a|0;b=b|0;a:{if(a>>>0>=515){a=qg(b);qg(b);break a}a=Fg(b);Fg(b)}while(1){if(a){if(a&1){ac(b,260)}a=a>>>1|0;continue}break}}function cS(a){var b=0;if(!(Pb(a,14853,3)|(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))-2147483647>>>0<2147484072)){b=w[a+3|0]<6}return b}function az(a){var b=0,c=0;b=jb-16|0;jb=b;v[b+8>>2]=a;c=b+8|0;a=1;while(1){if((a|0)>0){Xg(c);a=a-1|0;continue}break}jb=b+16|0;return v[b+8>>2]}function Xm(a,b){var c=0,d=0;d=v[a+4>>2];c=v[a+8>>2];while(1){if((c|0)!=(d|0)){c=c-b|0;v[a+8>>2]=c;continue}break}b=v[a>>2];if(b){zc(a);Jb(b)}}function MH(a,b,c,d,e,f){var g=0,h=0;g=v[a+32>>2];if(!w[a+23|0]){v[(c<<2)+g>>2]=b;return}h=g;g=d<<2;v[h+g>>2]=b;t[v[a+8>>2]+d|0]=e;v[f+g>>2]=c}function K5(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(!b){ux(a,0,0,0,0,0,0,c,d);return}ux(a,v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2],v[b+24>>2],b,c,d)}function DQ(a,b,c,d){var e=0;e=c&4;a:{b:{if(!(e|(b&255)!=4)){if(c&2){break b}_c(a,8,1,0,10);return}b=16;if(e){break a}}b=8}_c(a,b,c&2|1,0,d^1)}function nV(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c+12>>2]=-1;if(og(a,c+8|0)){v[c+4>>2]=w[c+8|0];aC(a,b,v[Ib(c+4|0,c+12|0)>>2])}jb=c+16|0}function jE(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-16|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){Ro(a);Jb(b)}}function ht(a,b){var c=0,d=0;d=pf(a,b);while(1){a:{c=d;if(!(c&65535)){c=0;break a}d=c-1|0;if(!oe(a,b,d&65535)){continue}}break}return c&65535}function fQ(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-12|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){Ro(a);Jb(b)}}function _h(a){var b=0;a=a*a;b=a*a;return C(a*b*(a*2439044879627741e-20+-.001388676377460993)+(b*.04166662332373906+(a*-.499999997251031+1)))}function KP(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-32|0;v[a+8>>2]=b;continue}break}b=v[a>>2];if(b){Ro(a);Jb(b)}}function Jm(a,b){var c=0;a=Nm(a);v[a>>2]=61196;c=v[b+8>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=c;t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function JU(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;v[c+12>>2]=-1;if(og(a,c+8|0)){v[c+4>>2]=w[c+8|0];BU(a,b,v[Ib(c+4|0,c+12|0)>>2])}jb=c+16|0}function sB(a,b){var c=0,d=0,e=0;c=jb-16|0;jb=c;u[c+14>>1]=1;d=c,e=fl(a,b),u[d+12>>1]=e;a=x[We(c+14|0,c+12|0)>>1];jb=c+16|0;return a-1&65535}function hz(a,b,c){var d=0;while(1){if((b|0)!=(c|0)){d=v[a>>2];v[a>>2]=d<<8^v[((w[b|0]^d>>>24)<<2)+29036>>2];b=b+1|0;continue}break}return a}function C3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-32|0;jb=g;h=g+8|0;II(h,b,c,d,e,f);Sc(a,g+20|0);Zl(h);jb=g+32|0}function zo(a,b){var c=0;a:{if(!b){break a}if(!Ob(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=3){c=LC(a,b);break a}c=qg(a);ac(a,b-4|0)}return c}function Wu(a,b){var c=0;a:{if(!b){break a}if(!Ob(v[a>>2],v[a+8>>2],b)){break a}if(b>>>0<=1){c=KC(a,1);break a}c=Fg(a);ac(a,b-2|0)}return c}function Fe(a,b,c){t[a+11|0]=c;t[a+10|0]=b;t[a+12|0]=w[a+12|0]&251;u[a+8>>1]=65535;v[a>>2]=0;v[a+4>>2]=0;t[a+12|0]=w[a+12|0]&252|1;return a}function $9(a,b){a=a|0;b=b|0;a=Gy(a);v[23296]=0;R(757,a|0,b|0);b=v[23296];v[23296]=0;if((b|0)==1){b=P()|0;O()|0;Cp(a);S(b|0);L()}return a|0}function yY(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=jb-16|0;jb=a;v[a+12>>2]=e;v[a+8>>2]=d-c;b=Ib(a+12|0,a+8|0);jb=a+16|0;return v[b>>2]}function fF(a,b,c,d,e){var f=0;f=c;c=0;a:{if(!d){break a}c=b>>8;if(!(b&1)){break a}c=_v(v[d>>2],c)}nb[v[v[a>>2]+28>>2]](a,f,c+d|0,b&2?e:2)}function Rk(a){var b=0,c=0,d=0;b=jb-16|0;jb=b;c=v[a+24>>2];d=v[a+40>>2];v[b+12>>2]=1;a=v[Yc(a+20|0,b+12|0)>>2];jb=b+16|0;return B(a,c+d|0)}function Nb(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=jb-16|0;jb=d;if(b>>>0>=117){dq(12e3);L()}e=d+8|0;Bb(e,a,b);xg(e,c);jb=d+16|0;return a|0}function wT(a,b,c,d){var e=0;b=a+b|0;e=-1;a:{while(1){if((a|0)==(b|0)){break a}b=b-1|0;if(_p(c,d,w[b|0])){continue}break}e=b-a|0}return e}function tg(a,b){var c=0,d=0,e=0;c=Jc(a);a=Fb(a);e=Ef(b);d=0;a:{if(!e){break a}a=a+c|0;b=ZD(c,a,b,b+e|0);d=(a|0)==(b|0)?-1:b-c|0}return d}function taa(a){a=a|0;var b=0;b=v[a>>2];if(nb[v[v[b>>2]+32>>2]](b,0,32)|0){a=v[a>>2];a=nb[v[v[a>>2]+32>>2]](a,32,1)^1}else{a=0}return a|0}function Xc(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=-32768;v[b+4>>2]=32767;a=u[Ne(b+8|0,td(b+12|0,b+4|0))>>1];jb=b+16|0;return a}function Sz(a,b){var c=0,d=0;v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[a+8>>2]=v[b+8>>2];v[b>>2]=0;v[b+4>>2]=0;c=Gb(b),d=0,v[c>>2]=d;return a}function Qz(a){a=50-(B(w[(a>>>4|0)+31376|0],a&15)>>>4|0)|0;a=a>>>0>23863?65536:23863/(a>>>0)|0;return Ic((a+119315e4>>>0)/(a<<1>>>0)|0,0)}function Dm(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[Wb(d+15|0,d+14|0)|0]|(c?-128:0),t[e+21|0]=f;jb=d+16|0}function Cm(a,b,c){var d=0,e=0,f=0;d=jb-16|0;jb=d;t[d+15|0]=b;t[d+14|0]=127;e=a,f=w[Wb(d+15|0,d+14|0)|0]|(c?-128:0),t[e+22|0]=f;jb=d+16|0}function V7(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=v[a+20>>2];ke(b,v[c+4>>2],v[c+8>>2]);WK(a,gc(b+8|0,v[b>>2],v[b+4>>2]),0);jb=b+16|0}function Pj(a){var b=0,c=0;b=Gm(v[v[a+20>>2]+28>>2]);if(!(b>>>0>249|w[a+4200|0]>=b>>>0)){c=v[(v[a+16>>2]+B(b,160)|0)+906300>>2]}return c}function LT(a){var b=0,c=0,d=0;c=jb-16|0;jb=c;b=c+8|0;lv(b,a);a=w[Lb(b,0)|0];d=w[Lb(b,1)|0];b=w[Lb(b,2)|0];jb=c+16|0;return a|d<<8|b<<16}function Kw(a,b){var c=0;if(b>>>0<=99){return vH(a,b)}if(b>>>0<=999){c=a;a=(b>>>0)/100|0;return Xr(uH(c,a),B(a,-100)+b|0)}return Zi(a,b)}function EE(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=v[a>>2];if(d>>>0<=127){d=v[(d<<2)+c>>2]}v[a>>2]=d;a=a+4|0;continue}break}return b}function z4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0;g=jb-32|0;jb=g;h=g+8|0;II(h,b,c,d,e,f);Sc(a,h);Zl(h);jb=g+32|0}function kA(a){var b=0;b=Mb(w[a+26|0]|w[a+27|0]<<8);return((w[a+24|0]>15)+(w[a+25|0]>64)|0)+(Mb(w[a+22|0]|w[a+23|0]<<8)<<1>>>0<b>>>0)|0}function dd(a,b){var c=0,d=0,e=0;c=Vf(a,b);if(c){v[a+12>>2]=v[a+12>>2]+b;return c}d=a,e=nb[v[v[a>>2]+24>>2]](a)|0,v[d+12>>2]=e;return c}function Pq(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if((b|0)<0){Wc();L()}b=(b-1>>>5|0)+1|0;c=QC(b);v[a+4>>2]=0;v[a>>2]=c;d=Gb(a),e=b,v[d>>2]=e}function C0(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;c=b;b=v[b>>2]+7&-8;v[c>>2]=b+16;d=a,e=uw(v[b>>2],v[b+4>>2],v[b+8>>2],v[b+12>>2]),A[d>>3]=e}function Al(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-1|0;v[a+8>>2]=b;continue}break}a=v[a>>2];if(a){Jb(a)}}function $r(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a+4>>2];c=a;break a}b=b-32|0;c=a+4|0}c=v[c>>2];v[a+4>>2]=d>>>b;v[a>>2]=d<<32-b|c>>>b}function yE(a,b,c,d){a=Qb(a);v[23296]=0;U(d|0,a|0,b|0,c|0);b=v[23296];v[23296]=0;if((b|0)!=1){return a}b=P()|0;O()|0;vc(a);S(b|0);L()}function s1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=vx(v[a+32>>2],b,c,d,2);if(a>>>0<=15){a=w[a+43728|0]}else{a=0}return(a>>>0<5?a+1|0:0)|0}function O7(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;if(!(!d|!Uc(c&255))){ZK(a,8,C(0))}a=Pj(a);if(a){nb[v[v[a>>2]+92>>2]](a,b,c,d,e)}}function yi(a,b,c){t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24;t[a+4|0]=c;t[a+5|0]=c>>>8;t[a+6|0]=c>>>16;t[a+7|0]=c>>>24}function waa(a,b){a=a|0;b=b|0;a=yu(a,b);if(!a){t[b+6|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0}return a|0}function io(a){var b=0;a=ge(a);b=255;a:{if(a>=255){break a}b=0;if(a<=0){break a}b=~~a>>>0;if(a<4294967296&a>=0){break a}b=0}return b}function RR(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=-128;v[b+4>>2]=127;a=t[Ne(b+8|0,td(b+12|0,b+4|0))|0];jb=b+16|0;return a}function Pi(a,b){var c=0;if(Ve(a)){c=v[a>>2];ml(a);Jb(c)}c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];xe(b,0);yd(b,0)}function DE(a,b,c){var d=0;while(1){if((a|0)!=(b|0)){d=t[a|0];if((d|0)>=0){d=v[(d<<2)+c>>2]}t[a|0]=d;a=a+1|0;continue}break}return b}function il(a,b){var c=0,d=0,e=0;if(ih(1073741823)>>>0<b>>>0){Wc();L()}c=ri(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=(b<<2)+c|0,v[d>>2]=e}function Zr(a,b){var c=0,d=0;a:{if(b>>>0<=31){d=v[a>>2];c=a+4|0;break a}b=b-32|0;c=a}c=v[c>>2];v[a>>2]=d<<b;v[a+4>>2]=c<<b|d>>>32-b}function VD(a){a=a|0;var b=0;a=Kb(a);v[23296]=0;R(124,a|0,13501);b=v[23296];v[23296]=0;if((b|0)==1){b=P()|0;O()|0;zb(a);S(b|0);L()}}function Sp(a,b){var c=0,d=0,e=0;if(ih(2147483647)>>>0<b>>>0){Wc();L()}c=TC(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=(b<<1)+c|0,v[d>>2]=e}function P6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0;if(b>>>0<=4){c=Sd(c,C(0));d=((b<<2)+a|0)+4220|0;if((b|0)==4){c=Qh(c)}z[d>>2]=c;vK(a)}}function Lh(a,b){var c=0,d=0;c=v[a>>2];d=v[a+4>>2];b=v[a+16>>2]+b|0;a=v[a+12>>2];b=(b|0)%(a|0)|0;return z[Lc(c,d,(b>>31&a)+b|0)>>2]}function Fw(a){a=a|0;var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+1;return Lf(t[b|0])|0}function Bf(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;if(b>>>0>=117){dq(11965);L()}d=c+8|0;Bb(d,a,b);xg(d,0);jb=c+16|0;return a|0}function w0(a){a=a|0;var b=0;if((nb[v[v[a>>2]+36>>2]](a)|0)!=-1){b=a;a=v[a+12>>2];v[b+12>>2]=a+1;a=Lf(t[a|0])}else{a=-1}return a|0}function mO(a,b){var c=0,d=0,e=0;if(ih(268435455)>>>0<b>>>0){Wc();L()}c=fE(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=(b<<4)+c|0,v[d>>2]=e}function ez(a,b){var c=0,d=0,e=0;if(ih(536870911)>>>0<b>>>0){Wc();L()}c=wD(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=(b<<3)+c|0,v[d>>2]=e}function cu(a,b){var c=0,d=0,e=0;if(ih(715827882)>>>0<b>>>0){Wc();L()}c=LS(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=B(b,6)+c|0,v[d>>2]=e}function LH(a,b){a:{if(a&255){a=1;if((b|0)!=255){break a}aa(14069,13048,1180,5695);L()}if((b|0)==255){return 0}a=b>>>0>10}return a}function xi(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=0;v[b+4>>2]=255;a=w[Ne(b+8|0,td(b+12|0,b+4|0))|0];jb=b+16|0;return a}function caa(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;if(b>>>0>=250){dq(12e3);L()}d=c+8|0;Bb(d,a,b);nm(d);jb=c+16|0;return a|0}function IC(a,b){var c=0;c=Sia(b&255,0,1536,0);b=mb;a=Sia(a&255,0,25,0);c=a+c|0;b=mb+b|0;b=a>>>0>c>>>0?b+1|0:b;a=c;mb=b;return a}function vN(a,b,c,d){a:{if(d>>>0>=64){d=-1;if(w[a+480180|0]&2){break a}}v[b+56>>2]=0;d=Rn(a,x[b+70>>1],v[b+48>>2],c,0)}return d}function pY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){v[d>>2]=t[b|0];d=d+4|0;b=b+1|0;continue}break}return c|0}function i0(a){a=a|0;var b=0;if((nb[v[v[a>>2]+36>>2]](a)|0)!=-1){b=a;a=v[a+12>>2];v[b+12>>2]=a+4;a=v[a>>2]}else{a=-1}return a|0}function g0(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;b=v[v[b>>2]-12>>2]+b|0;if(Kg(b)){b=v[b+72>>2];if(b){cH(b)}t[a|0]=1}return a|0}function ee(a){var b=0;a=v[a+4>>2];if(a){if(Pm(a)){a:{b=a+8|0;if(v[b>>2]){if((rv(b)|0)!=-1){break a}}nb[v[v[a>>2]+16>>2]](a)}}}}function dz(a,b){var c=0;c=v[a+484360>>2];b=b&255;if(kj(c,v[a+484364>>2])>>>0<=b>>>0){return Zb(c,w[a+484376|0])}return pj(c,b)}function bq(a,b){var c=0;c=Cd(v[a+4>>2],w[a+11|0]);if((c|0)==(Cd(v[b+4>>2],w[b+11|0])|0)){a=Tl(rd(a),rd(b),c)}else{a=1}return!a}function _F(a,b,c,d,e,f){a=nb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Gr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function XF(a,b,c,d,e,f){a=nb[v[v[a+8>>2]+4>>2]](a+8|0)|0;a=Dr(c,d,a,a+288|0,f,e,0)-a|0;if((a|0)<=287){v[b>>2]=((a|0)/12|0)%12}}function Ww(a,b,c){var d=0;d=v[a+32>>2];if(y[a+40>>2]<d+c>>>0){v[a+96>>2]=1;return 0}qc(b,d,c);v[a+32>>2]=v[a+32>>2]+c;return 1}function EV(a,b){a=a|0;b=b|0;v[a+4>>2]=b;t[a|0]=0;b=v[v[b>>2]-12>>2]+b|0;if(Kg(b)){b=v[b+72>>2];if(b){Tq(b)}t[a|0]=1}return a|0}function BE(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+8>>2]=a;v[d+12>>2]=b;v[d>>2]=c;v[d+4>>2]=0;a=Oq(d+8|0,d);jb=d+16|0;return v[a>>2]}function oE(a,b,c){a=Qh(a);a:{if(a>=b){break a}c=0;if(a<=C(0)){break a}if(a<C(4294967296)&a>=C(0)){c=~~a>>>0;break a}}return c}function jq(a){var b=0;b=-1;a:{if(a>=4294967295){break a}b=0;if(a<=0){break a}if(a<4294967296&a>=0){return~~a>>>0}b=0}return b}function hY(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;while(1){if((b|0)!=(c|0)){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;continue}break}return c|0}function bC(a,b){var c=0;c=v[b+4>>2];if(c){ic(a,c,v[b>>2]);return}c=v[b+8>>2];b=v[b+12>>2];if(!uc(c,b)){ke(a,c,b);return}$d(a)}function XD(){var a=0,b=0,c=0;a=jb-16|0;jb=a;b=Vb(a,15023);if(Fb(b)){c=(tg(b,13706)|0)!=-1}else{c=0}yb(b);jb=a+16|0;return c|0}function JO(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(b){Td(b,a)}if(c){Td(c,a)}if(d){Td(d,a)}if(e){Td(e,a)}}function Es(a){var b=0;b=A[a+4248>>3]/+y[v[a+16>>2]+24620>>2];A[a+4264>>3]=b;if(w[a+4240|0]){A[a+4264>>3]=b*(A[a+4288>>3]/60)}}function CJ(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;c=kJ(xc(8));v[c+4>>2]=a;v[c>>2]=56728;a=v[xf(b+8|0,c)>>2];jb=b+16|0;return a|0}function BY(a){a=a|0;var b=0;b=jb-16|0;jb=b;ai(bi(b+8|0,v[a+8>>2]));jb=b+16|0;a=v[a+8>>2];if(!a){return 1}return(nF(a)|0)==1|0}function uS(a,b){var c=0;c=jb-16|0;jb=c;a=Ph(c,a,1);jo(v[a+4>>2],x[b>>1]|x[b+2>>1]<<16);v[a+4>>2]=v[a+4>>2]+4;lc(a);jb=c+16|0}function dw(a,b){var c=0,d=0,e=0,f=0;c=Ef(b);d=xc(c+13|0);v[d+8>>2]=0;v[d+4>>2]=c;v[d>>2]=c;e=a,f=qc(zc(d),b,c+1|0),v[e>>2]=f}function al(a,b){var c=0;a:{if(y[a+12>>2]<b>>>0){c=0;if(nb[v[v[a>>2]+24>>2]](a)>>>0<b>>>0){break a}}v[a+12>>2]=b;c=1}return c}function QX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Jg(a,v[b+8>>2],0)){$v(b,c,d);return}a=v[a+8>>2];nb[v[v[a>>2]+28>>2]](a,b,c,d)}function Gq(a,b){return aq(w[b|0]|w[b+1|0]<<8|(w[b+2|0]<<16|w[b+3|0]<<24),w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24))?b:a}function jS(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;u[c+14>>1]=b;if((fl(v[a>>2],v[a+4>>2])|0)!=65535){RB(a,c+14|0)}jb=c+16|0}function ag(a,b,c){var d=0;d=4;a:{b:{switch(b-1|0){case 0:d=c;break a;case 1:break b;default:break a}}d=c?3:2}return Yn(a,d)}function YF(a,b,c,d,e,f){a=nb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Dr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function Ok(a,b,c,d){var e=0;e=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=e;e=v[b+12>>2];v[a+8>>2]=v[b+8>>2];v[a+12>>2]=e;Yx(a,c,d)}function JN(a){Ly(a);v[a>>2]=0;v[a+4>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;a=hg(a);hg(a+12|0);t[a+24|0]=1}function DT(a){var b=0;a:{if(Pb(a,3863,4)){break a}if(Pb(a+44|0,17659,3)){break a}b=(w[a+47|0]|w[a+48|0]<<8)>>>0>97}return b}function $F(a,b,c,d,e,f){a=nb[v[v[a+8>>2]>>2]](a+8|0)|0;a=Gr(c,d,a,a+168|0,f,e,0)-a|0;if((a|0)<=167){v[b>>2]=((a|0)/12|0)%7}}function xQ(a,b){var c=0;c=jb-16|0;jb=c;gR(c+8|0,a);ve(c,b);a=Mc(v[c+8>>2],v[c+12>>2],v[c>>2],v[c+4>>2]);jb=c+16|0;return a}function sc(a,b){var c=0;a=Ll(a);v[a+4>>2]=0;v[a>>2]=49072;c=Jd(Fb(b)+1|0);v[a+4>>2]=c;if(c){qc(c,Jc(b),Fb(b)+1|0)}return a}function rK(a){a=a|0;var b=0,c=0;b=a+4960|0;c=a+4504|0;while(1){b=vc(b-24|0);if((c|0)!=(b|0)){continue}break}return uf(a)|0}function x7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if(b>>>0<=2){d=(a+b|0)+4232|0,e=Vg(C(Sd(c,C(0))*C(127))),t[d|0]=e;Cs(a)}}function rQ(a){var b=0,c=0;while(1){b=c;if((b|0)!=8){c=b+1|0;if((w[a+b|0]-127&255)>>>0>160){continue}}break}return(b|0)==8}function pE(a,b){v[a>>2]=b;nH(a+4|0);v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function m8(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=0;if(b>>>0<=3){d=(a+b|0)+4264|0,e=Vg(C(Sd(c,C(0))*C(255))),t[d|0]=e;Gs(a)}}function Yz(a){v[a>>2]=0;v[a+4>>2]=0;v[a+24>>2]=0;v[a+28>>2]=0;v[a+16>>2]=0;v[a+20>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function Sga(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);d=b+c|0;c=pi(b,d);if(c){pl(a,c);_t(a,b,d,c)}}function PL(a,b){var c=0;if(!(w[a|0]!=w[b|0]|A[a+8>>3]!=A[b+8>>3]|w[a+16|0]!=w[b+16|0])){c=v[a+20>>2]==v[b+20>>2]}return c}function he(a,b,c){var d=0;a:{if((b|0)>(c|0)){break a}d=v[a>>2];if((d|0)>=(b|0)){b=c;if((d|0)<=(b|0)){break a}}v[a>>2]=b}}function Fo(a,b,c){var d=0;a:{if(b>>>0>c>>>0){break a}d=v[a>>2];if(d>>>0>=b>>>0){b=c;if(d>>>0<=b>>>0){break a}}v[a>>2]=b}}function z1(a,b,c){a=a|0;b=b|0;c=c|0;while(1){if((a|0)!=(b|0)){Fx(v[c>>2],a);v[c>>2]=v[c>>2]+12;a=a+12|0;continue}break}}function aP(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){ZO(a,1);ZO(a,0)}}function ZG(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+40>>2]](a)|0}v[a+12>>2]=b+4;return v[b>>2]}function YK(a,b,c){var d=0,e=0;d=Tc(a);if(d>>>0>=c>>>0){Ix(a,rj(tc(a),b,c),c);return}e=a;a=Fb(a);Zo(e,d,c-d|0,a,0,a,c,b)}function RP(a){var b=0;if(!(w[a+35|0]&2)){a=a+68|0;b=9;while(1){if(b){v[a>>2]=268435456;b=b-1|0;a=a+4|0;continue}break}}}function PR(a,b){var c=0;c=jb-16|0;jb=c;a:{if(!Vf(a,4)){FS(b);break a}Dh(c+8|0,b);jA(c,a,v[c+8>>2],v[c+12>>2])}jb=c+16|0}function Lg(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;v[f+12>>2]=e;c=bi(f+8|0,c);a=Ir(a,b,d,v[f+12>>2]);ai(c);jb=f+16|0;return a}function $O(a,b,c,d,e,f,g){t[a+17|0]=g;t[a+16|0]=f;v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;if(d){_O(a,1);_O(a,0)}}function mi(a,b,c){c=w[c|0];while(1){a:{if((a|0)!=(b|0)){if((c|0)!=w[a|0]){break a}}else{a=b}return a}a=a+1|0;continue}}function rX(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0;h=b;b=0;return nb[a|0](h|b,c,d,e,b|f,g)|0}function pl(a,b){var c=0,d=0,e=0;if(ih(-1)>>>0<b>>>0){Wc();L()}c=xc(b);v[a>>2]=c;v[a+4>>2]=c;d=Gb(a),e=b+c|0,v[d>>2]=e}function mR(a){var b=0;if(!(Pb(a,13658,3)|w[a+3|0]>31|(t[a+27|0]<0|w[a+32|0]>64))){b=(w[a+33|0]-1&255)>>>0<32}return b}function lN(a,b,c,d){var e=0,f=0;if(c&255){e=a,f=Yb(v[a>>2]+((B((d^-1|-256)+b|0,c<<24>>24)|0)/2|0)|0,0,256),v[e>>2]=f}}function jt(a){var b=0,c=0,d=0;d=a*a;a=0;b=1;c=1;while(1){a=a+2;c=d*c/(a*a);b=b+c;if(b*1e-7<c){continue}break}return b}function Pe(a){var b=0;b=v[a+32>>2];a:{if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1;a=0;break a}v[a+32>>2]=b+1;a=w[b|0]}return a}function dG(a,b,c){var d=0;d=jb-16|0;jb=d;v[d+12>>2]=c;b=bi(d+8|0,b);a=CG(a,9164,v[d+12>>2]);ai(b);jb=d+16|0;return a}function Bi(a){var b=0;while(1){a:{if((b|0)!=46){if(w[b+43760|0]!=(a|0)){break a}}else{b=0}return b}b=b+1|0;continue}}function zU(a){var b=0,c=0;c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-28|0;Md(b);continue}break}v[a+4>>2]=c}function z8(a){a=a|0;var b=0;b=jb-16|0;jb=b;if(!hd(a,4)){Xv(a)}a=v[hc(b+8|0,Eb(v[a+44>>2]))>>2];jb=b+16|0;return a|0}function y8(a){a=a|0;var b=0;b=jb-16|0;jb=b;if(!hd(a,4)){Xv(a)}a=v[hc(b+8|0,Eb(v[a+48>>2]))>>2];jb=b+16|0;return a|0}function r$(a){a=a|0;var b=0,c=0;c=v[a+4>>2];b=v[a>>2];a=v[a+8>>2];b=b+(a>>1)|0;if(a&1){c=v[c+v[b>>2]>>2]}nb[c|0](b)}function lP(a){v[a+700>>2]=0;u[a+842>>1]=0;v[a+688>>2]=0;v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0}function h6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=2){c=Sd(c,C(0));d=Db(a+4208|0,b),e=c,z[d>>2]=e;mK(a)}}function b7(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=5){c=Sd(c,C(0));d=Db(a+4208|0,b),e=c,z[d>>2]=e;CK(a)}}function W6(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=4){c=Sd(c,C(0));d=Db(a+4208|0,b),e=c,z[d>>2]=e;yK(a)}}function No(a){var b=0,c=0;c=v[a>>2];b=v[a+4>>2];while(1){if((b|0)!=(c|0)){b=b-36|0;_q(b);continue}break}v[a+4>>2]=c}function Bg(a){var b=0;hm(a);b=vt(v[a>>2],mk(x[a+34>>1]));v[a+20>>2]=b;if(!b){return 0}return uj(v[a>>2],x[a+34>>1])}function $5(a,b,c){a=a|0;b=b|0;c=C(c);var d=0,e=C(0);if(b>>>0<=3){c=Sd(c,C(0));d=Db(a+4208|0,b),e=c,z[d>>2]=e;kK(a)}}function wi(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=v[Ib(b+12|0,b+8|0)>>2];jb=b+16|0;return a}function pA(a){var b=0,c=0,d=0;if(v[a>>2]){Hc(a);b=v[a>>2];ui(a);Jb(b);c=Gb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function ih(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=2147483647;a=Ib(b+12|0,b+8|0);jb=b+16|0;return v[a>>2]}function bO(a){var b=0,c=0,d=0;if(v[a>>2]){Hc(a);b=v[a>>2];Qm(a);Jb(b);c=Gb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function XO(a){var b=0,c=0,d=0;if(v[a>>2]){Hc(a);b=v[a>>2];Fm(a);Jb(b);c=Gb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function HG(a,b,c,d,e,f,g,h,i){v[a>>2]=b;v[a+4>>2]=c;v[a+8>>2]=d;v[a+12>>2]=e&65535|(i>>>16&32768|e>>>16&32767)<<16}function CL(a){var b=0,c=0,d=0;if(v[a>>2]){Hc(a);b=v[a>>2];lu(a);Jb(b);c=Gb(a),d=0,v[c>>2]=d;v[a>>2]=0;v[a+4>>2]=0}}function qc(a,b,c){var d=0;if(c){d=a;while(1){t[d|0]=w[b|0];d=d+1|0;b=b+1|0;c=c-1|0;if(c){continue}break}}return a}function JH(a,b,c){var d=0,e=0,f=0;e=c*c;A[a>>3]=e;f=c;d=c*134217729;c=d+(c-d);d=f-c;A[b>>3]=d*d+((c+c)*d+(c*c-e))}function HQ(a){var b=0;if(!(Pb(a+44|0,13667,4)|w[a+29|0]!=16)){b=((w[a+42|0]|w[a+43|0]<<8)-1&65535)>>>0<2}return b}function CU(a,b,c,d,e){t[a+4|0]=b;t[a|0]=69;t[a+1|0]=99;t[a+2|0]=104;t[a+3|0]=111;t[a+7|0]=e;t[a+6|0]=d;t[a+5|0]=c}function Ad(a,b){var c=0;c=b+4|0;Op(v[a>>2],v[a+4>>2],c);oc(a,c);oc(a+4|0,b+8|0);oc(Gb(a),zc(b));v[b>>2]=v[b+4>>2]}function wK(a){a=a|0;v[a+4244>>2]=0;v[a+4248>>2]=0;v[a+4228>>2]=0;v[a+4232>>2]=0;a=a+4252|0;v[a>>2]=0;v[a+4>>2]=0}function tN(a,b){var c=0;c=b&15;if(c){t[a+827|0]=c<<2}b=b&240;if(b){t[a+826|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|262144}function eH(a,b){a=a|0;b=b|0;var c=0;c=v[a>>2];a:{if(!c){break a}if(!uc(hH(c,b),-1)){break a}v[a>>2]=0}return a|0}function Qk(a,b){var c=0;c=b&15;if(c){t[a+824|0]=c<<2}b=b&240;if(b){t[a+823|0]=b>>>4}v[a+88>>2]=v[a+88>>2]|131072}function Fr(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-4|0;if(b>>>0<=a>>>0){break a}oc(a,b);a=a+4|0;continue}}}function Cl(a,b){a:{if((a|0)==(b|0)){break a}while(1){b=b-1|0;if(b>>>0<=a>>>0){break a}ah(a,b);a=a+1|0;continue}}}function oP(a){var b=0,c=0;c=v[a+4>>2];b=v[a+8>>2];while(1){if((b|0)!=(c|0)){b=b-4|0;v[a+8>>2]=b;continue}break}}function aQ(a){if(Pb(a,13640,4)){a=0}else{a=(cc(w[a+4|0]|w[a+5|0]<<8|(w[a+6|0]<<16|w[a+7|0]<<24))|0)==1}return a}function T2(a,b){a=a|0;b=b|0;var c=0,d=0,e=0;if(a){c=a;a=nb[v[v[b>>2]+8>>2]](b)|0;d=c,e=Xf(a?a:21473),v[d>>2]=e}}function jw(a,b,c){while(1){a:{if((a|0)!=(b|0)){if(v[a>>2]!=(c|0)){break a}}else{a=b}return a}a=a+4|0;continue}}function ct(a,b){var c=0;c=1;a:{switch((b&255)-4|0){default:c=(a&255)==11;break;case 0:case 2:break a}}return c}function Wi(a){a:{a=v[a+4>>2]&74;if(a){if((a|0)==64){return 8}if((a|0)!=8){break a}return 16}return 0}return 10}function P$(a,b){a=a|0;b=b|0;var c=0,d=0;nb[v[v[a>>2]+24>>2]](a)|0;b=vw(b);v[a+36>>2]=b;c=a,d=mn(b),t[c+44|0]=d}function I$(a,b){a=a|0;b=b|0;var c=0,d=0;nb[v[v[a>>2]+24>>2]](a)|0;b=zw(b);v[a+36>>2]=b;c=a,d=mn(b),t[c+44|0]=d}function Am(a){a=w[a|0]|w[a+1|0]<<8|(w[a+2|0]<<16|w[a+3|0]<<24);return a<<24|a<<8&16711680|(a>>>8&65280|a>>>24)}function xg(a,b){var c=0;c=v[a+4>>2];if(b){a=v[a>>2];v[a>>2]=v[a>>2]|c;return}a=v[a>>2];v[a>>2]=v[a>>2]&(c^-1)}function tL(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=32767;a=u[Ib(b+12|0,b+8|0)>>1];jb=b+16|0;return a}function sQ(a,b){var c=0;c=b&255;b=c>>>24|0;a=a&255?1120:1056;c=a+(c<<8)|0;b=a>>>0>c>>>0?b+1|0:b;mb=b;return c}function ou(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=65535;a=x[Ib(b+12|0,b+8|0)>>1];jb=b+16|0;return a}function nu(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=(B(a,b)>>>0)/255;he(c+12|0,0,15);jb=c+16|0;return w[c+12|0]}function hd(a,b){var c=0;c=jb-16|0;jb=c;tk(c+8|0,a+24|0,b);a=Cb(v[v[c+8>>2]>>2],v[c+12>>2]);jb=c+16|0;return a}function OF(a,b){var c=0;c=jb-16|0;jb=c;a=uk(c,a,1);Hj(v[a+4>>2],w[b|0]);v[a+4>>2]=v[a+4>>2]+1;lc(a);jb=c+16|0}function Jg(a,b,c){if(!c){return v[a+4>>2]==v[b+4>>2]}if((a|0)==(b|0)){return 1}return!fj(v[a+4>>2],v[b+4>>2])}function CE(a,b){var c=0,d=0;c=a+68|0;a=0;while(1){if((a|0)!=9){d=Db(c,a);a=a+1|0;v[d>>2]=a<<b;continue}break}}function qp(a,b){var c=0;c=jb-32|0;jb=c;Dh(c+16|0,b);ln(c+24|0,a,v[c+16>>2],v[c+20>>2]);Dh(c+8|0,b);jb=c+32|0}function mM(a,b){var c=0;c=jb-16|0;jb=c;a=Bz(c,a);Qp(v[a+4>>2],v[b>>2]);v[a+4>>2]=v[a+4>>2]+4;lc(a);jb=c+16|0}function ju(a){var b=0;b=jb-16|0;jb=b;u[b+14>>1]=a;u[b+12>>1]=255;a=w[Zc(b+14|0,b+12|0)|0];jb=b+16|0;return a}function Zv(a,b,c,d,e,f,g){var h=0;h=b>>8;if(b&1){h=_v(v[e>>2],h)}nb[v[v[a>>2]+20>>2]](a,c,d,e+h|0,b&2?f:2,g)}function WL(a,b){a:{switch(b-1|0){default:return a+724|0;case 0:return a+732|0;case 1:break a}}return a+740|0}function Tk(a,b,c,d){var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;v[e+8>>2]=c;gc(a,b,v[Ib(e+12|0,e+8|0)>>2]);jb=e+16|0}function ki(a){var b=0,c=0;v[v[a+20>>2]>>2]=a;c=v[a+12>>2];b=v[c>>2];v[a+4>>2]=b;if(b){v[b+8>>2]=a}v[c>>2]=a}function jH(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+36>>2]](a)|0}return Lf(t[b|0])}function ZF(a,b,c,d,e){b=Ri(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function WF(a,b,c,d,e){b=Qi(b,c,d,e,4);if(!(w[d|0]&4)){v[a>>2]=((b|0)<69?b+2e3|0:(b|0)<100?b+1900|0:b)-1900}}function Vaa(){var a=0;a=jb-16|0;jb=a;if(bb(a+12|0,4)|0){Wr(v[115772],12500);L()}jb=a+16|0;return v[a+12>>2]}function Rq(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=jb-16|0;jb=d;t[d+15|0]=0;Zf(a,b,mi(b,b+c|0,d+15|0));jb=d+16|0}function Lw(a,b){var c=0;if(b>>>0<=9999){return Kw(a,b)}c=a;a=(b>>>0)/1e4|0;return Zi(Kw(c,a),B(a,-1e4)+b|0)}function HO(a){var b=0;b=v[a+4>>2];u[a+70>>1]=w[((x[b+20>>1]>>>6|x[b+22>>1]<<4)&65535)+28896|0]>>>x[a+68>>1]}function jga(a,b){a=a|0;b=b|0;if(!tS(a,b)){t[b+4|0]=0;t[b+5|0]=0;t[b|0]=0;t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0}}function cm(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=a;a=c+8|0;v[a>>2]=v[a>>2]+(b<<2);jb=c+16|0;return v[a>>2]}function ZH(a,b,c,d){z[d+4>>2]=a+c;a=C(a+C(c*C(-.5)));b=C(b*C(.8660253882408142));z[d+8>>2]=a-b;z[d>>2]=b+a}function Ux(a,b){a=Qb(a);v[a+20>>2]=0;v[a+12>>2]=0;v[a+16>>2]=0;Qb(a+24|0);Kb(a+36|0);v[a+48>>2]=b;return a}function FR(a,b){t[a+6|0]=255;v[a+16>>2]=0;u[a+4>>1]=0;v[a>>2]=0;if(b>=0){A[a+8>>3]=b;v[a+16>>2]=3}return a}function Bm(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=a;v[b+8>>2]=255;a=w[Ib(b+12|0,b+8|0)|0];jb=b+16|0;return a}function jv(a){var b=0;b=jb-16|0;jb=b;a=v[hc(b+8|0,rd(a)+Cd(v[a+4>>2],w[a+11|0])|0)>>2];jb=b+16|0;return a}function bR(a){var b=0;if(!(Pb(a,17654,4)|w[a+5|0]!=16|(w[a+54|0]-33&255)>>>0<224)){b=w[a+4|0]>95}return b}function _s(a){var b=0,c=0;while(1){if(b>>>0>=8){a=c<<24>>24}else{b=b+15|0;c=Nn(a);continue}break}return a}function Zfa(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(Aj(a,b+8|0)){c=cS(b+8|0)}jb=b+16|0;return c|0}function Vu(a,b){a:{switch(b-1|0){default:return a+48|0;case 0:return a+68|0;case 1:break a}}return a+88|0}function Cia(a,b){a=a|0;b=b|0;var c=0;b=jb-80|0;jb=b;c=-1;if(mU(a,b+8|0)){c=lU(b+8|0)}jb=b+80|0;return c|0}function z3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return QE(a,b,c,d,e,f,g,12767,980)|0}function ur(a,b,c,d,e,f){var g=0;g=b>>8;if(b&1){g=_v(v[d>>2],g)}nb[v[v[a>>2]+24>>2]](a,c,d+g|0,b&2?e:2,f)}function ru(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;zm(c+8|0,a);v[c+4>>2]=v[c+8>>2];gu(c+4|0,b);jb=c+16|0}function mF(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;v[e>>2]=c;v[h>>2]=f;return 3}function l3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return QE(a,b,c,d,e,f,g,12835,987)|0}function jO(a,b){var c=0;c=v[a+484344>>2];if(oe(c,v[a+484348>>2],b)){a=v[$b(c,b)+12>>2]}else{a=1}return a}function TU(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(Aj(a,b+8|0)){c=HB(b+8|0)}jb=b+16|0;return c|0}function Dk(a){var b=0;b=v[a+12>>2];if((b|0)==v[a+16>>2]){return nb[v[v[a>>2]+36>>2]](a)|0}return v[b>>2]}function wM(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-52|0;Pk(c);continue}break}v[a+4>>2]=b}function oC(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-20|0;Ab(c);continue}break}v[a+4>>2]=b}function ie(a,b){a=vl(a,v[b>>2],v[b+4>>2]);v[a+8>>2]=v[b+8>>2];vl(a+12|0,v[b+12>>2],v[b+16>>2]);return a}function ffa(a,b,c){a=a|0;b=b|0;c=c|0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(b){Sp(a,b);xo(a,b,c)}return a|0}function eQ(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;dQ(c);continue}break}v[a+4>>2]=b}function eO(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-12|0;Le(c);continue}break}v[a+4>>2]=b}function Sb(a,b,c){var d=0;c=v[a+4>>2]+c|0;d=b;b=v[a>>2]+b|0;c=d>>>0>b>>>0?c+1|0:c;v[a>>2]=b;v[a+4>>2]=c}function QO(a,b){var c=0;c=v[a+4>>2];while(1){if((b|0)!=(c|0)){c=c-32|0;Yk(c);continue}break}v[a+4>>2]=b}function yV(a,b,c){a=a|0;b=b|0;c=c|0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(b){il(a,b);rC(a,b,c)}return a|0}function um(a,b,c){a=a|0;b=b|0;c=c|0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(b){pl(a,b);Do(a,b,c)}return a|0}function dY(){if(w[467148]){return v[116786]}kp(467140,fK());t[467148]=1;v[116786]=467140;return 467140}function cT(a,b,c){a=a|0;b=b|0;c=c|0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(b){cu(a,b);MA(a,b,c)}return a|0}function ST(a){a:{if(Pb(a,14026,4)){break a}if(Pb(a+8|0,14007,4)){break a}return 1}return!Pb(a,14007,4)}function MN(a,b){var c=0,d=0;a:{if(b<0){break a}c=A[a>>3];if(!(c<0)){d=b;if(!(b<c)){break a}}A[a>>3]=d}}function nF(a){var b=0,c=0;b=jb-16|0;jb=b;a=bi(b+8|0,a);c=v[v[115798]>>2];ai(a);jb=b+16|0;return c?4:1}function Vk(a,b,c,d){a=a&65535;c=c&65535;if(a>>>0>=c>>>0){a=b>>>0<d>>>0&a>>>0<=c>>>0}else{a=1}return a}function zP(a){if(((w[a+68|0]|w[a+69|0]<<8)-128&65535)>>>0>=65409){a=Pb(a,17502,17)}else{a=1}return!a}function iB(a,b){if(b>>>0<=126){Te(((b<<5)+a|0)+480280|0);$n((B(b,872)+a|0)+1074992|0,a,b,134217728)}}function gB(a){var b=0,c=0;if(v[a>>2]){Hc(a);Jb(v[a>>2]);b=Gb(a),c=0,v[b>>2]=c;v[a>>2]=0;v[a+4>>2]=0}}function aW(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;c=-1;if(Aj(a,b+8|0)){c=mD(b+8|0)}jb=b+16|0;return c|0}function Xb(a,b,c){var d=0;if(c){d=a;while(1){t[d|0]=b;d=d+1|0;c=c-1|0;if(c){continue}break}}return a}function JW(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;c=-1;if(RD(a,b+8|0)){c=QD(b+8|0)}jb=b+32|0;return c|0}function Fq(a,b,c){var d=0;d=jb-16|0;jb=d;if(b){t[d+15|0]=0;zL(a+36|0,b,mi(b,b+c|0,d+15|0))}jb=d+16|0}function yq(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(Uq(a,b+8|0)){c=Mb(x[b+8>>1])}jb=b+16|0;return c|0}function v1(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;$B(c+8|0,b);Rq(a,v[c+8>>2],v[c+12>>2]);jb=c+16|0}function ul(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0;t[a+7|0]=0}function sm(a){a=a|0;var b=0,c=0;b=jb-16|0;jb=b;if(Ho(a,b+8|0)){c=cc(v[b+8>>2])}jb=b+16|0;return c|0}function XS(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){WS(c+52|0);zb(c+40|0);vc(c+16|0);vc(c+4|0);Jb(c)}}function OV(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;Em(c+8|0,b);Rq(a,v[c+8>>2],v[c+12>>2]);jb=c+16|0}function OR(a){u[a+10>>1]=0;u[a+12>>1]=0;u[a+8>>1]=1084;v[a>>2]=0;v[a+4>>2]=40;u[a+14>>1]=0;return a}function NV(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;Zj(a+8|0,0);Pq(a,127);RC(a,127,w[b|0]);return a|0}function EM(a){v[a+20>>2]=0;t[a+16|0]=7;v[a+8>>2]=1889785610;v[a+12>>2]=1072630333;t[a|0]=3;return a}function Du(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;t[a+6|0]=0}function BP(a){_d(a+140|0);Ab(a+120|0);Ab(a+100|0);Ab(a+80|0);Ab(a+60|0);Ab(a+40|0);Ab(a+20|0);Ab(a)}function r1(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Cz(vx(v[a+32>>2],b,c,d,3));return(a>>>0<5?a+1|0:0)|0}function gM(a,b){if(b>>>0<=255){a=v[((b<<2)+a|0)+900380>>2];a=a?a+492|0:21473}else{a=21473}return a}function Sc(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2];hE(b);return a}function NS(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]+B((b|0)/-6|0,6)|0;v[d>>2]=c;if((b|0)>0){qc(c,a,b)}}function oF(a,b,c,d,e){var f=0;f=jb-16|0;jb=f;e=bi(f+8|0,e);a=Jr(a,b,c,d);ai(e);jb=f+16|0;return a}function nfa(a,b){a=a|0;b=b|0;var c=0;b=jb-16|0;jb=b;c=-1;if(mB(a,b)){c=wR(b)}jb=b+16|0;return c|0}function hO(a,b,c){var d=0;d=jb-16|0;jb=d;a=v[hc(d+8|0,aO(b,c,Wd(a),kc(a)))>>2];jb=d+16|0;return a}function Yu(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=og(a,b+15|0);jb=b+16|0;return(a?w[b+15|0]:0)<<24>>24}function Q2(a,b){a=a|0;b=b|0;var c=0;b=Jc(b);c=v[a+4>>2];if(c){nb[c|0](b,v[a+8>>2]);return}Bs(b,a)}function M7(a,b,c){a=a|0;b=b|0;c=c|0;a=Pj(a);if(!a){return 0}return nb[v[v[a>>2]+100>>2]](a,b,c)|0}function Ln(a,b,c,d){a=a&255;c=c&255;if(a>>>0>=c>>>0){a=b>>>0<d>>>0&a>>>0<=c>>>0}else{a=1}return a}function Lfa(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=Uq(a,b+8|0);jb=b+16|0;return(a?x[b+8>>1]:0)<<16>>16}function bx(a,b,c){b=(B(B($w(a),ax(a,b)),125)>>>0)/(eI(a,b)>>>0)|0;a=(a&6)==6?b&-4:b;return a?a:c}function b5(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;nb[v[v[b>>2]+8>>2]](b,c);d=a;a=b+4|0;kp(d,a);PJ(a,c)}function s0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[a>>2]+12>>2]](a,b,c,d,e,f)|0}function r0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[a>>2]+24>>2]](a,b,c,d,e,f)|0}function q0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[a>>2]+16>>2]](a,b,c,d,e,f)|0}function p0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[a>>2]+28>>2]](a,b,c,d,e,f)|0}function n0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[a>>2]+20>>2]](a,b,c,d,e,f)|0}function m0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[v[v[a>>2]+44>>2]](a,b,c,d,e,f)|0}function ln(a,b,c,d){var e=0;e=jb-16|0;jb=e;Og(e+8|0,c,d);tG(a,b,v[e+8>>2],v[e+12>>2]);jb=e+16|0}function ei(a,b,c){if(c){while(1){v[a>>2]=v[b>>2];a=a+4|0;b=b+4|0;c=c-1|0;if(c){continue}break}}}function Pz(a,b,c){b=b-a>>2;while(1){if((b|0)>0){v[a>>2]=v[c>>2];b=b-1|0;a=a+4|0;continue}break}}function ME(a,b,c){var d=0;d=jb-16|0;jb=d;c=Vb(d,c);a=sc(a,c);yb(c);v[a>>2]=b;jb=d+16|0;return a}function Hi(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=v[a>>2];a=v[XA(c+8|0,b)>>2];jb=c+16|0;return a}function Cr(a,b,c,d){var e=0;e=jb-16|0;jb=e;ic(e+8|0,c,d);tG(a,b,v[e+8>>2],v[e+12>>2]);jb=e+16|0}function z2(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=v[xf(b+8|0,_j(xc(12),a))>>2];jb=b+16|0;return a|0}function pt(a,b){b=Sia(a,a>>31,b,b>>31)+5e5|0;a=mb;return Ic(Tia(b,b>>>0<5e5?a+1|0:a,1e6,0),mb)}function oR(a){var b=0,c=0;b=1;c=v[a>>2];a:{if((c|0)>0){b=120;if(c>>>0<121){break a}}v[a>>2]=b}}function gv(a,b){a=gD(a,v[b>>2],v[b+4>>2]);v[a+8>>2]=v[b+8>>2];gD(a+12|0,v[b+12>>2],v[b+16>>2])}function _$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb[v[v[b>>2]+16>>2]](a,b,v[c+8>>2],v[c+12>>2],0,d)}function YU(a,b){a=a|0;b=b|0;if(!Au(a,b)){t[b+1|0]=0;t[b+2|0]=0;t[b+3|0]=0;t[b+4|0]=0;t[b|0]=0}}function KX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;if(Jg(a,v[b+8>>2],f)){cw(b,c,d,e)}}function Hga(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=Ho(a,b+8|0);jb=b+16|0;return C(a?z[b+8>>2]:C(0))}function F3(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return WE(a,b,c,d,e,f,10511,977)|0}function C4(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return WE(a,b,c,d,e,f,10556,951)|0}function AV(a){a=a|0;var b=0;b=v[a+76>>2];if(uc(-1,b)){b=UC(a,32);v[a+76>>2]=b}return b<<24>>24}function x9(a,b){a=a|0;b=b|0;ni(a);ni(a);a:{if(b>>>0>=60){ac(a,4);break a}ni(a)}return ni(a)|0}function wG(a){var b=0;b=v[115798];if(a){v[115798]=(a|0)==-1?466932:a}return(b|0)==466932?-1:b}function qU(a){var b=0;if(!(Pb(a,26180,20)|(w[a+25|0]-9&255)>>>0<248)){b=t[a+47|0]>=0}return b}function pr(a,b,c,d){var e=0;v[a>>2]=v[b>>2];e=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=(c<<d)+e;return a}function fU(a,b){return(Yb((B(a>>>4|0,b)>>>0)/15|0,1,15)<<4|Yb((B(a&15,b)>>>0)/15|0,1,15))&255}function cda(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(b){il(a,b);wP(a,b)}return a|0}function ZA(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=a;a=v[rT(c+8|0,0-b|0)>>2];jb=c+16|0;return a}function SS(a,b,c){var d=0;d=jb-16|0;jb=d;t[d+15|0]=0;gc(a,b,mi(b,b+c|0,d+15|0)-b|0);jb=d+16|0}function NH(a){var b=0;b=+((a&2097151)>>>0);return C(Dj(+C((a|0)<0?-b:b),(a>>>21&1023)-788|0))}function zk(a){var b=0;b=jb-16|0;jb=b;a=v[hc(b+8|0,tc(a)+(Fb(a)<<2)|0)>>2];jb=b+16|0;return a}function tu(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=a;a=Vb(c,b);Sc(d,a);yb(a);jb=c+16|0}function tX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;a=nb[a|0](b,c,d,e)|0;ra(mb|0);return a|0}function sg(a,b){a=a|0;b=b|0;var c=0,d=0;c=jb-16|0;jb=c;d=a;a=Vb(c,b);Sc(d,a);zb(a);jb=c+16|0}function hB(a,b){a=a|0;b=b|0;v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);if(b){pl(a,b);kE(a,b)}return a|0}function cQ(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=B(c,12)+d;return a}function Pl(a,b,c){b=b-a|0;while(1){if((b|0)>0){t[a|0]=w[c|0];b=b-1|0;a=a+1|0;continue}break}}function BC(a){var b=0;b=a&255;a=b>>>21|0;b=(b<<11)+2624|0;a=b>>>0<2624?a+1|0:a;mb=a;return b}function zQ(a){var b=0,c=0;b=jb-16|0;jb=b;if(yQ(a,b+8|0)){c=cc(v[b+8>>2])}jb=b+16|0;return c}function xG(a){var b=0,c=0;c=a;while(1){b=c;c=b+4|0;if(v[b>>2]){continue}break}return b-a>>2}function wfa(a){a=a|0;var b=0,c=0;b=jb-32|0;jb=b;c=a;a=Bh(b+8|0);aS(c,a,0,0);Ab(a);jb=b+32|0}function kF(a){a=a|0;var b=0;v[a>>2]=82076;b=v[a+8>>2];if(!(!b|!w[a+12|0])){Jb(b)}return a|0}function k0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=+e;return nb[v[v[a>>2]+32>>2]](a,b,c,d,e)|0}function LV(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=og(a,b+8|0);jb=b+16|0;return(a?w[b+8|0]:0)&255}function lx(a,b,c,d,e){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=xK(d);b=b+1|0}UI(a,b,c,d,e)}function ax(a,b){a=a&255;return w[(B(a>>>1&3,15)+B(a>>>3&1,45)+((b&240)>>>4)|0)+63537|0]<<1}function Zea(a){a=a|0;var b=0;b=jb-16|0;jb=b;a=Xh(a,b+8|0);jb=b+16|0;return+(a?A[b+8>>3]:0)}function ZQ(a){a:{if(Pb(a,17447,4)){break a}if(Pb(a+8|0,14064,4)){break a}return 1}return 0}function PC(a,b){if((a&4088)>>>0>=520){b=$u(0-Wia(b^1230262859,25)|0,4)^1247037516}return b}function Ky(a){var b=0;v[a+84>>2]=0;v[a+88>>2]=0;b=v[a+80>>2];v[a+92>>2]=b;v[a+96>>2]=b<<12}function Dg(a){var b=0,c=0;while(1){c=b&65535;if(c>>>0<127){iB(a,c);b=b+1|0;continue}break}}function zi(a){var b=0;if(a>>>0>=11){b=a+16&-16;a=b-1|0;a=(a|0)==11?b:a}else{a=10}return a}function yl(a,b,c){var d=C(0);if(b>>>0<=c>>>0){d=z[Db(a+4208|0,b)>>2]}else{d=C(0)}return d}function sK(a,b){var c=0;c=v[a+12>>2];if((c|0)>0){v[a+20>>2]=(v[a+16>>2]+(b+c|0)|0)%(c|0)}}function iH(a){var b=0;b=v[a>>2];if(b){if(!uc(jH(b),-1)){return!v[a>>2]}v[a>>2]=0}return 1}function gD(a,b,c){var d=0;d=jb-16|0;jb=d;b=vl(d+8|0,b,c);KD(b,a);ee(b);jb=d+16|0;return a}function ew(a,b,c){var d=0;d=jb-16|0;jb=d;c=bi(d+8|0,c);a=Ow(a,b);ai(c);jb=d+16|0;return a}function cO(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[kc(a)+4|0]){dO(b+16|0)}if(b){Jb(b)}}}function V5(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ux(a,b,c,d,e,0,0,f,g)}function US(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[kc(a)+4|0]){$t(b+16|0)}if(b){Jb(b)}}}function QL(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){if(w[kc(a)+4|0]){ec(b+16|0)}if(b){Jb(b)}}}function Gv(a,b){a=a|0;b=b|0;b=b-1|0;if(b>>>0<=4){b=v[(b<<2)+21476>>2]}else{b=9634}Vb(a,b)}function GP(a){var b=0;b=a&255;a=b>>>27|0;b=(b<<5)+259|0;a=b>>>0<259?a+1|0:a;mb=a;return b}function $g(a,b){var c=0;c=jb-16|0;jb=c;v[c+8>>2]=a;a=v[XA(c+8|0,b)>>2];jb=c+16|0;return a}function vp(a,b,c){a=a+1074992|0;return v[(a+B(b,872)|0)+680>>2]>v[(a+B(c,872)|0)+680>>2]}function tw(a,b,c,d){var e=0;e=jb-16|0;jb=e;v[e+12>>2]=d;a=Ir(a,b,c,d);jb=e+16|0;return a}function sX(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;nb[a|0](b,c,d,e,f,g)}function aU(a,b,c){var d=0;d=jb-16|0;jb=d;yi(d+8|0,b,c);jb=d+16|0;return v[d+8>>2]==(a|0)}function Wia(a,b){var c=0,d=0;c=b&31;d=(-1>>>c&a)<<c;c=a;a=0-b&31;return d|(c&-1<<a)>>>a}
function R7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Pj(a);if(a){nb[v[v[a>>2]+76>>2]](a,b,c,d)}}function Q7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Pj(a);if(a){nb[v[v[a>>2]+84>>2]](a,b,c,d)}}function P7(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=Pj(a);if(a){nb[v[v[a>>2]+88>>2]](a,b,c,d)}}function JK(a,b){a=a|0;b=b|0;var c=0;c=Fb(a);if(c>>>0<b>>>0){su(a,b-c|0,0);return}bL(a,b)}function JJ(a){a=a|0;var b=0;v[a>>2]=49072;b=v[a+4>>2];if(b){Jb(b);v[a+4>>2]=0}return a|0}function Fg(a){var b=0;b=jb-16|0;jb=b;a=Uq(a,b+8|0);jb=b+16|0;return(a?x[b+8>>1]:0)&65535}function xv(){var a=0,b=0;a=jb-16|0;jb=a;b=xf(a+8|0,Qb(xc(12)));jb=a+16|0;return v[b>>2]}function wX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return nb[a|0](b,c,d,e,f)|0}function pz(a,b){a=_j(a,b);Sc(a+12|0,b+12|0);u[a+28>>1]=x[b+28>>1];v[a+24>>2]=v[b+24>>2]}function oh(a){var b=0;b=jb-16|0;jb=b;a=v[hc(b+8|0,tc(a)+Fb(a)|0)>>2];jb=b+16|0;return a}function ns(a){if(qJ(a)){a=ba(4)|0;v[a>>2]=0;a=Ll(a);v[a>>2]=91304;ha(a|0,91340,25);L()}}function gR(a,b){var c=0;c=jb-16|0;jb=c;Em(c+8|0,b);SS(a,v[c+8>>2],v[c+12>>2]);jb=c+16|0}function Ys(a){var b=0;b=jb-16|0;jb=b;a=v[hc(b+8|0,Jc(a)+Fb(a)|0)>>2];jb=b+16|0;return a}function PA(a,b,c){var d=0;d=jb-16|0;jb=d;au(a,c);t[d+15|0]=0;sd(b+c|0,d+15|0);jb=d+16|0}function LM(a,b){var c=0;c=w[a+851|0];if(c&1){t[a+851|0]=c|64;v[a+852>>2]=v[a+852>>2]+b}}function Ix(a,b,c){var d=0;d=jb-16|0;jb=d;Mh(a,c);t[d+15|0]=0;sd(b+c|0,d+15|0);jb=d+16|0}function Is(a,b){var c=0;c=Jc(a);if(c>>>0<=b>>>0){a=Fb(a)+c>>>0>=b>>>0}else{a=0}return a}function GM(a){a=Kb(a);Kb(a+12|0);Kb(a+24|0);Kb(a+36|0);Kb(a+48|0);v[a+60>>2]=0;return a}function Ee(a){var b=0;b=jb-16|0;jb=b;a=og(a,b+15|0);jb=b+16|0;return(a?w[b+15|0]:0)&255}function ot(a){var b=0;b=jb-16|0;jb=b;t[b+15|0]=0;Pl(a,ao(a),b+15|0);jb=b+16|0;return a}function kW(a){a=a|0;var b=0;b=v[a+4>>2];return(nb[v[v[b>>2]+20>>2]](b)|0)+v[a+12>>2]|0}function _G(a){var b=0;b=v[a>>2];if(b){if(!pn(Dk(b))){return!v[a>>2]}v[a>>2]=0}return 1}function Xp(a,b,c){var d=C(0);d=z[a>>2];if(!Vt(d,z[b>>2])){b=Vt(z[c>>2],d)?c:a}return b}function Th(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;return a}function TA(a){var b=0;b=Az(a);while(1){if((a|0)!=(b|0)){AU(a);a=a+32|0;continue}break}}function T7(a,b){a=a|0;b=b|0;a=Pj(a);if(!a){return 1}return nb[v[v[a>>2]+68>>2]](a,b)|0}function Pm(a){var b=0;b=rv(a+4|0);if((b|0)==-1){nb[v[v[a>>2]+8>>2]](a)}return(b|0)==-1}function Kv(a,b,c){var d=0;v[a>>2]=v[b>>2];d=v[b>>2];v[a+8>>2]=b;v[a+4>>2]=c+d;return a}function Ex(a,b,c,d){if(!((b|0)==(c|0)|(d|0)>=0)){t[b|0]=45;d=xK(d);b=b+1|0}zx(a,b,c,d)}function DL(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){aj(c,a,d)}return B((d|0)/6|0,6)+c|0}function BG(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=b;a=CG(a,11034,b);jb=c+16|0;return a}function Ap(a,b,c){a=Rk(a)-v[a+16>>2]|0;if(a>>>0>=2){c=C(C(C(c-b)/C(a>>>0))+b)}return c}function sk(a,b,c){var d=0,e=0;d=jb-16|0;jb=d;e=d+8|0;tk(e,a+24|0,b);xg(e,c);jb=d+16|0}function eI(a,b){a=a&255;return v[(b&12)+63540>>2]>>>((a>>>3^-1)&1)>>>((a>>>4^-1)&1)|0}function Sk(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;Bb(d,a,b);nm(d);jb=c+16|0;return a}function SW(){var a=0;a:{if(YD(19923969)){break a}if(XD()){break a}a=WD()^1}return a|0}function QR(a){var b=0;b=a+24|0;while(1){b=yb(b-12|0);if((b|0)!=(a|0)){continue}break}}function O_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return FE(b,c,d,e,f,1)|0}
function OP(a){var b=0;b=a+36|0;while(1){b=yb(b-12|0);if((b|0)!=(a|0)){continue}break}}function Mu(a,b){a=a|0;b=b|0;var c=0;c=jb-16|0;jb=c;t[c+15|0]=b;NJ(a,c+15|0);jb=c+16|0}function LD(a,b){var c=0;c=jb-16|0;jb=c;b=rg(c+8|0,b);KD(b,a);ee(b);jb=c+16|0;return a}function KN(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;tk(d,a,b);nm(d);jb=c+16|0;return a}function IB(a,b,c){t[a+2|0]=1;b=b&15;if(c){b=w[b+26128|0]}else{b=(b<<2)+4|0}t[a+4|0]=b}function Ec(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;Em(d,a);nl(d,b);jb=c+16|0;return a}function BO(a,b){return(a>>>0<=62?63-(B((b^-1)&63,(a?a+1|0:0)&255)>>>6|0)|b&192:b)&255}function qA(a,b,c,d){var e=0;e=jb-16|0;jb=e;a=Ph(e,a,d);Zt(b,c,a+4|0);lc(a);jb=e+16|0}function lY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[((b&255)<<2)+80576>>2]}return b<<24>>24}function kl(a,b,c){a=a|0;b=b|0;c=c|0;if(Nc(a,b)>>>0<=c>>>0){Tu();L()}return(c<<1)+a|0}function jY(a,b){a=a|0;b=b|0;if((b|0)>=0){b=v[((b&255)<<2)+79040>>2]}return b<<24>>24}function hE(a){var b=0;while(1){if((b|0)!=3){v[(b<<2)+a>>2]=0;b=b+1|0;continue}break}}function eZ(a){a=a|0;a=468440;while(1){a=Kc(a-12|0);if((a|0)!=468416){continue}break}}function dZ(a){a=a|0;a=468368;while(1){a=Kc(a-12|0);if((a|0)!=468080){continue}break}}function cZ(a){a=a|0;a=467768;while(1){a=Kc(a-12|0);if((a|0)!=467600){continue}break}}function _t(a,b,c,d){var e=0;e=jb-16|0;jb=e;a=uk(e,a,d);Zt(b,c,a+4|0);lc(a);jb=e+16|0}function Zs(a,b){if(!(t[b+851|0]&1&v[a+480180>>2]==8)){hy(a,b,0);hy(a,b,1);hy(a,b,2)}}function Y_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return HE(b,c,d,e,f,1)|0}function W_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return HE(b,c,d,e,f,0)|0}function St(a,b){var c=0;c=jb-16|0;jb=c;u[c+14>>1]=b;Ot(a+236|0,128,c+14|0);jb=c+16|0}function SY(a){a=a|0;a=468408;while(1){a=yb(a-12|0);if((a|0)!=468384){continue}break}}function RY(a){a=a|0;a=468064;while(1){a=yb(a-12|0);if((a|0)!=467776){continue}break}}function QY(a){a=a|0;a=467592;while(1){a=yb(a-12|0);if((a|0)!=467424){continue}break}}function PF(a,b){var c=0,d=0;Oe(a,de(b));b=kc(b);c=kc(a),d=v[b>>2],v[c>>2]=d;return a}function Op(a,b,c){var d=0;d=c;b=b-a|0;c=v[c>>2]-b|0;v[d>>2]=c;if((b|0)>0){qc(c,a,b)}}function NO(a,b,c,d){var e=0;e=jb-16|0;jb=e;a=Fi(e,a,d);Zt(b,c,a+4|0);lc(a);jb=e+16|0}function M_(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;return FE(b,c,d,e,f,0)|0}function L0(a,b){a=a|0;b=b|0;a=x[a>>1];b=x[b>>1];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function J0(a,b){a=a|0;b=b|0;a=v[a>>2];b=v[b>>2];return(a>>>0<b>>>0?-1:a>>>0>b>>>0)|0}function El(a){var b=0;if(a>>>0>=2){b=a+4&-4;a=b-1|0;a=(a|0)==2?b:a}else{a=1}return a}function Dt(a,b){a:{if(b){break a}if(a>>>0<=3){a=a|-16;break a}a=a>>>2|0}return a&255}function D3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return VE(a,b,c,d,e,12223,978)|0}function Bs(a,b){a=a|0;b=b|0;b=jb-16|0;jb=b;v[b>>2]=a;YJ(17676,b);As(92720);jb=b+16|0}function A4(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return VE(a,b,c,d,e,12323,952)|0}function zg(a,b,c){var d=0;d=A[a>>3];if(!AP(d,A[b>>3])){b=AP(A[c>>3],d)?c:a}return b}function x3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return PE(a,b,c,d,e,9518,981)|0}function wj(a,b,c){var d=0;d=v[a>>2];if(!cp(d,v[b>>2])){b=cp(v[c>>2],d)?c:a}return b}function wh(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0;Th(a)}function oe(a,b,c){if(xm(a,b,c)){a=Pf(a,c);a=Rb(v[a>>2],v[a+4>>2])}else{a=0}return a}function j3(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return PE(a,b,c,d,e,9590,988)|0}function cf(a){a=a|0;var b=0;b=v[a>>2];return(nb[v[v[b>>2]+24>>2]](b)|0)-v[a+8>>2]|0}function Sv(a,b){var c=0;while(1){if((b|0)!=(c|0)){vg(a+c|0);c=c+1|0;continue}break}}function Nz(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;v[a+8>>2]=v[b+8>>2]}function Nn(a){var b=0;b=a;a=v[a>>2];v[b>>2]=B(a,214013)+2531011;return a>>>16&32767}function MP(a,b,c,d,e,f){a=hc(a,b);hc(a+4|0,c);hc(a+8|0,d);hc(a+12|0,e);hc(a+16|0,f)}function BF(a,b){a:{if(!(w[a+120|0]|b>>>0>30)){t[a+120|0]=1;break a}a=ri(b)}return a}function zG(a){return(a|0)!=0&(a|0)!=88800&(a|0)!=88824&(a|0)!=466848&(a|0)!=466872}function w7(a,b){a=a|0;b=b|0;return C(b>>>0<=2?C(C(w[(a+b|0)+4232|0])/C(127)):C(0))}function rg(a,b){v[a>>2]=v[b>>2];v[a+4>>2]=v[b+4>>2];v[b>>2]=0;v[b+4>>2]=0;return a}function pF(a){a=a|0;v[a>>2]=83160;if(v[a+8>>2]!=(Bd()|0)){yG(v[a+8>>2])}return a|0}function mp(a){a=a|0;v[a+56>>2]=76808;v[a>>2]=76788;ws(a+4|0);Fk(a+56|0);return a|0}function l8(a,b){a=a|0;b=b|0;return C(b>>>0<=3?C(C(w[(a+b|0)+4264|0])/C(255)):C(0))}function jf(a){a=a|0;v[a+60>>2]=76972;v[a>>2]=76952;ws(a+8|0);Fk(a+60|0);return a|0}function iq(a,b){var c=0,d=0,e=0;c=v[a+24>>2];d=a,e=Ie(Lj(b)*+(c>>>0)),v[d+24>>2]=e}function T$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;a=SG(a,c,d,b);v[a>>2]=77148;return a|0}function Qd(a){var b=0;b=jb-16|0;jb=b;v[b+12>>2]=49240;co(a,49136,b+12|0);jb=b+16|0}function C5(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return WJ(a,b,c,d,0,0,0,0,e)|0}function sy(a){var b=0;b=jb-16|0;jb=b;hc(b+8|0,a+116|0);a=vM(a);jb=b+16|0;return a}function sN(a,b){var c=0;c=b&15;if(c){t[a+830|0]=c}b=b&240;if(b){t[a+829|0]=b>>>4}}function rr(a,b,c,d){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+B(c,d);return a}function qg(a){var b=0;b=jb-16|0;jb=b;a=Ho(a,b+8|0);jb=b+16|0;return a?v[b+8>>2]:0}function c8(a){a=a|0;t[a+4202|0]=1;v[a+4232>>2]=v[v[a+16>>2]+24620>>2];Gs(a);aL(a)}function Vo(a,b,c,d){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+(c<<d);return a}function QH(a,b){b=v[a+32>>2]+b|0;v[a+32>>2]=b;if(b>>>0>=y[a+40>>2]){v[a+96>>2]=1}}function M6(a){a=a|0;t[a+4202|0]=1;v[a+4256>>2]=v[v[a+16>>2]+24620>>2];vK(a);uK(a)}function oL(a,b,c){while(1){if(b){z[a>>2]=z[c>>2];b=b-1|0;a=a+4|0;continue}break}}function go(a,b){a=qc(a,b,34);u[a+34>>1]=x[b+34>>1];qc(a+36|0,b+36|0,68);return a}function Ot(a,b,c){while(1){if(b){u[a>>1]=x[c>>1];b=b-1|0;a=a+2|0;continue}break}}function HP(a){if((w[a+14|0]-53&255)>>>0>=252){a=Pb(a,15393,14)}else{a=1}return!a}function yf(a){var b=0;b=jb-16|0;jb=b;a=v[hc(b+8|0,Jf(a))>>2];jb=b+16|0;return a}function qj(a){var b=0;b=jb-16|0;jb=b;a=v[hc(b+8|0,Eb(a))>>2];jb=b+16|0;return a}function gl(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;jc(a+8|0,b+8|0)}function Zd(a){var b=0;b=jb-16|0;jb=b;a=v[hc(b+8|0,tc(a))>>2];jb=b+16|0;return a}function YJ(a,b){var c=0;c=jb-16|0;jb=c;v[c+12>>2]=b;BH(92720,a,b,0,0);jb=c+16|0}function Wfa(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Vv(a,b,c,d,e,524)|0}function Jf(a){var b=0;b=jb-16|0;jb=b;a=v[hc(b+8|0,kc(a))>>2];jb=b+16|0;return a}function Ii(a){var b=0;b=jb-16|0;jb=b;a=v[hc(b+8|0,rd(a))>>2];jb=b+16|0;return a}function $s(a){var b=0;b=jb-16|0;jb=b;a=v[hc(b+8|0,Jc(a))>>2];jb=b+16|0;return a}function xY(a,b,c){a=a|0;b=b|0;c=c|0;return(v[(c<<2)+82128>>2]&b)!=0&c>>>0<=127}function uX(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;nb[a|0](b,c,d,e,f)}function th(a,b,c){a=hc(a,b);b=v[c+4>>2];v[a+4>>2]=v[c>>2];v[a+8>>2]=b;return a}function kD(a,b,c){while(1){if(b){t[a|0]=w[c|0];b=b-1|0;a=a+1|0;continue}break}}function hg(a){var b=0,c=0;Cc(a+4|0);Zj(a+8|0,0);b=a,c=kc(a),v[b>>2]=c;return a}function er(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Vv(a,b,c,d,e,157)|0}function Vh(a){return(zj(v[a>>2],v[a+4>>2])|0)!=(0-zj(v[a+12>>2],v[a+16>>2])|0)}function SZ(){var a=0,b=0,c=0;a=Od(468496);v[a>>2]=83160;b=a,c=Bd(),v[b+8>>2]=c}function Mv(a,b){b=a+b|0;while(1){b=zb(b-12|0);if((b|0)!=(a|0)){continue}break}}function MT(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return Vv(a,b,c,d,e,319)|0}function pX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return nb[a|0](b,c,d,e)|0}function mZ(a){a=a|0;if(!w[467376]){bn(467364,83396);t[467376]=1}return 467364}function kZ(a){a=a|0;if(!w[467408]){bn(467396,83480);t[467408]=1}return 467396}function iZ(a){a=a|0;if(!w[467312]){bn(467300,83324);t[467312]=1}return 467300}function gZ(a){a=a|0;if(!w[467344]){bn(467332,83360);t[467344]=1}return 467332}function fo(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0;t[a+4|0]=0;t[a+5|0]=0}function ay(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[Gb(a)>>2]){mM(a,b);return}Uz(a,b)}function _Y(a){a=a|0;if(!w[467360]){Vb(467348,13339);t[467360]=1}return 467348}function _0(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=+d;e=+e;return mI(a-88|0,b,c,d,e)|0}function UY(a){a=a|0;if(!w[467328]){Vb(467316,13548);t[467328]=1}return 467316}function Ju(a,b){return Ie(Lj((+(a|0)*128+ +(b|0))*.0006510416666666666)*8363)}function HT(a,b){a=a|0;b=b|0;if(v[a+4>>2]!=v[Gb(a)>>2]){OF(a,b);return}LF(a,b)}function EC(a){var b=0;b=jb-16|0;jb=b;t[b+15|0]=0;Pl(a,Oo(a),b+15|0);jb=b+16|0}function ze(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;av(d,a);nl(d,b);jb=c+16|0}function wm(a,b){var c=0,d=0;c=jb-16|0;jb=c;d=c+8|0;$B(d,a);nl(d,b);jb=c+16|0}function bY(a,b){a=a|0;b=b|0;a=Ll(a);v[a>>2]=91832;dw(a+4|0,Jc(b));return a|0}function _i(a,b,c){if(v[a+80>>2]){v[a+92>>2]=v[a+92>>2]+(c+7&-8);return}Jb(b)}function Zi(a,b){var c=0;c=a;a=(b>>>0)/100|0;return Xr(Xr(c,a),B(a,-100)+b|0)}function YY(a){a=a|0;if(!w[467392]){Vb(467380,9155);t[467392]=1}return 467380}function XX(a,b,c){a=a|0;b=b|0;c=c|0;if(!w[468944]){t[468944]=1}gc(a,c,93172)}function XN(a){v[a>>2]=0;v[a+4>>2]=0;v[a>>2]=-2078137563;v[a+4>>2]=-873292572}function WY(a){a=a|0;if(!w[467296]){Vb(467284,5226);t[467296]=1}return 467284}function Ry(a){var b=0;if(!(w[a+2|0]|(w[a|0]|w[a+1|0]))){b=!w[a+3|0]}return b}function Qx(a,b){if((a|0)>=0){return(a|0)/(b|0)|0}return((a+1|0)/(b|0)|0)-1|0}function PX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;if(Jg(a,v[b+8>>2],0)){$v(b,c,d)}}function L9(a,b){a=a|0;b=b|0;if(y[a+4>>2]<y[Gb(a)>>2]){mM(a,b);return}Uz(a,b)}function In(a,b){if((a|0)>=0){return(a|0)%(b|0)|0}return((a^-1)%(b|0)^-1)+b|0}function FP(a,b){a=TQ(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2];return a}function ye(a){var b=0;b=jb-16|0;jb=b;Fu(b+8|0,a);jb=b+16|0;return v[b+8>>2]}function gG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb[v[v[a>>2]+32>>2]](a,b,c,d)|0}function cG(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb[v[v[a>>2]+48>>2]](a,b,c,d)|0}function ak(a){var b=0;b=jb-16|0;jb=b;a=v[xf(b+8|0,a)>>2];jb=b+16|0;return a}function aN(a,b,c){var d=0;return!b|!(w[a+35|0]&4?!a|(c|0)!=1:1)?d:w[b+34|0]}function Yd(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;d=v[b+8>>2];ac(b,c);uv(a,b,d,c)}function O6(a,b){a=a|0;b=b|0;return C(b>>>0<=4?z[((b<<2)+a|0)+4220>>2]:C(0))}function IF(a){var b=0;b=jb-16|0;jb=b;v[b+8>>2]=a;jb=b+16|0;return v[b+8>>2]}function Eb(a){var b=0;b=jb-16|0;jb=b;a=v[hc(b+8|0,a)>>2];jb=b+16|0;return a}function wO(a,b){b=1/(1/(b*6.283185307179586/3546895)+1);pO(a,b,0,0,b+-1,0)}function v3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ym(a,b,c,d,12724,982)|0}function uk(a,b,c){v[a>>2]=b;b=v[b+4>>2];v[a+4>>2]=b;v[a+8>>2]=b+c;return a}function tY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[(b<<2)+80576>>2]}return b|0}function rY(a,b){a=a|0;b=b|0;if(b>>>0<=127){b=v[(b<<2)+79040>>2]}return b|0}function r3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ym(a,b,c,d,12798,984)|0}function eS(a){var b=0;while(1){b=a;a=v[a>>2];if(a){continue}break}return b}function __(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return IE(b,c,d,e,1)|0}function X_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return IE(b,c,d,e,0)|0}function WG(a,b,c,d,e,f,g,h){return nb[v[v[a>>2]+16>>2]](a,b,c,d,e,f,g,h)|0}function U$(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)!=1){TG(a,c);return}Vb(a,7838)}function Q_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return GE(b,c,d,e,1)|0}function OK(a){a=a|0;v[a>>2]=46244;vc(a+4276|0);vc(a+4264|0);return uf(a)|0}function Nr(a,b,c,d,e,f,g,h){return nb[v[v[a>>2]+12>>2]](a,b,c,d,e,f,g,h)|0}function N_(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return GE(b,c,d,e,0)|0}function Kz(a,b){return(+(a>>>0)+ +(b|0)*4294967296)*2.3283064365386963e-10}function t3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ym(a,b,c,d,9473,983)|0}function qv(a,b,c){var d=0;d=b-a|0;if((a|0)!=(b|0)){aj(c,a,d)}return c+d|0}function p3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ym(a,b,c,d,9551,985)|0}function ng(a,b){var c=0;c=a;a=v[a+8>>2];b=a-b|0;v[c+8>>2]=a>>>0<b>>>0?0:b}function n3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ym(a,b,c,d,9353,986)|0}function jh(a,b,c){v[a+8>>2]=b;v[a+12>>2]=c;v[a>>2]=0;v[a+4>>2]=0;return a}function _X(a,b,c){a=a|0;b=b|0;c=c|0;return uc(a,v[b+4>>2])&v[b>>2]==(c|0)}function Xr(a,b){b=x[(b<<1)+75936>>1];t[a|0]=b;t[a+1|0]=b>>>8;return a+2|0}function Xj(a){var b=0;b=x[a+172>>1];a=x[a+156>>1];return(CP(a)?b:a)&65535}function B3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return Ym(a,b,c,d,9322,979)|0}function vm(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+48>>2]](a,b,c)|0}function rd(a){var b=0,c=0,d=0;return b=v[a>>2],c=a,d=Uf(w[a+11|0]),d?b:c}function qt(a,b){var c=0;c=v[b+4>>2];v[a>>2]=v[b>>2];v[a+4>>2]=c;return a}function cha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=zo(a,b),v[d>>2]=e}function cd(a,b){a=LD(a,b);v[a+8>>2]=v[b+8>>2];LD(a+12|0,b+12|0);return a}function bha(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0;d=c,e=Wu(a,b),u[d>>1]=e}function _c(a,b,c,d,e){t[a+3|0]=e;t[a+2|0]=d;t[a+1|0]=c;t[a|0]=b;return a}function Zt(a,b,c){b=b-a|0;if((b|0)>0){qc(v[c>>2],a,b);v[c>>2]=b+v[c>>2]}}function Ob(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+32>>2]](a,b,c)|0}function GR(a,b){t[a+6|0]=255;v[a+16>>2]=b;u[a+4>>1]=0;v[a>>2]=0;return a}function F7(a,b){a=a|0;b=b|0;a=v[a+20>>2];t[a+24|0]=w[a+24|0]&253|(b?2:0)}function DD(a,b){a=a|0;b=b|0;a=Ll(a);v[a>>2]=91832;dw(a+4|0,b);return a|0}function Ck(a,b,c){a=a|0;b=b|0;c=c|0;return nb[v[v[a>>2]+12>>2]](a,b,c)|0}function CD(a,b){a=rg(a,b);v[a+8>>2]=v[b+8>>2];rg(a+12|0,b+12|0);return a}function xw(a,b){var c=0;c=xs(a+4|0);v[a>>2]=77600;v[c>>2]=77620;Dn(c,b)}function ww(a,b){var c=0;c=MG(a+4|0);v[a>>2]=77968;v[c>>2]=77988;Dn(c,b)}function vP(a,b){t[a|0]=b;t[a+1|0]=b>>>8;t[a+2|0]=b>>>16;t[a+3|0]=b>>>24}function qH(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;jh(a,-1,-1)}function wI(a){a=a|0;return+(+y[v[a+32>>2]+480240>>2]*152587890625e-16)}function vc(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];ui(a);Jb(b)}return a}function rc(a,b){var c=0,d=0;v[a>>2]=b;c=a,d=Ef(b),v[c+4>>2]=d;return a}function pB(a,b,c){var d=0;d=(b|0)/(c|0)|0;v[a>>2]=d;v[a+4>>2]=b-B(c,d)}function lm(a){if(Uf(w[a+11|0])){a=fB(v[a+8>>2])-1|0}else{a=10}return a}function ld(a){var b=0;if(v[a>>2]){oC(a,v[a>>2]);b=v[a>>2];pC(a);Jb(b)}}function hQ(a){var b=0;if(v[a>>2]){eQ(a,v[a>>2]);b=v[a>>2];Ej(a);Jb(b)}}function gea(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;sE(a,b,c,d,e,127)}function bU(a,b,c){a=a&255;return a>>>0>=(b&255)>>>0&a>>>0<=(c&255)>>>0}function _o(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;v[e>>2]=c;return 3}function Wf(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];Lt(a);Jb(b)}return a}function Tw(a){return((mh(a)+(mh(a)<<8)|0)+(mh(a)<<16)|0)+(mh(a)<<24)|0}function IO(a,b){v[a+4>>2]=0;v[a+8>>2]=0;v[a>>2]=b?b:49716;v[a+12>>2]=0}function IK(a){a=a|0;return C(C(C(z[Db(a+4208|0,5)>>2]*C(198))+C(-99)))}function Fha(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;sE(a,b,c,d,e,101)}function CO(a){if(a>>>0<=8){return w[a+29024|0]}return w[a+29015|0]|256}function yk(a,b){a=a|0;b=b|0;t[a|0]=2;t[a+1|0]=3;t[a+2|0]=0;t[a+3|0]=4}function wR(a){if(Pb(a,13662,4)){a=1}else{a=Pb(a+8|0,13715,4)}return!a}function tz(a,b){a=Qb(a);Kb(a+12|0);u[a+28>>1]=0;v[a+24>>2]=b;return a}function jg(){var a=0;a=Nl(ba(4)|0);v[a>>2]=91716;ha(a|0,91792,25);L()}function hV(a){a=a|0;v[a+16>>2]=v[a+16>>2]|1;if(t[a+20|0]&1){va();L()}}function bw(a,b,c){if(!(v[a+28>>2]==1|v[a+4>>2]!=(b|0))){v[a+28>>2]=c}}function Zq(a){v[a>>2]=0;v[a+4>>2]=0;v[a+8>>2]=0;v[a+12>>2]=0;return a}function Xk(a,b){a=w[Lb(a+62|0,b)|0];return(a<<24>>24>=0?a&127:-1)&255}function Wy(a,b){if(b){Wy(a,v[b>>2]);Wy(a,v[b+4>>2]);Zl(b+16|0);Jb(b)}}function KA(a,b){if(b){KA(a,v[b>>2]);KA(a,v[b+4>>2]);$t(b+16|0);Jb(b)}}function JA(a,b){if(b){JA(a,v[b>>2]);JA(a,v[b+4>>2]);$t(b+16|0);Jb(b)}}function Hy(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];t[a+6|0]=w[b+6|0]}function Hp(a,b){if(b){Hp(a,v[b>>2]);Hp(a,v[b+4>>2]);dO(b+16|0);Jb(b)}}function $x(a,b){if(b){$x(a,v[b>>2]);$x(a,v[b+4>>2]);ec(b+16|0);Jb(b)}}function xX(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;nb[a|0](b,c,d,e)}function tM(a,b,c,d,e){v[a+12>>2]=e;v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b}function fw(a){a=a|0;if(v[a+8>>2]!=(Bd()|0)){yG(v[a+8>>2])}return a|0}function TL(a,b,c,d){if((b|0)==(d|0)){a=VL(a,b,c,d)}else{a=1}return!a}function NP(a,b,c,d,e){a=hc(a,b);hc(a+4|0,c);hc(a+8|0,d);hc(a+12|0,e)}function Mc(a,b,c,d){if((b|0)==(d|0)){a=RS(a,b,c,d)}else{a=1}return!a}function IX(a){a=a|0;if(!a){return 0}return(Fy(a,91388,91532)|0)!=0|0}function AJ(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){yn(c+120|0);Jb(c)}}function yB(a,b){var c=0;c=jb-16|0;jb=c;OC(c,a,32);SC(c,b);jb=c+16|0}function uu(a,b){var c=0;c=jb-16|0;jb=c;OC(c,a,64);SC(c,b);jb=c+16|0}function sS(a,b){v[a>>2]=v[b>>2];u[a+4>>1]=x[b+4>>1];jc(a+8|0,b+8|0)}function s$(a){a=a|0;var b=0;b=v[116788]+1|0;v[116788]=b;v[a+4>>2]=b}function qX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return nb[a|0](b,c,d)|0}function cl(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){kc(a);if(b){Jb(b)}}}function ZZ(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;Rh(a,f)}function Fl(a,b){return b?a<<8&16711680|a<<24|(a>>>8&65280|a>>>24):a}function DP(a,b){a=Sz(a,b);t[a+16|0]=w[b+16|0];v[a+12>>2]=v[b+12>>2]}function u3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return OE(a,b,c,d,4)|0}function s3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return OE(a,b,c,d,2)|0}function q3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return NE(a,b,c,d,4)|0}function o3(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return NE(a,b,c,d,2)|0}function lM(a,b){var c=0;c=jb-16|0;jb=c;Zz(c,1,b);Gc(a,c);jb=c+16|0}function PB(a,b){return eE(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?b:a}function Oq(a,b){return _u(v[b>>2],v[b+4>>2],v[a>>2],v[a+4>>2])?b:a}function Lc(a,b,c){if(wc(a,b)>>>0<=c>>>0){Tu();L()}return(c<<2)+a|0}function JM(a,b){v[a+852>>2]=v[a+852>>2]+b;t[a+851|0]=w[a+851|0]|64}function AS(a){t[a+4|0]=0;t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function oY(a,b,c){a=a|0;b=b|0;c=c|0;return(b>>>0<128?b:c)<<24>>24}function cP(a,b){var c=0,d=0;c=hc(a,v[b>>2]),d=w[b+4|0],t[c+4|0]=d}function _E(a,b,c,d){b=Pa(909,a|0,b|0,c|0,d|0)|0;mb=O()|0;return b}function EF(a,b,c){a:{if((a|0)==(b|0)){t[b+120|0]=0;break a}Jb(b)}}function AL(a,b){if((a|0)!=(b|0)){fS(a,v[b>>2],v[b+4>>2])}return a}function ym(a,b){v[a>>2]=v[(v[v[b>>2]-12>>2]+b|0)+24>>2];return a}function uI(a){a=a|0;return+(+v[v[a+32>>2]+1074456>>2]*.00390625)}function mW(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+12>>2]](a)|0}function lW(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+16>>2]](a)|0}function hr(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+32>>2]](a,0,b)|0}function fn(a,b){if(y[a+4>>2]<y[Gb(a)>>2]){OF(a,b);return}LF(a,b)}function d6(a,b,c){a=a|0;b=b|0;c=c|0;return Ki(a,b,c,879,86224)|0}function aS(a,b,c,d){a=ie(a,b);u[a+22>>1]=d;u[a+20>>1]=c;return a}function Jc(a){var b=0,c=0,d=0;return b=v[a>>2],c=a,d=Ve(a),d?b:c}function J8(a,b){a=a|0;b=b|0;if(!v[23296]){v[23297]=b;v[23296]=a}}function IH(a,b){a=GH(a-1|0);if(!a){a=GH(b);a=a?a+32|0:0}return a}function Ai(a,b){if(gg(v[a>>2],v[a+4>>2])>>>0>b>>>0){t[a+16|0]=b}}function z7(a,b,c){a=a|0;b=b|0;c=c|0;return Ki(a,b,c,868,4236)|0}function wy(a){zb(a+48|0);zb(a+36|0);zb(a+24|0);zb(a+12|0);zb(a)}function wn(a,b,c){return SR(v[a>>2],v[a+4>>2],b,v[a+12>>2]+c|0)}function u6(a,b,c){a=a|0;b=b|0;c=c|0;return Ki(a,b,c,876,5048)|0}function r8(a,b,c){a=a|0;b=b|0;c=c|0;return Ki(a,b,c,850,4268)|0}function nW(a){a=a|0;a=v[a+4>>2];return nb[v[v[a>>2]+8>>2]](a)|0}function nK(a){return C(C(z[Db(a+4208|0,11)>>2]*C(19980))+C(20))}function l6(a,b,c){a=a|0;b=b|0;c=c|0;return Ki(a,b,c,878,4276)|0}function iia(a,b){a=a|0;b=b|0;a=hu(a,b);v[a>>2]=91988;return a|0}function id(a,b){return((a^-2147483648)>>>b)-(-2147483648>>>b)|0}function gd(a){a=(a|0)<32767?a:32767;return(a|0)>-32768?a:-32768}function fx(a,b,c){return Kh(v[a>>2],v[a+4>>2],b,v[a+12>>2]+c|0)}function f7(a,b,c){a=a|0;b=b|0;c=c|0;return Ki(a,b,c,871,4280)|0}function eE(a,b,c,d){return a>>>0<c>>>0&(b|0)<=(d|0)|(b|0)<(d|0)}function Z6(a,b,c){a=a|0;b=b|0;c=c|0;return Ki(a,b,c,872,4276)|0}function Tp(a,b,c){a=Mb(a&65535);return(a|0)>=(b|0)&(a|0)<=(c|0)}function S6(a,b,c){a=a|0;b=b|0;c=c|0;return Ki(a,b,c,873,4268)|0}function JD(a,b,c){a=Nm(a);v[a+8>>2]=c;v[a+4>>2]=b;v[a>>2]=61196}function Iga(a,b){a=a|0;b=b|0;a=hu(a,b);v[a>>2]=92040;return a|0}function D6(a,b,c){a=a|0;b=b|0;c=c|0;return Ki(a,b,c,875,4228)|0}function $7(a,b,c){a=a|0;b=b|0;c=c|0;return Ki(a,b,c,858,4304)|0}function zt(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];Lz(a);Jb(b)}}function zY(a){a=a|0;a=v[a+8>>2];if(!a){return 1}return nF(a)|0}function yaa(a,b){a=a|0;b=b|0;a=wS(a,b);if(!a){vS(b)}return a|0}function xM(a){var b=0;if(v[a>>2]){Rs(a);b=v[a>>2];Qs(a);Jb(b)}}function vi(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];ho(a);Jb(b)}}function ud(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];Fm(a);Jb(b)}}function tr(a){var b=0;b=jb-16|0;A[b+8>>3]=a;return A[b+8>>3]*a}function te(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){IJ(b)}return a}function rz(a){var b=0;if(v[a>>2]){RO(a);b=v[a>>2];ho(a);Jb(b)}}function pM(a){var b=0;if(v[a>>2]){No(a);b=v[a>>2];nv(a);Jb(b)}}function ow(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+12>>2]](a,b)|0}function oK(a){return C(C(z[Db(a+4208|0,0)>>2]*C(1e4))+C(-1e4))}function nC(a){if(a>>>0>=214748365){jg();L()}return xc(B(a,20))}function lo(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];yS(a);Jb(b)}}function ll(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+28>>2]](a,b)|0}function lO(a){var b=0;if(v[a>>2]){fO(a);b=v[a>>2];Ej(a);Jb(b)}}function je(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];Qm(a);Jb(b)}}function gk(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];lu(a);Jb(b)}}function dl(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];or(a);Jb(b)}}function dQ(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];Ej(a);Jb(b)}}function _u(a,b,c,d){return(b|0)==(d|0)&a>>>0<c>>>0|b>>>0<d>>>0}function _p(a,b,c){if(!b){return 0}return Yt(a,Lf(c<<24>>24),b)}function _d(a){var b=0;if(v[a>>2]){zU(a);b=v[a>>2];wB(a);Jb(b)}}function _D(a){if(a>>>0>=357913942){jg();L()}return xc(B(a,12))}function YP(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];nv(a);Jb(b)}}function Wg(a,b,c,d){v[a+8>>2]=d;v[a+4>>2]=c;v[a>>2]=b;return a}function VN(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];Yy(a);Jb(b)}}function T5(a,b){a=a|0;b=b|0;if(!b){return 3}v[b>>2]=a;return 0}function QN(a,b){a=a|0;b=b|0;a=hu(a,b);v[a>>2]=91852;return a|0}function Mr(a,b){a=a|0;b=b|0;return nb[v[v[a>>2]+44>>2]](a,b)|0}function Kc(a){var b=0;if(Ve(a)){b=v[a>>2];ml(a);Jb(b)}return a}function FM(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];VT(a);Jb(b)}}function EH(a){var b=0;b=jb-16|0;z[b+12>>2]=a;return z[b+12>>2]}function Ds(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];Ox(a);Jb(b)}}function Bt(a){var b=0;if(v[a>>2]){Hc(a);b=v[a>>2];Gb(a);Jb(b)}}function yU(a,b){if(!b){return-1}b=_p(a,b,0);return b?b-a|0:-1}function wL(a){if(a>>>0>=82595525){jg();L()}return xc(B(a,52))}function wA(a,b){a=a|0;b=b|0;a=Ho(a,b);if(!a){tm(b)}return a|0}function vv(a,b){a=a|0;b=b|0;a=vD(a,b);if(!a){uD(b)}return a|0}function q_(a,b){a=a|0;b=b|0;bN(a,Fw(v[b>>2])<<24>>24,v[b>>2])}function po(a,b){a=a|0;b=b|0;a=OT(a,b);if(!a){RT(b)}return a|0}function oX(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+16>>2]](a,b,0,0,1,8)}function mv(a,b){a=Sc(a,b);jc(a+12|0,b+12|0);Tf(a+32|0,b+32|0)}function iv(a,b){a=a|0;b=b|0;a=fD(a,b);if(!a){Yq(b)}return a|0}function ir(a,b){a=a|0;b=b|0;a=nD(a,b);if(!a){zv(b)}return a|0}function iE(a){u[a+12>>1]=0;v[a+8>>2]=-1;v[a>>2]=0;v[a+4>>2]=0}function cc(a){return a<<8&16711680|a<<24|(a>>>8&65280|a>>>24)}function bM(a,b,c,d){u[a+4>>1]=c;t[a+6|0]=b;v[a>>2]=d;return a}function Zh(a,b){a=a|0;b=b|0;a=Xh(a,b);if(!a){ul(b)}return a|0}function Vq(a,b){var c=0;c=b+1|0;v[a>>2]=v[a>>2]>(c|0)?c:b+2|0}function Vf(a,b){return nb[v[v[a>>2]+32>>2]](a,v[a+12>>2],b)|0}function UB(a,b){a=a|0;b=b|0;a=yu(a,b);if(!a){Du(b)}return a|0}function SA(a,b){a=a|0;b=b|0;a=IS(a,b);if(!a){FA(b)}return a|0}function PN(a,b){a=a|0;b=b|0;a=cU(a,b);if(!a){mu(b)}return a|0}function LS(a){if(a>>>0>=715827883){jg();L()}return xc(B(a,6))}function Jt(a,b){a=a|0;b=b|0;a=PT(a,b);if(!a){ku(b)}return a|0}function I2(a,b,c){a=a|0;b=b|0;c=c|0;KO(a,0,v[b+1298404>>2],c)}function GK(a){a=a|0;return Wj(C(z[Db(a+4208|0,4)>>2]*C(4)))|0}function EQ(a){return w[a+15|0]<<12|w[a+14|0]<<4|w[a+13|0]<<20}function yM(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Jb(jm(c))}}function wg(a,b,c,d,e,f){return Ra(a|0,b|0,c|0,d|0,e|0,f|0)|0}function vl(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(c){Lm(c)}return a}function ri(a){if(a>>>0>=1073741824){jg();L()}return xc(a<<2)}function qha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;wE(a,b,c,d,101)}function p7(a,b,c){a=a|0;b=b|0;c=c|0;return Lv(a,b,c,0,870)|0}function oha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;tE(a,b,c,d,409)}function lh(a,b,c){return(v[((c&255)<<2)+a>>2]&b)!=0&(c|0)>=0}function hM(a,b){return b>>>0<4e3?((b<<5)+a|0)+946304|0:21473}function bga(a,b,c){a=a|0;b=b|0;c=c|0;Sc(a,dS(c,Jc(b),Fb(b)))}function Vha(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;tE(a,b,c,d,341)}function NI(a,b){a=(a+b|0)-1|0;return a-((a>>>0)%(b>>>0)|0)|0}function MD(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Jb(fc(c))}}function L6(a,b,c){a=a|0;b=b|0;c=c|0;return Lv(a,b,c,0,874)|0}function Fia(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;wE(a,b,c,d,127)}function E6(a,b,c){a=a|0;b=b|0;c=c|0;return Lv(a,b,c,1,874)|0}function yI(a){a=a|0;return+(65536/+y[v[a+32>>2]+480244>>2])}function ws(a){a=a|0;v[a>>2]=76272;yb(a+32|0);return En(a)|0}function wD(a){if(a>>>0>=536870912){jg();L()}return xc(a<<3)}function oc(a,b){var c=0;c=v[a>>2];v[a>>2]=v[b>>2];v[b>>2]=c}function g7(a){a=a|0;return C(C(z[Db(a+4208|0,6)>>2]*C(20)))}function fy(a,b){var c=0;c=x[a>>1];u[a>>1]=x[b>>1];u[b>>1]=c}function fE(a){if(a>>>0>=268435456){jg();L()}return xc(a<<4)}function eW(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ic(a,v[d>>2],0)}function Jx(a){a=a|0;v[a+32>>2]=0;v[a+28>>2]=v[a+28>>2]&-7|2}function IP(a){if(a>>>0>=134217728){jg();L()}return xc(a<<5)}function HM(a){v[a>>2]=0;Qb(a+4|0);Xb(a+16|0,0,144);return a}function HK(a){a=a|0;return C(C(z[Db(a+4208|0,2)>>2]*C(10)))}function Gg(a,b,c,d){mb=b-((a>>>0<c>>>0)+d|0)|0;return a-c|0}function GH(a){return t[(B(0-a&a,124511785)>>>27|0)+72576|0]}function vX(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;nb[a|0](b,c,d)}function vH(a,b){if(b>>>0<=9){return uH(a,b)}return Xr(a,b)}function u4(a,b){a=a|0;b=b|0;return C(TE(a,b,6190,1075834))}function tfa(a,b,c){a=a|0;b=b|0;c=c|0;return yE(a,b,c,36)|0}function tA(a,b){if(b){tA(a,v[b>>2]);tA(a,v[b+4>>2]);Jb(b)}}function sY(a,b,c){a=a|0;b=b|0;c=c|0;return EE(b,c,80576)|0}function sA(a,b){if(b){sA(a,v[b>>2]);sA(a,v[b+4>>2]);Jb(b)}}function s4(a,b){a=a|0;b=b|0;return C(SE(a,b,6233,1075834))}function rv(a){var b=0;b=a;a=v[a>>2]-1|0;v[b>>2]=a;return a}function r4(a,b){a=a|0;b=b|0;return C(SE(a,b,6135,1075835))}function qY(a,b,c){a=a|0;b=b|0;c=c|0;return EE(b,c,79040)|0}function q4(a,b){a=a|0;b=b|0;return C(TE(a,b,6091,1075835))}function mx(a,b,c,d,e,f){return LE(a,b,c,d,e,f,56788,57584)}function mq(a){return v[a+20>>2]+(v[a+8>>2]-v[a+24>>2]|0)|0}function mJ(a,b){a=a|0;b=b|0;return pi(v[b>>2],v[b+4>>2])|0}function lU(a){return!Pb(a,14012,4)&(w[a+4|0]-1&255)>>>0<10}function lJ(a,b){a=a|0;b=b|0;return re(v[b>>2],v[b+4>>2])|0}function kx(a,b,c,d,e,f){return LE(a,b,c,d,e,f,57664,58428)}function kY(a,b,c){a=a|0;b=b|0;c=c|0;return DE(b,c,80576)|0}function iY(a,b,c){a=a|0;b=b|0;c=c|0;return DE(b,c,79040)|0}function hu(a,b){a=Ll(a);v[a>>2]=91812;dw(a+4|0,b);return a}function hN(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Jb(Iy(b))}}function bi(a,b){var c=0,d=0;c=a,d=wG(b),v[c>>2]=d;return a}function _R(a){var b=0;b=v[a+100>>2];v[a+100>>2]=0;return b}function Xs(a,b){if(b){Xs(a,v[b>>2]);Xs(a,v[b+4>>2]);Jb(b)}}function Ws(a,b){if(b){Ws(a,v[b>>2]);Ws(a,v[b+4>>2]);Jb(b)}}function SV(a){a=a|0;a=FD(a,13176);v[a>>2]=25932;return a|0}function R9(a){a=a|0;a=hu(a,21473);v[a>>2]=91932;return a|0}function N7(a){a=a|0;a=Pj(a);if(a){nb[v[v[a>>2]+96>>2]](a)}}function Iz(a,b){if(b){Iz(a,v[b>>2]);Iz(a,v[b+4>>2]);Jb(b)}}function Ik(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Jb(Wf(b))}}function Hz(a,b){if(b){Hz(a,v[b>>2]);Hz(a,v[b+4>>2]);Jb(b)}}function Fn(a,b){return(((a<<12&b>>31)+b|0)/4096|0)%(a|0)|0}function F6(a){a=a|0;return C(C(z[Db(a+4208|0,6)>>2]*C(4)))}function ED(a,b){return GA(a,rd(b),Cd(v[b+4>>2],w[b+11|0]))}function nn(a,b,c,d){v[a+16>>2]=d;v[a+12>>2]=c;v[a+8>>2]=b}function nm(a){var b=0;b=v[a>>2];v[b>>2]=v[b>>2]|v[a+4>>2]}function kq(a,b,c){if((a|0)!=(b|0)){b=b-a|0;aj(c-b|0,a,b)}}function jR(a){var b=0;a=a+8|0;b=a>>>0<8?1:b;mb=b;return a}function gY(a,b,c){a=a|0;b=b|0;c=c|0;return((b|0)<0?c:b)|0}function fX(a){a=a|0;a=QN(a,7874);v[a>>2]=41832;return a|0}function Yx(a,b,c){A[a>>3]=A[a>>3]+b;A[a+8>>3]=A[a+8>>3]+c}function R$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;mb=0;return 0}function H2(a){a=a|0;LJ(a,2,100);Ai(v[a+24>>2]+484360|0,0)}function Fb(a){if(Ve(a)){return v[a+4>>2]}return w[a+11|0]}function AW(a){a=a|0;a=FD(a,8606);v[a>>2]=30340;return a|0}function zJ(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){IJ(c)}}function xp(a){return((a-65&255)>>>0<26?a+32|0:a)<<24>>24}function wU(a,b){t[a|0]=w[b|0];t[a+1|0]=w[b+1|0];return a}function eg(a){var b=0;oP(a);b=v[a>>2];if(b){yz(a);Jb(b)}}function bo(a){v[a>>2]=0;v[a+4>>2]=0;Zj(a+8|0,0);return a}function au(a,b){if(Uf(w[a+11|0])){Td(a,b);return}xe(a,b)}function Yw(a,b){return v[((a>>>24^b)<<2)+462064>>2]^a<<8}function VH(a){while(1){if((bs(a)|0)!=-1){continue}break}}function Mt(a,b){var c=0;c=v[a>>2];v[a>>2]=b;if(c){Jb(c)}}function Ko(a){a=ID(a);v[a+8>>2]=0;v[a>>2]=88724;return a}function Ic(a,b){return zE(a,b,2147483647,-2147483648,-1)}function GF(a){if(v[a>>2]){Hc(a);EF(gw(a),v[a>>2],ui(a))}}function Bw(a,b,c){v[a+28>>2]=c;v[a+20>>2]=b;v[a+24>>2]=b}function A2(a,b,c){a=a|0;b=b|0;c=c|0;Jo(a,b,c);return a|0}function $ga(a,b,c){a=a|0;b=b|0;c=c|0;Zf(a,b,ad(b,c)+b|0)}function xt(a,b){oc(a,b);oc(a+4|0,b+4|0);oc(Gb(a),Gb(b))}function xF(a){a=a|0;v[a>>2]=83248;yb(a+16|0);return a|0}function wF(a){a=a|0;v[a>>2]=83208;yb(a+12|0);return a|0}function tm(a){t[a|0]=0;t[a+1|0]=0;t[a+2|0]=0;t[a+3|0]=0}function pH(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;jh(a,-1,-1)}function fz(a,b){A[a>>3]=A[a>>3]*b;A[a+8>>3]=A[a+8>>3]*b}function eN(a,b){a=dN(a,b);dN(a+12|0,b+12|0);t[a+24|0]=1}function ah(a,b){var c=0;c=w[a|0];t[a|0]=w[b|0];t[b|0]=c}function Rt(a){vc(a+88|0);vc(a+68|0);vc(a+48|0);return a}function Q0(a,b,c){a=a|0;b=b|0;c=c|0;return Jd(B(b,c))|0}function PJ(a,b){Lm(v[b>>2]);Pm(v[a>>2]);v[a>>2]=v[b>>2]}function O2(a,b,c){a=a|0;b=b|0;c=c|0;Sc(a,dS(c,b,Ef(b)))}function KI(a){a=a|0;v[a>>2]=60540;fc(a+12|0);return a|0}function CW(a,b,c){a=a|0;b=b|0;c=c|0;uv(a,b,v[b+8>>2],c)}function $i(a){return Pe(a)|Pe(a)<<8|Pe(a)<<16|Pe(a)<<24}function y4(a,b){a=a|0;b=b|0;return Zm(a,b,11737,953)|0}function x6(a){a=a|0;tK(a);t[a+4202|0]=1;v[a+4224>>2]=0}function tv(a){a=a|0;v[a>>2]=91832;eF(a+4|0);return a|0}function raa(a,b,c){a=a|0;b=b|0;c=c|0;nE(a,b,c,749,748)}function pG(a,b,c){a=hc(a,b);hc(a+4|0,v[c>>2]);return a}function ks(a){a=a|0;v[a>>2]=49284;nx(a+4|0);return a|0}function i7(a){a=a|0;return z[Db(a+4208|0,3)>>2]<C(1)|0}function g4(a,b){a=a|0;b=b|0;return Zm(a,b,11640,960)|0}function eF(a){a=dx(v[a>>2]);if((rv(a+8|0)|0)<0){Jb(a)}}function e4(a,b){a=a|0;b=b|0;return mE(a,b,13148,961)|0}function dI(a,b,c){v[a+4>>2]=0;v[a>>2]=b;v[a+8>>2]=c<<3}function co(a,b,c){v[a>>2]=b;v[a+4>>2]=v[c>>2];return a}function YE(a,b,c,d,e){return Ia(a|0,b|0,c|0,d|0,e|0)|0}function YA(a){a=a&255;return Uc(a)^1|(a-49&255)>>>0<36}function Xd(a,b,c){return a>>>0<b>>>0?b:a>>>0<c>>>0?a:c}function V3(a,b){a=a|0;b=b|0;return Zm(a,b,11675,968)|0}function Tc(a){if(Ve(a)){a=ml(a)-1|0}else{a=10}return a}function S3(a,b){a=a|0;b=b|0;return Zm(a,b,11705,970)|0}function Rr(a){a=a|0;v[a>>2]=76208;_b(a+4|0);return a|0}function Qb(a){v[a>>2]=0;v[a+4>>2]=0;Cc(a+8|0);return a}function QI(a){a=a|0;v[a>>2]=61004;fc(a+4|0);return a|0}function Mo(a){var b=0;b=v[a+8>>2];v[a+8>>2]=0;return b}function K3(a,b){a=a|0;b=b|0;return Zm(a,b,11801,973)|0}function JT(a){a=a|0;v[a>>2]=91812;eF(a+4|0);return a|0}function JL(a){return(a|0)==1179012417|(a|0)==538987841}function H6(a){a=a|0;return z[Db(a+4208|0,1)>>2]<C(1)|0}function H3(a,b){a=a|0;b=b|0;return Zm(a,b,11769,974)|0}function En(a){a=a|0;v[a>>2]=76144;_b(a+4|0);return a|0}function DF(a){var b=0;b=v[a>>2];v[a>>2]=0;if(b){Pm(b)}}function AD(a){a=a|0;v[a>>2]=43104;ee(a+4|0);return a|0}function yX(a){a=a|0;a=nb[a|0]()|0;ra(mb|0);return a|0}function y$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;Zf(a,c,d)}function v$(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;sG(a,c,d)}function qn(a,b){v[a+16>>2]=!v[a+24>>2]|(v[a+16>>2]|b)}function mh(a){var b=0;b=bs(a);v[a+1396>>2]=0;return b}function mH(a){a=a|0;return Tr(v[v[a>>2]-12>>2]+a|0)|0}function m9(a,b,c){a=a|0;b=b|0;c=c|0;nE(a,b,c,820,819)}function j_(a,b){a=a|0;b=b|0;gc(a,ZG(v[b>>2]),v[b>>2])}function hp(a){return w[a+2|0]&2?(w[a+1|0]&6)==6?4:1:0}function gH(a){a=a|0;return Sr(v[v[a>>2]-12>>2]+a|0)|0}function cn(a){if(Ve(a)){a=ml(a)-1|0}else{a=1}return a}function ada(a,b){a=a|0;b=b|0;if(!hR(a,b)){Xb(b,0,40)}}function _ga(a,b){a=a|0;b=b|0;return Vb(a,b?b:21473)|0}function ZE(a,b,c,d,e,f){Oa(a|0,b|0,c|0,d|0,e|0,f|0,1)}function Z$(a){a=a|0;return mp(v[v[a>>2]-12>>2]+a|0)|0}function Yb(a,b,c){return(a|0)<(b|0)?b:(a|0)<(c|0)?a:c}function X$(a){a=a|0;return jf(v[v[a>>2]-12>>2]+a|0)|0}function Ng(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+20>>2]](a,b)}function NL(a,b){return B(b&65535,a&65535)+7>>>3&65535}function Ih(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+24>>2]](a,b)}function Hh(a,b){a=a|0;b=b|0;nb[v[v[b>>2]+28>>2]](a,b)}function FL(a,b){return(b>>>0<=15?t[a+b|0]:63)<<24>>24}function EL(a,b){return(b>>>0<=45?t[a+b|0]:63)<<24>>24}function A5(a,b){a=a|0;b=b|0;return mE(a,b,6393,902)|0}function $w(a){return(a&6)==6?384:1152>>>((a&14)==2)|0}function zb(a){if(Uf(w[a+11|0])){Jb(v[a>>2])}return a}function xn(a,b,c,d){return v[(c<<2)+a>>2]+(b+d<<1)|0}function r7(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,b+4228|0,7)}function pv(a,b,c){v[a+4>>2]=c;v[a>>2]=b;if(c){Lm(c)}}function nG(a,b,c){a=uG(a,b,c,0,-2147483648);return a}function nB(a,b){a=ie(a,b);Xb(a+20|0,0,1040);return a}function hga(a,b,c){a=a|0;b=b|0;c=c|0;fS(a,b,Db(b,c))}function fr(a,b){a=jc(a,b);Xb(a+20|0,0,1040);return a}function fc(a){if(v[a>>2]){Hc(a);Jb(v[a>>2])}return a}function en(a,b){return nb[v[v[a>>2]+36>>2]](a,b,0)|0}function dn(a,b){return nb[v[v[a>>2]+52>>2]](a,b,0)|0}function df(a,b,c,d){t[a+8|0]=d;v[a+4>>2]=c;v[a>>2]=b}function b8(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,b+4260|0,8)}function Y1(a,b){a=a|0;b=b|0;ON(v[a>>2],b);return a|0}function Vi(a){a=a|0;return nb[v[v[a>>2]+16>>2]](a)|0}function Vb(a,b){a=a|0;b=b|0;Jo(a,b,Ef(b));return a|0}function Ui(a){a=a|0;return nb[v[v[a>>2]+12>>2]](a)|0}function UK(a){vc(a+36|0);vc(a+24|0);Ds(a+12|0);Ds(a)}function Iy(a){Cp(a+223860|0);fc(a+223848|0);return a}function Ig(a){a=a|0;return nb[v[v[a>>2]+24>>2]](a)|0}function Ff(a,b,c,d){b=b+d|0;mb=a+c>>>0<c>>>0?b+1|0:b}function wz(a){a=Qb(a);v[a+12>>2]=0;u[a+16>>1]=65280}function sU(a,b,c,d){return sr(a,b,c,d,28,153391690)}function qD(a,b,c,d){return sr(a,b,c,d,36,119304648)}function nt(a,b,c){t[a|0]=b;t[a+1|0]=w[c|0];return a}function lq(a,b,c,d,e){gc(a,b+d|0,(e|0)==-1?c-d|0:e)}function lga(a){a=a|0;jm(93216);vA(93208);yb(93196)}
function kfa(a,b,c){a=a|0;b=b|0;c=c|0;qE(a,b,c,13,2)}function hv(a){a=a|0;return nb[v[v[a>>2]+8>>2]](a)|0}function h8(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0}function Ria(a){if(a){return 31-E(a-1^a)|0}return 32}function Ms(a){a=a|0;a=Bh(a);v[a+20>>2]=0;return a|0}function L7(a){a=a|0;t[a+4202|0]=1;Es(a);Hx(a);VK(a)}function $C(a,b){return(w[b+34|0]&8)>>>3&(a&2050)==2}function zfa(a,b,c){a=a|0;b=b|0;c=c|0;qE(a,b,c,5,3)}function wZ(){Od(468728);AF(468736);v[117182]=86096}function uZ(){Od(468744);AF(468752);v[117186]=86252}function uO(a,b){v[a+8>>2]=0;v[a+12>>2]=0;A[a>>3]=b}function tD(a){return FH(a,C(15845632502852868e13))}function pda(a,b,c){a=a|0;b=b|0;c=c|0;Sc(a,Bv(b,c))}function oj(a){if(!a){return 0}return v[a+44>>2]!=0}function kp(a,b){b=v[b>>2];v[a>>2]=b;Lm(b);return a}function jn(a,b,c){v[a>>2]=b;v[a+4>>2]=c-b;return a}function h7(a){a=a|0;return C(z[Db(a+4208|0,1)>>2])}function ega(a,b,c){a=a|0;b=b|0;c=c|0;vE(a,b,c,256)}function de(a){var b=0;b=v[a>>2];v[a>>2]=0;return b}function c1(a,b,c){a=a|0;b=b|0;c=c|0;rI(a-88|0,b,c)}function a1(a,b,c){a=a|0;b=b|0;c=c|0;oI(a-88|0,b,c)}function _ea(a,b){a=a|0;b=b|0;return Fj(a,b,1030)|0}function Yca(a,b){a=a|0;b=b|0;Jo(a,b,12);return a|0}function YT(a,b,c,d){return sr(a,b,c,d,48,89478486)}function Vr(a,b){v[a>>2]=b;v[a+4>>2]=b>>31;return a}function VC(a){return FH(a,C(2524354896707238e-44))}function UN(a,b,c,d){return sr(a,b,c,d,7,613566757)}function Tl(a,b,c){if(!c){return 0}return Pb(a,b,c)}function TC(a){if((a|0)<0){jg();L()}return xc(a<<1)}function Sj(a){if(!a){return 0}return nj(w[a+31|0])}function Rea(a,b){a=a|0;b=b|0;return Uv(a,b,1100)|0}function Qw(a){if(!a){return 0}v[115772]=a;return-1}function P2(a){a=a|0;a=v[a+4>>2];return(a?a:4972)|0}function OC(a,b,c){t[a+8|0]=1;v[a+4>>2]=c;v[a>>2]=b}function Le(a){var b=0;b=v[a>>2];if(b){Gb(a);Jb(b)}}function KK(a){a=a|0;return C(z[Db(a+4208|0,0)>>2])}function Io(a){a=a|0;a=zc(a);nb[v[v[a>>2]>>2]](a)|0}function G6(a){a=a|0;return C(z[Db(a+4208|0,3)>>2])}function Fz(a){t[a+6|0]=0;u[a+4>>1]=65535;v[a>>2]=0}function Co(a,b,c){gc(a,(c>>>3&536870908)+b|0,c&31)}function Bv(a,b){a=a|0;b=b|0;return GA(a,b,Ef(b))|0}function Bb(a,b,c){gc(a,(c>>>3&536870908)+b|0,1<<c)}function rl(a,b){return(a&65535)>>>0<(b&65535)>>>0}function qo(a){a=(a|0)<120?a:120;return(a|0)>1?a:1}function hfa(a,b){a=a|0;b=b|0;if(!yu(a,b)){Du(b)}}
function gS(a,b,c){a=a|0;b=b|0;c=c|0;Sc(a,yF(b,c))}function g1(a,b){a=a|0;b=b|0;return Uo(a,b,1047)|0}function e1(a,b,c){a=a|0;b=b|0;c=+c;tI(a-88|0,b,c)}function b1(a,b){a=a|0;b=b|0;return pI(a-88|0,b)|0}function Wn(a,b,c){if((a|0)!=(b|0)){aj(c,a,b-a|0)}}function Vl(a){hj(a+724|0);hj(a+732|0);hj(a+740|0)}function Vfa(a,b){a=a|0;b=b|0;return Fj(a,b,422)|0}function U0(a,b,c){a=a|0;b=b|0;c=+c;iI(a-92|0,b,c)}function S0(a,b,c){a=a|0;b=b|0;c=+c;gI(a-92|0,b,c)}function Pfa(a,b){a=a|0;b=b|0;return Fj(a,b,826)|0}function K0(a,b){a=a|0;b=b|0;return Uo(a,b,1049)|0}function I0(a,b){a=a|0;b=b|0;return Uo(a,b,1050)|0}function F0(a,b){a=a|0;b=b|0;return Uo(a,b,1051)|0}function B2(a,b){a=a|0;b=b|0;return Uo(a,b,1046)|0}function $D(a,b,c){a=a|0;b=b|0;c=c|0;Sc(a,ED(b,c))}function $0(a,b){a=a|0;b=b|0;return nI(a-88|0,b)|0}function yS(a){return(v[Gb(a)>>2]-v[a>>2]|0)/33|0}function wga(a,b){a=a|0;b=b|0;if(!wS(a,b)){vS(b)}}function wB(a){return(v[Gb(a)>>2]-v[a>>2]|0)/28|0}function via(a,b){a=a|0;b=b|0;if(!cU(a,b)){mu(b)}}function tn(a,b,c){v[a>>2]=b;v[a+4>>2]=c;return a}function pC(a){return(v[Gb(a)>>2]-v[a>>2]|0)/20|0}function o6(a,b){a=a|0;b=b|0;return C(yl(a,b,12))}function nv(a){return(v[Gb(a)>>2]-v[a>>2]|0)/36|0}function k4(a){a=a|0;return Wv(a,12655,1074416)|0}function j9(a,b){a=a|0;b=b|0;return Fj(a,b,225)|0}function iT(a){if(!(a&255)){return 1}return Uc(a)}function gc(a,b,c){v[a+4>>2]=c;v[a>>2]=b;return a}function g9(a,b){a=a|0;b=b|0;return Fj(a,b,326)|0}function cF(a){return(a<<1)+16777216>>>0<16777217}function aga(a,b){a=a|0;b=b|0;if(!fD(a,b)){Yq(b)}}function Wk(a,b,c){A[a+8>>3]=c;A[a>>3]=b;return a}function VT(a){return(v[Gb(a)>>2]-v[a>>2]|0)/48|0}function VQ(a){return(v[Gb(a)>>2]-v[a>>2]|0)/56|0}function Up(a,b,c){return v[(b<<2)+a>>2]+(c<<2)|0}function Qs(a){return(v[Gb(a)>>2]-v[a>>2]|0)/52|0}function Mh(a,b){if(Ve(a)){Td(a,b);return}xe(a,b)}function Lt(a){return(v[Gb(a)>>2]-v[a>>2]|0)/24|0}function KL(a,b){return(a|0)==1179011410&b>>>0>80}function IG(a){return(Mj(a)|0)!=0|(a|32)-97>>>0<6}function ID(a){v[a+4>>2]=0;v[a>>2]=91284;return a}function Hea(a,b){a=a|0;b=b|0;return Fj(a,b,71)|0}function FD(a,b){a=DD(a,b);v[a>>2]=92092;return a}function Ep(a,b){v[a+4>>2]=256;v[a>>2]=b;return a}function Ej(a){return(v[Gb(a)>>2]-v[a>>2]|0)/12|0}function CC(a){return!Pb(a,26016,25)&w[a+34|0]<65}function Bga(a,b){a=a|0;b=b|0;return Fj(a,b,91)|0}function $l(a,b,c){v[a+4>>2]=c;u[a>>1]=b;return a}function zA(a,b){a=a|0;b=b|0;if(!IS(a,b)){FA(b)}}function z6(a,b){a=a|0;b=b|0;return C(yl(a,b,1))}function rx(a,b){v[a>>2]=v[b>>2];Sc(a+4|0,b+4|0)}function rT(a,b){v[a>>2]=v[a>>2]+B(b,6);return a}function r9(a,b){a=a|0;b=b|0;if(!nD(a,b)){zv(b)}}function pq(a,b){a=a|0;b=b|0;if(!Xh(a,b)){ul(b)}}function o4(a){a=a|0;return RE(a,8698,1074448)|0}function m7(a,b){a=a|0;b=b|0;return C(yl(a,b,6))}function lz(a){v[a+24>>2]=x[a+20>>1]<<x[a+22>>1]}function lu(a){return(v[Gb(a)>>2]-v[a>>2]|0)/6|0}function l9(a,b){a=a|0;b=b|0;return Fj(a,b,73)|0}function l4(a){a=a|0;return Wv(a,5280,1074424)|0}function ko(a,b,c){t[a+2|0]=c;u[a>>1]=b;return a}function kU(a,b){a=UT(a,b);if(!a){tB(b)}return a}function gV(a,b){a=a|0;b=b|0;if(!ZB(a,b)){Eu(b)}}function g6(a,b){a=a|0;b=b|0;return C(yl(a,b,2))}function fd(a,b,c,d){return Dd(a,B(Eg(b),c)+d|0)}function eJ(a,b){a=a|0;b=b|0;qk(a,b,57624,57632)}function e9(a,b){a=a|0;b=b|0;return Fj(a,b,60)|0}function dJ(a,b){a=a|0;b=b|0;qk(a,b,57640,57648)}function d1(a,b){a=a|0;b=b|0;return+sI(a-88|0,b)}function bN(a,b,c){v[a+4>>2]=c;t[a|0]=b;return a}function aJ(a,b){a=a|0;b=b|0;qk(a,b,58444,58452)}function a7(a,b){a=a|0;b=b|0;return C(yl(a,b,5))}function _I(a,b){a=a|0;b=b|0;qk(a,b,58460,58468)}function _5(a,b){a=a|0;b=b|0;return C(yl(a,b,3))}function ZI(a,b){a=a|0;b=b|0;qk(a,b,59272,59280)}function Yy(a){return(v[Gb(a)>>2]-v[a>>2]|0)/7|0}function YI(a,b){a=a|0;b=b|0;qk(a,b,59288,59296)}function WO(a,b){v[a>>2]=v[a>>2]+(b<<1);return a}function VI(a,b){a=a|0;b=b|0;qk(a,b,60100,60108)}function V6(a,b){a=a|0;b=b|0;return C(yl(a,b,4))}function TI(a,b){a=a|0;b=b|0;qk(a,b,60116,60124)}function T0(a,b){a=a|0;b=b|0;return+hI(a-92|0,b)}function SB(a,b){a=a|0;b=b|0;if(!vD(a,b)){uD(b)}}function R0(a,b){a=a|0;b=b|0;return+fI(a-92|0,b)}function QT(a,b){a=a|0;b=b|0;if(!PT(a,b)){ku(b)}}function Og(a,b,c){var d=0;d=a;a=b;jn(d,a,a+c|0)}function Lo(a,b,c){a=$d(a);v[a+4>>2]=c;v[a>>2]=b}function Jia(a,b){a=a|0;b=b|0;return su(a,1,b)|0}function Iu(a,b){a=a|0;b=b|0;if(!Uq(a,b)){Iq(b)}}function Hs(a){a=a|0;vc(a+4208|0);return uf(a)|0}function EK(a){a=a|0;vc(a+4256|0);return uf(a)|0}function $K(a){a=a|0;fc(a+4208|0);return uf(a)|0}function xH(a,b){if(!a){return 0}return Ow(a,b)}function wia(a,b,c){a=a|0;b=b|0;c=c|0;_B(a,b,c)}function vk(a){return nb[v[v[a>>2]+36>>2]](a)|0}function td(a,b){return cp(v[b>>2],v[a>>2])?b:a}function rH(a,b,c){a=a|0;b=b|0;c=c|0;return a|0}function qq(a,b,c){if(b){Xb(a,Lf(c),b)}return a}function mn(a){return nb[v[v[a>>2]+28>>2]](a)|0}function m4(a){a=a|0;return RE(a,7071,480214)|0}function cia(a,b){a=a|0;b=b|0;Wo(a,b,340,339,8)}function Zc(a,b){return rl(x[b>>1],x[a>>1])?b:a}function Yc(a,b){return aq(v[a>>2],v[b>>2])?b:a}function Wt(a,b){a=a|0;b=b|0;return Ob(a,b,1)^1}function We(a,b){return rl(x[a>>1],x[b>>1])?b:a}function WB(a,b){return(b&255)==2&(a&255)>>>0<3}function VR(a){var b=0;b=v[a>>2];Be(a);return b}function Tea(a,b){a=a|0;b=b|0;Wo(a,b,574,573,8)}function S2(a){a=a|0;return ME(a,49032,12379)|0}function Ol(a,b){return Vt(z[b>>2],z[a>>2])?b:a}function Ne(a,b){return cp(v[a>>2],v[b>>2])?b:a}function Ly(a){if(w[a+24|0]){iN(a);t[a+24|0]=0}}function L3(a){a=a|0;return Wv(a,5777,480272)|0}function KV(a,b){a=a|0;b=b|0;Fp(a,b);return a|0}function Ib(a,b){return aq(v[b>>2],v[a>>2])?b:a}function Gx(a,b){return Vt(z[a>>2],z[b>>2])?b:a}function Eh(a,b,c){return Ja(914,a|0,b|0,c|0)|0}function Dga(a,b){a=a|0;b=b|0;Wo(a,b,454,453,6)}function Bea(a,b){a=a|0;b=b|0;Wo(a,b,605,604,8)}function BS(a){return!Pb(a,13720,4)&w[a+4|0]<32}function AF(a){var b=0,c=0;b=a,c=Bd(),v[b>>2]=c}function zO(a){gz(a);Xb(a+27|0,0,255);return a}function wu(a,b,c){a=a|0;b=b|0;c=c|0;BU(a,b,c)}function uh(a,b){t[a+4|0]=0;v[a>>2]=b;return a}function p8(a,b,c){a=a|0;b=b|0;c=c|0;YK(a,b,c)}function m6(a){a=a|0;pK(a);xx(a);t[a+4202|0]=1}function lt(a){return(a>>>0<9?a:a-9|256)&65535}function hf(a,b,c){if(!(w[a|0]&32)){zB(b,c,a)}}function bg(a,b,c){a=Tia(a,b,c,c>>31);return a}function bP(a){v[a>>2]=0;v[a+4>>2]=-1;return a}function aY(a,b,c){a=a|0;b=b|0;c=c|0;gc(a,c,b)}function _m(a,b,c,d,e){Sa(a|0,b|0,c|0,d|0,e|0)}function _6(a){a=a|0;t[a+4202|0]=1;AK(a);CK(a)}function T6(a){a=a|0;t[a+4202|0]=1;yK(a);wK(a)}function Sea(a,b){a=a|0;b=b|0;return hR(a,b)|0}function RU(a,b){a=a|0;b=b|0;Wo(a,b,281,280,8)}function R2(a){a=a|0;return ME(a,49052,8109)|0}function NA(a,b,c){a=a|0;b=b|0;c=c|0;XB(a,b,c)}function HB(a){return!Pb(a,15236,4)&w[a+4|0]<4}function Er(a,b){return(a&255)>>>0<(b&255)>>>0}function Cz(a){return a>>>0<=45?w[a+43680|0]:0}function C2(a,b){a=a|0;b=b|0;Sc(a,KJ(b,17462))}function $j(a,b){return(B(b,104)+a|0)+484380|0}function yc(a,b){if(y[a>>2]>b>>>0){v[a>>2]=b}}function yb(a){if(Ve(a)){Jb(v[a>>2])}return a}function xs(a){a=OJ(a);v[a>>2]=77440;return a}function xU(a,b){a=a|0;b=b|0;return yF(a,b)|0}function vga(a,b){a=a|0;b=b|0;Qv(a,b,17,3,16)}function ug(a,b){if(x[a>>1]>b>>>0){u[a>>1]=b}}function sH(a,b){a=a|0;b=b|0;return ED(a,b)|0}function rW(a){a=a|0;v[a>>2]=61060;return a|0}function nw(a,b,c){a=uG(a,b,c,-1,-1);return a}function mt(a,b){a=a|0;b=b|0;return Rh(a,b)|0}function lH(a){a=a|0;Gw(v[v[a>>2]-12>>2]+a|0)}function jQ(a){return Ie(443250/+(a>>>0)*1e4)}function hU(a){t[a+12|0]=w[a+12|0]|2;return a}function gX(a,b){a=a|0;b=b|0;return aE(a,b)|0}function fW(a){a=a|0;v[a>>2]=42968;return a|0}function fH(a){a=a|0;Ew(v[v[a>>2]-12>>2]+a|0)}function ep(a,b){a=a|0;b=b|0;return kH(a,b)^1}function ef(a,b){return Er(w[a|0],w[b|0])?b:a}function dW(a){a=a|0;v[a>>2]=42728;return a|0}function _k(a,b,c,d){return(b-d|0)+(a-c<<3)|0}function ZJ(a,b){a=a|0;b=b|0;return KJ(a,b)|0}function Yi(a,b){a=a|0;b=b|0;return kH(a,b)|0}function Y$(a){a=a|0;VG(v[v[a>>2]-12>>2]+a|0)}function Wh(a,b){if(v[a>>2]>(b|0)){v[a>>2]=b}}function Wb(a,b){return Er(w[b|0],w[a|0])?b:a}function W$(a){a=a|0;UG(v[v[a>>2]-12>>2]+a|0)}function Via(a,b,c,d){a=Qia(a,b,c,d);return a}function UW(a,b){a=a|0;b=b|0;return Bv(a,b)|0}function U8(a,b){a=a|0;b=b|0;oy(AL(a+24|0,b))}function Sha(a,b){a=a|0;b=b|0;xE(a,b,344,343)}function Qr(a,b){a=a|0;b=b|0;return $G(a,b)^1}function Ox(a){return v[Gb(a)>>2]-v[a>>2]>>11}function Od(a){a=ID(a);v[a>>2]=83536;return a}function Nl(a){a=Ll(a);v[a>>2]=91696;return a}function MG(a){a=OJ(a);v[a>>2]=77832;return a}function Kj(a,b){a=a|0;b=b|0;return $G(a,b)|0}function KQ(a){a=Sia(a&65535,0,80,0);return a}function K1(a){a=a|0;v[a>>2]=60640;return a|0}function Iia(a,b){a=a|0;b=b|0;xE(a,b,287,286)}function HJ(a){a=a|0;v[a>>2]=49116;return a|0}function HF(a,b,c){a=a|0;b=b|0;c=c|0;return-1}function Gm(a){return(a>>>0>127?a^128:-1)&255}function FU(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function D1(a){a=a|0;v[a>>2]=60140;return a|0}function CT(a){mb=0;a=(a&65535)-98|0;return a}function $d(a){v[a>>2]=0;v[a+4>>2]=0;return a}function zZ(a){a=a|0;Vd(a,468688,Pd(467096))}function yz(a){return v[zc(a)>>2]-v[a>>2]>>2}function yZ(a){a=a|0;Vd(a,468696,Pd(467008))}function xZ(a){a=a|0;Vd(a,468712,Pd(467016))}function w4(a){a=a|0;return UE(a,7015,957)|0}function vZ(a){a=a|0;Vd(a,468728,Pd(467024))}function ui(a){return v[Gb(a)>>2]-v[a>>2]>>2}function tZ(a){a=a|0;Vd(a,468744,Pd(467032))}function sh(a){return v[v[a+8>>2]>>2]==(a|0)}function sZ(a){a=a|0;Vd(a,468760,Pd(467104))}function rZ(a){a=a|0;Vd(a,468768,Pd(467112))}function pw(){ha(Nl(ba(4)|0)|0,91780,25);L()}function or(a){return v[Gb(a)>>2]-v[a>>2]>>4}function lea(a,b){a=a|0;b=b|0;Rv(a,b,1042,2)}function ho(a){return v[Gb(a)>>2]-v[a>>2]>>5}function hF(a,b,c){a=a|0;b=b|0;c=c|0;TG(a,c)}function gha(a,b){a=a|0;b=b|0;qr(a,b,1042,2)}function c4(a){a=a|0;return UE(a,6552,965)|0}function ZR(a){if(a){YH(a);se(v[a+80>>2],a)}}function XZ(a){a=a|0;Vd(a,468448,Pd(466960))}function XE(a){a=Ga(a|0)|0;mb=O()|0;return a}function Wj(a){return oE(a,C(4294967296),-1)}function WZ(a){a=a|0;Vd(a,468456,Pd(466968))}function VZ(a){a=a|0;Vd(a,468464,Pd(467164))}function UZ(a){a=a|0;Vd(a,468480,Pd(467156))}function TZ(a){a=a|0;Vd(a,468488,Pd(467172))}function SR(a,b,c,d){return(B(b,d)+c<<1)+a|0}function RZ(a){a=a|0;Vd(a,468496,Pd(467180))}function Qm(a){return v[Gb(a)>>2]-v[a>>2]>>3}function QZ(a){a=a|0;Vd(a,468512,Pd(467188))}function Q1(a){a=a|0;PI(a);return v[a+16>>2]}function Pg(a,b,c,d){return(B(b,d)+c<<3)+a|0}function PZ(a){a=a|0;Vd(a,468520,Pd(467204))}function Oj(a){a=a&255;return(a|0)==255?-1:a}function OZ(a){a=a|0;Vd(a,468528,Pd(467196))}function OU(a,b){a=a|0;b=b|0;Qv(a,b,44,2,44)}function NZ(a){a=a|0;Vd(a,468536,Pd(467212))}function MZ(a){a=a|0;Vd(a,468544,Pd(467220))}function Lz(a){return v[Gb(a)>>2]-v[a>>2]>>8}function LZ(a){a=a|0;Vd(a,468568,Pd(467228))}function Kx(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0}function Kh(a,b,c,d){return(B(b,d)+c<<2)+a|0}function KZ(a){a=a|0;Vd(a,468600,Pd(466976))}function JZ(a){a=a|0;Vd(a,468608,Pd(466984))}function IZ(a){a=a|0;Vd(a,468616,Pd(466992))}function IJ(a){if(a){nb[v[v[a>>2]+4>>2]](a)}}function H0(a){a=a|0;return ib(v[a+60>>2])|0}function Gy(a){t[a+24|0]=0;t[a|0]=0;return a}function Go(a,b,c,d){a=Tia(a,b,c,d);return a}function GZ(a){a=a|0;Vd(a,468632,Pd(467040))}function Fm(a){return v[Gb(a)>>2]-v[a>>2]>>1}function FZ(a){a=a|0;Vd(a,468640,Pd(467048))}function EZ(a){a=a|0;Vd(a,468648,Pd(467056))}function DZ(a){a=a|0;Vd(a,468656,Pd(467064))}function Cd(a,b){if(!Uf(b)){a=Lf(b)}return a}function CZ(a){a=a|0;Vd(a,468664,Pd(467072))}function BZ(a){a=a|0;Vd(a,468672,Pd(467080))}function Ax(a){return C(C(a*C(7900))+C(100))}function AZ(a){a=a|0;Vd(a,468680,Pd(467088))}function xm(a,b,c){return pf(a,b)>>>0>c>>>0}function u0(a,b){a=a|0;b=b|0;qr(a,b,1025,2)}function tc(a){if(Ve(a)){a=v[a>>2]}return a}function rj(a,b,c){if(c){aj(a,b,c)}return a}function on(a){a=a|0;ZG(v[a>>2]);return a|0}function nf(a,b){if(w[a|0]>b>>>0){t[a|0]=b}}function lX(a,b){a=a|0;b=b|0;Nv(a,b,1058,2)}function jo(a,b){u[a>>1]=b;u[a+2>>1]=b>>>16}function ii(a,b){a=a|0;b=b|0;return C(C(0))}function gJ(a){t[a+4|0]=0;t[a|0]=0;return a}function cK(a){return Oh(C(eK(a)*C(32768)))}function Zk(a,b){return a<<24>>24<b<<24>>24}function Yj(a,b){return a<<16>>16<b<<16>>16}function XA(a,b){v[a>>2]=v[a>>2]+b;return a}function R1(a){a=a|0;PI(a);return v[a+4>>2]}function NK(a){a=a|0;nb[v[v[a>>2]+4>>2]](a)}function JF(a,b,c){return qv(IF(a),IF(b),c)}function I8(a,b){a=a|0;b=b|0;qr(a,b,1058,1)}function Hl(a){a=a|0;Fw(v[a>>2]);return a|0}function He(a,b,c){if(c){qc(a,b,c)}return a}function HZ(a){a=a|0;Vd(a,468624,Pd(467e3))}function B0(a,b){a=a|0;b=b|0;qr(a,b,1025,4)}function $o(a){return v[Gb(a)>>2]-v[a>>2]|0}function $U(a,b){a=a|0;b=b|0;Rv(a,b,1025,2)}function zw(a){a=a|0;return zh(a,467172)|0}function xk(a,b){nb[v[v[b>>2]+44>>2]](a,b)}function xW(a){a=a|0;return v[a+4>>2]!=0|0}function wr(a,b){nb[v[v[b>>2]+40>>2]](a,b)}function wk(a,b){nb[v[v[b>>2]+32>>2]](a,b)}function vw(a){a=a|0;return zh(a,467180)|0}function t0(a){a=a|0;return zh(a,466976)|0}function sz(a){v[a>>2]=v[a>>2]+32;return a}function sM(a){v[a>>2]=v[a>>2]+52;return a}function rm(a){v[a>>2]=v[a>>2]+28;return a}function qw(a){a=a|0;return zh(a,467220)|0}function ml(a){return v[a+8>>2]&2147483647}function mX(a,b){a=a|0;b=b|0;Nv(a,b,290,0)}function l0(a){a=a|0;return zh(a,466992)|0}function kw(a){a=a|0;return zh(a,467228)|0}function jd(a,b){a=a|0;b=b|0;YK(a,b,Ef(b))}function iK(a){return C(C(a*C(96))+C(-96))}function hm(a){uz(v[a+20>>2]);v[a+20>>2]=0}function ff(a,b,c){a=Sia(c,0,a,b);return a}function f8(a,b){a=a|0;b=b|0;t[a+4201|0]=b}function es(a){return(a|0)<=65535&(a|0)>=0}function eo(a){v[a>>2]=v[a>>2]+16;return a}function cN(a,b){return BE(a,b,2147483647)}function _q(a){gr(a+32|0);Ab(a+12|0);zb(a)}function Xu(a){a=a|0;return zh(a,467164)|0}function Xda(a,b){a=a|0;b=b|0;uE(a,b,2,31)}function WP(a,b,c,d){gc(a,b,(d|0)==-1?c:d)}function Pk(a){yb(a+36|0);vc(a+24|0);gk(a)}function PU(a,b){a=a|0;b=b|0;Rv(a,b,274,0)}function IW(a,b){a=a|0;b=b|0;Nv(a,b,257,0)}function FH(a,b){return C(EH(a?C(-b):b)*b)}function Et(a){Le(a+24|0);fc(a+12|0);fc(a)}function E7(a,b,c){a=a|0;b=b|0;c=c|0;$d(a)}function Cw(a){a=a|0;return zh(a,467156)|0}function $p(a){v[a>>2]=v[a>>2]+12;return a}function yF(a,b){return vr(a,Jc(b),Fb(b))}function w1(a,b){a=a|0;b=b|0;Sm(a,b+12|0)}function uH(a,b){t[a|0]=b+48;return a+1|0}function tia(a,b){a=a|0;b=b|0;uE(a,b,3,8)}function n1(a,b){a=a|0;b=b|0;CI(a-88|0,b)}function m1(a,b){a=a|0;b=b|0;AI(a-88|0,b)}function kk(a){v[a>>2]=v[a>>2]+6;return a}function kI(a,b){a=a|0;b=b|0;JE(a,b,2048)}function jK(a){a=a|0;Xb(a+4296|0,0,81928)}function jI(a,b){a=a|0;b=b|0;JE(a,b,4096)}function ix(a,b,c,d){return Up(a,c,b+d|0)}function it(a){v[a>>2]=v[a>>2]+8;return a}function gfa(a,b){a=a|0;b=b|0;Mi(a,b,274)}function ds(a){a=a|0;ys(a+8|0);return a|0}function dk(a,b){return v[a>>2]-v[b>>2]|0}function bfa(a,b){a=a|0;b=b|0;Mi(a,b,106)}function Z0(a,b){a=a|0;b=b|0;lI(a-88|0,b)}function W0(a,b){a=a|0;b=b|0;kI(a-92|0,b)}function V0(a,b){a=a|0;b=b|0;jI(a-92|0,b)}function UO(a){v[a>>2]=v[a>>2]-2;return a}function Tr(a){a=a|0;Fk(a+8|0);return a|0}function Sr(a){a=a|0;Fk(a+4|0);return a|0}function Se(a){v[a>>2]=v[a>>2]+2;return a}function OY(a,b){a=a|0;b=b|0;Rh(a,b+16|0)}function Nia(a,b){a=a|0;b=b|0;Mi(a,b,136)}function Mf(a){a=a|0;Bh(a+8|0);return a|0}function MU(a,b){a=a|0;b=b|0;Po(a+12|0,b)}function M8(a,b){a=a|0;b=b|0;Rh(a,b+36|0)}function LN(a,b){if(z[a>>2]>b){z[a>>2]=b}}function IY(a,b){a=a|0;b=b|0;Rh(a,b+12|0)}function IU(a,b){a=a|0;b=b|0;Bq(a+36|0,b)}function Gf(a,b){v[a>>2]=v[b>>2];return a}function F9(a,b){a=a|0;b=b|0;Po(a+40|0,b)}function Ek(a){a=a|0;return jH(a)<<24>>24}function Ce(a){v[a>>2]=v[a>>2]+4;return a}function Be(a){v[a>>2]=v[a>>2]+1;return a}function yJ(a){return(tc(a)+Fb(a)|0)-1|0}function uq(a,b){t[a|0]=b;t[a+1|0]=b>>>8}function uga(a,b){a=a|0;b=b|0;Fq(a,b,17)}function s7(a){a=a|0;t[a+4202|0]=1;QK(a)}function r6(a){a=a|0;return v[a+4260>>2]}function p1(a){a=a|0;return ds(a-88|0)|0}function mk(a){return B(Hm(a),Gd(a))&255}function mS(a,b){a=a|0;b=b|0;Mi(a,b,284)}function lc(a){v[v[a>>2]+4>>2]=v[a+4>>2]}function l1(a,b){a=a|0;b=+b;zI(a-88|0,b)}function j1(a,b){a=a|0;b=+b;xI(a-88|0,b)}function hj(a){u[a+4>>1]=65535;v[a>>2]=0}function h1(a,b){a=a|0;b=+b;vI(a-88|0,b)}function dga(a,b){a=a|0;b=b|0;Mi(a,b,42)}function Zha(a,b){a=a|0;b=b|0;Mi(a,b,34)}function ZM(a,b,c){v[a>>2]=b;v[a+4>>2]=c}function Y0(a){a=a|0;return ds(a-92|0)|0}function Ud(a,b){return(b|0)!=0&(a|0)!=0}function Pr(a,b){v[a+24>>2]=v[a+24>>2]+b}function Nh(a,b){return v[a>>2]!=v[b>>2]}function NY(a,b){a=a|0;b=b|0;bn(a,83280)}function MY(a,b){a=a|0;b=b|0;bn(a,83300)}function Kr(a){a=a|0;Tv(a,156,92140,954)}function KD(a,b){oc(a,b);oc(a+4|0,b+4|0)}function HY(a,b){a=a|0;b=b|0;Vb(a,11138)}function GY(a,b){a=a|0;b=b|0;Vb(a,11255)}function Ak(a){return(a|0)==32|a-9>>>0<5}function Af(a,b){v[a+8>>2]=b|-2147483648}function $ea(a,b){a=a|0;b=b|0;Mi(a,b,72)}function wV(a,b){a=a|0;b=b|0;Mi(a,b,59)}function tga(a,b){a=a|0;b=b|0;aC(a,b,8)}function qI(a){v[a+4>>2]=v[a+4>>2]|8192}function lV(a,b){a=a|0;b=b|0;Fq(a,b,11)}function lF(a,b){a=a|0;b=b|0;return b|0}function e8(a){a=a|0;return w[a+4201|0]}function d8(a){a=a|0;return w[a+4202|0]}function _S(a,b){a=a|0;b=b|0;Fq(a,b,32)}function Yg(a,b,c){t[a+4|0]=c;v[a>>2]=b}function XM(a,b){return(Xk(a,b)|0)!=255}function UF(a,b){a=a|0;b=b|0;Je(a,1,45)}function Ty(a,b,c){return a<b?b:a>c?c:a}function Tj(a,b){return Jy(a&255,b&255)}function Tca(a,b){a=a|0;b=b|0;rE(a,b,3)}function TF(a,b){a=a|0;b=b|0;aG(a,1,45)}function Sy(a,b,c){return a<b?b:a>c?c:a}function Sh(a){return(a&65535)>>>0<3999}function Rw(a){return(p(a),j(2))>>>20|0}function RQ(a,b,c,d){return _k(c,d,a,b)}function R5(a){a=a|0;return(a|0)==277|0}function Om(a){a=v[a+8>>2];if(a){Jb(a)}}function Mb(a){return(a<<8|a>>>8)&65535}function EB(a,b){a=a|0;b=b|0;Mi(a,b,50)}function $m(a,b,c){return Zf(a,b,b+c|0)}function xr(a){a=a|0;return 2147483647}function vJ(a){return a?(a|0)==2?3:2:1}function pk(a,b){v[a+4>>2]=2;v[a>>2]=b}function oA(a,b){a=a|0;b=b|0;rE(a,b,2)}function ke(a,b,c){jn(a,b,ad(b,c)+b|0)}function k1(a){a=a|0;return+yI(a-88|0)}function jW(a){a=a|0;return v[a+16>>2]}function jP(a,b,c){return yE(a,b,c,41)}function ij(a,b){return tc(a)+(b<<2)|0}function i1(a){a=a|0;return+wI(a-88|0)}function f1(a){a=a|0;return+uI(a-88|0)}function eL(a){a=a|0;return 1869112133}function dV(a){a=a|0;return v[a+12>>2]}function a6(a){a=a|0;return-2013527448}function Xi(a,b){v[a+4>>2]=1;v[a>>2]=b}function Vy(a,b){return zE(a,b,-1,0,0)}function Vg(a){return oE(a,C(255),255)}function Sca(a){a=a|0;FQ(a);return a|0}function Qu(a,b,c){return rr(a,b,c,20)}function Id(a){v[v[a+8>>2]>>2]=v[a>>2]}function Hv(a,b){v[a+4>>2]=4;v[a>>2]=b}function Av(a,b){v[a+4>>2]=3;v[a>>2]=b}function At(a,b,c){return rr(a,b,c,12)}function $T(a,b,c){return rr(a,b,c,48)}function yD(a,b,c){ic(a,b,Hg(b,c)<<3)}function sJ(a){a=C(a-a);return C(a/a)}function s6(a){a=a|0;return-275227023}function ro(a,b){u[a+8>>1]=b;return a}function pf(a,b){return ik(a,b)&65535}function oq(a,b,c){return rr(a,b,c,6)}function om(a){return(a&740327453)!=0}function ol(a,b,c){return pr(a,b,c,2)}function o7(a){a=a|0;return-270114148}function nj(a){return(a-1&255)>>>0<17}function kJ(a){v[a>>2]=49364;return a}function kH(a,b){return iH(a)^iH(b)^1}function i6(a){a=a|0;return 302837129}function gE(a,b,c){return pr(a,b,c,4)}function fi(a,b,c){Sc(Sc(a,b)+12|0,c)}function fJ(a){v[a>>2]=57608;return a}function d7(a){a=a|0;return-285139079}function ar(a,b,c){return Vo(a,b,c,3)}function ai(a){a=v[a>>2];if(a){wG(a)}}function _J(a,b){a=a|0;b=b|0;return 0}function Z7(a){a=a|0;return 542066252}function X6(a){a=a|0;return-284078960}function Ve(a){return w[a+11|0]>>>7|0}function Ur(a,b){a=a|0;b=b|0;return-1}function U5(a,b){a=a|0;b=b|0;return 3}function To(a,b,c){return Vo(a,b,c,4)}function S5(a,b){a=a|0;b=b|0;return 2}function Qf(a,b,c){return fd(a,b,c,0)}function Q6(a){a=a|0;return-281111764}function Ph(a,b,c){return Vo(a,b,c,2)}function OJ(a){v[a>>2]=77468;return a}function Nm(a){v[a>>2]=60592;return a}function M1(a){a=a|0;return w[a+40|0]}function Lx(a,b){a=a|0;b=b|0;return 1}function Lq(a){a=a|0;return v[a+4>>2]}function Ll(a){v[a>>2]=92392;return a}function L$(a){a=a|0;return KG(a,0)|0}function Kia(a,b){a=a|0;b=b|0;et(a,b)}function Ke(a,b){v[a+4>>2]=b;return a}function KJ(a,b){return vr(a,b,Ef(b))}function K$(a){a=a|0;return KG(a,1)|0}function JP(a,b,c){return pr(a,b,c,5)}function J6(a){a=a|0;return-271958638}function IL(a,b){_c(a,b&4?16:8,1,0,0)}function HD(a){a=a|0;return v[a+8>>2]}function Fi(a,b,c){return Vo(a,b,c,1)}function FI(a){v[a>>2]=61832;return a}function Eo(a,b,c){return pr(a,b,c,1)}function EN(a,b){return(0-b|0)!=(a|0)}function EI(a){v[a>>2]=61856;return a}function E$(a){a=a|0;return JG(a,0)|0}function Dz(a,b,c){return Vo(a,b,c,5)}function DI(a){v[a>>2]=61936;return a}function D$(a){a=a|0;return JG(a,1)|0}function CS(a,b,c){ic(a,b,wc(b,c)<<2)}function CP(a){return(a&65535)==65534}function B6(a){a=a|0;return-620920304}function $G(a,b){return _G(a)^_G(b)^1}function xP(a,b,c,d){tP(gc(a,b,c),d)}function wx(a){a=a|0;lE(a,48952,905)}function vs(a){return x[a+480192>>1]}function vq(a,b){a=a|0;b=b|0;Fx(a,b)}function vj(a,b){a=a|0;b=b|0;KB(a,b)}function us(a){return x[a+480190>>1]}function sx(a,b){a=a|0;b=b|0;Sm(a,b)}function rt(a){return v[Gb(a)>>2]<<5}function rs(a,b){a=a|0;b=b|0;sx(a,b)}function nN(a){return(a+5&255)>>>0<2}function lia(a){a=a|0;return LT(a)|0}function jaa(a){a=a|0;return Ig(a)|0}function hX(a,b){a=a|0;b=b|0;AM(a,b)}function gi(a,b){a=a|0;b=b|0;Rh(a,b)}function gK(a){v[a>>2]=0;v[a+4>>2]=0}function eu(a,b){return w[a+b|0]!=63}function cL(a,b,c){a=a|0;b=b|0;c=c|0}function _g(a){dl(a+44|0);fc(a+32|0)}function Vm(a,b){a=a|0;b=b|0;rs(a,b)}function VP(a,b){return B(b,872)+a|0}function VJ(a){a=a|0;lE(a,48896,903)}function Uca(a){a=a|0;return ri(a)|0}function TW(a,b){a=a|0;b=b|0;cE(a,b)}function OI(a,b,c,d,e){UI(a,b,c,d,e)}function Mq(a,b){a=a|0;b=b|0;lv(a,b)}function Lm(a){v[a+4>>2]=v[a+4>>2]+1}function KY(a){a=a|0;return t[a+8|0]}function JY(a){a=a|0;return t[a+9|0]}function JR(a,b){if(!DR(a,b)){cA(b)}}function HA(a,b){a=a|0;b=b|0;rJ(a,b)}function H1(a){a=a|0;return w[a+8|0]}function Fx(a,b){a=a|0;b=b|0;gi(a,b)}function Eg(a){return x[a+480188>>1]}function CQ(a){return(a|0)<120?a:120}function Bx(a,b){a=a|0;b=b|0;JK(a,b)}function BW(a){a=a|0;_C(Jc(a),Fb(a))}function B7(a,b){a=a|0;b=b|0;mt(a,b)}function AQ(a){return(a&255)>>>0<129}function zS(a,b){return B(b,33)+a|0}function yt(a,b){return B(b,36)+a|0}function wq(a,b){return(b-a|0)/28|0}function wp(a){return bU(a,251,255)}function wd(a,b){return(b-a|0)/12|0}function w6(a){a=a|0;v[a+4224>>2]=0}function uc(a,b){return(a|0)==(b|0)}function tU(a){a=a|0;return xc(a)|0}function nq(a,b){return(b-a|0)/48|0}function le(a,b,c){return pG(a,b,c)}function kj(a,b){return gg(a,b)&255}function ik(a,b){return(b-a|0)/52|0}function hc(a,b){v[a>>2]=b;return a}function fl(a,b){return ou(Nc(a,b))}function e0(a){a=a|0;return Dk(a)|0}function dg(a){return C(D(a))==C(N)}function cv(a){t[a+2|0]=0;u[a>>1]=0}function cq(a){return(a&255)==1?1:2}function cW(a){a=a|0;oD(Xb(a,0,36))}function bl(a,b){return B(b,24)+a|0}function bW(a){a=a|0;return Bh(a)|0}function aq(a,b){return a>>>0<b>>>0}function Zb(a,b){return pe(a,b&255)}function YC(a){a=a|0;return Fg(a)|0}function Xx(a,b){return B(b,28)+a|0}function WR(a,b){return $g(a,0-b|0)}function Uw(a){return!Pb(a,92708,6)}function UA(a,b,c){return Yt(a,b,c)}function Tz(a,b){return B(b,56)+a|0}function Tt(a,b){return(b-a|0)/33|0}function Tf(a,b){return Zj(a,de(b))}function Rp(a,b){return(b-a|0)/56|0}function RG(a){a=a|0;return tv(a)|0}function QJ(a){a=a|0;return Fk(a)|0}function Pf(a,b){return B(b,52)+a|0}function KB(a,b){GB(a,v[a+16>>2]|b)}function Ji(a,b,c){return qv(a,b,c)}function Hd(a,b){return B(b,12)+a|0}function FW(a){a=a|0;return qg(a)|0}function FB(a){a=a|0;return hv(a)|0}function Eq(a){a=a|0;return Ee(a)|0}function Df(a,b){return(b-a|0)/20|0}function Cp(a){if(w[a+24|0]){iN(a)}}function Cg(a,b){return B(b,20)+a|0}function Bn(a,b){return(b-a|0)/24|0}function A9(a){a=a|0;return ni(a)|0}function $q(a,b){return(b-a|0)/36|0}function zx(a,b,c,d){Ov(a,b,c,d,9)}function zn(a,b){v[a+1298464>>2]=b}function wS(a,b){return Uv(a,b,18)}function ve(a,b){gc(a,Jc(b),Fb(b))}function vU(a,b){return uk(a,b,28)}function vD(a,b){return Uv(a,b,20)}function uj(a,b){return B(mk(b),a)}function sD(a,b){return uk(a,b,36)}function qJ(a){return(Oj(a)|0)==-1}function px(a,b,c,d){Ov(a,b,c,d,4)}function pJ(a,b){a=a|0;b=b|0;fc(b)}function oN(a){je(a+8|0);hN(a+4|0)}function oJ(a,b){a=a|0;b=b|0;im(b)}function nT(a){return w[a+1|0]!=63}function kh(a,b){v[a>>2]=v[a>>2]|b}function hi(a){a=a|0;t[a+4202|0]=0}function fB(a){return a&2147483647}function cp(a,b){return(a|0)<(b|0)}function ck(a,b){return(b-a|0)/6|0}function ZW(a){a=a|0;Rm(a,1,13298)}function Yn(a,b){return(b<<13)+a|0}function Xy(a,b){return(b-a|0)/7|0}function Wq(a,b){return(b<<11)+a|0}function Vc(a,b){return BE(a,b,-1)}function Uf(a){return(a&128)>>>7|0}function Rl(a){return C(D(a))<C(N)}function RF(a){return zh(a,467048)}function QF(a){return zh(a,467040)}function P0(a,b){a=a|0;b=b|0;Jb(b)}function O8(a){a=a|0;Fq(a,21473,1)}function NF(a){return zh(a,467064)}function MF(a){return zh(a,467056)}function Ls(a,b){return(a-b|0)/6|0}function Kk(a,b){return(a+b|0)-1|0}function Iq(a){t[a|0]=0;t[a+1|0]=0}function Gh(a,b){a=a|0;b=b|0;Kb(a)}function GJ(a,b,c,d){Ov(a,b,c,d,2)}function Ev(a,b){return uk(a,b,12)}function Dd(a,b){return B(b,6)+a|0}function Aw(a){return uc(a,-1)?0:a}function zea(a){a=a|0;jS(a,65535)}function yh(a){v[a>>2]=1;return a}function xfa(a){a=a|0;sg(a,16638)}function wf(a){return a!=a?C(0):a}function vh(a){v[a>>2]=v[a>>2]+20}function uz(a){if(a){Jb(a+-64|0)}}function ss(a){return pE(a,76144)}function qx(a,b){return PL(a,b)^1}function qm(a){v[a>>2]=2;return a}function qG(a,b){return pG(a,0,b)}function pha(a){a=a|0;sg(a,16007)}function pe(a,b){return(b<<5)+a|0}function gq(a,b){return ne(a,b)^1}function fe(a,b){return!Pb(a,b,4)}function ed(a,b){return(b<<4)+a|0}function dm(a,b){return(b<<8)+a|0}function dc(a,b){return(b<<1)+a|0}function dH(a){return pE(a,76208)}function _v(a,b){return v[a+b>>2]}function ZX(a){a=a|0;return 12996}function ZC(a){return(a&16)>>>4|0}function Yl(a){u[a>>1]=0;return a}function Yf(a,b){return Jc(a)+b|0}function YX(a){a=a|0;return 10178}function YN(a,b){return uk(a,b,8)}function Wd(a){return v[kc(a)>>2]}function V$(a){a=a|0;return 10298}function Uc(a){return bU(a,1,120)}function Ss(a){fc(a+4|0);return a}function Re(a,b){return(b<<3)+a|0}function Rb(a,b){return uc(a,b)^1}function Pn(a){return a+1074328|0}function Oc(a,b){return tc(a)+b|0}function Mj(a){return a-48>>>0<10}function JI(a){v[a>>2]=v[a>>2]+24}function GX(a){a=a|0;return 12882}function FX(a){a=a|0;return 10668}function Db(a,b){return(b<<2)+a|0}function Cc(a){v[a>>2]=0;return a}function Bz(a,b){return uk(a,b,4)}function yfa(a){a=a|0;sg(a,3968)}function yT(a,b,c){AE(a,b,c,256)}function tq(a,b,c){vE(a,b,c,128)}function sq(a){return Xb(a,0,48)}function mha(a){a=a|0;sg(a,4445)}function kS(a,b){qc(a,b+4|0,256)}function hea(a){a=a|0;sg(a,4126)}function gia(a){a=a|0;sg(a,3892)}function fha(a){a=a|0;sg(a,4339)}function dq(a){Tv(a,24,92072,26)}function aV(a){a=a|0;sg(a,4319)}
function VX(a){a=a|0;return 6827}function Uy(a){t[a|0]=0;return a}function Uu(a,b,c){AE(a,b,c,128)}function Ufa(a){a=a|0;tu(a,3883)}function Sfa(a){a=a|0;tu(a,4848)}function SK(a){return(a&8)>>>3|0}function Rf(a,b,c,d){df(a,c,d,b)}function PG(a){v[a+72>>2]=465976}function OW(a){a=a|0;sg(a,16665)}function NG(a){v[a+72>>2]=466060}function Kg(a){return!v[a+16>>2]}function K9(a){a=a|0;kg(a,lj(a))}function If(a,b){hc(Cc(a)+4|0,b)}function HX(a){a=a|0;return 9737}function GW(a){a=a|0;_C(a,Ef(a))}function GI(a,b){return Hg(a,b)}
function EX(a){a=a|0;return 5681}function EU(a){Tv(a,24,92020,23)}function $u(a,b){return Wia(a,b)}function zj(a,b){return b-a>>11}function zf(a){a=a|0;return a|0}function yr(a){a=a|0;return 127}function yG(a){if(zG(a)){Jb(a)}}function xf(a,b){return Zj(a,b)}function vu(a,b,c){df(a,c,30,b)}function vB(a,b){return so(b,a)}function tl(a,b){return Cd(a,b)}function tk(a,b,c){gc(a,b,1<<c)}function tj(a,b,c){df(a,c,20,b)}function re(a,b){return wc(a,b)}function rG(a,b){return wd(a,b)}function qi(a,b){return(a|b)!=0}function qf(a){zb(a+20|0);zb(a)}function pj(a,b){return pe(a,b)}function pi(a,b){return ad(a,b)}function o1(a){a=a|0;cx(a-88|0)}function mo(a,b){return rl(a,b)}function lf(a){return An(Lf(a))}function lZ(a){a=a|0;Kc(467364)}function ky(a){u[a+480214>>1]=0}function jp(a,b){return Db(a,b)}function jm(a){Mt(a,0);return a}function jl(a,b,c){df(a,c,22,b)}function jc(a,b){return CD(a,b)}function jZ(a){a=a|0;Kc(467396)}function iN(a){gN(a+12|0);fN(a)}function hZ(a){a=a|0;Kc(467300)}function hC(a){return(a&255)==1}function gw(a){return Gb(a+8|0)}function gh(a,b){return!Cd(a,b)}function gQ(a,b){Pv(a,b,12,-12)}function fZ(a){a=a|0;Kc(467332)}function el(a,b,c){df(a,c,28,b)}function ek(a,b,c){df(a,c,12,b)}function cg(a){return si(a)?0:a}function bm(a){return am(ge(a))}function bf(a,b){return og(a,b)}function aw(a,b){return Qg(a,b)}function at(a){gO(a+12|0);lO(a)}function _y(a,b){return Nc(a,b)}function Zz(a,b,c){df(a,c,64,b)}function Zu(a,b){return LC(a,b)}function Zl(a){yb(a+12|0);yb(a)}function Zj(a,b){return hc(a,b)}function Ze(a,b,c){df(a,c,32,b)}function ZY(a){a=a|0;yb(467348)}function Yk(a){zb(a+12|0);ud(a)}function YL(a,b){return WL(a,b)}function XY(a){a=a|0;yb(467380)}function XT(a,b){Pv(a,b,48,-48)}function X0(a){a=a|0;cx(a-92|0)}function VY(a){a=a|0;yb(467284)}function Uh(a,b,c){df(a,c,13,b)}function TY(a){a=a|0;yb(467316)}function Sg(a){return nN(a&255)}function Rd(a){return(a&255)!=0}function PW(a){a=a|0;sg(a,4493)}function Ni(a,b){return a>>>b&1}function NC(a,b){return KC(a,b)}function Mn(a,b){return Er(a,b)}function KT(a,b){return Xe(b,a)}function Js(a,b){return Yj(a,b)}function Ie(a){return jq(ge(a))}function Fc(a,b){return Wq(a,b)}function Ei(a,b){return Vu(a,b)}function Cb(a,b){return(a&b)!=0}function An(a){return a<<24>>24}function Ag(a,b){return Rb(a,b)}function Ab(a){ee(a+12|0);ee(a)}function $b(a,b){return Pf(a,b)}function zF(a){a=a|0;Jb(fw(a))}function xq(a){return a>>>0<11}function wc(a,b){return b-a>>2}function tx(a){a=a|0;Jb(JJ(a))}function tH(){return(gb()|0)>0}function t2(a){a=a|0;Jb(ks(a))}function so(a,b){return a-b>>1}function se(a,b){if(!a){Jb(b)}}function sd(a,b){t[a|0]=w[b|0]}function rh(a,b){return b-a>>8}function qK(a){a=a|0;Jb(rK(a))}function q6(a){a=a|0;return 13}function pn(a){return(a|0)==-1}function oW(a){a=a|0;Jb(AD(a))}function mY(a){a=a|0;Jb(kF(a))}function hh(a,b){return b-a>>4}function gg(a,b){return b-a>>5}function eY(a){a=a|0;Jb(jF(a))}function cx(a){a=a|0;Jb(ds(a))}function bc(a,b){v[a+100>>2]=b}function bL(a,b){Ix(a,tc(a),b)}function _K(a){a=a|0;Jb($K(a))}function XP(a){return a+4096|0}function WQ(a,b){Qv(a,b,5,3,4)}function VG(a){a=a|0;Jb(mp(a))}function Um(a){a=a|0;Jb(JT(a))}function UG(a){a=a|0;Jb(jf(a))}function S1(a){a=a|0;Jb(QI(a))}function Qt(a,b){return a-b>>2}function QC(a){return xc(a<<2)}function PY(a){a=a|0;Jb(xF(a))}function P5(){return 19923969}
function Nk(a){a=a|0;Jb(uf(a))}function Nc(a,b){return b-a>>1}function Mm(a){a=a|0;Jb(tv(a))}function LY(a){a=a|0;Jb(wF(a))}function Jy(a,b){return a<<8|b}function JS(a,b){jn(a,b,vd(b))}function Iw(a){a=a|0;Jb(Fk(a))}function I1(a){a=a|0;Jb(KI(a))}function Hw(a){a=a|0;Jb(En(a))}function Hn(a){a=a|0;Jb(Hs(a))}function Hg(a,b){return b-a>>3}function Gw(a){a=a|0;Jb(Tr(a))}function Gd(a){return a&64?2:1}function GD(a){return a+1024|0}function FY(a){a=a|0;Jb(pF(a))}function Ew(a){a=a|0;Jb(Sr(a))}function Dx(a){a=a|0;Jb(OK(a))}function Dw(a){a=a|0;Jb(Rr(a))}function DK(a){a=a|0;Jb(EK(a))}function Ct(a){return a>>>27^a}function Az(a){return a+4896|0}function $$(a){a=a|0;Jb(ws(a))}function zT(a,b){df(a,b,40,2)}function zK(a){a=a|0;return 5}function yo(a){return a>>>0<5}function xd(a){return(a|0)!=0}function we(a){a=a|0;return 1}function ue(a){a=a|0;return 2}function ps(a,b){v[a+32>>2]=b}function oH(a){a=a|0;return-1}function mc(a){a=a|0;return 0}function iR(a,b){ic(a,b,1108)}function hq(a){return a+256|0}function dA(a,b){ic(a,b,1024)}function c7(a){a=a|0;return 6}function bd(a,b){kp(a,b+28|0)}function bA(a){return a+128|0}function af(a){return D(a)==N}function ad(a,b){return b-a|0}function _e(a,b){u[a+28>>1]=b}function Zn(a,b){v[a+36>>2]=b}function YQ(a,b){df(a,b,33,1)}function Y7(a){a=a|0;return 9}function Xe(a,b){return a-b|0}function Vj(a){return xd(a)^1}function TN(a,b){Pv(a,b,7,-7)}function Sq(a,b){df(a,b,26,3)}function RK(a){a=a|0;return 3}function Pu(a){return!v[a>>2]}function OL(a,b,c){Wk(a,b,-c)}function Mw(){return ob()<<16}function MK(a){a=a|0;return 7}function MB(a,b){ic(a,b,1954)}function Lb(a,b){return a+b|0}function Kb(a){hE(a);return a}function Hr(a){return a>>>0<2}function Hm(a){return a&1?2:1}function Hk(a){return(a&5)!=0}function Gn(a){a=a|0;return 4}function ES(a){sq(Xb(a,0,48))}function EA(a,b){ic(a,b,4896)}function zc(a){return a+12|0}function xu(a,b){ic(a,b,512)}function xe(a,b){t[a+11|0]=b}function wv(a,b){MD(a,de(b))}function vd(a){return a+16|0}function up(a,b){z[a+8>>2]=b}function uR(a,b){ic(a,b,126)}function tp(a,b){z[a+4>>2]=b}function to(a,b){ie(a,b+8|0)}function sp(a,b){t[a+33|0]=b}function sT(a,b){ic(a,b,218)}function sP(a,b){ic(a,b,263)}function pU(a,b){ic(a,b,610)}function pT(a,b){ic(a,b,157)}function mP(a){return a+48|0}function lQ(a,b){ic(a,b,204)}function kT(a,b){ic(a,b,576)}function kO(a,b,c){Xl(a,c,b)}function ic(a,b,c){gc(a,b,c)}function hT(a,b){ic(a,b,674)}function gm(a,b,c){Co(a,b,c)}function fO(a){eO(a,v[a>>2])}function f0(a){a=a|0;KB(a,1)}function dy(a,b){t[a+34|0]=b}function dx(a){return a-12|0}function cy(a,b){t[a+32|0]=b}function ch(a,b,c){qv(a,b,c)}function cM(a){return a-32|0}function by(a,b){t[a+35|0]=b}function bT(a){return a+36|0}function ao(a){return a+32|0}function _z(a,b){Mt(a,de(b))}function _A(a,b){df(a,b,8,2)}function Yh(a,b,c){kD(a,b,c)}function Wp(a){return a+14|0}function Vp(a,b){return a<<b}function Td(a,b){v[a+4>>2]=b}function Rs(a){wM(a,v[a>>2])}function RO(a){QO(a,v[a>>2])}function QQ(a){return a-28|0}function Or(a,b){kp(a,b+4|0)}function Oo(a){return a+20|0}function OQ(a,b){ic(a,b,146)}function Ml(a,b){v[a+8>>2]=b}function JQ(a,b){ic(a,b,608)}function Hc(a){Td(a,v[a>>2])}function HC(a,b){ic(a,b,497)}function GS(a,b){ic(a,b,128)}function Cj(a){return a-36|0}function CR(a,b){ic(a,b,130)}function Aq(a,b){ic(a,b,192)}function Ae(a,b){a=a|0;b=b|0}function AR(a,b){ic(a,b,600)}function $y(a){t[a+6152|0]=0}function $N(a,b,c){_l(a,c,b)}function zp(a){Xb(a,0,8192)}function yO(a,b){ic(a,b,27)}function yC(a,b){Mi(a,b,37)}function xK(a){return 0-a|0}function wC(a,b){ic(a,b,41)}function vo(a){v[a+12>>2]=0}function vT(a,b){ic(a,b,48)}function ty(a){Xb(a,0,4096)}function rA(a,b){ic(a,b,40)}function qu(a,b){ic(a,b,64)}function pu(a,b){ic(a,b,66)}function pS(a,b){ic(a,b,52)}function of(){EU(10893);L()}function nR(a,b){ic(a,b,32)}function mm(){dq(10893);L()}function lB(a,b){ic(a,b,12)}function kd(a){return a+1|0}function kc(a){return a+4|0}function iu(a,b){ic(a,b,22)}function fC(a,b){ic(a,b,11)}function av(a,b){gc(a,b,22)}function _T(a,b){qc(a,b,48)}function _Q(a,b){ic(a,b,96)}function YB(a,b){ic(a,b,17)}function Xq(a,b){ic(a,b,36)}function Vt(a,b){return a<b}function Ue(a){return a+2|0}function Sf(a,b){t[a+3|0]=b}function Qq(a){return a&127}function PD(a,b){ic(a,b,24)}function Ou(a,b){ic(a,b,65)}function O5(){return 393220}function Nx(a){Xb(a,0,2048)}function Nu(a,b){ic(a,b,16)}function Lf(a){return a&255}function LB(a){Xb(a,0,1954)}function Kn(a){return a-4|0}function KR(a,b){ic(a,b,30)}function HS(a,b){ic(a,b,80)}function Gb(a){return a+8|0}function Em(a,b){gc(a,b,32)}function De(a){return!Fb(a)}function Ci(a){return a+3|0}function BT(a,b){ic(a,b,98)}function BA(a,b){ic(a,b,33)}function Ao(a,b){t[a+1|0]=b}function AP(a,b){return a<b}function AC(a,b){ic(a,b,38)}function $B(a,b){gc(a,b,20)}function zu(a,b){ic(a,b,5)}function zR(a){Xb(a,0,600)}function yd(a,b){v[a>>2]=b}function wo(a,b){ic(a,b,7)}function uA(a){sA(a,Wd(a))}function tR(a){Xb(a,0,126)}function si(a){return a!=a}function rV(a){a=a|0;Bh(a)}function ql(a,b){ic(a,b,2)}function oU(a){Xb(a,0,610)}function oT(a){Xb(a,0,157)}function lr(a){a=a|0;mr(a)}function kv(a,b){ic(a,b,3)}function kQ(a){Xb(a,0,204)}function kC(a,b){Yh(a,2,b)}function jT(a){Xb(a,0,576)}function gO(a){Hp(a,Wd(a))}function gN(a){Ws(a,Wd(a))}function faa(){return jb|0}function fN(a){Xs(a,Wd(a))}function eT(a){Xb(a,0,192)}function eB(a,b){ic(a,b,6)}function cA(a){Xb(a,0,130)}function _b(a){Pm(v[a>>2])}function YS(a){JA(a,Wd(a))}function Wc(){EU(7636);L()}function WS(a){KA(a,Wd(a))}function Uk(a){Wy(a,Wd(a))}function Tu(){dq(7636);L()}function SL(a){$x(a,Wd(a))}function QP(a){Hz(a,Wd(a))}function Pt(a){tA(a,Wd(a))}function PP(a){Iz(a,Wd(a))}function Nq(a,b){ic(a,b,1)}function NQ(a){Xb(a,0,146)}function LK(a,b){oL(a,3,b)}function Km(a,b){ic(a,b,8)}function Jn(a,b){z[a>>2]=b}function IQ(a){Xb(a,0,608)}function GC(a){Xb(a,0,497)}function Ez(a){Xb(a,0,256)}function Di(a,b){u[a>>1]=b}function Dh(a,b){ic(a,b,4)}function Dc(a){a=a|0;Jb(a)}function Ac(a){v[a+8>>2]=0}function $k(a,b){Co(a,b,0)}function zC(a){Xb(a,0,38)}function xT(a){Xb(a,0,48)}function vC(a){Xb(a,0,41)}function tB(a){Xb(a,0,66)}function oS(a){Xb(a,0,52)}function ku(a){Xb(a,0,64)}function fL(a){Xm(a,2048)}function ev(a){return a&1}function Yq(a){Xb(a,0,36)}function Y2(){return 2048}function W9(a){a=a|0;jb=a}function Fh(a,b){t[a|0]=b}function FA(a){Xb(a,0,80)}function CA(a){Xb(a,0,33)}function AT(a){Xb(a,0,98)}function $Q(a){Xb(a,0,96)}function yL(a,b){wM(a,b)}function xR(a){Sv(a,512)}function uP(a){v[a>>2]=0}function uB(a,b){gl(a,b)}function qs(a){yb(a+4|0)}function lC(a){u[a>>1]=0}function ft(a,b){eM(a,b)}function fh(a){a=a|0;L()}function di(a,b){Jh(a,b)}function dR(a,b){ie(a,b)}function dO(a){je(a+8|0)}function dB(a,b){jc(a,b)}function Xt(a,b){MS(a,b)}function Wm(a,b){GB(a,b)}function So(a,b){Sc(a,b)}function Qp(a,b){yd(a,b)}function Px(a,b){Tf(a,b)}function Pc(a){fc(a+8|0)}function OO(a,b){QO(a,b)}function OB(a,b){NJ(a,b)}function Nd(a,b){Td(a,b)}function Md(a){Ab(a+8|0)}function LO(a,b){Kf(a,b)}function Ks(a,b){Jn(a,b)}function Hj(a,b){Fh(a,b)}function Fu(a,b){bC(a,b)}function AA(a,b){sS(a,b)}function $t(a){zb(a+4|0)}function vg(a){t[a|0]=0}function kr(a){Mv(a,36)}function kB(a){CE(a,16)}function jC(a){Sv(a,16)}function bE(a){Mv(a,48)}function WT(a){Xm(a,48)}function Ch(a){Mv(a,24)}function Bo(a){CE(a,11)}function $fa(){va();L()}function vy(a){zM(a,0)}function vA(a){Mt(a,0)}function uy(a){yM(a,0)}function os(a){AJ(a,0)}function ig(a){XS(a,0)}function gr(a){MD(a,0)}function gF(){wa();L()}function dj(a){BJ(a,0)}function cj(a){zJ(a,0)}function br(a){Xm(a,8)}function UX(){gF();L()}function SN(a){Xm(a,7)}function Qc(a){Oe(a,0)}function OS(a){Xm(a,6)}function Gi(a){Xm(a,2)}function FS(a){Sv(a,4)}function $L(a){DM(a,0)}function kf(a){a=a|0}function im(a){vc(a)}function ec(a){zb(a)}function bQ(a){Qb(a)}function _N(a){bo(a)}function ZP(a){Ce(a)}function Tb(a){yb(a)}function Ro(a){zc(a)}function CF(a){Cc(a)}function $z(a){kk(a)}function $I(a){Be(a)}
// EMSCRIPTEN_END_FUNCS
e=w;var nb=c([null,Vb,$D,Sm,WW,Rm,IW,GW,OD,BW,zW,cD,EV,AV,Jq,vj,hV,$,Xu,ll,eH,Ig,vm,iia,JT,zf,Iga,lga,fga,$fa,_fa,Dfa,iA,tfa,qfa,vba,wea,MQ,A0,z0,Wr,MQ,Vaa,Jaa,QN,et,Fp,daa,baa,KM,T9,tU,zL,Rh,Vb,P8,p8,Fx,JK,Bx,gi,fK,W5,N5,F5,m5,b5,l0,k0,S$,rs,W2,AM,u2,p2,A1,u1,gi,q1,g1,O0,N0,M0,K0,I0,F0,B0,sH,u0,o0,aH,GA,Fw,va,Ob,oX,nX,mX,lX,kX,jX,Vm,iX,hX,sH,gX,fX,ha,dX,cX,bX,sx,aX,$W,_W,XD,WD,ZW,Cv,YW,Qo,UW,lr,Po,wl,sg,RW,Qo,TW,SW,QW,XW,PW,UD,OW,UD,VW,VD,NW,MW,LW,Vm,KW,$c,Ob,FW,vv,EW,Ig,DW,ND,CW,nk,ND,er,AW,tv,sv,cW,yW,qW,pW,bW,Li,YV,XV,hv,oD,WV,y9,z9,ON,w9,x9,ay,Ms,ac,A9,Yd,lD,TV,SV,YC,QV,PV,YC,LV,Yu,KV,Q8,cf,Efa,kaa,RV,Eq,Cf,WU,jaa,sia,_8,O8,BV,tC,zV,yV,sC,xV,lg,wV,vV,Gc,uV,tV,mg,bh,sV,rV,oV,dC,nV,mV,lV,Ku,KO,FC,hx,kV,jV,iV,gV,fV,Mu,eV,UB,Ed,Bq,aV,$U,Cu,TB,_U,ZU,YU,SB,XU,RB,Lu,Ru,RU,zq,QU,Nb,Bf,sg,PU,wu,OU,jd,yq,NU,MU,LU,FB,EB,pd,KU,sm,JU,IU,HU,BB,AB,Li,tu,Pia,Oia,Xaa,Nia,dh,Mia,Iia,hk,Lia,Kia,xU,Jia,Xh,Mf,Fia,Eia,Dia,jU,Aia,hk,sj,zia,yia,rq,xia,rB,wia,via,uia,tia,TT,QT,pia,mia,gn,kia,kg,nU,lia,Ku,MT,jia,hia,jB,gia,sv,fia,hB,HT,Kda,cia,zq,oo,bia,aia,EB,$ha,_ha,Zha,Yha,Xha,zm,Wha,Vha,Uha,Sha,hk,ET,Tha,Xh,Mf,qB,Nha,Kha,Ah,Fha,Eha,Bha,Aha,zha,yha,xha,wha,pq,vha,uha,tha,SA,MV,sha,rha,sg,qha,pha,oha,JV,nha,mha,lha,kha,hB,cT,jha,iha,sg,hha,gha,iU,Gha,fha,eha,Hha,dha,cha,bha,OA,OA,NA,aha,$ga,aT,OA,_ga,cY,Zga,Yga,Xga,Wga,Vga,Uga,Tga,ZS,qd,no,Hga,HA,Sga,z8,y8,x8,w8,v8,u8,Rga,Qga,Kf,Pga,Oga,Nga,Mga,$D,Waa,Taa,L8,Y8,Z8,Lga,Kga,Jga,H9,s8,rs,Raa,Qaa,Paa,Oaa,Dga,Cga,Bga,Aga,zga,yga,xga,wga,vga,uga,tga,sga,rga,pga,oga,qga,tS,Mf,mS,zA,kga,yA,jga,iga,hga,gga,lS,xA,ega,Yu,sC,dga,jS,iS,Rq,wA,cga,Je,bga,gS,pq,Iu,pq,aga,Mq,sg,jU,pq,$aa,gn,Xfa,Wfa,Vfa,Ufa,oA,Nt,Tfa,Sfa,Rfa,Qfa,Pfa,Ofa,Nfa,uC,Mfa,Lfa,Kfa,Jfa,Ifa,Hfa,Gfa,Ffa,LA,Cfa,Bfa,Afa,zfa,sg,$S,_S,VA,yfa,xfa,Cu,sv,Baa,vq,wfa,um,ru,Zf,iaa,Faa,gt,WN,haa,gaa,GN,bt,BN,eaa,rN,EO,caa,iz,jj,Zh,lfa,kfa,Jt,ufa,Wt,hfa,um,gfa,ffa,rR,no,efa,dfa,qR,cfa,bfa,afa,It,$ea,_ea,Zea,Yea,Tea,Vz,Sea,Rea,Qea,hk,Xh,Mf,Zh,Nea,Mea,Lea,Kea,yA,Hea,Gea,It,Fea,$8,Cea,Bea,sj,eR,Vz,Lu,Aea,zea,yea,xea,Gt,vea,Gt,uea,hr,NV,rea,hk,sea,tea,Rz,TQ,Xh,Mf,Jt,oea,lea,zA,kea,hea,gea,FQ,qR,SA,fea,Cu,sg,Yda,Xda,SB,Wda,Vda,Uda,Tda,iQ,sm,Qda,Pda,Oda,Nda,Mda,Lda,em,_P,Jda,Ida,Hda,Gda,Fda,Eda,Dda,Cda,Bda,Ada,zda,yda,xda,yA,wda,vda,uda,Wt,tda,sda,zq,taa,vv,FB,Aaa,zaa,zq,yaa,Zh,vv,xaa,waa,vaa,pda,oda,nda,mda,lda,kda,Pq,hda,gda,fda,eda,dda,cda,bda,ada,$ca,_ca,Zca,Yca,eX,cE,Xca,sg,Wca,Vca,kl,Caa,aba,tU,SO,Zaa,Yaa,Uaa,Saa,mt,Naa,FO,Laa,Kaa,xO,Iaa,Haa,Gaa,Xn,iO,Eaa,Daa,po,raa,sj,PN,ir,v9,u9,t9,J9,OV,s9,iv,ir,UB,r9,PN,paa,q9,uaa,hk,Xh,Mf,saa,hk,Xh,Mf,qaa,hk,Xh,Mf,naa,xU,vq,aaa,$9,_9,Z9,Y9,X9,_aa,Sca,nP,V9,xc,S9,T8,R9,JW,aW,VV,_V,P9,O9,UV,$V,HW,ZV,oM,N9,M9,L9,nM,qy,K9,I9,Maa,G9,F9,E9,D9,uL,I8,Bv,aE,dE,ay,B9,rs,su,Hq,maa,oaa,n9,m9,sj,l9,Vz,k9,j9,i9,Jt,h9,Zh,g9,f9,e9,d9,c9,hk,Xh,Mf,o9,X8,W8,V8,U8,Jh,Gl,S8,R8,N8,G8,F8,E8,D8,C8,sL,K8,rp,rL,rk,Jh,Kf,A8,$e,t8,B8,H8,q8,o8,J7,n8,Qj,gL,fg,pL,_7,K7,Bl,D7,gi,C7,B7,A7,ay,mt,y7,ny,PK,e7,Y6,R6,K6,C6,t6,v6,j6,c6,$J,Bs,X5,V5,V1,X1,L5,K5,I5,ZJ,C9,Z1,E5,$J,D5,E2,v2,H2,B5,C1,VJ,wx,z5,S2,JJ,R2,wJ,x5,I7,u5,k6,v5,b6,s5,A2,O2,q5,C2,UJ,gS,TJ,SJ,RJ,f5,d5,VJ,wx,$4,_4,Z4,Y4,X4,W4,V4,U4,T4,S4,R4,Q4,P4,O4,N4,M4,L4,K4,J4,I4,H4,G4,F4,E4,B4,z4,x4,DD,v1,I2,v4,h4,z2,f4,d4,Mk,x1,y1,b4,B1,W3,U3,M8,R3,wx,M3,J3,G3,Cn,w1,E3,C3,A3,y3,w3,u3,s3,q3,o3,m3,k3,i3,MJ,d3,b3,jM,Kt,LJ,_2,Z2,X2,V2,U2,T2,op,laa,jr,qM,ph,M2,K2,qh,KM,G2,U9,D2,aH,vr,B2,y2,w2,Q9,F2,N2,J2,Gv,aa,Y1,DJ,CJ,W1,RI,U1,T1,J1,z1,t1,dM,Tca,Q0,P0,L0,J0,D0,C0,SG,RG,dY,t0,s0,r0,q0,p0,n0,m0,g0,Ig,f0,zf,WX,bY,T$,RG,Q$,Tq,cH,zw,vw,B$,A$,qw,Ih,Hh,Gr,Jb,pw,ep,Yi,Ek,ow,Hl,s$,r$,Vi,Ng,gG,Ui,Cw,kw,Ih,Hh,Dr,Qr,Kj,e0,ll,on,Vi,Ng,cG,Ui,Z_,U_,XG,P_,Mr,vm,K_,zr,kf,s_,Kr,r_,q_,p_,SF,n_,l_,k_,Ck,j_,SF,h_,g_,e_,d_,a_,$Z,XZ,WZ,VZ,UZ,TZ,SZ,RZ,QZ,PZ,OZ,NZ,MZ,LZ,KZ,JZ,IZ,HZ,GZ,FZ,EZ,DZ,CZ,BZ,AZ,zZ,yZ,xZ,wZ,vZ,uZ,tZ,sZ,rZ,qZ,cZ,dZ,eZ,lZ,jZ,hZ,fZ,QY,RY,SY,ZY,XY,VY,TY,Uca,gF,Mm,Lq,Rca,Qca,Pca,Oca,Nca,Mca,Lca,Kca,Jca,Ica,Hca,Gca,Fca,Eca,Dca,Cca,Bca,Aca,zca,yca,xca,wca,vca,uca,tca,sca,rca,qca,pca,oca,nca,mca,lca,kca,jca,ica,hca,gca,fca,eca,dca,cca,bca,aca,$ba,_ba,Zba,Yba,Xba,Wba,Vba,Uba,Tba,Sba,Rba,Qba,Pba,Oba,Nba,Mba,Lba,Kba,Jba,Iba,Hba,Gba,Fba,Eba,Dba,Cba,Bba,Aba,zba,yba,xba,wba,uba,tba,sba,rba,qba,pba,oba,nba,mba,lba,kba,jba,iba,hba,gba,fba,eba,dba,cba,bba,Mm,jda,ida,Dha,Cha,jea,iea,cea,bea,nga,mga,Xea,Wea,Fga,Ega,TU,SU,Rha,Qha,qV,pV,cV,bV,Pea,Oea,nea,mea,rda,qda,Cia,Bia,ria,qia,GV,FV,DV,CV,Eea,Dea,qea,pea,jfa,ifa,Gga,FU,Mha,Lha,Jha,Iha,Hia,Gia,eia,dia,Jea,Iea,p9,b9,a9,nfa,mfa,Sda,Rda,Vea,Uea,Pha,Oha,eea,dea,_da,Zda,oia,nia,aea,$da,vfa,pfa,ofa,IV,HV,VU,UU,Zfa,Yfa,sfa,rfa,Um,Lq,dW,Dc,Io,_J,Dc,zf,Dc,mc,we,we,mc,mc,eW,tW,sW,fW,Dc,Io,Dc,AD,oW,nW,mW,lW,kW,jW,iW,hW,gW,Hs,Hn,Hn,eL,mc,kf,mc,mc,mc,Ae,Gn,m8,l8,k8,j8,i8,ii,Lx,Lx,Kx,cL,Kx,Kx,h8,kf,FU,g8,f8,e8,d8,c8,hi,aL,F7,mc,mc,we,Jx,ue,ue,we,b8,a8,Ae,kf,Ae,kf,$K,_K,_K,Z7,mc,kf,mc,mc,mc,Ae,Y7,ZK,X7,W7,V7,U7,ii,T7,S7,R7,Q7,P7,O7,N7,M7,L7,hi,VK,mc,mc,we,ue,ue,we,XK,WK,uf,fh,UX,H7,Mx,G7,mc,E7,cL,p7,f7,Z6,S6,L6,D6,u6,l6,d6,E6,r8,$7,z7,Hs,Hn,Hn,eL,mc,kf,mc,mc,mc,Ae,RK,x7,w7,v7,u7,t7,ii,s7,hi,QK,mc,mc,we,ue,ue,we,r7,q7,EK,DK,DK,d7,mc,kf,mc,mc,mc,Ae,c7,b7,a7,$6,ii,_6,hi,AK,mc,mc,we,ue,ue,Nk,Nk,X6,mc,kf,mc,mc,mc,Ae,zK,W6,V6,U6,ii,T6,hi,wK,mc,mc,we,ue,ue,Hs,Hn,Hn,Q6,mc,kf,mc,mc,mc,Ae,zK,P6,O6,N6,ii,M6,hi,uK,mc,mc,we,ue,ue,OK,Dx,Dx,J6,mc,kf,mc,mc,mc,Ae,MK,I6,m7,l7,ii,k7,hi,j7,mc,mc,we,ue,ue,Ae,kf,KK,H6,G6,IK,F6,HK,GK,Dx,NK,o7,MK,n7,KK,i7,h7,IK,g7,HK,GK,Nk,Nk,B6,mc,kf,mc,mc,mc,Ae,ue,A6,z6,y6,ii,x6,hi,w6,mc,mc,we,ue,ue,rK,qK,qK,s6,mc,kf,mc,mc,r6,Ae,q6,p6,o6,n6,ii,m6,hi,xx,mc,mc,we,ue,ue,Ae,kf,Nk,Nk,i6,mc,kf,mc,mc,mc,Ae,RK,h6,g6,f6,ii,e6,hi,lK,mc,mc,we,ue,ue,Nk,Nk,a6,mc,kf,mc,mc,mc,Ae,Gn,$5,_5,Z5,ii,Y5,hi,jK,mc,mc,we,ue,ue,HJ,Dc,Q2,tx,P2,tx,tx,fh,ks,t2,L2,zf,fh,zf,Dc,s2,r2,fh,mJ,lJ,mJ,lJ,Ae,ls,Ae,ls,pJ,oJ,pJ,oJ,Dc,x2,zf,Dc,q2,o2,Dc,eJ,dJ,fh,l2,bJ,k2,bJ,n2,cJ,m2,cJ,Dc,j2,i2,Dc,aJ,_I,hs,hs,hs,hs,h2,jx,jx,jx,Dc,g2,f2,Dc,ZI,YI,c2,WI,b2,WI,e2,XI,d2,XI,Dc,a2,$1,Dc,VI,TI,gs,gs,gs,gs,_1,gx,gx,gx,D1,Dc,Io,Dc,KI,I1,we,we,H1,G1,Lq,F1,E1,fh,fh,K1,Dc,Io,Dc,QI,S1,we,mc,we,R1,Q1,P1,O1,N1,M1,L1,fh,rW,Dc,Io,Dc,Dc,xW,we,we,Lq,HD,wW,vW,uW,Ae,ls,Ae,ls,ds,cx,s1,r1,CI,AI,zI,yI,xI,wI,vI,uI,tI,sI,rI,pI,oI,nI,mI,lI,kI,jI,iI,hI,gI,fI,p1,o1,n1,m1,l1,k1,j1,i1,h1,f1,e1,d1,c1,b1,a1,$0,_0,Z0,Y0,X0,W0,V0,U0,T0,S0,R0,zf,fh,zf,fh,zf,fh,H0,G0,E0,En,Hw,Ae,rH,qH,pH,mc,mc,x0,oH,w0,Ur,v0,Ur,Rr,Dw,Ae,rH,qH,pH,mc,mc,j0,oH,i0,Ur,h0,Ur,ws,$$,a0,_$,d0,c0,b0,mp,VG,Z$,Y$,Sr,Ew,gH,fH,jf,UG,X$,W$,Tr,Gw,mH,lH,zf,Dc,V$,aY,$X,_X,U$,Mm,y0,mc,R$,Hw,F$,E$,D$,C$,QJ,Iw,Fk,Iw,Hw,I$,LG,H$,G$,Dw,M$,L$,K$,J$,Tr,Gw,mH,lH,QJ,Iw,Dw,P$,LG,O$,N$,Sr,Ew,gH,fH,jF,eY,NK,kF,mY,lY,kY,jY,iY,lF,hY,gY,fY,pF,FY,EY,DY,CY,BY,mc,AY,zY,wF,LY,KY,JY,IY,HY,GY,xF,PY,HD,dV,OY,NY,MY,zf,Dc,Dc,xY,wY,vY,uY,tY,sY,rY,qY,lF,pY,oY,nY,Dc,mF,mF,_o,we,we,yY,we,Dc,sF,rF,_o,mc,mc,qF,Gn,Dc,sF,rF,_o,mc,mc,qF,Gn,Dc,vF,uF,_o,mc,mc,tF,Gn,Dc,vF,uF,_o,mc,mc,tF,Gn,zf,Dc,z$,y$,x$,zf,Dc,w$,v$,u$,Dc,t$,q$,p$,o$,kG,kG,n$,m$,l$,k$,j$,Dc,i$,h$,g$,f$,bG,bG,e$,d$,c$,b$,a$,Dc,$_,__,Y_,X_,W_,V_,T_,S_,Dc,R_,Q_,O_,N_,M_,L_,J_,I_,zf,Dc,ue,H_,G_,F_,E_,D_,C_,bZ,aZ,$Y,_Y,YY,WY,UY,zf,Dc,ue,B_,A_,z_,y_,x_,w_,pZ,oZ,nZ,mZ,kZ,iZ,gZ,fw,zF,v_,fw,zF,u_,Dc,yr,yr,Gh,Gh,Gh,UF,mc,yk,yk,Dc,yr,yr,Gh,Gh,Gh,UF,mc,yk,yk,Dc,xr,xr,Gh,Gh,Gh,TF,mc,yk,yk,Dc,xr,xr,Gh,Gh,Gh,TF,mc,yk,yk,Dc,t_,o_,Dc,m_,i_,Dc,f_,c_,Dc,b_,_Z,Dc,HF,ZZ,Ae,Dc,HF,YZ,Ae,zf,fh,Dc,ZX,hF,Dc,YX,XX,hF,Mm,fh,Dc,VX,wa,zf,Dc,kf,kf,TX,LX,NX,OX,Dc,GX,Dc,FX,Um,Mm,Um,Um,Um,Um,Mm,Dc,EX,Dc,KX,MX,PX,Dc,SX,RX,QX,Dc,HX]);function ob(){return s.byteLength/65536|0}function tb(ub){ub=ub|0;var pb=ob()|0;var qb=pb+ub|0;if(pb<qb&&qb<65536){var rb=new ArrayBuffer(B(qb,65536));var sb=new Int8Array(rb);sb.set(t);t=new Int8Array(rb);u=new Int16Array(rb);v=new Int32Array(rb);w=new Uint8Array(rb);x=new Uint16Array(rb);y=new Uint32Array(rb);z=new Float32Array(rb);A=new Float64Array(rb);s=rb;r.buffer=s;e=w}return pb}return{"ya":GU,"za":O5,"Aa":P5,"Ba":Dc,"Ca":Jb,"Da":M5,"Ea":J5,"Fa":H5,"Ga":Bs,"Ha":Ae,"Ia":R5,"Ja":Q5,"Ka":U5,"La":Lx,"Ma":S5,"Na":_J,"Oa":T5,"Pa":zf,"Qa":bK,"Ra":aK,"Sa":bK,"Ta":Y2,"Ua":DX,"Va":CX,"Wa":BX,"Xa":G5,"Ya":XJ,"Za":C5,"_a":WJ,"$a":l5,"ab":f3,"bb":g3,"cb":j5,"db":i5,"eb":h5,"fb":k5,"gb":h3,"hb":I3,"ib":$2,"jb":L3,"kb":i4,"lb":c3,"mb":O3,"nb":e3,"ob":N3,"pb":a3,"qb":n3,"rb":j3,"sb":l3,"tb":B3,"ub":x3,"vb":z3,"wb":p3,"xb":r3,"yb":t3,"zb":v3,"Ab":c4,"Bb":e4,"Cb":p4,"Db":k4,"Eb":j4,"Fb":o4,"Gb":n4,"Hb":l4,"Ib":m4,"Jb":t4,"Kb":u4,"Lb":q4,"Mb":s4,"Nb":r4,"Ob":X3,"Pb":a4,"Qb":_3,"Rb":Z3,"Sb":$3,"Tb":Y3,"Ub":H3,"Vb":y4,"Wb":V3,"Xb":S3,"Yb":g4,"Zb":K3,"_b":T3,"$b":Q3,"ac":P3,"bc":A4,"cc":D3,"dc":C4,"ec":F3,"fc":w4,"gc":A5,"hc":y5,"ic":AX,"jc":w5,"kc":t5,"lc":r5,"mc":p5,"nc":zX,"oc":o5,"pc":n5,"qc":g5,"rc":e5,"sc":c5,"tc":D4,"uc":a5,"vc":Jd,"wc":nb,"xc":J8,"yc":faa,"zc":W9,"Ac":JX,"Bc":IX,"Cc":yX,"Dc":xX,"Ec":wX,"Fc":vX,"Gc":uX,"Hc":tX,"Ic":qX,"Jc":sX,"Kc":rX,"Lc":qX,"Mc":pX,"Nc":pX}}return vb(xb)}
// EMSCRIPTEN_END_ASM




)(asmLibraryArg);
  },

  instantiate: /** @suppress{checkTypes} */ function(binary, info) {
    return {
      then: function(ok) {
        var module = new WebAssembly.Module(binary);
        ok({
          'instance': new WebAssembly.Instance(module)
        });
        // Emulate a simple WebAssembly.instantiate(..).then(()=>{}).catch(()=>{}) syntax.
        return { catch: function() {} };
      }
    };
  },

  RuntimeError: Error
};

// We don't need to actually download a wasm binary, mark it as present but empty.
wasmBinary = [];


